#![feature(simd, simd_ffi, link_llvm_intrinsics)]
#![allow(non_snake_case)]

//! Bindings to (almost) all LLVM intrinsics.
//!
//! Intrinsics are categorised into modules by the architecture on
//! which they are supported (however, see [Platform
//! support](#platform-support) for a caveat), with certain intrinsics
//! available at the top level. These are raw bindings and absolutely
//! zero error checking is performed.
//!
//! # Naming
//!
//! The intrinsics are named entirely for their internal LLVM names,
//! with the `llvm` prefix stripped, `.` replaced by `_` and, if it
//! exists, a platform prefix replaced by being placed in a module of
//! that name. For example, `llvm.adjust.trampoline` becomes
//! `::adjust_trampoline` and `llvm.x86.addcarry.u32` becomes
//! `::x86::addcarry_u32`.
//!
//! Many of these intrinsics have corresponding intrinsics exposed by
//! GCC/Clang in C/C++, these names are listed in
//! [`gcc_names`](gcc_names/index.html).
//!
//! # Platform support
//!
//! An intrinsic being available in a certain module (or at the top
//! level) does not guarantee that it is supported on all CPUs of that
//! architecture (resp. all CPUs), e.g. the `x86::avx512_...`
//! intrinsics are only supported on the very latest x86-64 CPUs, not
//! on older x86 processors.
//!
//! Using an intrinsic in a configuration that is not supported will
//! likely cause LLVM assertions or general badness along those lines.

extern crate simdty;

extern {
    /// The `llvm.amdgcn.s.barrier` intrinsic; known as `__builtin_amdgcn_s_barrier` in GCC.
    #[link_name = "llvm.amdgcn.s.barrier"]
    pub fn amdgcn_s_barrier() -> ();
    /// The `llvm.amdgcn.s.waitcnt` intrinsic.
    #[link_name = "llvm.amdgcn.s.waitcnt"]
    pub fn amdgcn_s_waitcnt(a: i32) -> ();
    /// The `llvm.amdgcn.div.fmas.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.div.fmas.v4f32"]
    pub fn amdgcn_div_fmas_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.div.fmas.f32` intrinsic.
    #[link_name = "llvm.amdgcn.div.fmas.f32"]
    pub fn amdgcn_div_fmas_f32(a: f32, b: f32, c: f32, d: bool) -> f32;
    /// The `llvm.amdgcn.div.fmas.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.div.fmas.v2f64"]
    pub fn amdgcn_div_fmas_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: bool) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.div.fmas.f64` intrinsic.
    #[link_name = "llvm.amdgcn.div.fmas.f64"]
    pub fn amdgcn_div_fmas_f64(a: f64, b: f64, c: f64, d: bool) -> f64;
    /// The `llvm.amdgcn.div.fixup.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.div.fixup.v4f32"]
    pub fn amdgcn_div_fixup_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.div.fixup.f32` intrinsic.
    #[link_name = "llvm.amdgcn.div.fixup.f32"]
    pub fn amdgcn_div_fixup_f32(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.amdgcn.div.fixup.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.div.fixup.v2f64"]
    pub fn amdgcn_div_fixup_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.div.fixup.f64` intrinsic.
    #[link_name = "llvm.amdgcn.div.fixup.f64"]
    pub fn amdgcn_div_fixup_f64(a: f64, b: f64, c: f64) -> f64;
    /// The `llvm.amdgcn.trig.preop.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.trig.preop.v4f32"]
    pub fn amdgcn_trig_preop_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.trig.preop.f32` intrinsic.
    #[link_name = "llvm.amdgcn.trig.preop.f32"]
    pub fn amdgcn_trig_preop_f32(a: f32, b: i32) -> f32;
    /// The `llvm.amdgcn.trig.preop.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.trig.preop.v2f64"]
    pub fn amdgcn_trig_preop_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.trig.preop.f64` intrinsic.
    #[link_name = "llvm.amdgcn.trig.preop.f64"]
    pub fn amdgcn_trig_preop_f64(a: f64, b: i32) -> f64;
    /// The `llvm.amdgcn.sin.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.sin.v4f32"]
    pub fn amdgcn_sin_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.sin.f32` intrinsic.
    #[link_name = "llvm.amdgcn.sin.f32"]
    pub fn amdgcn_sin_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.sin.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.sin.v2f64"]
    pub fn amdgcn_sin_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.sin.f64` intrinsic.
    #[link_name = "llvm.amdgcn.sin.f64"]
    pub fn amdgcn_sin_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.cos.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.cos.v4f32"]
    pub fn amdgcn_cos_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.cos.f32` intrinsic.
    #[link_name = "llvm.amdgcn.cos.f32"]
    pub fn amdgcn_cos_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.cos.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.cos.v2f64"]
    pub fn amdgcn_cos_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.cos.f64` intrinsic.
    #[link_name = "llvm.amdgcn.cos.f64"]
    pub fn amdgcn_cos_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.log.clamp.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.log.clamp.v4f32"]
    pub fn amdgcn_log_clamp_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.log.clamp.f32` intrinsic.
    #[link_name = "llvm.amdgcn.log.clamp.f32"]
    pub fn amdgcn_log_clamp_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.log.clamp.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.log.clamp.v2f64"]
    pub fn amdgcn_log_clamp_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.log.clamp.f64` intrinsic.
    #[link_name = "llvm.amdgcn.log.clamp.f64"]
    pub fn amdgcn_log_clamp_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.rcp.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.rcp.v4f32"]
    pub fn amdgcn_rcp_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.rcp.f32` intrinsic.
    #[link_name = "llvm.amdgcn.rcp.f32"]
    pub fn amdgcn_rcp_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.rcp.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.rcp.v2f64"]
    pub fn amdgcn_rcp_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.rcp.f64` intrinsic.
    #[link_name = "llvm.amdgcn.rcp.f64"]
    pub fn amdgcn_rcp_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.rsq.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.v4f32"]
    pub fn amdgcn_rsq_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.rsq.f32` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.f32"]
    pub fn amdgcn_rsq_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.rsq.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.v2f64"]
    pub fn amdgcn_rsq_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.rsq.f64` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.f64"]
    pub fn amdgcn_rsq_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.rsq.legacy` intrinsic; known as `__builtin_amdgcn_rsq_legacy` in GCC.
    #[link_name = "llvm.amdgcn.rsq.legacy"]
    pub fn amdgcn_rsq_legacy(a: f32) -> f32;
    /// The `llvm.amdgcn.rsq.clamp.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.clamp.v4f32"]
    pub fn amdgcn_rsq_clamp_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.rsq.clamp.f32` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.clamp.f32"]
    pub fn amdgcn_rsq_clamp_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.rsq.clamp.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.clamp.v2f64"]
    pub fn amdgcn_rsq_clamp_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.rsq.clamp.f64` intrinsic.
    #[link_name = "llvm.amdgcn.rsq.clamp.f64"]
    pub fn amdgcn_rsq_clamp_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.ldexp.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.ldexp.v4f32"]
    pub fn amdgcn_ldexp_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.ldexp.f32` intrinsic.
    #[link_name = "llvm.amdgcn.ldexp.f32"]
    pub fn amdgcn_ldexp_f32(a: f32, b: i32) -> f32;
    /// The `llvm.amdgcn.ldexp.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.ldexp.v2f64"]
    pub fn amdgcn_ldexp_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.ldexp.f64` intrinsic.
    #[link_name = "llvm.amdgcn.ldexp.f64"]
    pub fn amdgcn_ldexp_f64(a: f64, b: i32) -> f64;
    /// The `llvm.amdgcn.frexp.mant.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.mant.v4f32"]
    pub fn amdgcn_frexp_mant_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.frexp.mant.f32` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.mant.f32"]
    pub fn amdgcn_frexp_mant_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.frexp.mant.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.mant.v2f64"]
    pub fn amdgcn_frexp_mant_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.frexp.mant.f64` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.mant.f64"]
    pub fn amdgcn_frexp_mant_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.frexp.exp.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.exp.v4f32"]
    pub fn amdgcn_frexp_exp_v4f32(a: ::simdty::f32x4) -> i32;
    /// The `llvm.amdgcn.frexp.exp.f32` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.exp.f32"]
    pub fn amdgcn_frexp_exp_f32(a: f32) -> i32;
    /// The `llvm.amdgcn.frexp.exp.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.exp.v2f64"]
    pub fn amdgcn_frexp_exp_v2f64(a: ::simdty::f64x2) -> i32;
    /// The `llvm.amdgcn.frexp.exp.f64` intrinsic.
    #[link_name = "llvm.amdgcn.frexp.exp.f64"]
    pub fn amdgcn_frexp_exp_f64(a: f64) -> i32;
    /// The `llvm.amdgcn.fract.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.fract.v4f32"]
    pub fn amdgcn_fract_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.fract.f32` intrinsic.
    #[link_name = "llvm.amdgcn.fract.f32"]
    pub fn amdgcn_fract_f32(a: f32) -> f32;
    /// The `llvm.amdgcn.fract.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.fract.v2f64"]
    pub fn amdgcn_fract_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.fract.f64` intrinsic.
    #[link_name = "llvm.amdgcn.fract.f64"]
    pub fn amdgcn_fract_f64(a: f64) -> f64;
    /// The `llvm.amdgcn.class.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.class.v4f32"]
    pub fn amdgcn_class_v4f32(a: ::simdty::f32x4, b: i32) -> bool;
    /// The `llvm.amdgcn.class.f32` intrinsic.
    #[link_name = "llvm.amdgcn.class.f32"]
    pub fn amdgcn_class_f32(a: f32, b: i32) -> bool;
    /// The `llvm.amdgcn.class.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.class.v2f64"]
    pub fn amdgcn_class_v2f64(a: ::simdty::f64x2, b: i32) -> bool;
    /// The `llvm.amdgcn.class.f64` intrinsic.
    #[link_name = "llvm.amdgcn.class.f64"]
    pub fn amdgcn_class_f64(a: f64, b: i32) -> bool;
    /// The `llvm.amdgcn.cubeid` intrinsic; known as `__builtin_amdgcn_cubeid` in GCC.
    #[link_name = "llvm.amdgcn.cubeid"]
    pub fn amdgcn_cubeid(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.amdgcn.cubema` intrinsic; known as `__builtin_amdgcn_cubema` in GCC.
    #[link_name = "llvm.amdgcn.cubema"]
    pub fn amdgcn_cubema(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.amdgcn.cubesc` intrinsic; known as `__builtin_amdgcn_cubesc` in GCC.
    #[link_name = "llvm.amdgcn.cubesc"]
    pub fn amdgcn_cubesc(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.amdgcn.cubetc` intrinsic; known as `__builtin_amdgcn_cubetc` in GCC.
    #[link_name = "llvm.amdgcn.cubetc"]
    pub fn amdgcn_cubetc(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.amdgcn.atomic.inc.v16i8.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.v16i8.p0i8"]
    pub fn amdgcn_atomic_inc_v16i8_p0i8(a: *mut i8, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.amdgcn.atomic.inc.i8.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.i8.p0i8"]
    pub fn amdgcn_atomic_inc_i8_p0i8(a: *mut i8, b: i8) -> i8;
    /// The `llvm.amdgcn.atomic.inc.v8i16.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.v8i16.p0i8"]
    pub fn amdgcn_atomic_inc_v8i16_p0i8(a: *mut i8, b: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.amdgcn.atomic.inc.i16.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.i16.p0i8"]
    pub fn amdgcn_atomic_inc_i16_p0i8(a: *mut i8, b: i16) -> i16;
    /// The `llvm.amdgcn.atomic.inc.v4i32.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.v4i32.p0i8"]
    pub fn amdgcn_atomic_inc_v4i32_p0i8(a: *mut i8, b: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.amdgcn.atomic.inc.i32.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.i32.p0i8"]
    pub fn amdgcn_atomic_inc_i32_p0i8(a: *mut i8, b: i32) -> i32;
    /// The `llvm.amdgcn.atomic.inc.v2i64.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.v2i64.p0i8"]
    pub fn amdgcn_atomic_inc_v2i64_p0i8(a: *mut i8, b: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.amdgcn.atomic.inc.i64.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.inc.i64.p0i8"]
    pub fn amdgcn_atomic_inc_i64_p0i8(a: *mut i8, b: i64) -> i64;
    /// The `llvm.amdgcn.atomic.dec.v16i8.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.v16i8.p0i8"]
    pub fn amdgcn_atomic_dec_v16i8_p0i8(a: *mut i8, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.amdgcn.atomic.dec.i8.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.i8.p0i8"]
    pub fn amdgcn_atomic_dec_i8_p0i8(a: *mut i8, b: i8) -> i8;
    /// The `llvm.amdgcn.atomic.dec.v8i16.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.v8i16.p0i8"]
    pub fn amdgcn_atomic_dec_v8i16_p0i8(a: *mut i8, b: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.amdgcn.atomic.dec.i16.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.i16.p0i8"]
    pub fn amdgcn_atomic_dec_i16_p0i8(a: *mut i8, b: i16) -> i16;
    /// The `llvm.amdgcn.atomic.dec.v4i32.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.v4i32.p0i8"]
    pub fn amdgcn_atomic_dec_v4i32_p0i8(a: *mut i8, b: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.amdgcn.atomic.dec.i32.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.i32.p0i8"]
    pub fn amdgcn_atomic_dec_i32_p0i8(a: *mut i8, b: i32) -> i32;
    /// The `llvm.amdgcn.atomic.dec.v2i64.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.v2i64.p0i8"]
    pub fn amdgcn_atomic_dec_v2i64_p0i8(a: *mut i8, b: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.amdgcn.atomic.dec.i64.p0i8` intrinsic.
    #[link_name = "llvm.amdgcn.atomic.dec.i64.p0i8"]
    pub fn amdgcn_atomic_dec_i64_p0i8(a: *mut i8, b: i64) -> i64;
    /// The `llvm.amdgcn.image.load.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.v16i8"]
    pub fn amdgcn_image_load_v16i8(a: ::simdty::i8x16, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.i8"]
    pub fn amdgcn_image_load_i8(a: i8, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.v8i16"]
    pub fn amdgcn_image_load_v8i16(a: ::simdty::i16x8, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.i16"]
    pub fn amdgcn_image_load_i16(a: i16, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.v4i32"]
    pub fn amdgcn_image_load_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.i32"]
    pub fn amdgcn_image_load_i32(a: i32, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.v2i64"]
    pub fn amdgcn_image_load_v2i64(a: ::simdty::i64x2, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.i64"]
    pub fn amdgcn_image_load_i64(a: i64, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.v16i8"]
    pub fn amdgcn_image_load_mip_v16i8(a: ::simdty::i8x16, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.i8"]
    pub fn amdgcn_image_load_mip_i8(a: i8, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.v8i16"]
    pub fn amdgcn_image_load_mip_v8i16(a: ::simdty::i16x8, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.i16"]
    pub fn amdgcn_image_load_mip_i16(a: i16, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.v4i32"]
    pub fn amdgcn_image_load_mip_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.i32"]
    pub fn amdgcn_image_load_mip_i32(a: i32, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.v2i64"]
    pub fn amdgcn_image_load_mip_v2i64(a: ::simdty::i64x2, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.load.mip.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.load.mip.i64"]
    pub fn amdgcn_image_load_mip_i64(a: i64, b: ::simdty::i32x8, c: i32, d: bool, e: bool, f: bool, g: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.image.store.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.v16i8"]
    pub fn amdgcn_image_store_v16i8(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.i8"]
    pub fn amdgcn_image_store_i8(a: ::simdty::f32x4, b: i8, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.v8i16"]
    pub fn amdgcn_image_store_v8i16(a: ::simdty::f32x4, b: ::simdty::i16x8, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.i16"]
    pub fn amdgcn_image_store_i16(a: ::simdty::f32x4, b: i16, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.v4i32"]
    pub fn amdgcn_image_store_v4i32(a: ::simdty::f32x4, b: ::simdty::i32x4, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.i32"]
    pub fn amdgcn_image_store_i32(a: ::simdty::f32x4, b: i32, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.v2i64"]
    pub fn amdgcn_image_store_v2i64(a: ::simdty::f32x4, b: ::simdty::i64x2, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.i64"]
    pub fn amdgcn_image_store_i64(a: ::simdty::f32x4, b: i64, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.v16i8"]
    pub fn amdgcn_image_store_mip_v16i8(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.i8"]
    pub fn amdgcn_image_store_mip_i8(a: ::simdty::f32x4, b: i8, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.v8i16"]
    pub fn amdgcn_image_store_mip_v8i16(a: ::simdty::f32x4, b: ::simdty::i16x8, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.i16"]
    pub fn amdgcn_image_store_mip_i16(a: ::simdty::f32x4, b: i16, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.v4i32"]
    pub fn amdgcn_image_store_mip_v4i32(a: ::simdty::f32x4, b: ::simdty::i32x4, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.i32"]
    pub fn amdgcn_image_store_mip_i32(a: ::simdty::f32x4, b: i32, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.v2i64"]
    pub fn amdgcn_image_store_mip_v2i64(a: ::simdty::f32x4, b: ::simdty::i64x2, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.store.mip.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.store.mip.i64"]
    pub fn amdgcn_image_store_mip_i64(a: ::simdty::f32x4, b: i64, c: ::simdty::i32x8, d: i32, e: bool, f: bool, g: bool, h: bool) -> ();
    /// The `llvm.amdgcn.image.atomic.swap.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.v16i8"]
    pub fn amdgcn_image_atomic_swap_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.i8"]
    pub fn amdgcn_image_atomic_swap_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.v8i16"]
    pub fn amdgcn_image_atomic_swap_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.i16"]
    pub fn amdgcn_image_atomic_swap_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.v4i32"]
    pub fn amdgcn_image_atomic_swap_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.i32"]
    pub fn amdgcn_image_atomic_swap_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.v2i64"]
    pub fn amdgcn_image_atomic_swap_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.swap.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.swap.i64"]
    pub fn amdgcn_image_atomic_swap_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.v16i8"]
    pub fn amdgcn_image_atomic_add_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.i8"]
    pub fn amdgcn_image_atomic_add_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.v8i16"]
    pub fn amdgcn_image_atomic_add_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.i16"]
    pub fn amdgcn_image_atomic_add_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.v4i32"]
    pub fn amdgcn_image_atomic_add_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.i32"]
    pub fn amdgcn_image_atomic_add_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.v2i64"]
    pub fn amdgcn_image_atomic_add_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.add.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.add.i64"]
    pub fn amdgcn_image_atomic_add_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.v16i8"]
    pub fn amdgcn_image_atomic_sub_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.i8"]
    pub fn amdgcn_image_atomic_sub_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.v8i16"]
    pub fn amdgcn_image_atomic_sub_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.i16"]
    pub fn amdgcn_image_atomic_sub_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.v4i32"]
    pub fn amdgcn_image_atomic_sub_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.i32"]
    pub fn amdgcn_image_atomic_sub_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.v2i64"]
    pub fn amdgcn_image_atomic_sub_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.sub.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.sub.i64"]
    pub fn amdgcn_image_atomic_sub_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.v16i8"]
    pub fn amdgcn_image_atomic_smin_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.i8"]
    pub fn amdgcn_image_atomic_smin_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.v8i16"]
    pub fn amdgcn_image_atomic_smin_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.i16"]
    pub fn amdgcn_image_atomic_smin_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.v4i32"]
    pub fn amdgcn_image_atomic_smin_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.i32"]
    pub fn amdgcn_image_atomic_smin_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.v2i64"]
    pub fn amdgcn_image_atomic_smin_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smin.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smin.i64"]
    pub fn amdgcn_image_atomic_smin_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.v16i8"]
    pub fn amdgcn_image_atomic_umin_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.i8"]
    pub fn amdgcn_image_atomic_umin_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.v8i16"]
    pub fn amdgcn_image_atomic_umin_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.i16"]
    pub fn amdgcn_image_atomic_umin_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.v4i32"]
    pub fn amdgcn_image_atomic_umin_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.i32"]
    pub fn amdgcn_image_atomic_umin_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.v2i64"]
    pub fn amdgcn_image_atomic_umin_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umin.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umin.i64"]
    pub fn amdgcn_image_atomic_umin_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.v16i8"]
    pub fn amdgcn_image_atomic_smax_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.i8"]
    pub fn amdgcn_image_atomic_smax_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.v8i16"]
    pub fn amdgcn_image_atomic_smax_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.i16"]
    pub fn amdgcn_image_atomic_smax_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.v4i32"]
    pub fn amdgcn_image_atomic_smax_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.i32"]
    pub fn amdgcn_image_atomic_smax_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.v2i64"]
    pub fn amdgcn_image_atomic_smax_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.smax.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.smax.i64"]
    pub fn amdgcn_image_atomic_smax_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.v16i8"]
    pub fn amdgcn_image_atomic_umax_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.i8"]
    pub fn amdgcn_image_atomic_umax_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.v8i16"]
    pub fn amdgcn_image_atomic_umax_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.i16"]
    pub fn amdgcn_image_atomic_umax_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.v4i32"]
    pub fn amdgcn_image_atomic_umax_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.i32"]
    pub fn amdgcn_image_atomic_umax_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.v2i64"]
    pub fn amdgcn_image_atomic_umax_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.umax.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.umax.i64"]
    pub fn amdgcn_image_atomic_umax_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.v16i8"]
    pub fn amdgcn_image_atomic_and_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.i8"]
    pub fn amdgcn_image_atomic_and_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.v8i16"]
    pub fn amdgcn_image_atomic_and_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.i16"]
    pub fn amdgcn_image_atomic_and_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.v4i32"]
    pub fn amdgcn_image_atomic_and_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.i32"]
    pub fn amdgcn_image_atomic_and_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.v2i64"]
    pub fn amdgcn_image_atomic_and_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.and.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.and.i64"]
    pub fn amdgcn_image_atomic_and_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.v16i8"]
    pub fn amdgcn_image_atomic_or_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.i8"]
    pub fn amdgcn_image_atomic_or_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.v8i16"]
    pub fn amdgcn_image_atomic_or_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.i16"]
    pub fn amdgcn_image_atomic_or_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.v4i32"]
    pub fn amdgcn_image_atomic_or_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.i32"]
    pub fn amdgcn_image_atomic_or_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.v2i64"]
    pub fn amdgcn_image_atomic_or_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.or.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.or.i64"]
    pub fn amdgcn_image_atomic_or_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.v16i8"]
    pub fn amdgcn_image_atomic_xor_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.i8"]
    pub fn amdgcn_image_atomic_xor_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.v8i16"]
    pub fn amdgcn_image_atomic_xor_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.i16"]
    pub fn amdgcn_image_atomic_xor_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.v4i32"]
    pub fn amdgcn_image_atomic_xor_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.i32"]
    pub fn amdgcn_image_atomic_xor_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.v2i64"]
    pub fn amdgcn_image_atomic_xor_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.xor.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.xor.i64"]
    pub fn amdgcn_image_atomic_xor_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.v16i8"]
    pub fn amdgcn_image_atomic_inc_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.i8"]
    pub fn amdgcn_image_atomic_inc_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.v8i16"]
    pub fn amdgcn_image_atomic_inc_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.i16"]
    pub fn amdgcn_image_atomic_inc_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.v4i32"]
    pub fn amdgcn_image_atomic_inc_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.i32"]
    pub fn amdgcn_image_atomic_inc_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.v2i64"]
    pub fn amdgcn_image_atomic_inc_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.inc.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.inc.i64"]
    pub fn amdgcn_image_atomic_inc_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.v16i8"]
    pub fn amdgcn_image_atomic_dec_v16i8(a: i32, b: ::simdty::i8x16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.i8"]
    pub fn amdgcn_image_atomic_dec_i8(a: i32, b: i8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.v8i16"]
    pub fn amdgcn_image_atomic_dec_v8i16(a: i32, b: ::simdty::i16x8, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.i16"]
    pub fn amdgcn_image_atomic_dec_i16(a: i32, b: i16, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.v4i32"]
    pub fn amdgcn_image_atomic_dec_v4i32(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.i32"]
    pub fn amdgcn_image_atomic_dec_i32(a: i32, b: i32, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.v2i64"]
    pub fn amdgcn_image_atomic_dec_v2i64(a: i32, b: ::simdty::i64x2, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.dec.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.dec.i64"]
    pub fn amdgcn_image_atomic_dec_i64(a: i32, b: i64, c: ::simdty::i32x8, d: bool, e: bool, f: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.v16i8"]
    pub fn amdgcn_image_atomic_cmpswap_v16i8(a: i32, b: i32, c: ::simdty::i8x16, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.i8` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.i8"]
    pub fn amdgcn_image_atomic_cmpswap_i8(a: i32, b: i32, c: i8, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.v8i16"]
    pub fn amdgcn_image_atomic_cmpswap_v8i16(a: i32, b: i32, c: ::simdty::i16x8, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.i16` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.i16"]
    pub fn amdgcn_image_atomic_cmpswap_i16(a: i32, b: i32, c: i16, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.v4i32"]
    pub fn amdgcn_image_atomic_cmpswap_v4i32(a: i32, b: i32, c: ::simdty::i32x4, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.i32` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.i32"]
    pub fn amdgcn_image_atomic_cmpswap_i32(a: i32, b: i32, c: i32, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.v2i64"]
    pub fn amdgcn_image_atomic_cmpswap_v2i64(a: i32, b: i32, c: ::simdty::i64x2, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.image.atomic.cmpswap.i64` intrinsic.
    #[link_name = "llvm.amdgcn.image.atomic.cmpswap.i64"]
    pub fn amdgcn_image_atomic_cmpswap_i64(a: i32, b: i32, c: i64, d: ::simdty::i32x8, e: bool, f: bool, g: bool) -> i32;
    /// The `llvm.amdgcn.buffer.load.format.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.format.v4f32"]
    pub fn amdgcn_buffer_load_format_v4f32(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.buffer.load.format.f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.format.f32"]
    pub fn amdgcn_buffer_load_format_f32(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> f32;
    /// The `llvm.amdgcn.buffer.load.format.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.format.v2f64"]
    pub fn amdgcn_buffer_load_format_v2f64(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.buffer.load.format.f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.format.f64"]
    pub fn amdgcn_buffer_load_format_f64(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> f64;
    /// The `llvm.amdgcn.buffer.load.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.v4f32"]
    pub fn amdgcn_buffer_load_v4f32(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> ::simdty::f32x4;
    /// The `llvm.amdgcn.buffer.load.f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.f32"]
    pub fn amdgcn_buffer_load_f32(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> f32;
    /// The `llvm.amdgcn.buffer.load.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.v2f64"]
    pub fn amdgcn_buffer_load_v2f64(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> ::simdty::f64x2;
    /// The `llvm.amdgcn.buffer.load.f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.load.f64"]
    pub fn amdgcn_buffer_load_f64(a: ::simdty::i32x4, b: i32, c: i32, d: bool, e: bool) -> f64;
    /// The `llvm.amdgcn.buffer.store.format.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.format.v4f32"]
    pub fn amdgcn_buffer_store_format_v4f32(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.format.f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.format.f32"]
    pub fn amdgcn_buffer_store_format_f32(a: f32, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.format.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.format.v2f64"]
    pub fn amdgcn_buffer_store_format_v2f64(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.format.f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.format.f64"]
    pub fn amdgcn_buffer_store_format_f64(a: f64, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.v4f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.v4f32"]
    pub fn amdgcn_buffer_store_v4f32(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.f32` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.f32"]
    pub fn amdgcn_buffer_store_f32(a: f32, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.v2f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.v2f64"]
    pub fn amdgcn_buffer_store_v2f64(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.store.f64` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.store.f64"]
    pub fn amdgcn_buffer_store_f64(a: f64, b: ::simdty::i32x4, c: i32, d: i32, e: bool, f: bool) -> ();
    /// The `llvm.amdgcn.buffer.atomic.swap` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.swap"]
    pub fn amdgcn_buffer_atomic_swap(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.add` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.add"]
    pub fn amdgcn_buffer_atomic_add(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.sub` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.sub"]
    pub fn amdgcn_buffer_atomic_sub(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.smin` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.smin"]
    pub fn amdgcn_buffer_atomic_smin(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.umin` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.umin"]
    pub fn amdgcn_buffer_atomic_umin(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.smax` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.smax"]
    pub fn amdgcn_buffer_atomic_smax(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.umax` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.umax"]
    pub fn amdgcn_buffer_atomic_umax(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.and` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.and"]
    pub fn amdgcn_buffer_atomic_and(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.or` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.or"]
    pub fn amdgcn_buffer_atomic_or(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.xor` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.xor"]
    pub fn amdgcn_buffer_atomic_xor(a: i32, b: ::simdty::i32x4, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.buffer.atomic.cmpswap` intrinsic.
    #[link_name = "llvm.amdgcn.buffer.atomic.cmpswap"]
    pub fn amdgcn_buffer_atomic_cmpswap(a: i32, b: i32, c: ::simdty::i32x4, d: i32, e: i32, f: bool) -> i32;
    /// The `llvm.amdgcn.read.workdim` intrinsic.
    #[link_name = "llvm.amdgcn.read.workdim"]
    pub fn amdgcn_read_workdim() -> i32;
    /// The `llvm.amdgcn.buffer.wbinvl1.sc` intrinsic; known as `__builtin_amdgcn_buffer_wbinvl1_sc` in GCC.
    #[link_name = "llvm.amdgcn.buffer.wbinvl1.sc"]
    pub fn amdgcn_buffer_wbinvl1_sc() -> ();
    /// The `llvm.amdgcn.buffer.wbinvl1` intrinsic; known as `__builtin_amdgcn_buffer_wbinvl1` in GCC.
    #[link_name = "llvm.amdgcn.buffer.wbinvl1"]
    pub fn amdgcn_buffer_wbinvl1() -> ();
    /// The `llvm.amdgcn.s.dcache.inv` intrinsic; known as `__builtin_amdgcn_s_dcache_inv` in GCC.
    #[link_name = "llvm.amdgcn.s.dcache.inv"]
    pub fn amdgcn_s_dcache_inv() -> ();
    /// The `llvm.amdgcn.s.memtime` intrinsic; known as `__builtin_amdgcn_s_memtime` in GCC.
    #[link_name = "llvm.amdgcn.s.memtime"]
    pub fn amdgcn_s_memtime() -> i64;
    /// The `llvm.amdgcn.s.sleep` intrinsic; known as `__builtin_amdgcn_s_sleep` in GCC.
    #[link_name = "llvm.amdgcn.s.sleep"]
    pub fn amdgcn_s_sleep(a: i32) -> ();
    /// The `llvm.amdgcn.s.getreg` intrinsic; known as `__builtin_amdgcn_s_getreg` in GCC.
    #[link_name = "llvm.amdgcn.s.getreg"]
    pub fn amdgcn_s_getreg(a: i32) -> i32;
    /// The `llvm.amdgcn.groupstaticsize` intrinsic; known as `__builtin_amdgcn_groupstaticsize` in GCC.
    #[link_name = "llvm.amdgcn.groupstaticsize"]
    pub fn amdgcn_groupstaticsize() -> i32;
    /// The `llvm.amdgcn.interp.p1` intrinsic; known as `__builtin_amdgcn_interp_p1` in GCC.
    #[link_name = "llvm.amdgcn.interp.p1"]
    pub fn amdgcn_interp_p1(a: i32, b: i32, c: i32, d: i32) -> f32;
    /// The `llvm.amdgcn.interp.p2` intrinsic; known as `__builtin_amdgcn_interp_p2` in GCC.
    #[link_name = "llvm.amdgcn.interp.p2"]
    pub fn amdgcn_interp_p2(a: f32, b: i32, c: i32, d: i32, e: i32) -> f32;
    /// The `llvm.amdgcn.ps.live` intrinsic.
    #[link_name = "llvm.amdgcn.ps.live"]
    pub fn amdgcn_ps_live() -> bool;
    /// The `llvm.amdgcn.mbcnt.lo` intrinsic; known as `__builtin_amdgcn_mbcnt_lo` in GCC.
    #[link_name = "llvm.amdgcn.mbcnt.lo"]
    pub fn amdgcn_mbcnt_lo(a: i32, b: i32) -> i32;
    /// The `llvm.amdgcn.mbcnt.hi` intrinsic; known as `__builtin_amdgcn_mbcnt_hi` in GCC.
    #[link_name = "llvm.amdgcn.mbcnt.hi"]
    pub fn amdgcn_mbcnt_hi(a: i32, b: i32) -> i32;
    /// The `llvm.amdgcn.ds.swizzle` intrinsic; known as `__builtin_amdgcn_ds_swizzle` in GCC.
    #[link_name = "llvm.amdgcn.ds.swizzle"]
    pub fn amdgcn_ds_swizzle(a: i32, b: i32) -> i32;
    /// The `llvm.amdgcn.lerp` intrinsic; known as `__builtin_amdgcn_lerp` in GCC.
    #[link_name = "llvm.amdgcn.lerp"]
    pub fn amdgcn_lerp(a: i32, b: i32, c: i32) -> i32;
    /// The `llvm.amdgcn.s.dcache.inv.vol` intrinsic; known as `__builtin_amdgcn_s_dcache_inv_vol` in GCC.
    #[link_name = "llvm.amdgcn.s.dcache.inv.vol"]
    pub fn amdgcn_s_dcache_inv_vol() -> ();
    /// The `llvm.amdgcn.buffer.wbinvl1.vol` intrinsic; known as `__builtin_amdgcn_buffer_wbinvl1_vol` in GCC.
    #[link_name = "llvm.amdgcn.buffer.wbinvl1.vol"]
    pub fn amdgcn_buffer_wbinvl1_vol() -> ();
    /// The `llvm.amdgcn.mov.dpp.v16i8` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.v16i8"]
    pub fn amdgcn_mov_dpp_v16i8(a: ::simdty::i8x16, b: i32, c: i32, d: i32, e: bool) -> ::simdty::i8x16;
    /// The `llvm.amdgcn.mov.dpp.i8` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.i8"]
    pub fn amdgcn_mov_dpp_i8(a: i8, b: i32, c: i32, d: i32, e: bool) -> i8;
    /// The `llvm.amdgcn.mov.dpp.v8i16` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.v8i16"]
    pub fn amdgcn_mov_dpp_v8i16(a: ::simdty::i16x8, b: i32, c: i32, d: i32, e: bool) -> ::simdty::i16x8;
    /// The `llvm.amdgcn.mov.dpp.i16` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.i16"]
    pub fn amdgcn_mov_dpp_i16(a: i16, b: i32, c: i32, d: i32, e: bool) -> i16;
    /// The `llvm.amdgcn.mov.dpp.v4i32` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.v4i32"]
    pub fn amdgcn_mov_dpp_v4i32(a: ::simdty::i32x4, b: i32, c: i32, d: i32, e: bool) -> ::simdty::i32x4;
    /// The `llvm.amdgcn.mov.dpp.i32` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.i32"]
    pub fn amdgcn_mov_dpp_i32(a: i32, b: i32, c: i32, d: i32, e: bool) -> i32;
    /// The `llvm.amdgcn.mov.dpp.v2i64` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.v2i64"]
    pub fn amdgcn_mov_dpp_v2i64(a: ::simdty::i64x2, b: i32, c: i32, d: i32, e: bool) -> ::simdty::i64x2;
    /// The `llvm.amdgcn.mov.dpp.i64` intrinsic.
    #[link_name = "llvm.amdgcn.mov.dpp.i64"]
    pub fn amdgcn_mov_dpp_i64(a: i64, b: i32, c: i32, d: i32, e: bool) -> i64;
    /// The `llvm.amdgcn.s.dcache.wb` intrinsic; known as `__builtin_amdgcn_s_dcache_wb` in GCC.
    #[link_name = "llvm.amdgcn.s.dcache.wb"]
    pub fn amdgcn_s_dcache_wb() -> ();
    /// The `llvm.amdgcn.s.dcache.wb.vol` intrinsic; known as `__builtin_amdgcn_s_dcache_wb_vol` in GCC.
    #[link_name = "llvm.amdgcn.s.dcache.wb.vol"]
    pub fn amdgcn_s_dcache_wb_vol() -> ();
    /// The `llvm.amdgcn.s.memrealtime` intrinsic; known as `__builtin_amdgcn_s_memrealtime` in GCC.
    #[link_name = "llvm.amdgcn.s.memrealtime"]
    pub fn amdgcn_s_memrealtime() -> i64;
    /// The `llvm.amdgcn.ds.permute` intrinsic.
    #[link_name = "llvm.amdgcn.ds.permute"]
    pub fn amdgcn_ds_permute(a: i32, b: i32) -> i32;
    /// The `llvm.amdgcn.ds.bpermute` intrinsic.
    #[link_name = "llvm.amdgcn.ds.bpermute"]
    pub fn amdgcn_ds_bpermute(a: i32, b: i32) -> i32;
    /// The `llvm.bpf.load.byte` intrinsic; known as `__builtin_bpf_load_byte` in GCC.
    #[link_name = "llvm.bpf.load.byte"]
    pub fn bpf_load_byte(a: *mut i8, b: i64) -> i64;
    /// The `llvm.bpf.load.half` intrinsic; known as `__builtin_bpf_load_half` in GCC.
    #[link_name = "llvm.bpf.load.half"]
    pub fn bpf_load_half(a: *mut i8, b: i64) -> i64;
    /// The `llvm.bpf.load.word` intrinsic; known as `__builtin_bpf_load_word` in GCC.
    #[link_name = "llvm.bpf.load.word"]
    pub fn bpf_load_word(a: *mut i8, b: i64) -> i64;
    /// The `llvm.bpf.pseudo` intrinsic; known as `__builtin_bpf_pseudo` in GCC.
    #[link_name = "llvm.bpf.pseudo"]
    pub fn bpf_pseudo(a: i64, b: i64) -> i64;
    /// The `llvm.s390.tbegin` intrinsic.
    #[link_name = "llvm.s390.tbegin"]
    pub fn s390_tbegin(a: *mut i8, b: i32) -> i32;
    /// The `llvm.s390.tbegin.nofloat` intrinsic.
    #[link_name = "llvm.s390.tbegin.nofloat"]
    pub fn s390_tbegin_nofloat(a: *mut i8, b: i32) -> i32;
    /// The `llvm.s390.tbeginc` intrinsic.
    #[link_name = "llvm.s390.tbeginc"]
    pub fn s390_tbeginc(a: *mut i8, b: i32) -> ();
    /// The `llvm.s390.tabort` intrinsic.
    #[link_name = "llvm.s390.tabort"]
    pub fn s390_tabort(a: i64) -> ();
    /// The `llvm.s390.tend` intrinsic; known as `__builtin_tend` in GCC.
    #[link_name = "llvm.s390.tend"]
    pub fn s390_tend() -> i32;
    /// The `llvm.s390.etnd` intrinsic; known as `__builtin_tx_nesting_depth` in GCC.
    #[link_name = "llvm.s390.etnd"]
    pub fn s390_etnd() -> i32;
    /// The `llvm.s390.ppa.txassist` intrinsic; known as `__builtin_tx_assist` in GCC.
    #[link_name = "llvm.s390.ppa.txassist"]
    pub fn s390_ppa_txassist(a: i32) -> ();
    /// The `llvm.s390.lcbb` intrinsic; known as `__builtin_s390_lcbb` in GCC.
    #[link_name = "llvm.s390.lcbb"]
    pub fn s390_lcbb(a: *mut i8, b: i32) -> i32;
    /// The `llvm.s390.vlbb` intrinsic; known as `__builtin_s390_vlbb` in GCC.
    #[link_name = "llvm.s390.vlbb"]
    pub fn s390_vlbb(a: *mut i8, b: i32) -> ::simdty::i8x16;
    /// The `llvm.s390.vll` intrinsic; known as `__builtin_s390_vll` in GCC.
    #[link_name = "llvm.s390.vll"]
    pub fn s390_vll(a: i32, b: *mut i8) -> ::simdty::i8x16;
    /// The `llvm.s390.vpdi` intrinsic; known as `__builtin_s390_vpdi` in GCC.
    #[link_name = "llvm.s390.vpdi"]
    pub fn s390_vpdi(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
    /// The `llvm.s390.vperm` intrinsic; known as `__builtin_s390_vperm` in GCC.
    #[link_name = "llvm.s390.vperm"]
    pub fn s390_vperm(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vstl` intrinsic; known as `__builtin_s390_vstl` in GCC.
    #[link_name = "llvm.s390.vstl"]
    pub fn s390_vstl(a: ::simdty::i8x16, b: i32, c: *mut i8) -> ();
    /// The `llvm.s390.vaq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vaq"]
    pub fn s390_vaq(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vacq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vacq"]
    pub fn s390_vacq(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vaccq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vaccq"]
    pub fn s390_vaccq(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vacccq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vacccq"]
    pub fn s390_vacccq(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vcksm` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vcksm"]
    pub fn s390_vcksm(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.s390.vsl` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsl"]
    pub fn s390_vsl(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vslb` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vslb"]
    pub fn s390_vslb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsra` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsra"]
    pub fn s390_vsra(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsrab` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsrab"]
    pub fn s390_vsrab(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsrl` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsrl"]
    pub fn s390_vsrl(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsrlb` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsrlb"]
    pub fn s390_vsrlb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsldb` intrinsic; known as `__builtin_s390_vsldb` in GCC.
    #[link_name = "llvm.s390.vsldb"]
    pub fn s390_vsldb(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
    /// The `llvm.s390.vsq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsq"]
    pub fn s390_vsq(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsbiq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsbiq"]
    pub fn s390_vsbiq(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vscbiq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vscbiq"]
    pub fn s390_vscbiq(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsbcbiq` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsbcbiq"]
    pub fn s390_vsbcbiq(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.s390.vsumb` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumb"]
    pub fn s390_vsumb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i32x4;
    /// The `llvm.s390.vsumh` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumh"]
    pub fn s390_vsumh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
    /// The `llvm.s390.vsumgh` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumgh"]
    pub fn s390_vsumgh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i64x2;
    /// The `llvm.s390.vsumgf` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumgf"]
    pub fn s390_vsumgf(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
    /// The `llvm.s390.vsumqf` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumqf"]
    pub fn s390_vsumqf(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i8x16;
    /// The `llvm.s390.vsumqg` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vsumqg"]
    pub fn s390_vsumqg(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i8x16;
    /// The `llvm.s390.vtm` intrinsic; known as `__builtin_s390_` in GCC.
    #[link_name = "llvm.s390.vtm"]
    pub fn s390_vtm(a: ::simdty::i8x16, b: ::simdty::i8x16) -> i32;
    /// The `llvm.s390.vfidb` intrinsic.
    #[link_name = "llvm.s390.vfidb"]
    pub fn s390_vfidb(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.s390.tdc.v4f32` intrinsic.
    #[link_name = "llvm.s390.tdc.v4f32"]
    pub fn s390_tdc_v4f32(a: ::simdty::f32x4, b: i64) -> i32;
    /// The `llvm.s390.tdc.f32` intrinsic.
    #[link_name = "llvm.s390.tdc.f32"]
    pub fn s390_tdc_f32(a: f32, b: i64) -> i32;
    /// The `llvm.s390.tdc.v2f64` intrinsic.
    #[link_name = "llvm.s390.tdc.v2f64"]
    pub fn s390_tdc_v2f64(a: ::simdty::f64x2, b: i64) -> i32;
    /// The `llvm.s390.tdc.f64` intrinsic.
    #[link_name = "llvm.s390.tdc.f64"]
    pub fn s390_tdc_f64(a: f64, b: i64) -> i32;
    /// The `llvm.va_start` intrinsic.
    #[link_name = "llvm.va_start"]
    pub fn vastart(a: *mut i8) -> ();
    /// The `llvm.va_copy` intrinsic.
    #[link_name = "llvm.va_copy"]
    pub fn vacopy(a: *mut i8, b: *mut i8) -> ();
    /// The `llvm.va_end` intrinsic.
    #[link_name = "llvm.va_end"]
    pub fn vaend(a: *mut i8) -> ();
    /// The `llvm.gcroot` intrinsic.
    #[link_name = "llvm.gcroot"]
    pub fn gcroot(a: *mut *mut i8, b: *mut i8) -> ();
    /// The `llvm.gcread` intrinsic.
    #[link_name = "llvm.gcread"]
    pub fn gcread(a: *mut i8, b: *mut *mut i8) -> *mut i8;
    /// The `llvm.gcwrite` intrinsic.
    #[link_name = "llvm.gcwrite"]
    pub fn gcwrite(a: *mut i8, b: *mut i8, c: *mut *mut i8) -> ();
    /// The `llvm.returnaddress` intrinsic.
    #[link_name = "llvm.returnaddress"]
    pub fn returnaddress(a: i32) -> *mut i8;
    /// The `llvm.frameaddress` intrinsic.
    #[link_name = "llvm.frameaddress"]
    pub fn frameaddress(a: i32) -> *mut i8;
    /// The `llvm.localaddress` intrinsic.
    #[link_name = "llvm.localaddress"]
    pub fn localaddress() -> *mut i8;
    /// The `llvm.localrecover` intrinsic.
    #[link_name = "llvm.localrecover"]
    pub fn localrecover(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
    /// The `llvm.stacksave` intrinsic; known as `__builtin_stack_save` in GCC.
    #[link_name = "llvm.stacksave"]
    pub fn stacksave() -> *mut i8;
    /// The `llvm.stackrestore` intrinsic; known as `__builtin_stack_restore` in GCC.
    #[link_name = "llvm.stackrestore"]
    pub fn stackrestore(a: *mut i8) -> ();
    /// The `llvm.get.dynamic.area.offset.v16i8` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.v16i8"]
    pub fn get_dynamic_area_offset_v16i8() -> ::simdty::i8x16;
    /// The `llvm.get.dynamic.area.offset.i8` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.i8"]
    pub fn get_dynamic_area_offset_i8() -> i8;
    /// The `llvm.get.dynamic.area.offset.v8i16` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.v8i16"]
    pub fn get_dynamic_area_offset_v8i16() -> ::simdty::i16x8;
    /// The `llvm.get.dynamic.area.offset.i16` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.i16"]
    pub fn get_dynamic_area_offset_i16() -> i16;
    /// The `llvm.get.dynamic.area.offset.v4i32` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.v4i32"]
    pub fn get_dynamic_area_offset_v4i32() -> ::simdty::i32x4;
    /// The `llvm.get.dynamic.area.offset.i32` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.i32"]
    pub fn get_dynamic_area_offset_i32() -> i32;
    /// The `llvm.get.dynamic.area.offset.v2i64` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.v2i64"]
    pub fn get_dynamic_area_offset_v2i64() -> ::simdty::i64x2;
    /// The `llvm.get.dynamic.area.offset.i64` intrinsic.
    #[link_name = "llvm.get.dynamic.area.offset.i64"]
    pub fn get_dynamic_area_offset_i64() -> i64;
    /// The `llvm.thread.pointer` intrinsic; known as `__builtin_thread_pointer` in GCC.
    #[link_name = "llvm.thread.pointer"]
    pub fn thread_pointer() -> *mut i8;
    /// The `llvm.prefetch` intrinsic.
    #[link_name = "llvm.prefetch"]
    pub fn prefetch(a: *mut i8, b: i32, c: i32, d: i32) -> ();
    /// The `llvm.pcmarker` intrinsic.
    #[link_name = "llvm.pcmarker"]
    pub fn pcmarker(a: i32) -> ();
    /// The `llvm.readcyclecounter` intrinsic.
    #[link_name = "llvm.readcyclecounter"]
    pub fn readcyclecounter() -> i64;
    /// The `llvm.assume` intrinsic.
    #[link_name = "llvm.assume"]
    pub fn assume(a: bool) -> ();
    /// The `llvm.stackprotector` intrinsic.
    #[link_name = "llvm.stackprotector"]
    pub fn stackprotector(a: *mut i8, b: *mut *mut i8) -> ();
    /// The `llvm.stackguard` intrinsic.
    #[link_name = "llvm.stackguard"]
    pub fn stackguard() -> *mut i8;
    /// The `llvm.instrprof.increment` intrinsic.
    #[link_name = "llvm.instrprof.increment"]
    pub fn instrprof_increment(a: *mut i8, b: i64, c: i32, d: i32) -> ();
    /// The `llvm.instrprof.value.profile` intrinsic.
    #[link_name = "llvm.instrprof.value.profile"]
    pub fn instrprof_value_profile(a: *mut i8, b: i64, c: i64, d: i32, e: i32) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.v16i8` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.v16i8"]
    pub fn memcpy_p0i8_p0i8_v16i8(a: *mut i8, b: *mut i8, c: ::simdty::i8x16, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.i8` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.i8"]
    pub fn memcpy_p0i8_p0i8_i8(a: *mut i8, b: *mut i8, c: i8, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.v8i16` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.v8i16"]
    pub fn memcpy_p0i8_p0i8_v8i16(a: *mut i8, b: *mut i8, c: ::simdty::i16x8, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.i16` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.i16"]
    pub fn memcpy_p0i8_p0i8_i16(a: *mut i8, b: *mut i8, c: i16, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.v4i32` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.v4i32"]
    pub fn memcpy_p0i8_p0i8_v4i32(a: *mut i8, b: *mut i8, c: ::simdty::i32x4, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.i32` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.i32"]
    pub fn memcpy_p0i8_p0i8_i32(a: *mut i8, b: *mut i8, c: i32, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.v2i64` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.v2i64"]
    pub fn memcpy_p0i8_p0i8_v2i64(a: *mut i8, b: *mut i8, c: ::simdty::i64x2, d: i32, e: bool) -> ();
    /// The `llvm.memcpy.p0i8.p0i8.i64` intrinsic.
    #[link_name = "llvm.memcpy.p0i8.p0i8.i64"]
    pub fn memcpy_p0i8_p0i8_i64(a: *mut i8, b: *mut i8, c: i64, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.v16i8` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.v16i8"]
    pub fn memmove_p0i8_p0i8_v16i8(a: *mut i8, b: *mut i8, c: ::simdty::i8x16, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.i8` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.i8"]
    pub fn memmove_p0i8_p0i8_i8(a: *mut i8, b: *mut i8, c: i8, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.v8i16` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.v8i16"]
    pub fn memmove_p0i8_p0i8_v8i16(a: *mut i8, b: *mut i8, c: ::simdty::i16x8, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.i16` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.i16"]
    pub fn memmove_p0i8_p0i8_i16(a: *mut i8, b: *mut i8, c: i16, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.v4i32` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.v4i32"]
    pub fn memmove_p0i8_p0i8_v4i32(a: *mut i8, b: *mut i8, c: ::simdty::i32x4, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.i32` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.i32"]
    pub fn memmove_p0i8_p0i8_i32(a: *mut i8, b: *mut i8, c: i32, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.v2i64` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.v2i64"]
    pub fn memmove_p0i8_p0i8_v2i64(a: *mut i8, b: *mut i8, c: ::simdty::i64x2, d: i32, e: bool) -> ();
    /// The `llvm.memmove.p0i8.p0i8.i64` intrinsic.
    #[link_name = "llvm.memmove.p0i8.p0i8.i64"]
    pub fn memmove_p0i8_p0i8_i64(a: *mut i8, b: *mut i8, c: i64, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.v16i8` intrinsic.
    #[link_name = "llvm.memset.p0i8.v16i8"]
    pub fn memset_p0i8_v16i8(a: *mut i8, b: i8, c: ::simdty::i8x16, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.i8` intrinsic.
    #[link_name = "llvm.memset.p0i8.i8"]
    pub fn memset_p0i8_i8(a: *mut i8, b: i8, c: i8, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.v8i16` intrinsic.
    #[link_name = "llvm.memset.p0i8.v8i16"]
    pub fn memset_p0i8_v8i16(a: *mut i8, b: i8, c: ::simdty::i16x8, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.i16` intrinsic.
    #[link_name = "llvm.memset.p0i8.i16"]
    pub fn memset_p0i8_i16(a: *mut i8, b: i8, c: i16, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.v4i32` intrinsic.
    #[link_name = "llvm.memset.p0i8.v4i32"]
    pub fn memset_p0i8_v4i32(a: *mut i8, b: i8, c: ::simdty::i32x4, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.i32` intrinsic.
    #[link_name = "llvm.memset.p0i8.i32"]
    pub fn memset_p0i8_i32(a: *mut i8, b: i8, c: i32, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.v2i64` intrinsic.
    #[link_name = "llvm.memset.p0i8.v2i64"]
    pub fn memset_p0i8_v2i64(a: *mut i8, b: i8, c: ::simdty::i64x2, d: i32, e: bool) -> ();
    /// The `llvm.memset.p0i8.i64` intrinsic.
    #[link_name = "llvm.memset.p0i8.i64"]
    pub fn memset_p0i8_i64(a: *mut i8, b: i8, c: i64, d: i32, e: bool) -> ();
    /// The `llvm.fma.v4f32` intrinsic.
    #[link_name = "llvm.fma.v4f32"]
    pub fn fma_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.fma.f32` intrinsic.
    #[link_name = "llvm.fma.f32"]
    pub fn fma_f32(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.fma.v2f64` intrinsic.
    #[link_name = "llvm.fma.v2f64"]
    pub fn fma_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.fma.f64` intrinsic.
    #[link_name = "llvm.fma.f64"]
    pub fn fma_f64(a: f64, b: f64, c: f64) -> f64;
    /// The `llvm.fmuladd.v4f32` intrinsic.
    #[link_name = "llvm.fmuladd.v4f32"]
    pub fn fmuladd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.fmuladd.f32` intrinsic.
    #[link_name = "llvm.fmuladd.f32"]
    pub fn fmuladd_f32(a: f32, b: f32, c: f32) -> f32;
    /// The `llvm.fmuladd.v2f64` intrinsic.
    #[link_name = "llvm.fmuladd.v2f64"]
    pub fn fmuladd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.fmuladd.f64` intrinsic.
    #[link_name = "llvm.fmuladd.f64"]
    pub fn fmuladd_f64(a: f64, b: f64, c: f64) -> f64;
    /// The `llvm.sqrt.v4f32` intrinsic.
    #[link_name = "llvm.sqrt.v4f32"]
    pub fn sqrt_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.sqrt.f32` intrinsic.
    #[link_name = "llvm.sqrt.f32"]
    pub fn sqrt_f32(a: f32) -> f32;
    /// The `llvm.sqrt.v2f64` intrinsic.
    #[link_name = "llvm.sqrt.v2f64"]
    pub fn sqrt_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.sqrt.f64` intrinsic.
    #[link_name = "llvm.sqrt.f64"]
    pub fn sqrt_f64(a: f64) -> f64;
    /// The `llvm.powi.v4f32` intrinsic.
    #[link_name = "llvm.powi.v4f32"]
    pub fn powi_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
    /// The `llvm.powi.f32` intrinsic.
    #[link_name = "llvm.powi.f32"]
    pub fn powi_f32(a: f32, b: i32) -> f32;
    /// The `llvm.powi.v2f64` intrinsic.
    #[link_name = "llvm.powi.v2f64"]
    pub fn powi_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
    /// The `llvm.powi.f64` intrinsic.
    #[link_name = "llvm.powi.f64"]
    pub fn powi_f64(a: f64, b: i32) -> f64;
    /// The `llvm.sin.v4f32` intrinsic.
    #[link_name = "llvm.sin.v4f32"]
    pub fn sin_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.sin.f32` intrinsic.
    #[link_name = "llvm.sin.f32"]
    pub fn sin_f32(a: f32) -> f32;
    /// The `llvm.sin.v2f64` intrinsic.
    #[link_name = "llvm.sin.v2f64"]
    pub fn sin_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.sin.f64` intrinsic.
    #[link_name = "llvm.sin.f64"]
    pub fn sin_f64(a: f64) -> f64;
    /// The `llvm.cos.v4f32` intrinsic.
    #[link_name = "llvm.cos.v4f32"]
    pub fn cos_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.cos.f32` intrinsic.
    #[link_name = "llvm.cos.f32"]
    pub fn cos_f32(a: f32) -> f32;
    /// The `llvm.cos.v2f64` intrinsic.
    #[link_name = "llvm.cos.v2f64"]
    pub fn cos_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.cos.f64` intrinsic.
    #[link_name = "llvm.cos.f64"]
    pub fn cos_f64(a: f64) -> f64;
    /// The `llvm.pow.v4f32` intrinsic.
    #[link_name = "llvm.pow.v4f32"]
    pub fn pow_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.pow.f32` intrinsic.
    #[link_name = "llvm.pow.f32"]
    pub fn pow_f32(a: f32, b: f32) -> f32;
    /// The `llvm.pow.v2f64` intrinsic.
    #[link_name = "llvm.pow.v2f64"]
    pub fn pow_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.pow.f64` intrinsic.
    #[link_name = "llvm.pow.f64"]
    pub fn pow_f64(a: f64, b: f64) -> f64;
    /// The `llvm.log.v4f32` intrinsic.
    #[link_name = "llvm.log.v4f32"]
    pub fn log_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.log.f32` intrinsic.
    #[link_name = "llvm.log.f32"]
    pub fn log_f32(a: f32) -> f32;
    /// The `llvm.log.v2f64` intrinsic.
    #[link_name = "llvm.log.v2f64"]
    pub fn log_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.log.f64` intrinsic.
    #[link_name = "llvm.log.f64"]
    pub fn log_f64(a: f64) -> f64;
    /// The `llvm.log10.v4f32` intrinsic.
    #[link_name = "llvm.log10.v4f32"]
    pub fn log10_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.log10.f32` intrinsic.
    #[link_name = "llvm.log10.f32"]
    pub fn log10_f32(a: f32) -> f32;
    /// The `llvm.log10.v2f64` intrinsic.
    #[link_name = "llvm.log10.v2f64"]
    pub fn log10_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.log10.f64` intrinsic.
    #[link_name = "llvm.log10.f64"]
    pub fn log10_f64(a: f64) -> f64;
    /// The `llvm.log2.v4f32` intrinsic.
    #[link_name = "llvm.log2.v4f32"]
    pub fn log2_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.log2.f32` intrinsic.
    #[link_name = "llvm.log2.f32"]
    pub fn log2_f32(a: f32) -> f32;
    /// The `llvm.log2.v2f64` intrinsic.
    #[link_name = "llvm.log2.v2f64"]
    pub fn log2_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.log2.f64` intrinsic.
    #[link_name = "llvm.log2.f64"]
    pub fn log2_f64(a: f64) -> f64;
    /// The `llvm.exp.v4f32` intrinsic.
    #[link_name = "llvm.exp.v4f32"]
    pub fn exp_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.exp.f32` intrinsic.
    #[link_name = "llvm.exp.f32"]
    pub fn exp_f32(a: f32) -> f32;
    /// The `llvm.exp.v2f64` intrinsic.
    #[link_name = "llvm.exp.v2f64"]
    pub fn exp_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.exp.f64` intrinsic.
    #[link_name = "llvm.exp.f64"]
    pub fn exp_f64(a: f64) -> f64;
    /// The `llvm.exp2.v4f32` intrinsic.
    #[link_name = "llvm.exp2.v4f32"]
    pub fn exp2_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.exp2.f32` intrinsic.
    #[link_name = "llvm.exp2.f32"]
    pub fn exp2_f32(a: f32) -> f32;
    /// The `llvm.exp2.v2f64` intrinsic.
    #[link_name = "llvm.exp2.v2f64"]
    pub fn exp2_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.exp2.f64` intrinsic.
    #[link_name = "llvm.exp2.f64"]
    pub fn exp2_f64(a: f64) -> f64;
    /// The `llvm.fabs.v4f32` intrinsic.
    #[link_name = "llvm.fabs.v4f32"]
    pub fn fabs_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.fabs.f32` intrinsic.
    #[link_name = "llvm.fabs.f32"]
    pub fn fabs_f32(a: f32) -> f32;
    /// The `llvm.fabs.v2f64` intrinsic.
    #[link_name = "llvm.fabs.v2f64"]
    pub fn fabs_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.fabs.f64` intrinsic.
    #[link_name = "llvm.fabs.f64"]
    pub fn fabs_f64(a: f64) -> f64;
    /// The `llvm.copysign.v4f32` intrinsic.
    #[link_name = "llvm.copysign.v4f32"]
    pub fn copysign_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.copysign.f32` intrinsic.
    #[link_name = "llvm.copysign.f32"]
    pub fn copysign_f32(a: f32, b: f32) -> f32;
    /// The `llvm.copysign.v2f64` intrinsic.
    #[link_name = "llvm.copysign.v2f64"]
    pub fn copysign_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.copysign.f64` intrinsic.
    #[link_name = "llvm.copysign.f64"]
    pub fn copysign_f64(a: f64, b: f64) -> f64;
    /// The `llvm.floor.v4f32` intrinsic.
    #[link_name = "llvm.floor.v4f32"]
    pub fn floor_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.floor.f32` intrinsic.
    #[link_name = "llvm.floor.f32"]
    pub fn floor_f32(a: f32) -> f32;
    /// The `llvm.floor.v2f64` intrinsic.
    #[link_name = "llvm.floor.v2f64"]
    pub fn floor_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.floor.f64` intrinsic.
    #[link_name = "llvm.floor.f64"]
    pub fn floor_f64(a: f64) -> f64;
    /// The `llvm.ceil.v4f32` intrinsic.
    #[link_name = "llvm.ceil.v4f32"]
    pub fn ceil_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.ceil.f32` intrinsic.
    #[link_name = "llvm.ceil.f32"]
    pub fn ceil_f32(a: f32) -> f32;
    /// The `llvm.ceil.v2f64` intrinsic.
    #[link_name = "llvm.ceil.v2f64"]
    pub fn ceil_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.ceil.f64` intrinsic.
    #[link_name = "llvm.ceil.f64"]
    pub fn ceil_f64(a: f64) -> f64;
    /// The `llvm.trunc.v4f32` intrinsic.
    #[link_name = "llvm.trunc.v4f32"]
    pub fn trunc_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.trunc.f32` intrinsic.
    #[link_name = "llvm.trunc.f32"]
    pub fn trunc_f32(a: f32) -> f32;
    /// The `llvm.trunc.v2f64` intrinsic.
    #[link_name = "llvm.trunc.v2f64"]
    pub fn trunc_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.trunc.f64` intrinsic.
    #[link_name = "llvm.trunc.f64"]
    pub fn trunc_f64(a: f64) -> f64;
    /// The `llvm.rint.v4f32` intrinsic.
    #[link_name = "llvm.rint.v4f32"]
    pub fn rint_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.rint.f32` intrinsic.
    #[link_name = "llvm.rint.f32"]
    pub fn rint_f32(a: f32) -> f32;
    /// The `llvm.rint.v2f64` intrinsic.
    #[link_name = "llvm.rint.v2f64"]
    pub fn rint_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.rint.f64` intrinsic.
    #[link_name = "llvm.rint.f64"]
    pub fn rint_f64(a: f64) -> f64;
    /// The `llvm.nearbyint.v4f32` intrinsic.
    #[link_name = "llvm.nearbyint.v4f32"]
    pub fn nearbyint_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.nearbyint.f32` intrinsic.
    #[link_name = "llvm.nearbyint.f32"]
    pub fn nearbyint_f32(a: f32) -> f32;
    /// The `llvm.nearbyint.v2f64` intrinsic.
    #[link_name = "llvm.nearbyint.v2f64"]
    pub fn nearbyint_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.nearbyint.f64` intrinsic.
    #[link_name = "llvm.nearbyint.f64"]
    pub fn nearbyint_f64(a: f64) -> f64;
    /// The `llvm.round.v4f32` intrinsic.
    #[link_name = "llvm.round.v4f32"]
    pub fn round_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.round.f32` intrinsic.
    #[link_name = "llvm.round.f32"]
    pub fn round_f32(a: f32) -> f32;
    /// The `llvm.round.v2f64` intrinsic.
    #[link_name = "llvm.round.v2f64"]
    pub fn round_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.round.f64` intrinsic.
    #[link_name = "llvm.round.f64"]
    pub fn round_f64(a: f64) -> f64;
    /// The `llvm.canonicalize.v4f32` intrinsic.
    #[link_name = "llvm.canonicalize.v4f32"]
    pub fn canonicalize_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.canonicalize.f32` intrinsic.
    #[link_name = "llvm.canonicalize.f32"]
    pub fn canonicalize_f32(a: f32) -> f32;
    /// The `llvm.canonicalize.v2f64` intrinsic.
    #[link_name = "llvm.canonicalize.v2f64"]
    pub fn canonicalize_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.canonicalize.f64` intrinsic.
    #[link_name = "llvm.canonicalize.f64"]
    pub fn canonicalize_f64(a: f64) -> f64;
    /// The `llvm.minnum.v4f32` intrinsic.
    #[link_name = "llvm.minnum.v4f32"]
    pub fn minnum_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.minnum.f32` intrinsic.
    #[link_name = "llvm.minnum.f32"]
    pub fn minnum_f32(a: f32, b: f32) -> f32;
    /// The `llvm.minnum.v2f64` intrinsic.
    #[link_name = "llvm.minnum.v2f64"]
    pub fn minnum_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.minnum.f64` intrinsic.
    #[link_name = "llvm.minnum.f64"]
    pub fn minnum_f64(a: f64, b: f64) -> f64;
    /// The `llvm.maxnum.v4f32` intrinsic.
    #[link_name = "llvm.maxnum.v4f32"]
    pub fn maxnum_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
    /// The `llvm.maxnum.f32` intrinsic.
    #[link_name = "llvm.maxnum.f32"]
    pub fn maxnum_f32(a: f32, b: f32) -> f32;
    /// The `llvm.maxnum.v2f64` intrinsic.
    #[link_name = "llvm.maxnum.v2f64"]
    pub fn maxnum_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
    /// The `llvm.maxnum.f64` intrinsic.
    #[link_name = "llvm.maxnum.f64"]
    pub fn maxnum_f64(a: f64, b: f64) -> f64;
    /// The `llvm.setjmp` intrinsic.
    #[link_name = "llvm.setjmp"]
    pub fn setjmp(a: *mut i8) -> i32;
    /// The `llvm.longjmp` intrinsic.
    #[link_name = "llvm.longjmp"]
    pub fn longjmp(a: *mut i8, b: i32) -> ();
    /// The `llvm.sigsetjmp` intrinsic.
    #[link_name = "llvm.sigsetjmp"]
    pub fn sigsetjmp(a: *mut i8, b: i32) -> i32;
    /// The `llvm.siglongjmp` intrinsic.
    #[link_name = "llvm.siglongjmp"]
    pub fn siglongjmp(a: *mut i8, b: i32) -> ();
    /// The `llvm.objectsize.v16i8.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.v16i8.p0i8"]
    pub fn objectsize_v16i8_p0i8(a: *mut i8, b: bool) -> ::simdty::i8x16;
    /// The `llvm.objectsize.i8.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.i8.p0i8"]
    pub fn objectsize_i8_p0i8(a: *mut i8, b: bool) -> i8;
    /// The `llvm.objectsize.v8i16.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.v8i16.p0i8"]
    pub fn objectsize_v8i16_p0i8(a: *mut i8, b: bool) -> ::simdty::i16x8;
    /// The `llvm.objectsize.i16.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.i16.p0i8"]
    pub fn objectsize_i16_p0i8(a: *mut i8, b: bool) -> i16;
    /// The `llvm.objectsize.v4i32.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.v4i32.p0i8"]
    pub fn objectsize_v4i32_p0i8(a: *mut i8, b: bool) -> ::simdty::i32x4;
    /// The `llvm.objectsize.i32.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.i32.p0i8"]
    pub fn objectsize_i32_p0i8(a: *mut i8, b: bool) -> i32;
    /// The `llvm.objectsize.v2i64.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.v2i64.p0i8"]
    pub fn objectsize_v2i64_p0i8(a: *mut i8, b: bool) -> ::simdty::i64x2;
    /// The `llvm.objectsize.i64.p0i8` intrinsic; known as `__builtin_object_size` in GCC.
    #[link_name = "llvm.objectsize.i64.p0i8"]
    pub fn objectsize_i64_p0i8(a: *mut i8, b: bool) -> i64;
    /// The `llvm.expect.v16i8` intrinsic.
    #[link_name = "llvm.expect.v16i8"]
    pub fn expect_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.expect.i8` intrinsic.
    #[link_name = "llvm.expect.i8"]
    pub fn expect_i8(a: i8, b: i8) -> i8;
    /// The `llvm.expect.v8i16` intrinsic.
    #[link_name = "llvm.expect.v8i16"]
    pub fn expect_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.expect.i16` intrinsic.
    #[link_name = "llvm.expect.i16"]
    pub fn expect_i16(a: i16, b: i16) -> i16;
    /// The `llvm.expect.v4i32` intrinsic.
    #[link_name = "llvm.expect.v4i32"]
    pub fn expect_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.expect.i32` intrinsic.
    #[link_name = "llvm.expect.i32"]
    pub fn expect_i32(a: i32, b: i32) -> i32;
    /// The `llvm.expect.v2i64` intrinsic.
    #[link_name = "llvm.expect.v2i64"]
    pub fn expect_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.expect.i64` intrinsic.
    #[link_name = "llvm.expect.i64"]
    pub fn expect_i64(a: i64, b: i64) -> i64;
    /// The `llvm.bswap.v16i8` intrinsic.
    #[link_name = "llvm.bswap.v16i8"]
    pub fn bswap_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.bswap.i8` intrinsic.
    #[link_name = "llvm.bswap.i8"]
    pub fn bswap_i8(a: i8) -> i8;
    /// The `llvm.bswap.v8i16` intrinsic.
    #[link_name = "llvm.bswap.v8i16"]
    pub fn bswap_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.bswap.i16` intrinsic.
    #[link_name = "llvm.bswap.i16"]
    pub fn bswap_i16(a: i16) -> i16;
    /// The `llvm.bswap.v4i32` intrinsic.
    #[link_name = "llvm.bswap.v4i32"]
    pub fn bswap_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.bswap.i32` intrinsic.
    #[link_name = "llvm.bswap.i32"]
    pub fn bswap_i32(a: i32) -> i32;
    /// The `llvm.bswap.v2i64` intrinsic.
    #[link_name = "llvm.bswap.v2i64"]
    pub fn bswap_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.bswap.i64` intrinsic.
    #[link_name = "llvm.bswap.i64"]
    pub fn bswap_i64(a: i64) -> i64;
    /// The `llvm.ctpop.v16i8` intrinsic.
    #[link_name = "llvm.ctpop.v16i8"]
    pub fn ctpop_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.ctpop.i8` intrinsic.
    #[link_name = "llvm.ctpop.i8"]
    pub fn ctpop_i8(a: i8) -> i8;
    /// The `llvm.ctpop.v8i16` intrinsic.
    #[link_name = "llvm.ctpop.v8i16"]
    pub fn ctpop_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.ctpop.i16` intrinsic.
    #[link_name = "llvm.ctpop.i16"]
    pub fn ctpop_i16(a: i16) -> i16;
    /// The `llvm.ctpop.v4i32` intrinsic.
    #[link_name = "llvm.ctpop.v4i32"]
    pub fn ctpop_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.ctpop.i32` intrinsic.
    #[link_name = "llvm.ctpop.i32"]
    pub fn ctpop_i32(a: i32) -> i32;
    /// The `llvm.ctpop.v2i64` intrinsic.
    #[link_name = "llvm.ctpop.v2i64"]
    pub fn ctpop_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.ctpop.i64` intrinsic.
    #[link_name = "llvm.ctpop.i64"]
    pub fn ctpop_i64(a: i64) -> i64;
    /// The `llvm.ctlz.v16i8` intrinsic.
    #[link_name = "llvm.ctlz.v16i8"]
    pub fn ctlz_v16i8(a: ::simdty::i8x16, b: bool) -> ::simdty::i8x16;
    /// The `llvm.ctlz.i8` intrinsic.
    #[link_name = "llvm.ctlz.i8"]
    pub fn ctlz_i8(a: i8, b: bool) -> i8;
    /// The `llvm.ctlz.v8i16` intrinsic.
    #[link_name = "llvm.ctlz.v8i16"]
    pub fn ctlz_v8i16(a: ::simdty::i16x8, b: bool) -> ::simdty::i16x8;
    /// The `llvm.ctlz.i16` intrinsic.
    #[link_name = "llvm.ctlz.i16"]
    pub fn ctlz_i16(a: i16, b: bool) -> i16;
    /// The `llvm.ctlz.v4i32` intrinsic.
    #[link_name = "llvm.ctlz.v4i32"]
    pub fn ctlz_v4i32(a: ::simdty::i32x4, b: bool) -> ::simdty::i32x4;
    /// The `llvm.ctlz.i32` intrinsic.
    #[link_name = "llvm.ctlz.i32"]
    pub fn ctlz_i32(a: i32, b: bool) -> i32;
    /// The `llvm.ctlz.v2i64` intrinsic.
    #[link_name = "llvm.ctlz.v2i64"]
    pub fn ctlz_v2i64(a: ::simdty::i64x2, b: bool) -> ::simdty::i64x2;
    /// The `llvm.ctlz.i64` intrinsic.
    #[link_name = "llvm.ctlz.i64"]
    pub fn ctlz_i64(a: i64, b: bool) -> i64;
    /// The `llvm.cttz.v16i8` intrinsic.
    #[link_name = "llvm.cttz.v16i8"]
    pub fn cttz_v16i8(a: ::simdty::i8x16, b: bool) -> ::simdty::i8x16;
    /// The `llvm.cttz.i8` intrinsic.
    #[link_name = "llvm.cttz.i8"]
    pub fn cttz_i8(a: i8, b: bool) -> i8;
    /// The `llvm.cttz.v8i16` intrinsic.
    #[link_name = "llvm.cttz.v8i16"]
    pub fn cttz_v8i16(a: ::simdty::i16x8, b: bool) -> ::simdty::i16x8;
    /// The `llvm.cttz.i16` intrinsic.
    #[link_name = "llvm.cttz.i16"]
    pub fn cttz_i16(a: i16, b: bool) -> i16;
    /// The `llvm.cttz.v4i32` intrinsic.
    #[link_name = "llvm.cttz.v4i32"]
    pub fn cttz_v4i32(a: ::simdty::i32x4, b: bool) -> ::simdty::i32x4;
    /// The `llvm.cttz.i32` intrinsic.
    #[link_name = "llvm.cttz.i32"]
    pub fn cttz_i32(a: i32, b: bool) -> i32;
    /// The `llvm.cttz.v2i64` intrinsic.
    #[link_name = "llvm.cttz.v2i64"]
    pub fn cttz_v2i64(a: ::simdty::i64x2, b: bool) -> ::simdty::i64x2;
    /// The `llvm.cttz.i64` intrinsic.
    #[link_name = "llvm.cttz.i64"]
    pub fn cttz_i64(a: i64, b: bool) -> i64;
    /// The `llvm.bitreverse.v16i8` intrinsic.
    #[link_name = "llvm.bitreverse.v16i8"]
    pub fn bitreverse_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
    /// The `llvm.bitreverse.i8` intrinsic.
    #[link_name = "llvm.bitreverse.i8"]
    pub fn bitreverse_i8(a: i8) -> i8;
    /// The `llvm.bitreverse.v8i16` intrinsic.
    #[link_name = "llvm.bitreverse.v8i16"]
    pub fn bitreverse_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
    /// The `llvm.bitreverse.i16` intrinsic.
    #[link_name = "llvm.bitreverse.i16"]
    pub fn bitreverse_i16(a: i16) -> i16;
    /// The `llvm.bitreverse.v4i32` intrinsic.
    #[link_name = "llvm.bitreverse.v4i32"]
    pub fn bitreverse_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
    /// The `llvm.bitreverse.i32` intrinsic.
    #[link_name = "llvm.bitreverse.i32"]
    pub fn bitreverse_i32(a: i32) -> i32;
    /// The `llvm.bitreverse.v2i64` intrinsic.
    #[link_name = "llvm.bitreverse.v2i64"]
    pub fn bitreverse_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
    /// The `llvm.bitreverse.i64` intrinsic.
    #[link_name = "llvm.bitreverse.i64"]
    pub fn bitreverse_i64(a: i64) -> i64;
    /// The `llvm.eh.typeid.for` intrinsic.
    #[link_name = "llvm.eh.typeid.for"]
    pub fn eh_typeid_for(a: *mut i8) -> i32;
    /// The `llvm.eh.return.i32` intrinsic.
    #[link_name = "llvm.eh.return.i32"]
    pub fn eh_return_i32(a: i32, b: *mut i8) -> ();
    /// The `llvm.eh.return.i64` intrinsic.
    #[link_name = "llvm.eh.return.i64"]
    pub fn eh_return_i64(a: i64, b: *mut i8) -> ();
    /// The `llvm.eh.unwind.init` intrinsic; known as `__builtin_unwind_init` in GCC.
    #[link_name = "llvm.eh.unwind.init"]
    pub fn eh_unwind_init() -> ();
    /// The `llvm.eh.dwarf.cfa` intrinsic.
    #[link_name = "llvm.eh.dwarf.cfa"]
    pub fn eh_dwarf_cfa(a: i32) -> *mut i8;
    /// The `llvm.eh.sjlj.lsda` intrinsic.
    #[link_name = "llvm.eh.sjlj.lsda"]
    pub fn eh_sjlj_lsda() -> *mut i8;
    /// The `llvm.eh.sjlj.callsite` intrinsic.
    #[link_name = "llvm.eh.sjlj.callsite"]
    pub fn eh_sjlj_callsite(a: i32) -> ();
    /// The `llvm.eh.sjlj.functioncontext` intrinsic.
    #[link_name = "llvm.eh.sjlj.functioncontext"]
    pub fn eh_sjlj_functioncontext(a: *mut i8) -> ();
    /// The `llvm.eh.sjlj.setjmp` intrinsic.
    #[link_name = "llvm.eh.sjlj.setjmp"]
    pub fn eh_sjlj_setjmp(a: *mut i8) -> i32;
    /// The `llvm.eh.sjlj.longjmp` intrinsic.
    #[link_name = "llvm.eh.sjlj.longjmp"]
    pub fn eh_sjlj_longjmp(a: *mut i8) -> ();
    /// The `llvm.eh.sjlj.setup.dispatch` intrinsic.
    #[link_name = "llvm.eh.sjlj.setup.dispatch"]
    pub fn eh_sjlj_setup_dispatch() -> ();
    /// The `llvm.var.annotation` intrinsic.
    #[link_name = "llvm.var.annotation"]
    pub fn var_annotation(a: *mut i8, b: *mut i8, c: *mut i8, d: i32) -> ();
    /// The `llvm.ptr.annotation.p0v16i8` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0v16i8"]
    pub fn ptr_annotation_p0v16i8(a: *mut ::simdty::i8x16, b: *mut i8, c: *mut i8, d: i32) -> *mut ::simdty::i8x16;
    /// The `llvm.ptr.annotation.p0i8` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0i8"]
    pub fn ptr_annotation_p0i8(a: *mut i8, b: *mut i8, c: *mut i8, d: i32) -> *mut i8;
    /// The `llvm.ptr.annotation.p0v8i16` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0v8i16"]
    pub fn ptr_annotation_p0v8i16(a: *mut ::simdty::i16x8, b: *mut i8, c: *mut i8, d: i32) -> *mut ::simdty::i16x8;
    /// The `llvm.ptr.annotation.p0i16` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0i16"]
    pub fn ptr_annotation_p0i16(a: *mut i16, b: *mut i8, c: *mut i8, d: i32) -> *mut i16;
    /// The `llvm.ptr.annotation.p0v4i32` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0v4i32"]
    pub fn ptr_annotation_p0v4i32(a: *mut ::simdty::i32x4, b: *mut i8, c: *mut i8, d: i32) -> *mut ::simdty::i32x4;
    /// The `llvm.ptr.annotation.p0i32` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0i32"]
    pub fn ptr_annotation_p0i32(a: *mut i32, b: *mut i8, c: *mut i8, d: i32) -> *mut i32;
    /// The `llvm.ptr.annotation.p0v2i64` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0v2i64"]
    pub fn ptr_annotation_p0v2i64(a: *mut ::simdty::i64x2, b: *mut i8, c: *mut i8, d: i32) -> *mut ::simdty::i64x2;
    /// The `llvm.ptr.annotation.p0i64` intrinsic.
    #[link_name = "llvm.ptr.annotation.p0i64"]
    pub fn ptr_annotation_p0i64(a: *mut i64, b: *mut i8, c: *mut i8, d: i32) -> *mut i64;
    /// The `llvm.annotation.v16i8` intrinsic.
    #[link_name = "llvm.annotation.v16i8"]
    pub fn annotation_v16i8(a: ::simdty::i8x16, b: *mut i8, c: *mut i8, d: i32) -> ::simdty::i8x16;
    /// The `llvm.annotation.i8` intrinsic.
    #[link_name = "llvm.annotation.i8"]
    pub fn annotation_i8(a: i8, b: *mut i8, c: *mut i8, d: i32) -> i8;
    /// The `llvm.annotation.v8i16` intrinsic.
    #[link_name = "llvm.annotation.v8i16"]
    pub fn annotation_v8i16(a: ::simdty::i16x8, b: *mut i8, c: *mut i8, d: i32) -> ::simdty::i16x8;
    /// The `llvm.annotation.i16` intrinsic.
    #[link_name = "llvm.annotation.i16"]
    pub fn annotation_i16(a: i16, b: *mut i8, c: *mut i8, d: i32) -> i16;
    /// The `llvm.annotation.v4i32` intrinsic.
    #[link_name = "llvm.annotation.v4i32"]
    pub fn annotation_v4i32(a: ::simdty::i32x4, b: *mut i8, c: *mut i8, d: i32) -> ::simdty::i32x4;
    /// The `llvm.annotation.i32` intrinsic.
    #[link_name = "llvm.annotation.i32"]
    pub fn annotation_i32(a: i32, b: *mut i8, c: *mut i8, d: i32) -> i32;
    /// The `llvm.annotation.v2i64` intrinsic.
    #[link_name = "llvm.annotation.v2i64"]
    pub fn annotation_v2i64(a: ::simdty::i64x2, b: *mut i8, c: *mut i8, d: i32) -> ::simdty::i64x2;
    /// The `llvm.annotation.i64` intrinsic.
    #[link_name = "llvm.annotation.i64"]
    pub fn annotation_i64(a: i64, b: *mut i8, c: *mut i8, d: i32) -> i64;
    /// The `llvm.init.trampoline` intrinsic; known as `__builtin_init_trampoline` in GCC.
    #[link_name = "llvm.init.trampoline"]
    pub fn init_trampoline(a: *mut i8, b: *mut i8, c: *mut i8) -> ();
    /// The `llvm.adjust.trampoline` intrinsic; known as `__builtin_adjust_trampoline` in GCC.
    #[link_name = "llvm.adjust.trampoline"]
    pub fn adjust_trampoline(a: *mut i8) -> *mut i8;
    /// The `llvm.lifetime.start` intrinsic.
    #[link_name = "llvm.lifetime.start"]
    pub fn lifetime_start(a: i64, b: *mut i8) -> ();
    /// The `llvm.lifetime.end` intrinsic.
    #[link_name = "llvm.lifetime.end"]
    pub fn lifetime_end(a: i64, b: *mut i8) -> ();
    /// The `llvm.invariant.group.barrier` intrinsic.
    #[link_name = "llvm.invariant.group.barrier"]
    pub fn invariant_group_barrier(a: *mut i8) -> *mut i8;
    /// The `llvm.experimental.stackmap` intrinsic.
    #[link_name = "llvm.experimental.stackmap"]
    pub fn experimental_stackmap(a: i64, b: i32, ...) -> ();
    /// The `llvm.experimental.patchpoint.void` intrinsic.
    #[link_name = "llvm.experimental.patchpoint.void"]
    pub fn experimental_patchpoint_void(a: i64, b: i32, c: *mut i8, d: i32, ...) -> ();
    /// The `llvm.experimental.patchpoint.i64` intrinsic.
    #[link_name = "llvm.experimental.patchpoint.i64"]
    pub fn experimental_patchpoint_i64(a: i64, b: i32, c: *mut i8, d: i32, ...) -> i64;
    /// The `llvm.flt.rounds` intrinsic; known as `__builtin_flt_rounds` in GCC.
    #[link_name = "llvm.flt.rounds"]
    pub fn flt_rounds() -> i32;
    /// The `llvm.trap` intrinsic; known as `__builtin_trap` in GCC.
    #[link_name = "llvm.trap"]
    pub fn trap() -> ();
    /// The `llvm.debugtrap` intrinsic; known as `__builtin_debugtrap` in GCC.
    #[link_name = "llvm.debugtrap"]
    pub fn debugtrap() -> ();
    /// The `llvm.experimental.guard` intrinsic.
    #[link_name = "llvm.experimental.guard"]
    pub fn experimental_guard(a: bool, ...) -> ();
    /// The `llvm.donothing` intrinsic.
    #[link_name = "llvm.donothing"]
    pub fn donothing() -> ();
    /// The `llvm.convert.to.fp16.v4f32` intrinsic.
    #[link_name = "llvm.convert.to.fp16.v4f32"]
    pub fn convert_to_fp16_v4f32(a: ::simdty::f32x4) -> i16;
    /// The `llvm.convert.to.fp16.f32` intrinsic.
    #[link_name = "llvm.convert.to.fp16.f32"]
    pub fn convert_to_fp16_f32(a: f32) -> i16;
    /// The `llvm.convert.to.fp16.v2f64` intrinsic.
    #[link_name = "llvm.convert.to.fp16.v2f64"]
    pub fn convert_to_fp16_v2f64(a: ::simdty::f64x2) -> i16;
    /// The `llvm.convert.to.fp16.f64` intrinsic.
    #[link_name = "llvm.convert.to.fp16.f64"]
    pub fn convert_to_fp16_f64(a: f64) -> i16;
    /// The `llvm.convert.from.fp16.v4f32` intrinsic.
    #[link_name = "llvm.convert.from.fp16.v4f32"]
    pub fn convert_from_fp16_v4f32(a: i16) -> ::simdty::f32x4;
    /// The `llvm.convert.from.fp16.f32` intrinsic.
    #[link_name = "llvm.convert.from.fp16.f32"]
    pub fn convert_from_fp16_f32(a: i16) -> f32;
    /// The `llvm.convert.from.fp16.v2f64` intrinsic.
    #[link_name = "llvm.convert.from.fp16.v2f64"]
    pub fn convert_from_fp16_v2f64(a: i16) -> ::simdty::f64x2;
    /// The `llvm.convert.from.fp16.f64` intrinsic.
    #[link_name = "llvm.convert.from.fp16.f64"]
    pub fn convert_from_fp16_f64(a: i16) -> f64;
    /// The `llvm.convertff.v4f32.v4f32` intrinsic.
    #[link_name = "llvm.convertff.v4f32.v4f32"]
    pub fn convertff_v4f32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertff.v4f32.f32` intrinsic.
    #[link_name = "llvm.convertff.v4f32.f32"]
    pub fn convertff_v4f32_f32(a: f32, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertff.v4f32.v2f64` intrinsic.
    #[link_name = "llvm.convertff.v4f32.v2f64"]
    pub fn convertff_v4f32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertff.v4f32.f64` intrinsic.
    #[link_name = "llvm.convertff.v4f32.f64"]
    pub fn convertff_v4f32_f64(a: f64, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertff.f32.v4f32` intrinsic.
    #[link_name = "llvm.convertff.f32.v4f32"]
    pub fn convertff_f32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> f32;
    /// The `llvm.convertff.f32.f32` intrinsic.
    #[link_name = "llvm.convertff.f32.f32"]
    pub fn convertff_f32_f32(a: f32, b: i32, c: i32) -> f32;
    /// The `llvm.convertff.f32.v2f64` intrinsic.
    #[link_name = "llvm.convertff.f32.v2f64"]
    pub fn convertff_f32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> f32;
    /// The `llvm.convertff.f32.f64` intrinsic.
    #[link_name = "llvm.convertff.f32.f64"]
    pub fn convertff_f32_f64(a: f64, b: i32, c: i32) -> f32;
    /// The `llvm.convertff.v2f64.v4f32` intrinsic.
    #[link_name = "llvm.convertff.v2f64.v4f32"]
    pub fn convertff_v2f64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertff.v2f64.f32` intrinsic.
    #[link_name = "llvm.convertff.v2f64.f32"]
    pub fn convertff_v2f64_f32(a: f32, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertff.v2f64.v2f64` intrinsic.
    #[link_name = "llvm.convertff.v2f64.v2f64"]
    pub fn convertff_v2f64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertff.v2f64.f64` intrinsic.
    #[link_name = "llvm.convertff.v2f64.f64"]
    pub fn convertff_v2f64_f64(a: f64, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertff.f64.v4f32` intrinsic.
    #[link_name = "llvm.convertff.f64.v4f32"]
    pub fn convertff_f64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> f64;
    /// The `llvm.convertff.f64.f32` intrinsic.
    #[link_name = "llvm.convertff.f64.f32"]
    pub fn convertff_f64_f32(a: f32, b: i32, c: i32) -> f64;
    /// The `llvm.convertff.f64.v2f64` intrinsic.
    #[link_name = "llvm.convertff.f64.v2f64"]
    pub fn convertff_f64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> f64;
    /// The `llvm.convertff.f64.f64` intrinsic.
    #[link_name = "llvm.convertff.f64.f64"]
    pub fn convertff_f64_f64(a: f64, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.v4f32.v16i8` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.v16i8"]
    pub fn convertfsi_v4f32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.i8` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.i8"]
    pub fn convertfsi_v4f32_i8(a: i8, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.v8i16` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.v8i16"]
    pub fn convertfsi_v4f32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.i16` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.i16"]
    pub fn convertfsi_v4f32_i16(a: i16, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.v4i32` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.v4i32"]
    pub fn convertfsi_v4f32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.i32` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.i32"]
    pub fn convertfsi_v4f32_i32(a: i32, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.v2i64` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.v2i64"]
    pub fn convertfsi_v4f32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.v4f32.i64` intrinsic.
    #[link_name = "llvm.convertfsi.v4f32.i64"]
    pub fn convertfsi_v4f32_i64(a: i64, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfsi.f32.v16i8` intrinsic.
    #[link_name = "llvm.convertfsi.f32.v16i8"]
    pub fn convertfsi_f32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.i8` intrinsic.
    #[link_name = "llvm.convertfsi.f32.i8"]
    pub fn convertfsi_f32_i8(a: i8, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.v8i16` intrinsic.
    #[link_name = "llvm.convertfsi.f32.v8i16"]
    pub fn convertfsi_f32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.i16` intrinsic.
    #[link_name = "llvm.convertfsi.f32.i16"]
    pub fn convertfsi_f32_i16(a: i16, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.v4i32` intrinsic.
    #[link_name = "llvm.convertfsi.f32.v4i32"]
    pub fn convertfsi_f32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.i32` intrinsic.
    #[link_name = "llvm.convertfsi.f32.i32"]
    pub fn convertfsi_f32_i32(a: i32, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.v2i64` intrinsic.
    #[link_name = "llvm.convertfsi.f32.v2i64"]
    pub fn convertfsi_f32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.f32.i64` intrinsic.
    #[link_name = "llvm.convertfsi.f32.i64"]
    pub fn convertfsi_f32_i64(a: i64, b: i32, c: i32) -> f32;
    /// The `llvm.convertfsi.v2f64.v16i8` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.v16i8"]
    pub fn convertfsi_v2f64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.i8` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.i8"]
    pub fn convertfsi_v2f64_i8(a: i8, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.v8i16` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.v8i16"]
    pub fn convertfsi_v2f64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.i16` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.i16"]
    pub fn convertfsi_v2f64_i16(a: i16, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.v4i32` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.v4i32"]
    pub fn convertfsi_v2f64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.i32` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.i32"]
    pub fn convertfsi_v2f64_i32(a: i32, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.v2i64` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.v2i64"]
    pub fn convertfsi_v2f64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.v2f64.i64` intrinsic.
    #[link_name = "llvm.convertfsi.v2f64.i64"]
    pub fn convertfsi_v2f64_i64(a: i64, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfsi.f64.v16i8` intrinsic.
    #[link_name = "llvm.convertfsi.f64.v16i8"]
    pub fn convertfsi_f64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.i8` intrinsic.
    #[link_name = "llvm.convertfsi.f64.i8"]
    pub fn convertfsi_f64_i8(a: i8, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.v8i16` intrinsic.
    #[link_name = "llvm.convertfsi.f64.v8i16"]
    pub fn convertfsi_f64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.i16` intrinsic.
    #[link_name = "llvm.convertfsi.f64.i16"]
    pub fn convertfsi_f64_i16(a: i16, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.v4i32` intrinsic.
    #[link_name = "llvm.convertfsi.f64.v4i32"]
    pub fn convertfsi_f64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.i32` intrinsic.
    #[link_name = "llvm.convertfsi.f64.i32"]
    pub fn convertfsi_f64_i32(a: i32, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.v2i64` intrinsic.
    #[link_name = "llvm.convertfsi.f64.v2i64"]
    pub fn convertfsi_f64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> f64;
    /// The `llvm.convertfsi.f64.i64` intrinsic.
    #[link_name = "llvm.convertfsi.f64.i64"]
    pub fn convertfsi_f64_i64(a: i64, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.v4f32.v16i8` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.v16i8"]
    pub fn convertfui_v4f32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.i8` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.i8"]
    pub fn convertfui_v4f32_i8(a: i8, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.v8i16` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.v8i16"]
    pub fn convertfui_v4f32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.i16` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.i16"]
    pub fn convertfui_v4f32_i16(a: i16, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.v4i32` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.v4i32"]
    pub fn convertfui_v4f32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.i32` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.i32"]
    pub fn convertfui_v4f32_i32(a: i32, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.v2i64` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.v2i64"]
    pub fn convertfui_v4f32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.v4f32.i64` intrinsic.
    #[link_name = "llvm.convertfui.v4f32.i64"]
    pub fn convertfui_v4f32_i64(a: i64, b: i32, c: i32) -> ::simdty::f32x4;
    /// The `llvm.convertfui.f32.v16i8` intrinsic.
    #[link_name = "llvm.convertfui.f32.v16i8"]
    pub fn convertfui_f32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.i8` intrinsic.
    #[link_name = "llvm.convertfui.f32.i8"]
    pub fn convertfui_f32_i8(a: i8, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.v8i16` intrinsic.
    #[link_name = "llvm.convertfui.f32.v8i16"]
    pub fn convertfui_f32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.i16` intrinsic.
    #[link_name = "llvm.convertfui.f32.i16"]
    pub fn convertfui_f32_i16(a: i16, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.v4i32` intrinsic.
    #[link_name = "llvm.convertfui.f32.v4i32"]
    pub fn convertfui_f32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.i32` intrinsic.
    #[link_name = "llvm.convertfui.f32.i32"]
    pub fn convertfui_f32_i32(a: i32, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.v2i64` intrinsic.
    #[link_name = "llvm.convertfui.f32.v2i64"]
    pub fn convertfui_f32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.f32.i64` intrinsic.
    #[link_name = "llvm.convertfui.f32.i64"]
    pub fn convertfui_f32_i64(a: i64, b: i32, c: i32) -> f32;
    /// The `llvm.convertfui.v2f64.v16i8` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.v16i8"]
    pub fn convertfui_v2f64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.i8` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.i8"]
    pub fn convertfui_v2f64_i8(a: i8, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.v8i16` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.v8i16"]
    pub fn convertfui_v2f64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.i16` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.i16"]
    pub fn convertfui_v2f64_i16(a: i16, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.v4i32` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.v4i32"]
    pub fn convertfui_v2f64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.i32` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.i32"]
    pub fn convertfui_v2f64_i32(a: i32, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.v2i64` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.v2i64"]
    pub fn convertfui_v2f64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.v2f64.i64` intrinsic.
    #[link_name = "llvm.convertfui.v2f64.i64"]
    pub fn convertfui_v2f64_i64(a: i64, b: i32, c: i32) -> ::simdty::f64x2;
    /// The `llvm.convertfui.f64.v16i8` intrinsic.
    #[link_name = "llvm.convertfui.f64.v16i8"]
    pub fn convertfui_f64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.i8` intrinsic.
    #[link_name = "llvm.convertfui.f64.i8"]
    pub fn convertfui_f64_i8(a: i8, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.v8i16` intrinsic.
    #[link_name = "llvm.convertfui.f64.v8i16"]
    pub fn convertfui_f64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.i16` intrinsic.
    #[link_name = "llvm.convertfui.f64.i16"]
    pub fn convertfui_f64_i16(a: i16, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.v4i32` intrinsic.
    #[link_name = "llvm.convertfui.f64.v4i32"]
    pub fn convertfui_f64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.i32` intrinsic.
    #[link_name = "llvm.convertfui.f64.i32"]
    pub fn convertfui_f64_i32(a: i32, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.v2i64` intrinsic.
    #[link_name = "llvm.convertfui.f64.v2i64"]
    pub fn convertfui_f64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> f64;
    /// The `llvm.convertfui.f64.i64` intrinsic.
    #[link_name = "llvm.convertfui.f64.i64"]
    pub fn convertfui_f64_i64(a: i64, b: i32, c: i32) -> f64;
    /// The `llvm.convertsif.v16i8.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.v16i8.v4f32"]
    pub fn convertsif_v16i8_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsif.v16i8.f32` intrinsic.
    #[link_name = "llvm.convertsif.v16i8.f32"]
    pub fn convertsif_v16i8_f32(a: f32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsif.v16i8.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.v16i8.v2f64"]
    pub fn convertsif_v16i8_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsif.v16i8.f64` intrinsic.
    #[link_name = "llvm.convertsif.v16i8.f64"]
    pub fn convertsif_v16i8_f64(a: f64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsif.i8.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.i8.v4f32"]
    pub fn convertsif_i8_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertsif.i8.f32` intrinsic.
    #[link_name = "llvm.convertsif.i8.f32"]
    pub fn convertsif_i8_f32(a: f32, b: i32, c: i32) -> i8;
    /// The `llvm.convertsif.i8.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.i8.v2f64"]
    pub fn convertsif_i8_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertsif.i8.f64` intrinsic.
    #[link_name = "llvm.convertsif.i8.f64"]
    pub fn convertsif_i8_f64(a: f64, b: i32, c: i32) -> i8;
    /// The `llvm.convertsif.v8i16.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.v8i16.v4f32"]
    pub fn convertsif_v8i16_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsif.v8i16.f32` intrinsic.
    #[link_name = "llvm.convertsif.v8i16.f32"]
    pub fn convertsif_v8i16_f32(a: f32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsif.v8i16.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.v8i16.v2f64"]
    pub fn convertsif_v8i16_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsif.v8i16.f64` intrinsic.
    #[link_name = "llvm.convertsif.v8i16.f64"]
    pub fn convertsif_v8i16_f64(a: f64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsif.i16.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.i16.v4f32"]
    pub fn convertsif_i16_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertsif.i16.f32` intrinsic.
    #[link_name = "llvm.convertsif.i16.f32"]
    pub fn convertsif_i16_f32(a: f32, b: i32, c: i32) -> i16;
    /// The `llvm.convertsif.i16.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.i16.v2f64"]
    pub fn convertsif_i16_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertsif.i16.f64` intrinsic.
    #[link_name = "llvm.convertsif.i16.f64"]
    pub fn convertsif_i16_f64(a: f64, b: i32, c: i32) -> i16;
    /// The `llvm.convertsif.v4i32.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.v4i32.v4f32"]
    pub fn convertsif_v4i32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsif.v4i32.f32` intrinsic.
    #[link_name = "llvm.convertsif.v4i32.f32"]
    pub fn convertsif_v4i32_f32(a: f32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsif.v4i32.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.v4i32.v2f64"]
    pub fn convertsif_v4i32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsif.v4i32.f64` intrinsic.
    #[link_name = "llvm.convertsif.v4i32.f64"]
    pub fn convertsif_v4i32_f64(a: f64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsif.i32.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.i32.v4f32"]
    pub fn convertsif_i32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertsif.i32.f32` intrinsic.
    #[link_name = "llvm.convertsif.i32.f32"]
    pub fn convertsif_i32_f32(a: f32, b: i32, c: i32) -> i32;
    /// The `llvm.convertsif.i32.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.i32.v2f64"]
    pub fn convertsif_i32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertsif.i32.f64` intrinsic.
    #[link_name = "llvm.convertsif.i32.f64"]
    pub fn convertsif_i32_f64(a: f64, b: i32, c: i32) -> i32;
    /// The `llvm.convertsif.v2i64.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.v2i64.v4f32"]
    pub fn convertsif_v2i64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsif.v2i64.f32` intrinsic.
    #[link_name = "llvm.convertsif.v2i64.f32"]
    pub fn convertsif_v2i64_f32(a: f32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsif.v2i64.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.v2i64.v2f64"]
    pub fn convertsif_v2i64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsif.v2i64.f64` intrinsic.
    #[link_name = "llvm.convertsif.v2i64.f64"]
    pub fn convertsif_v2i64_f64(a: f64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsif.i64.v4f32` intrinsic.
    #[link_name = "llvm.convertsif.i64.v4f32"]
    pub fn convertsif_i64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertsif.i64.f32` intrinsic.
    #[link_name = "llvm.convertsif.i64.f32"]
    pub fn convertsif_i64_f32(a: f32, b: i32, c: i32) -> i64;
    /// The `llvm.convertsif.i64.v2f64` intrinsic.
    #[link_name = "llvm.convertsif.i64.v2f64"]
    pub fn convertsif_i64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertsif.i64.f64` intrinsic.
    #[link_name = "llvm.convertsif.i64.f64"]
    pub fn convertsif_i64_f64(a: f64, b: i32, c: i32) -> i64;
    /// The `llvm.convertuif.v16i8.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.v16i8.v4f32"]
    pub fn convertuif_v16i8_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuif.v16i8.f32` intrinsic.
    #[link_name = "llvm.convertuif.v16i8.f32"]
    pub fn convertuif_v16i8_f32(a: f32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuif.v16i8.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.v16i8.v2f64"]
    pub fn convertuif_v16i8_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuif.v16i8.f64` intrinsic.
    #[link_name = "llvm.convertuif.v16i8.f64"]
    pub fn convertuif_v16i8_f64(a: f64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuif.i8.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.i8.v4f32"]
    pub fn convertuif_i8_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertuif.i8.f32` intrinsic.
    #[link_name = "llvm.convertuif.i8.f32"]
    pub fn convertuif_i8_f32(a: f32, b: i32, c: i32) -> i8;
    /// The `llvm.convertuif.i8.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.i8.v2f64"]
    pub fn convertuif_i8_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertuif.i8.f64` intrinsic.
    #[link_name = "llvm.convertuif.i8.f64"]
    pub fn convertuif_i8_f64(a: f64, b: i32, c: i32) -> i8;
    /// The `llvm.convertuif.v8i16.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.v8i16.v4f32"]
    pub fn convertuif_v8i16_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuif.v8i16.f32` intrinsic.
    #[link_name = "llvm.convertuif.v8i16.f32"]
    pub fn convertuif_v8i16_f32(a: f32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuif.v8i16.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.v8i16.v2f64"]
    pub fn convertuif_v8i16_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuif.v8i16.f64` intrinsic.
    #[link_name = "llvm.convertuif.v8i16.f64"]
    pub fn convertuif_v8i16_f64(a: f64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuif.i16.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.i16.v4f32"]
    pub fn convertuif_i16_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertuif.i16.f32` intrinsic.
    #[link_name = "llvm.convertuif.i16.f32"]
    pub fn convertuif_i16_f32(a: f32, b: i32, c: i32) -> i16;
    /// The `llvm.convertuif.i16.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.i16.v2f64"]
    pub fn convertuif_i16_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertuif.i16.f64` intrinsic.
    #[link_name = "llvm.convertuif.i16.f64"]
    pub fn convertuif_i16_f64(a: f64, b: i32, c: i32) -> i16;
    /// The `llvm.convertuif.v4i32.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.v4i32.v4f32"]
    pub fn convertuif_v4i32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuif.v4i32.f32` intrinsic.
    #[link_name = "llvm.convertuif.v4i32.f32"]
    pub fn convertuif_v4i32_f32(a: f32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuif.v4i32.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.v4i32.v2f64"]
    pub fn convertuif_v4i32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuif.v4i32.f64` intrinsic.
    #[link_name = "llvm.convertuif.v4i32.f64"]
    pub fn convertuif_v4i32_f64(a: f64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuif.i32.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.i32.v4f32"]
    pub fn convertuif_i32_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertuif.i32.f32` intrinsic.
    #[link_name = "llvm.convertuif.i32.f32"]
    pub fn convertuif_i32_f32(a: f32, b: i32, c: i32) -> i32;
    /// The `llvm.convertuif.i32.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.i32.v2f64"]
    pub fn convertuif_i32_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertuif.i32.f64` intrinsic.
    #[link_name = "llvm.convertuif.i32.f64"]
    pub fn convertuif_i32_f64(a: f64, b: i32, c: i32) -> i32;
    /// The `llvm.convertuif.v2i64.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.v2i64.v4f32"]
    pub fn convertuif_v2i64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuif.v2i64.f32` intrinsic.
    #[link_name = "llvm.convertuif.v2i64.f32"]
    pub fn convertuif_v2i64_f32(a: f32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuif.v2i64.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.v2i64.v2f64"]
    pub fn convertuif_v2i64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuif.v2i64.f64` intrinsic.
    #[link_name = "llvm.convertuif.v2i64.f64"]
    pub fn convertuif_v2i64_f64(a: f64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuif.i64.v4f32` intrinsic.
    #[link_name = "llvm.convertuif.i64.v4f32"]
    pub fn convertuif_i64_v4f32(a: ::simdty::f32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertuif.i64.f32` intrinsic.
    #[link_name = "llvm.convertuif.i64.f32"]
    pub fn convertuif_i64_f32(a: f32, b: i32, c: i32) -> i64;
    /// The `llvm.convertuif.i64.v2f64` intrinsic.
    #[link_name = "llvm.convertuif.i64.v2f64"]
    pub fn convertuif_i64_v2f64(a: ::simdty::f64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertuif.i64.f64` intrinsic.
    #[link_name = "llvm.convertuif.i64.f64"]
    pub fn convertuif_i64_f64(a: f64, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.v16i8.v16i8` intrinsic.
    #[link_name = "llvm.convertss.v16i8.v16i8"]
    pub fn convertss_v16i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.i8` intrinsic.
    #[link_name = "llvm.convertss.v16i8.i8"]
    pub fn convertss_v16i8_i8(a: i8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.v8i16` intrinsic.
    #[link_name = "llvm.convertss.v16i8.v8i16"]
    pub fn convertss_v16i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.i16` intrinsic.
    #[link_name = "llvm.convertss.v16i8.i16"]
    pub fn convertss_v16i8_i16(a: i16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.v4i32` intrinsic.
    #[link_name = "llvm.convertss.v16i8.v4i32"]
    pub fn convertss_v16i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.i32` intrinsic.
    #[link_name = "llvm.convertss.v16i8.i32"]
    pub fn convertss_v16i8_i32(a: i32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.v2i64` intrinsic.
    #[link_name = "llvm.convertss.v16i8.v2i64"]
    pub fn convertss_v16i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.v16i8.i64` intrinsic.
    #[link_name = "llvm.convertss.v16i8.i64"]
    pub fn convertss_v16i8_i64(a: i64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertss.i8.v16i8` intrinsic.
    #[link_name = "llvm.convertss.i8.v16i8"]
    pub fn convertss_i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.i8` intrinsic.
    #[link_name = "llvm.convertss.i8.i8"]
    pub fn convertss_i8_i8(a: i8, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.v8i16` intrinsic.
    #[link_name = "llvm.convertss.i8.v8i16"]
    pub fn convertss_i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.i16` intrinsic.
    #[link_name = "llvm.convertss.i8.i16"]
    pub fn convertss_i8_i16(a: i16, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.v4i32` intrinsic.
    #[link_name = "llvm.convertss.i8.v4i32"]
    pub fn convertss_i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.i32` intrinsic.
    #[link_name = "llvm.convertss.i8.i32"]
    pub fn convertss_i8_i32(a: i32, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.v2i64` intrinsic.
    #[link_name = "llvm.convertss.i8.v2i64"]
    pub fn convertss_i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.i8.i64` intrinsic.
    #[link_name = "llvm.convertss.i8.i64"]
    pub fn convertss_i8_i64(a: i64, b: i32, c: i32) -> i8;
    /// The `llvm.convertss.v8i16.v16i8` intrinsic.
    #[link_name = "llvm.convertss.v8i16.v16i8"]
    pub fn convertss_v8i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.i8` intrinsic.
    #[link_name = "llvm.convertss.v8i16.i8"]
    pub fn convertss_v8i16_i8(a: i8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.v8i16` intrinsic.
    #[link_name = "llvm.convertss.v8i16.v8i16"]
    pub fn convertss_v8i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.i16` intrinsic.
    #[link_name = "llvm.convertss.v8i16.i16"]
    pub fn convertss_v8i16_i16(a: i16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.v4i32` intrinsic.
    #[link_name = "llvm.convertss.v8i16.v4i32"]
    pub fn convertss_v8i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.i32` intrinsic.
    #[link_name = "llvm.convertss.v8i16.i32"]
    pub fn convertss_v8i16_i32(a: i32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.v2i64` intrinsic.
    #[link_name = "llvm.convertss.v8i16.v2i64"]
    pub fn convertss_v8i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.v8i16.i64` intrinsic.
    #[link_name = "llvm.convertss.v8i16.i64"]
    pub fn convertss_v8i16_i64(a: i64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertss.i16.v16i8` intrinsic.
    #[link_name = "llvm.convertss.i16.v16i8"]
    pub fn convertss_i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.i8` intrinsic.
    #[link_name = "llvm.convertss.i16.i8"]
    pub fn convertss_i16_i8(a: i8, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.v8i16` intrinsic.
    #[link_name = "llvm.convertss.i16.v8i16"]
    pub fn convertss_i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.i16` intrinsic.
    #[link_name = "llvm.convertss.i16.i16"]
    pub fn convertss_i16_i16(a: i16, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.v4i32` intrinsic.
    #[link_name = "llvm.convertss.i16.v4i32"]
    pub fn convertss_i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.i32` intrinsic.
    #[link_name = "llvm.convertss.i16.i32"]
    pub fn convertss_i16_i32(a: i32, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.v2i64` intrinsic.
    #[link_name = "llvm.convertss.i16.v2i64"]
    pub fn convertss_i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.i16.i64` intrinsic.
    #[link_name = "llvm.convertss.i16.i64"]
    pub fn convertss_i16_i64(a: i64, b: i32, c: i32) -> i16;
    /// The `llvm.convertss.v4i32.v16i8` intrinsic.
    #[link_name = "llvm.convertss.v4i32.v16i8"]
    pub fn convertss_v4i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.i8` intrinsic.
    #[link_name = "llvm.convertss.v4i32.i8"]
    pub fn convertss_v4i32_i8(a: i8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.v8i16` intrinsic.
    #[link_name = "llvm.convertss.v4i32.v8i16"]
    pub fn convertss_v4i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.i16` intrinsic.
    #[link_name = "llvm.convertss.v4i32.i16"]
    pub fn convertss_v4i32_i16(a: i16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.v4i32` intrinsic.
    #[link_name = "llvm.convertss.v4i32.v4i32"]
    pub fn convertss_v4i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.i32` intrinsic.
    #[link_name = "llvm.convertss.v4i32.i32"]
    pub fn convertss_v4i32_i32(a: i32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.v2i64` intrinsic.
    #[link_name = "llvm.convertss.v4i32.v2i64"]
    pub fn convertss_v4i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.v4i32.i64` intrinsic.
    #[link_name = "llvm.convertss.v4i32.i64"]
    pub fn convertss_v4i32_i64(a: i64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertss.i32.v16i8` intrinsic.
    #[link_name = "llvm.convertss.i32.v16i8"]
    pub fn convertss_i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.i8` intrinsic.
    #[link_name = "llvm.convertss.i32.i8"]
    pub fn convertss_i32_i8(a: i8, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.v8i16` intrinsic.
    #[link_name = "llvm.convertss.i32.v8i16"]
    pub fn convertss_i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.i16` intrinsic.
    #[link_name = "llvm.convertss.i32.i16"]
    pub fn convertss_i32_i16(a: i16, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.v4i32` intrinsic.
    #[link_name = "llvm.convertss.i32.v4i32"]
    pub fn convertss_i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.i32` intrinsic.
    #[link_name = "llvm.convertss.i32.i32"]
    pub fn convertss_i32_i32(a: i32, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.v2i64` intrinsic.
    #[link_name = "llvm.convertss.i32.v2i64"]
    pub fn convertss_i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.i32.i64` intrinsic.
    #[link_name = "llvm.convertss.i32.i64"]
    pub fn convertss_i32_i64(a: i64, b: i32, c: i32) -> i32;
    /// The `llvm.convertss.v2i64.v16i8` intrinsic.
    #[link_name = "llvm.convertss.v2i64.v16i8"]
    pub fn convertss_v2i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.i8` intrinsic.
    #[link_name = "llvm.convertss.v2i64.i8"]
    pub fn convertss_v2i64_i8(a: i8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.v8i16` intrinsic.
    #[link_name = "llvm.convertss.v2i64.v8i16"]
    pub fn convertss_v2i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.i16` intrinsic.
    #[link_name = "llvm.convertss.v2i64.i16"]
    pub fn convertss_v2i64_i16(a: i16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.v4i32` intrinsic.
    #[link_name = "llvm.convertss.v2i64.v4i32"]
    pub fn convertss_v2i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.i32` intrinsic.
    #[link_name = "llvm.convertss.v2i64.i32"]
    pub fn convertss_v2i64_i32(a: i32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.v2i64` intrinsic.
    #[link_name = "llvm.convertss.v2i64.v2i64"]
    pub fn convertss_v2i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.v2i64.i64` intrinsic.
    #[link_name = "llvm.convertss.v2i64.i64"]
    pub fn convertss_v2i64_i64(a: i64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertss.i64.v16i8` intrinsic.
    #[link_name = "llvm.convertss.i64.v16i8"]
    pub fn convertss_i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.i8` intrinsic.
    #[link_name = "llvm.convertss.i64.i8"]
    pub fn convertss_i64_i8(a: i8, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.v8i16` intrinsic.
    #[link_name = "llvm.convertss.i64.v8i16"]
    pub fn convertss_i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.i16` intrinsic.
    #[link_name = "llvm.convertss.i64.i16"]
    pub fn convertss_i64_i16(a: i16, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.v4i32` intrinsic.
    #[link_name = "llvm.convertss.i64.v4i32"]
    pub fn convertss_i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.i32` intrinsic.
    #[link_name = "llvm.convertss.i64.i32"]
    pub fn convertss_i64_i32(a: i32, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.v2i64` intrinsic.
    #[link_name = "llvm.convertss.i64.v2i64"]
    pub fn convertss_i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertss.i64.i64` intrinsic.
    #[link_name = "llvm.convertss.i64.i64"]
    pub fn convertss_i64_i64(a: i64, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.v16i8.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.v16i8"]
    pub fn convertsu_v16i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.i8` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.i8"]
    pub fn convertsu_v16i8_i8(a: i8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.v8i16"]
    pub fn convertsu_v16i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.i16` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.i16"]
    pub fn convertsu_v16i8_i16(a: i16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.v4i32"]
    pub fn convertsu_v16i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.i32` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.i32"]
    pub fn convertsu_v16i8_i32(a: i32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.v2i64"]
    pub fn convertsu_v16i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.v16i8.i64` intrinsic.
    #[link_name = "llvm.convertsu.v16i8.i64"]
    pub fn convertsu_v16i8_i64(a: i64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertsu.i8.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.i8.v16i8"]
    pub fn convertsu_i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.i8` intrinsic.
    #[link_name = "llvm.convertsu.i8.i8"]
    pub fn convertsu_i8_i8(a: i8, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.i8.v8i16"]
    pub fn convertsu_i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.i16` intrinsic.
    #[link_name = "llvm.convertsu.i8.i16"]
    pub fn convertsu_i8_i16(a: i16, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.i8.v4i32"]
    pub fn convertsu_i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.i32` intrinsic.
    #[link_name = "llvm.convertsu.i8.i32"]
    pub fn convertsu_i8_i32(a: i32, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.i8.v2i64"]
    pub fn convertsu_i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.i8.i64` intrinsic.
    #[link_name = "llvm.convertsu.i8.i64"]
    pub fn convertsu_i8_i64(a: i64, b: i32, c: i32) -> i8;
    /// The `llvm.convertsu.v8i16.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.v16i8"]
    pub fn convertsu_v8i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.i8` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.i8"]
    pub fn convertsu_v8i16_i8(a: i8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.v8i16"]
    pub fn convertsu_v8i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.i16` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.i16"]
    pub fn convertsu_v8i16_i16(a: i16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.v4i32"]
    pub fn convertsu_v8i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.i32` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.i32"]
    pub fn convertsu_v8i16_i32(a: i32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.v2i64"]
    pub fn convertsu_v8i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.v8i16.i64` intrinsic.
    #[link_name = "llvm.convertsu.v8i16.i64"]
    pub fn convertsu_v8i16_i64(a: i64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertsu.i16.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.i16.v16i8"]
    pub fn convertsu_i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.i8` intrinsic.
    #[link_name = "llvm.convertsu.i16.i8"]
    pub fn convertsu_i16_i8(a: i8, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.i16.v8i16"]
    pub fn convertsu_i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.i16` intrinsic.
    #[link_name = "llvm.convertsu.i16.i16"]
    pub fn convertsu_i16_i16(a: i16, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.i16.v4i32"]
    pub fn convertsu_i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.i32` intrinsic.
    #[link_name = "llvm.convertsu.i16.i32"]
    pub fn convertsu_i16_i32(a: i32, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.i16.v2i64"]
    pub fn convertsu_i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.i16.i64` intrinsic.
    #[link_name = "llvm.convertsu.i16.i64"]
    pub fn convertsu_i16_i64(a: i64, b: i32, c: i32) -> i16;
    /// The `llvm.convertsu.v4i32.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.v16i8"]
    pub fn convertsu_v4i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.i8` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.i8"]
    pub fn convertsu_v4i32_i8(a: i8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.v8i16"]
    pub fn convertsu_v4i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.i16` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.i16"]
    pub fn convertsu_v4i32_i16(a: i16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.v4i32"]
    pub fn convertsu_v4i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.i32` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.i32"]
    pub fn convertsu_v4i32_i32(a: i32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.v2i64"]
    pub fn convertsu_v4i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.v4i32.i64` intrinsic.
    #[link_name = "llvm.convertsu.v4i32.i64"]
    pub fn convertsu_v4i32_i64(a: i64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertsu.i32.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.i32.v16i8"]
    pub fn convertsu_i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.i8` intrinsic.
    #[link_name = "llvm.convertsu.i32.i8"]
    pub fn convertsu_i32_i8(a: i8, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.i32.v8i16"]
    pub fn convertsu_i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.i16` intrinsic.
    #[link_name = "llvm.convertsu.i32.i16"]
    pub fn convertsu_i32_i16(a: i16, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.i32.v4i32"]
    pub fn convertsu_i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.i32` intrinsic.
    #[link_name = "llvm.convertsu.i32.i32"]
    pub fn convertsu_i32_i32(a: i32, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.i32.v2i64"]
    pub fn convertsu_i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.i32.i64` intrinsic.
    #[link_name = "llvm.convertsu.i32.i64"]
    pub fn convertsu_i32_i64(a: i64, b: i32, c: i32) -> i32;
    /// The `llvm.convertsu.v2i64.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.v16i8"]
    pub fn convertsu_v2i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.i8` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.i8"]
    pub fn convertsu_v2i64_i8(a: i8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.v8i16"]
    pub fn convertsu_v2i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.i16` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.i16"]
    pub fn convertsu_v2i64_i16(a: i16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.v4i32"]
    pub fn convertsu_v2i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.i32` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.i32"]
    pub fn convertsu_v2i64_i32(a: i32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.v2i64"]
    pub fn convertsu_v2i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.v2i64.i64` intrinsic.
    #[link_name = "llvm.convertsu.v2i64.i64"]
    pub fn convertsu_v2i64_i64(a: i64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertsu.i64.v16i8` intrinsic.
    #[link_name = "llvm.convertsu.i64.v16i8"]
    pub fn convertsu_i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.i8` intrinsic.
    #[link_name = "llvm.convertsu.i64.i8"]
    pub fn convertsu_i64_i8(a: i8, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.v8i16` intrinsic.
    #[link_name = "llvm.convertsu.i64.v8i16"]
    pub fn convertsu_i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.i16` intrinsic.
    #[link_name = "llvm.convertsu.i64.i16"]
    pub fn convertsu_i64_i16(a: i16, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.v4i32` intrinsic.
    #[link_name = "llvm.convertsu.i64.v4i32"]
    pub fn convertsu_i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.i32` intrinsic.
    #[link_name = "llvm.convertsu.i64.i32"]
    pub fn convertsu_i64_i32(a: i32, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.v2i64` intrinsic.
    #[link_name = "llvm.convertsu.i64.v2i64"]
    pub fn convertsu_i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertsu.i64.i64` intrinsic.
    #[link_name = "llvm.convertsu.i64.i64"]
    pub fn convertsu_i64_i64(a: i64, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.v16i8.v16i8` intrinsic.
    #[link_name = "llvm.convertus.v16i8.v16i8"]
    pub fn convertus_v16i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.i8` intrinsic.
    #[link_name = "llvm.convertus.v16i8.i8"]
    pub fn convertus_v16i8_i8(a: i8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.v8i16` intrinsic.
    #[link_name = "llvm.convertus.v16i8.v8i16"]
    pub fn convertus_v16i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.i16` intrinsic.
    #[link_name = "llvm.convertus.v16i8.i16"]
    pub fn convertus_v16i8_i16(a: i16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.v4i32` intrinsic.
    #[link_name = "llvm.convertus.v16i8.v4i32"]
    pub fn convertus_v16i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.i32` intrinsic.
    #[link_name = "llvm.convertus.v16i8.i32"]
    pub fn convertus_v16i8_i32(a: i32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.v2i64` intrinsic.
    #[link_name = "llvm.convertus.v16i8.v2i64"]
    pub fn convertus_v16i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.v16i8.i64` intrinsic.
    #[link_name = "llvm.convertus.v16i8.i64"]
    pub fn convertus_v16i8_i64(a: i64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertus.i8.v16i8` intrinsic.
    #[link_name = "llvm.convertus.i8.v16i8"]
    pub fn convertus_i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.i8` intrinsic.
    #[link_name = "llvm.convertus.i8.i8"]
    pub fn convertus_i8_i8(a: i8, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.v8i16` intrinsic.
    #[link_name = "llvm.convertus.i8.v8i16"]
    pub fn convertus_i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.i16` intrinsic.
    #[link_name = "llvm.convertus.i8.i16"]
    pub fn convertus_i8_i16(a: i16, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.v4i32` intrinsic.
    #[link_name = "llvm.convertus.i8.v4i32"]
    pub fn convertus_i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.i32` intrinsic.
    #[link_name = "llvm.convertus.i8.i32"]
    pub fn convertus_i8_i32(a: i32, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.v2i64` intrinsic.
    #[link_name = "llvm.convertus.i8.v2i64"]
    pub fn convertus_i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.i8.i64` intrinsic.
    #[link_name = "llvm.convertus.i8.i64"]
    pub fn convertus_i8_i64(a: i64, b: i32, c: i32) -> i8;
    /// The `llvm.convertus.v8i16.v16i8` intrinsic.
    #[link_name = "llvm.convertus.v8i16.v16i8"]
    pub fn convertus_v8i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.i8` intrinsic.
    #[link_name = "llvm.convertus.v8i16.i8"]
    pub fn convertus_v8i16_i8(a: i8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.v8i16` intrinsic.
    #[link_name = "llvm.convertus.v8i16.v8i16"]
    pub fn convertus_v8i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.i16` intrinsic.
    #[link_name = "llvm.convertus.v8i16.i16"]
    pub fn convertus_v8i16_i16(a: i16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.v4i32` intrinsic.
    #[link_name = "llvm.convertus.v8i16.v4i32"]
    pub fn convertus_v8i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.i32` intrinsic.
    #[link_name = "llvm.convertus.v8i16.i32"]
    pub fn convertus_v8i16_i32(a: i32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.v2i64` intrinsic.
    #[link_name = "llvm.convertus.v8i16.v2i64"]
    pub fn convertus_v8i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.v8i16.i64` intrinsic.
    #[link_name = "llvm.convertus.v8i16.i64"]
    pub fn convertus_v8i16_i64(a: i64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertus.i16.v16i8` intrinsic.
    #[link_name = "llvm.convertus.i16.v16i8"]
    pub fn convertus_i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.i8` intrinsic.
    #[link_name = "llvm.convertus.i16.i8"]
    pub fn convertus_i16_i8(a: i8, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.v8i16` intrinsic.
    #[link_name = "llvm.convertus.i16.v8i16"]
    pub fn convertus_i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.i16` intrinsic.
    #[link_name = "llvm.convertus.i16.i16"]
    pub fn convertus_i16_i16(a: i16, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.v4i32` intrinsic.
    #[link_name = "llvm.convertus.i16.v4i32"]
    pub fn convertus_i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.i32` intrinsic.
    #[link_name = "llvm.convertus.i16.i32"]
    pub fn convertus_i16_i32(a: i32, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.v2i64` intrinsic.
    #[link_name = "llvm.convertus.i16.v2i64"]
    pub fn convertus_i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.i16.i64` intrinsic.
    #[link_name = "llvm.convertus.i16.i64"]
    pub fn convertus_i16_i64(a: i64, b: i32, c: i32) -> i16;
    /// The `llvm.convertus.v4i32.v16i8` intrinsic.
    #[link_name = "llvm.convertus.v4i32.v16i8"]
    pub fn convertus_v4i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.i8` intrinsic.
    #[link_name = "llvm.convertus.v4i32.i8"]
    pub fn convertus_v4i32_i8(a: i8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.v8i16` intrinsic.
    #[link_name = "llvm.convertus.v4i32.v8i16"]
    pub fn convertus_v4i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.i16` intrinsic.
    #[link_name = "llvm.convertus.v4i32.i16"]
    pub fn convertus_v4i32_i16(a: i16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.v4i32` intrinsic.
    #[link_name = "llvm.convertus.v4i32.v4i32"]
    pub fn convertus_v4i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.i32` intrinsic.
    #[link_name = "llvm.convertus.v4i32.i32"]
    pub fn convertus_v4i32_i32(a: i32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.v2i64` intrinsic.
    #[link_name = "llvm.convertus.v4i32.v2i64"]
    pub fn convertus_v4i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.v4i32.i64` intrinsic.
    #[link_name = "llvm.convertus.v4i32.i64"]
    pub fn convertus_v4i32_i64(a: i64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertus.i32.v16i8` intrinsic.
    #[link_name = "llvm.convertus.i32.v16i8"]
    pub fn convertus_i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.i8` intrinsic.
    #[link_name = "llvm.convertus.i32.i8"]
    pub fn convertus_i32_i8(a: i8, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.v8i16` intrinsic.
    #[link_name = "llvm.convertus.i32.v8i16"]
    pub fn convertus_i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.i16` intrinsic.
    #[link_name = "llvm.convertus.i32.i16"]
    pub fn convertus_i32_i16(a: i16, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.v4i32` intrinsic.
    #[link_name = "llvm.convertus.i32.v4i32"]
    pub fn convertus_i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.i32` intrinsic.
    #[link_name = "llvm.convertus.i32.i32"]
    pub fn convertus_i32_i32(a: i32, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.v2i64` intrinsic.
    #[link_name = "llvm.convertus.i32.v2i64"]
    pub fn convertus_i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.i32.i64` intrinsic.
    #[link_name = "llvm.convertus.i32.i64"]
    pub fn convertus_i32_i64(a: i64, b: i32, c: i32) -> i32;
    /// The `llvm.convertus.v2i64.v16i8` intrinsic.
    #[link_name = "llvm.convertus.v2i64.v16i8"]
    pub fn convertus_v2i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.i8` intrinsic.
    #[link_name = "llvm.convertus.v2i64.i8"]
    pub fn convertus_v2i64_i8(a: i8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.v8i16` intrinsic.
    #[link_name = "llvm.convertus.v2i64.v8i16"]
    pub fn convertus_v2i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.i16` intrinsic.
    #[link_name = "llvm.convertus.v2i64.i16"]
    pub fn convertus_v2i64_i16(a: i16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.v4i32` intrinsic.
    #[link_name = "llvm.convertus.v2i64.v4i32"]
    pub fn convertus_v2i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.i32` intrinsic.
    #[link_name = "llvm.convertus.v2i64.i32"]
    pub fn convertus_v2i64_i32(a: i32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.v2i64` intrinsic.
    #[link_name = "llvm.convertus.v2i64.v2i64"]
    pub fn convertus_v2i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.v2i64.i64` intrinsic.
    #[link_name = "llvm.convertus.v2i64.i64"]
    pub fn convertus_v2i64_i64(a: i64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertus.i64.v16i8` intrinsic.
    #[link_name = "llvm.convertus.i64.v16i8"]
    pub fn convertus_i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.i8` intrinsic.
    #[link_name = "llvm.convertus.i64.i8"]
    pub fn convertus_i64_i8(a: i8, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.v8i16` intrinsic.
    #[link_name = "llvm.convertus.i64.v8i16"]
    pub fn convertus_i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.i16` intrinsic.
    #[link_name = "llvm.convertus.i64.i16"]
    pub fn convertus_i64_i16(a: i16, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.v4i32` intrinsic.
    #[link_name = "llvm.convertus.i64.v4i32"]
    pub fn convertus_i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.i32` intrinsic.
    #[link_name = "llvm.convertus.i64.i32"]
    pub fn convertus_i64_i32(a: i32, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.v2i64` intrinsic.
    #[link_name = "llvm.convertus.i64.v2i64"]
    pub fn convertus_i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertus.i64.i64` intrinsic.
    #[link_name = "llvm.convertus.i64.i64"]
    pub fn convertus_i64_i64(a: i64, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.v16i8.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.v16i8"]
    pub fn convertuu_v16i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.i8` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.i8"]
    pub fn convertuu_v16i8_i8(a: i8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.v8i16"]
    pub fn convertuu_v16i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.i16` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.i16"]
    pub fn convertuu_v16i8_i16(a: i16, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.v4i32"]
    pub fn convertuu_v16i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.i32` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.i32"]
    pub fn convertuu_v16i8_i32(a: i32, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.v2i64"]
    pub fn convertuu_v16i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.v16i8.i64` intrinsic.
    #[link_name = "llvm.convertuu.v16i8.i64"]
    pub fn convertuu_v16i8_i64(a: i64, b: i32, c: i32) -> ::simdty::i8x16;
    /// The `llvm.convertuu.i8.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.i8.v16i8"]
    pub fn convertuu_i8_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.i8` intrinsic.
    #[link_name = "llvm.convertuu.i8.i8"]
    pub fn convertuu_i8_i8(a: i8, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.i8.v8i16"]
    pub fn convertuu_i8_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.i16` intrinsic.
    #[link_name = "llvm.convertuu.i8.i16"]
    pub fn convertuu_i8_i16(a: i16, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.i8.v4i32"]
    pub fn convertuu_i8_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.i32` intrinsic.
    #[link_name = "llvm.convertuu.i8.i32"]
    pub fn convertuu_i8_i32(a: i32, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.i8.v2i64"]
    pub fn convertuu_i8_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.i8.i64` intrinsic.
    #[link_name = "llvm.convertuu.i8.i64"]
    pub fn convertuu_i8_i64(a: i64, b: i32, c: i32) -> i8;
    /// The `llvm.convertuu.v8i16.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.v16i8"]
    pub fn convertuu_v8i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.i8` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.i8"]
    pub fn convertuu_v8i16_i8(a: i8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.v8i16"]
    pub fn convertuu_v8i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.i16` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.i16"]
    pub fn convertuu_v8i16_i16(a: i16, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.v4i32"]
    pub fn convertuu_v8i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.i32` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.i32"]
    pub fn convertuu_v8i16_i32(a: i32, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.v2i64"]
    pub fn convertuu_v8i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.v8i16.i64` intrinsic.
    #[link_name = "llvm.convertuu.v8i16.i64"]
    pub fn convertuu_v8i16_i64(a: i64, b: i32, c: i32) -> ::simdty::i16x8;
    /// The `llvm.convertuu.i16.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.i16.v16i8"]
    pub fn convertuu_i16_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.i8` intrinsic.
    #[link_name = "llvm.convertuu.i16.i8"]
    pub fn convertuu_i16_i8(a: i8, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.i16.v8i16"]
    pub fn convertuu_i16_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.i16` intrinsic.
    #[link_name = "llvm.convertuu.i16.i16"]
    pub fn convertuu_i16_i16(a: i16, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.i16.v4i32"]
    pub fn convertuu_i16_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.i32` intrinsic.
    #[link_name = "llvm.convertuu.i16.i32"]
    pub fn convertuu_i16_i32(a: i32, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.i16.v2i64"]
    pub fn convertuu_i16_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.i16.i64` intrinsic.
    #[link_name = "llvm.convertuu.i16.i64"]
    pub fn convertuu_i16_i64(a: i64, b: i32, c: i32) -> i16;
    /// The `llvm.convertuu.v4i32.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.v16i8"]
    pub fn convertuu_v4i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.i8` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.i8"]
    pub fn convertuu_v4i32_i8(a: i8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.v8i16"]
    pub fn convertuu_v4i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.i16` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.i16"]
    pub fn convertuu_v4i32_i16(a: i16, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.v4i32"]
    pub fn convertuu_v4i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.i32` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.i32"]
    pub fn convertuu_v4i32_i32(a: i32, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.v2i64"]
    pub fn convertuu_v4i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.v4i32.i64` intrinsic.
    #[link_name = "llvm.convertuu.v4i32.i64"]
    pub fn convertuu_v4i32_i64(a: i64, b: i32, c: i32) -> ::simdty::i32x4;
    /// The `llvm.convertuu.i32.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.i32.v16i8"]
    pub fn convertuu_i32_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.i8` intrinsic.
    #[link_name = "llvm.convertuu.i32.i8"]
    pub fn convertuu_i32_i8(a: i8, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.i32.v8i16"]
    pub fn convertuu_i32_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.i16` intrinsic.
    #[link_name = "llvm.convertuu.i32.i16"]
    pub fn convertuu_i32_i16(a: i16, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.i32.v4i32"]
    pub fn convertuu_i32_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.i32` intrinsic.
    #[link_name = "llvm.convertuu.i32.i32"]
    pub fn convertuu_i32_i32(a: i32, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.i32.v2i64"]
    pub fn convertuu_i32_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.i32.i64` intrinsic.
    #[link_name = "llvm.convertuu.i32.i64"]
    pub fn convertuu_i32_i64(a: i64, b: i32, c: i32) -> i32;
    /// The `llvm.convertuu.v2i64.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.v16i8"]
    pub fn convertuu_v2i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.i8` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.i8"]
    pub fn convertuu_v2i64_i8(a: i8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.v8i16"]
    pub fn convertuu_v2i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.i16` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.i16"]
    pub fn convertuu_v2i64_i16(a: i16, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.v4i32"]
    pub fn convertuu_v2i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.i32` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.i32"]
    pub fn convertuu_v2i64_i32(a: i32, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.v2i64"]
    pub fn convertuu_v2i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.v2i64.i64` intrinsic.
    #[link_name = "llvm.convertuu.v2i64.i64"]
    pub fn convertuu_v2i64_i64(a: i64, b: i32, c: i32) -> ::simdty::i64x2;
    /// The `llvm.convertuu.i64.v16i8` intrinsic.
    #[link_name = "llvm.convertuu.i64.v16i8"]
    pub fn convertuu_i64_v16i8(a: ::simdty::i8x16, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.i8` intrinsic.
    #[link_name = "llvm.convertuu.i64.i8"]
    pub fn convertuu_i64_i8(a: i8, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.v8i16` intrinsic.
    #[link_name = "llvm.convertuu.i64.v8i16"]
    pub fn convertuu_i64_v8i16(a: ::simdty::i16x8, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.i16` intrinsic.
    #[link_name = "llvm.convertuu.i64.i16"]
    pub fn convertuu_i64_i16(a: i16, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.v4i32` intrinsic.
    #[link_name = "llvm.convertuu.i64.v4i32"]
    pub fn convertuu_i64_v4i32(a: ::simdty::i32x4, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.i32` intrinsic.
    #[link_name = "llvm.convertuu.i64.i32"]
    pub fn convertuu_i64_i32(a: i32, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.v2i64` intrinsic.
    #[link_name = "llvm.convertuu.i64.v2i64"]
    pub fn convertuu_i64_v2i64(a: ::simdty::i64x2, b: i32, c: i32) -> i64;
    /// The `llvm.convertuu.i64.i64` intrinsic.
    #[link_name = "llvm.convertuu.i64.i64"]
    pub fn convertuu_i64_i64(a: i64, b: i32, c: i32) -> i64;
    /// The `llvm.clear_cache` intrinsic.
    #[link_name = "llvm.clear_cache"]
    pub fn clear_cache(a: *mut i8, b: *mut i8) -> ();
    /// The `llvm.load.relative.v16i8` intrinsic.
    #[link_name = "llvm.load.relative.v16i8"]
    pub fn load_relative_v16i8(a: *mut i8, b: ::simdty::i8x16) -> *mut i8;
    /// The `llvm.load.relative.i8` intrinsic.
    #[link_name = "llvm.load.relative.i8"]
    pub fn load_relative_i8(a: *mut i8, b: i8) -> *mut i8;
    /// The `llvm.load.relative.v8i16` intrinsic.
    #[link_name = "llvm.load.relative.v8i16"]
    pub fn load_relative_v8i16(a: *mut i8, b: ::simdty::i16x8) -> *mut i8;
    /// The `llvm.load.relative.i16` intrinsic.
    #[link_name = "llvm.load.relative.i16"]
    pub fn load_relative_i16(a: *mut i8, b: i16) -> *mut i8;
    /// The `llvm.load.relative.v4i32` intrinsic.
    #[link_name = "llvm.load.relative.v4i32"]
    pub fn load_relative_v4i32(a: *mut i8, b: ::simdty::i32x4) -> *mut i8;
    /// The `llvm.load.relative.i32` intrinsic.
    #[link_name = "llvm.load.relative.i32"]
    pub fn load_relative_i32(a: *mut i8, b: i32) -> *mut i8;
    /// The `llvm.load.relative.v2i64` intrinsic.
    #[link_name = "llvm.load.relative.v2i64"]
    pub fn load_relative_v2i64(a: *mut i8, b: ::simdty::i64x2) -> *mut i8;
    /// The `llvm.load.relative.i64` intrinsic.
    #[link_name = "llvm.load.relative.i64"]
    pub fn load_relative_i64(a: *mut i8, b: i64) -> *mut i8;
    /// The `llvm.wasm.current.memory.v16i8` intrinsic.
    #[link_name = "llvm.wasm.current.memory.v16i8"]
    pub fn wasm_current_memory_v16i8() -> ::simdty::i8x16;
    /// The `llvm.wasm.current.memory.i8` intrinsic.
    #[link_name = "llvm.wasm.current.memory.i8"]
    pub fn wasm_current_memory_i8() -> i8;
    /// The `llvm.wasm.current.memory.v8i16` intrinsic.
    #[link_name = "llvm.wasm.current.memory.v8i16"]
    pub fn wasm_current_memory_v8i16() -> ::simdty::i16x8;
    /// The `llvm.wasm.current.memory.i16` intrinsic.
    #[link_name = "llvm.wasm.current.memory.i16"]
    pub fn wasm_current_memory_i16() -> i16;
    /// The `llvm.wasm.current.memory.v4i32` intrinsic.
    #[link_name = "llvm.wasm.current.memory.v4i32"]
    pub fn wasm_current_memory_v4i32() -> ::simdty::i32x4;
    /// The `llvm.wasm.current.memory.i32` intrinsic.
    #[link_name = "llvm.wasm.current.memory.i32"]
    pub fn wasm_current_memory_i32() -> i32;
    /// The `llvm.wasm.current.memory.v2i64` intrinsic.
    #[link_name = "llvm.wasm.current.memory.v2i64"]
    pub fn wasm_current_memory_v2i64() -> ::simdty::i64x2;
    /// The `llvm.wasm.current.memory.i64` intrinsic.
    #[link_name = "llvm.wasm.current.memory.i64"]
    pub fn wasm_current_memory_i64() -> i64;
    /// The `llvm.wasm.grow.memory.v16i8` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.v16i8"]
    pub fn wasm_grow_memory_v16i8(a: ::simdty::i8x16) -> ();
    /// The `llvm.wasm.grow.memory.i8` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.i8"]
    pub fn wasm_grow_memory_i8(a: i8) -> ();
    /// The `llvm.wasm.grow.memory.v8i16` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.v8i16"]
    pub fn wasm_grow_memory_v8i16(a: ::simdty::i16x8) -> ();
    /// The `llvm.wasm.grow.memory.i16` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.i16"]
    pub fn wasm_grow_memory_i16(a: i16) -> ();
    /// The `llvm.wasm.grow.memory.v4i32` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.v4i32"]
    pub fn wasm_grow_memory_v4i32(a: ::simdty::i32x4) -> ();
    /// The `llvm.wasm.grow.memory.i32` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.i32"]
    pub fn wasm_grow_memory_i32(a: i32) -> ();
    /// The `llvm.wasm.grow.memory.v2i64` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.v2i64"]
    pub fn wasm_grow_memory_v2i64(a: ::simdty::i64x2) -> ();
    /// The `llvm.wasm.grow.memory.i64` intrinsic.
    #[link_name = "llvm.wasm.grow.memory.i64"]
    pub fn wasm_grow_memory_i64(a: i64) -> ();
}
/// LLVM intrinsics for the aarch64 architecture.
pub mod aarch64 {
    extern {
        /// The `llvm.aarch64.ldxr.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.ldxr.p0i8"]
        pub fn ldxr_p0i8(a: *mut i8) -> i64;
        /// The `llvm.aarch64.ldaxr.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.ldaxr.p0i8"]
        pub fn ldaxr_p0i8(a: *mut i8) -> i64;
        /// The `llvm.aarch64.stxr.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.stxr.p0i8"]
        pub fn stxr_p0i8(a: i64, b: *mut i8) -> i32;
        /// The `llvm.aarch64.stlxr.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.stlxr.p0i8"]
        pub fn stlxr_p0i8(a: i64, b: *mut i8) -> i32;
        /// The `llvm.aarch64.stxp` intrinsic.
        #[link_name = "llvm.aarch64.stxp"]
        pub fn stxp(a: i64, b: i64, c: *mut i8) -> i32;
        /// The `llvm.aarch64.stlxp` intrinsic.
        #[link_name = "llvm.aarch64.stlxp"]
        pub fn stlxp(a: i64, b: i64, c: *mut i8) -> i32;
        /// The `llvm.aarch64.clrex` intrinsic.
        #[link_name = "llvm.aarch64.clrex"]
        pub fn clrex() -> ();
        /// The `llvm.aarch64.sdiv.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.v16i8"]
        pub fn sdiv_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.sdiv.i8` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.i8"]
        pub fn sdiv_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.sdiv.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.v8i16"]
        pub fn sdiv_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.sdiv.i16` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.i16"]
        pub fn sdiv_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.sdiv.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.v4i32"]
        pub fn sdiv_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.sdiv.i32` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.i32"]
        pub fn sdiv_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.sdiv.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.v2i64"]
        pub fn sdiv_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.sdiv.i64` intrinsic.
        #[link_name = "llvm.aarch64.sdiv.i64"]
        pub fn sdiv_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.udiv.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.udiv.v16i8"]
        pub fn udiv_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.udiv.i8` intrinsic.
        #[link_name = "llvm.aarch64.udiv.i8"]
        pub fn udiv_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.udiv.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.udiv.v8i16"]
        pub fn udiv_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.udiv.i16` intrinsic.
        #[link_name = "llvm.aarch64.udiv.i16"]
        pub fn udiv_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.udiv.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.udiv.v4i32"]
        pub fn udiv_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.udiv.i32` intrinsic.
        #[link_name = "llvm.aarch64.udiv.i32"]
        pub fn udiv_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.udiv.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.udiv.v2i64"]
        pub fn udiv_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.udiv.i64` intrinsic.
        #[link_name = "llvm.aarch64.udiv.i64"]
        pub fn udiv_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.hint` intrinsic.
        #[link_name = "llvm.aarch64.hint"]
        pub fn hint(a: i32) -> ();
        /// The `llvm.aarch64.rbit.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.rbit.v16i8"]
        pub fn rbit_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.rbit.i8` intrinsic.
        #[link_name = "llvm.aarch64.rbit.i8"]
        pub fn rbit_i8(a: i8) -> i8;
        /// The `llvm.aarch64.rbit.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.rbit.v8i16"]
        pub fn rbit_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.rbit.i16` intrinsic.
        #[link_name = "llvm.aarch64.rbit.i16"]
        pub fn rbit_i16(a: i16) -> i16;
        /// The `llvm.aarch64.rbit.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.rbit.v4i32"]
        pub fn rbit_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.rbit.i32` intrinsic.
        #[link_name = "llvm.aarch64.rbit.i32"]
        pub fn rbit_i32(a: i32) -> i32;
        /// The `llvm.aarch64.rbit.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.rbit.v2i64"]
        pub fn rbit_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.rbit.i64` intrinsic.
        #[link_name = "llvm.aarch64.rbit.i64"]
        pub fn rbit_i64(a: i64) -> i64;
        /// The `llvm.aarch64.dmb` intrinsic; known as `__builtin_arm_dmb` in GCC.
        #[link_name = "llvm.aarch64.dmb"]
        pub fn dmb(a: i32) -> ();
        /// The `llvm.aarch64.dsb` intrinsic; known as `__builtin_arm_dsb` in GCC.
        #[link_name = "llvm.aarch64.dsb"]
        pub fn dsb(a: i32) -> ();
        /// The `llvm.aarch64.isb` intrinsic; known as `__builtin_arm_isb` in GCC.
        #[link_name = "llvm.aarch64.isb"]
        pub fn isb(a: i32) -> ();
        /// The `llvm.aarch64.neon.saddv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v16i8"]
        pub fn neon_saddv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v8i16"]
        pub fn neon_saddv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v4i32"]
        pub fn neon_saddv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v2i64"]
        pub fn neon_saddv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v4f32"]
        pub fn neon_saddv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v16i8.v2f64"]
        pub fn neon_saddv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v16i8"]
        pub fn neon_saddv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.saddv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v8i16"]
        pub fn neon_saddv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.saddv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v4i32"]
        pub fn neon_saddv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.saddv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v2i64"]
        pub fn neon_saddv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.saddv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v4f32"]
        pub fn neon_saddv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.saddv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i8.v2f64"]
        pub fn neon_saddv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v16i8"]
        pub fn neon_saddv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v8i16"]
        pub fn neon_saddv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v4i32"]
        pub fn neon_saddv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v2i64"]
        pub fn neon_saddv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v4f32"]
        pub fn neon_saddv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v8i16.v2f64"]
        pub fn neon_saddv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v16i8"]
        pub fn neon_saddv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.saddv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v8i16"]
        pub fn neon_saddv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.saddv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v4i32"]
        pub fn neon_saddv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.saddv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v2i64"]
        pub fn neon_saddv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.saddv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v4f32"]
        pub fn neon_saddv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.saddv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i16.v2f64"]
        pub fn neon_saddv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.saddv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v16i8"]
        pub fn neon_saddv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v8i16"]
        pub fn neon_saddv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v4i32"]
        pub fn neon_saddv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v2i64"]
        pub fn neon_saddv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v4f32"]
        pub fn neon_saddv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v4i32.v2f64"]
        pub fn neon_saddv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v16i8"]
        pub fn neon_saddv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.saddv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v8i16"]
        pub fn neon_saddv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.saddv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v4i32"]
        pub fn neon_saddv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.saddv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v2i64"]
        pub fn neon_saddv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.saddv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v4f32"]
        pub fn neon_saddv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.saddv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i32.v2f64"]
        pub fn neon_saddv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.saddv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v16i8"]
        pub fn neon_saddv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v8i16"]
        pub fn neon_saddv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v4i32"]
        pub fn neon_saddv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v2i64"]
        pub fn neon_saddv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v4f32"]
        pub fn neon_saddv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.v2i64.v2f64"]
        pub fn neon_saddv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v16i8"]
        pub fn neon_saddv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.saddv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v8i16"]
        pub fn neon_saddv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.saddv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v4i32"]
        pub fn neon_saddv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.saddv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v2i64"]
        pub fn neon_saddv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.saddv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v4f32"]
        pub fn neon_saddv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.saddv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddv.i64.v2f64"]
        pub fn neon_saddv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v16i8"]
        pub fn neon_uaddv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v8i16"]
        pub fn neon_uaddv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v4i32"]
        pub fn neon_uaddv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v2i64"]
        pub fn neon_uaddv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v4f32"]
        pub fn neon_uaddv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v16i8.v2f64"]
        pub fn neon_uaddv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v16i8"]
        pub fn neon_uaddv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.uaddv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v8i16"]
        pub fn neon_uaddv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.uaddv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v4i32"]
        pub fn neon_uaddv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.uaddv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v2i64"]
        pub fn neon_uaddv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.uaddv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v4f32"]
        pub fn neon_uaddv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.uaddv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i8.v2f64"]
        pub fn neon_uaddv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v16i8"]
        pub fn neon_uaddv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v8i16"]
        pub fn neon_uaddv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v4i32"]
        pub fn neon_uaddv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v2i64"]
        pub fn neon_uaddv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v4f32"]
        pub fn neon_uaddv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v8i16.v2f64"]
        pub fn neon_uaddv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v16i8"]
        pub fn neon_uaddv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.uaddv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v8i16"]
        pub fn neon_uaddv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.uaddv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v4i32"]
        pub fn neon_uaddv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.uaddv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v2i64"]
        pub fn neon_uaddv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.uaddv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v4f32"]
        pub fn neon_uaddv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.uaddv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i16.v2f64"]
        pub fn neon_uaddv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v16i8"]
        pub fn neon_uaddv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v8i16"]
        pub fn neon_uaddv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v4i32"]
        pub fn neon_uaddv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v2i64"]
        pub fn neon_uaddv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v4f32"]
        pub fn neon_uaddv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v4i32.v2f64"]
        pub fn neon_uaddv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v16i8"]
        pub fn neon_uaddv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.uaddv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v8i16"]
        pub fn neon_uaddv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.uaddv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v4i32"]
        pub fn neon_uaddv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.uaddv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v2i64"]
        pub fn neon_uaddv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.uaddv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v4f32"]
        pub fn neon_uaddv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.uaddv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i32.v2f64"]
        pub fn neon_uaddv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v16i8"]
        pub fn neon_uaddv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v8i16"]
        pub fn neon_uaddv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v4i32"]
        pub fn neon_uaddv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v2i64"]
        pub fn neon_uaddv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v4f32"]
        pub fn neon_uaddv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.v2i64.v2f64"]
        pub fn neon_uaddv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v16i8"]
        pub fn neon_uaddv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.uaddv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v8i16"]
        pub fn neon_uaddv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.uaddv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v4i32"]
        pub fn neon_uaddv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.uaddv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v2i64"]
        pub fn neon_uaddv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.uaddv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v4f32"]
        pub fn neon_uaddv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.uaddv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddv.i64.v2f64"]
        pub fn neon_uaddv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.faddv.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v16i8"]
        pub fn neon_faddv_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v8i16"]
        pub fn neon_faddv_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v4i32"]
        pub fn neon_faddv_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v2i64"]
        pub fn neon_faddv_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v4f32"]
        pub fn neon_faddv_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v4f32.v2f64"]
        pub fn neon_faddv_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.faddv.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v16i8"]
        pub fn neon_faddv_f32_v16i8(a: ::simdty::i8x16) -> f32;
        /// The `llvm.aarch64.neon.faddv.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v8i16"]
        pub fn neon_faddv_f32_v8i16(a: ::simdty::i16x8) -> f32;
        /// The `llvm.aarch64.neon.faddv.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v4i32"]
        pub fn neon_faddv_f32_v4i32(a: ::simdty::i32x4) -> f32;
        /// The `llvm.aarch64.neon.faddv.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v2i64"]
        pub fn neon_faddv_f32_v2i64(a: ::simdty::i64x2) -> f32;
        /// The `llvm.aarch64.neon.faddv.f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v4f32"]
        pub fn neon_faddv_f32_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.aarch64.neon.faddv.f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f32.v2f64"]
        pub fn neon_faddv_f32_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.aarch64.neon.faddv.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v16i8"]
        pub fn neon_faddv_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v8i16"]
        pub fn neon_faddv_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v4i32"]
        pub fn neon_faddv_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v2i64"]
        pub fn neon_faddv_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v4f32"]
        pub fn neon_faddv_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.v2f64.v2f64"]
        pub fn neon_faddv_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.faddv.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v16i8"]
        pub fn neon_faddv_f64_v16i8(a: ::simdty::i8x16) -> f64;
        /// The `llvm.aarch64.neon.faddv.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v8i16"]
        pub fn neon_faddv_f64_v8i16(a: ::simdty::i16x8) -> f64;
        /// The `llvm.aarch64.neon.faddv.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v4i32"]
        pub fn neon_faddv_f64_v4i32(a: ::simdty::i32x4) -> f64;
        /// The `llvm.aarch64.neon.faddv.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v2i64"]
        pub fn neon_faddv_f64_v2i64(a: ::simdty::i64x2) -> f64;
        /// The `llvm.aarch64.neon.faddv.f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v4f32"]
        pub fn neon_faddv_f64_v4f32(a: ::simdty::f32x4) -> f64;
        /// The `llvm.aarch64.neon.faddv.f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.faddv.f64.v2f64"]
        pub fn neon_faddv_f64_v2f64(a: ::simdty::f64x2) -> f64;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v16i8"]
        pub fn neon_saddlv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v8i16"]
        pub fn neon_saddlv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v4i32"]
        pub fn neon_saddlv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v2i64"]
        pub fn neon_saddlv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v4f32"]
        pub fn neon_saddlv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v16i8.v2f64"]
        pub fn neon_saddlv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v16i8"]
        pub fn neon_saddlv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.saddlv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v8i16"]
        pub fn neon_saddlv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.saddlv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v4i32"]
        pub fn neon_saddlv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.saddlv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v2i64"]
        pub fn neon_saddlv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.saddlv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v4f32"]
        pub fn neon_saddlv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.saddlv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i8.v2f64"]
        pub fn neon_saddlv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v16i8"]
        pub fn neon_saddlv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v8i16"]
        pub fn neon_saddlv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v4i32"]
        pub fn neon_saddlv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v2i64"]
        pub fn neon_saddlv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v4f32"]
        pub fn neon_saddlv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v8i16.v2f64"]
        pub fn neon_saddlv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v16i8"]
        pub fn neon_saddlv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.saddlv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v8i16"]
        pub fn neon_saddlv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.saddlv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v4i32"]
        pub fn neon_saddlv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.saddlv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v2i64"]
        pub fn neon_saddlv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.saddlv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v4f32"]
        pub fn neon_saddlv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.saddlv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i16.v2f64"]
        pub fn neon_saddlv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v16i8"]
        pub fn neon_saddlv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v8i16"]
        pub fn neon_saddlv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v4i32"]
        pub fn neon_saddlv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v2i64"]
        pub fn neon_saddlv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v4f32"]
        pub fn neon_saddlv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v4i32.v2f64"]
        pub fn neon_saddlv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v16i8"]
        pub fn neon_saddlv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.saddlv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v8i16"]
        pub fn neon_saddlv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.saddlv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v4i32"]
        pub fn neon_saddlv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.saddlv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v2i64"]
        pub fn neon_saddlv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.saddlv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v4f32"]
        pub fn neon_saddlv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.saddlv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i32.v2f64"]
        pub fn neon_saddlv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v16i8"]
        pub fn neon_saddlv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v8i16"]
        pub fn neon_saddlv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v4i32"]
        pub fn neon_saddlv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v2i64"]
        pub fn neon_saddlv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v4f32"]
        pub fn neon_saddlv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.v2i64.v2f64"]
        pub fn neon_saddlv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v16i8"]
        pub fn neon_saddlv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.saddlv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v8i16"]
        pub fn neon_saddlv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.saddlv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v4i32"]
        pub fn neon_saddlv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.saddlv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v2i64"]
        pub fn neon_saddlv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.saddlv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v4f32"]
        pub fn neon_saddlv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.saddlv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlv.i64.v2f64"]
        pub fn neon_saddlv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v16i8"]
        pub fn neon_uaddlv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v8i16"]
        pub fn neon_uaddlv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v4i32"]
        pub fn neon_uaddlv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v2i64"]
        pub fn neon_uaddlv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v4f32"]
        pub fn neon_uaddlv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v16i8.v2f64"]
        pub fn neon_uaddlv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v16i8"]
        pub fn neon_uaddlv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v8i16"]
        pub fn neon_uaddlv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v4i32"]
        pub fn neon_uaddlv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v2i64"]
        pub fn neon_uaddlv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v4f32"]
        pub fn neon_uaddlv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i8.v2f64"]
        pub fn neon_uaddlv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v16i8"]
        pub fn neon_uaddlv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v8i16"]
        pub fn neon_uaddlv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v4i32"]
        pub fn neon_uaddlv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v2i64"]
        pub fn neon_uaddlv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v4f32"]
        pub fn neon_uaddlv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v8i16.v2f64"]
        pub fn neon_uaddlv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v16i8"]
        pub fn neon_uaddlv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v8i16"]
        pub fn neon_uaddlv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v4i32"]
        pub fn neon_uaddlv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v2i64"]
        pub fn neon_uaddlv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v4f32"]
        pub fn neon_uaddlv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i16.v2f64"]
        pub fn neon_uaddlv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v16i8"]
        pub fn neon_uaddlv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v8i16"]
        pub fn neon_uaddlv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v4i32"]
        pub fn neon_uaddlv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v2i64"]
        pub fn neon_uaddlv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v4f32"]
        pub fn neon_uaddlv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v4i32.v2f64"]
        pub fn neon_uaddlv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v16i8"]
        pub fn neon_uaddlv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v8i16"]
        pub fn neon_uaddlv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v4i32"]
        pub fn neon_uaddlv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v2i64"]
        pub fn neon_uaddlv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v4f32"]
        pub fn neon_uaddlv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i32.v2f64"]
        pub fn neon_uaddlv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v16i8"]
        pub fn neon_uaddlv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v8i16"]
        pub fn neon_uaddlv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v4i32"]
        pub fn neon_uaddlv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v2i64"]
        pub fn neon_uaddlv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v4f32"]
        pub fn neon_uaddlv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.v2i64.v2f64"]
        pub fn neon_uaddlv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v16i8"]
        pub fn neon_uaddlv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v8i16"]
        pub fn neon_uaddlv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v4i32"]
        pub fn neon_uaddlv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v2i64"]
        pub fn neon_uaddlv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v4f32"]
        pub fn neon_uaddlv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.uaddlv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlv.i64.v2f64"]
        pub fn neon_uaddlv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.shadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v16i8"]
        pub fn neon_shadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.shadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v8i16"]
        pub fn neon_shadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.shadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v4i32"]
        pub fn neon_shadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.shadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v2i64"]
        pub fn neon_shadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.shadd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v4f32"]
        pub fn neon_shadd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.shadd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.shadd.v2f64"]
        pub fn neon_shadd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uhadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v16i8"]
        pub fn neon_uhadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uhadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v8i16"]
        pub fn neon_uhadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uhadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v4i32"]
        pub fn neon_uhadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uhadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v2i64"]
        pub fn neon_uhadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uhadd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v4f32"]
        pub fn neon_uhadd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uhadd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhadd.v2f64"]
        pub fn neon_uhadd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.srhadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v16i8"]
        pub fn neon_srhadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.srhadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v8i16"]
        pub fn neon_srhadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.srhadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v4i32"]
        pub fn neon_srhadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.srhadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v2i64"]
        pub fn neon_srhadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.srhadd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v4f32"]
        pub fn neon_srhadd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.srhadd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.srhadd.v2f64"]
        pub fn neon_srhadd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.urhadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v16i8"]
        pub fn neon_urhadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.urhadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v8i16"]
        pub fn neon_urhadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.urhadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v4i32"]
        pub fn neon_urhadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.urhadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v2i64"]
        pub fn neon_urhadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.urhadd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v4f32"]
        pub fn neon_urhadd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.urhadd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urhadd.v2f64"]
        pub fn neon_urhadd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.sqadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.v16i8"]
        pub fn neon_sqadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqadd.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.i8"]
        pub fn neon_sqadd_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.v8i16"]
        pub fn neon_sqadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqadd.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.i16"]
        pub fn neon_sqadd_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.v4i32"]
        pub fn neon_sqadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqadd.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.i32"]
        pub fn neon_sqadd_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.v2i64"]
        pub fn neon_sqadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqadd.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqadd.i64"]
        pub fn neon_sqadd_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.suqadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.v16i8"]
        pub fn neon_suqadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.suqadd.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.i8"]
        pub fn neon_suqadd_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.suqadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.v8i16"]
        pub fn neon_suqadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.suqadd.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.i16"]
        pub fn neon_suqadd_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.suqadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.v4i32"]
        pub fn neon_suqadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.suqadd.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.i32"]
        pub fn neon_suqadd_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.suqadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.v2i64"]
        pub fn neon_suqadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.suqadd.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.suqadd.i64"]
        pub fn neon_suqadd_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.usqadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.v16i8"]
        pub fn neon_usqadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.usqadd.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.i8"]
        pub fn neon_usqadd_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.usqadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.v8i16"]
        pub fn neon_usqadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.usqadd.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.i16"]
        pub fn neon_usqadd_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.usqadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.v4i32"]
        pub fn neon_usqadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.usqadd.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.i32"]
        pub fn neon_usqadd_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.usqadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.v2i64"]
        pub fn neon_usqadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.usqadd.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.usqadd.i64"]
        pub fn neon_usqadd_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.uqadd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.v16i8"]
        pub fn neon_uqadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uqadd.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.i8"]
        pub fn neon_uqadd_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.uqadd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.v8i16"]
        pub fn neon_uqadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uqadd.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.i16"]
        pub fn neon_uqadd_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.uqadd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.v4i32"]
        pub fn neon_uqadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uqadd.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.i32"]
        pub fn neon_uqadd_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.uqadd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.v2i64"]
        pub fn neon_uqadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uqadd.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqadd.i64"]
        pub fn neon_uqadd_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.sqdmulh.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.v16i8"]
        pub fn neon_sqdmulh_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqdmulh.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.i8"]
        pub fn neon_sqdmulh_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqdmulh.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.v8i16"]
        pub fn neon_sqdmulh_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqdmulh.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.i16"]
        pub fn neon_sqdmulh_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqdmulh.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.v4i32"]
        pub fn neon_sqdmulh_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqdmulh.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.i32"]
        pub fn neon_sqdmulh_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqdmulh.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.v2i64"]
        pub fn neon_sqdmulh_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqdmulh.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulh.i64"]
        pub fn neon_sqdmulh_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.sqrdmulh.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.v16i8"]
        pub fn neon_sqrdmulh_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqrdmulh.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.i8"]
        pub fn neon_sqrdmulh_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqrdmulh.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.v8i16"]
        pub fn neon_sqrdmulh_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqrdmulh.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.i16"]
        pub fn neon_sqrdmulh_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqrdmulh.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.v4i32"]
        pub fn neon_sqrdmulh_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqrdmulh.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.i32"]
        pub fn neon_sqrdmulh_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqrdmulh.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.v2i64"]
        pub fn neon_sqrdmulh_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqrdmulh.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrdmulh.i64"]
        pub fn neon_sqrdmulh_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.pmul.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v16i8"]
        pub fn neon_pmul_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.pmul.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v8i16"]
        pub fn neon_pmul_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.pmul.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v4i32"]
        pub fn neon_pmul_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.pmul.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v2i64"]
        pub fn neon_pmul_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.pmul.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v4f32"]
        pub fn neon_pmul_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.pmul.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmul.v2f64"]
        pub fn neon_pmul_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.pmull64` intrinsic.
        #[link_name = "llvm.aarch64.neon.pmull64"]
        pub fn neon_pmull64(a: i64, b: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fmulx.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmulx.v4f32"]
        pub fn neon_fmulx_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmulx.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmulx.f32"]
        pub fn neon_fmulx_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.neon.fmulx.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmulx.v2f64"]
        pub fn neon_fmulx_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmulx.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmulx.f64"]
        pub fn neon_fmulx_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.sqdmulls.scalar` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqdmulls.scalar"]
        pub fn neon_sqdmulls_scalar(a: i32, b: i32) -> i64;
        /// The `llvm.aarch64.neon.shsub.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v16i8"]
        pub fn neon_shsub_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.shsub.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v8i16"]
        pub fn neon_shsub_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.shsub.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v4i32"]
        pub fn neon_shsub_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.shsub.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v2i64"]
        pub fn neon_shsub_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.shsub.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v4f32"]
        pub fn neon_shsub_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.shsub.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.shsub.v2f64"]
        pub fn neon_shsub_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uhsub.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v16i8"]
        pub fn neon_uhsub_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uhsub.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v8i16"]
        pub fn neon_uhsub_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uhsub.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v4i32"]
        pub fn neon_uhsub_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uhsub.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v2i64"]
        pub fn neon_uhsub_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uhsub.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v4f32"]
        pub fn neon_uhsub_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uhsub.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uhsub.v2f64"]
        pub fn neon_uhsub_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.sqsub.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.v16i8"]
        pub fn neon_sqsub_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqsub.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.i8"]
        pub fn neon_sqsub_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqsub.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.v8i16"]
        pub fn neon_sqsub_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqsub.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.i16"]
        pub fn neon_sqsub_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqsub.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.v4i32"]
        pub fn neon_sqsub_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqsub.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.i32"]
        pub fn neon_sqsub_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqsub.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.v2i64"]
        pub fn neon_sqsub_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqsub.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqsub.i64"]
        pub fn neon_sqsub_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.uqsub.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.v16i8"]
        pub fn neon_uqsub_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uqsub.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.i8"]
        pub fn neon_uqsub_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.uqsub.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.v8i16"]
        pub fn neon_uqsub_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uqsub.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.i16"]
        pub fn neon_uqsub_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.uqsub.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.v4i32"]
        pub fn neon_uqsub_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uqsub.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.i32"]
        pub fn neon_uqsub_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.uqsub.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.v2i64"]
        pub fn neon_uqsub_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uqsub.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqsub.i64"]
        pub fn neon_uqsub_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.facge.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v16i8.v4f32"]
        pub fn neon_facge_v16i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facge.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v16i8.f32"]
        pub fn neon_facge_v16i8_f32(a: f32, b: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facge.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v16i8.v2f64"]
        pub fn neon_facge_v16i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facge.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v16i8.f64"]
        pub fn neon_facge_v16i8_f64(a: f64, b: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facge.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i8.v4f32"]
        pub fn neon_facge_i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.facge.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i8.f32"]
        pub fn neon_facge_i8_f32(a: f32, b: f32) -> i8;
        /// The `llvm.aarch64.neon.facge.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i8.v2f64"]
        pub fn neon_facge_i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.facge.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i8.f64"]
        pub fn neon_facge_i8_f64(a: f64, b: f64) -> i8;
        /// The `llvm.aarch64.neon.facge.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v8i16.v4f32"]
        pub fn neon_facge_v8i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facge.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v8i16.f32"]
        pub fn neon_facge_v8i16_f32(a: f32, b: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facge.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v8i16.v2f64"]
        pub fn neon_facge_v8i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facge.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v8i16.f64"]
        pub fn neon_facge_v8i16_f64(a: f64, b: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facge.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i16.v4f32"]
        pub fn neon_facge_i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.facge.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i16.f32"]
        pub fn neon_facge_i16_f32(a: f32, b: f32) -> i16;
        /// The `llvm.aarch64.neon.facge.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i16.v2f64"]
        pub fn neon_facge_i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.facge.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i16.f64"]
        pub fn neon_facge_i16_f64(a: f64, b: f64) -> i16;
        /// The `llvm.aarch64.neon.facge.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v4i32.v4f32"]
        pub fn neon_facge_v4i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facge.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v4i32.f32"]
        pub fn neon_facge_v4i32_f32(a: f32, b: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facge.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v4i32.v2f64"]
        pub fn neon_facge_v4i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facge.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v4i32.f64"]
        pub fn neon_facge_v4i32_f64(a: f64, b: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facge.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i32.v4f32"]
        pub fn neon_facge_i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.facge.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i32.f32"]
        pub fn neon_facge_i32_f32(a: f32, b: f32) -> i32;
        /// The `llvm.aarch64.neon.facge.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i32.v2f64"]
        pub fn neon_facge_i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.facge.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i32.f64"]
        pub fn neon_facge_i32_f64(a: f64, b: f64) -> i32;
        /// The `llvm.aarch64.neon.facge.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v2i64.v4f32"]
        pub fn neon_facge_v2i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facge.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v2i64.f32"]
        pub fn neon_facge_v2i64_f32(a: f32, b: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facge.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v2i64.v2f64"]
        pub fn neon_facge_v2i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facge.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.v2i64.f64"]
        pub fn neon_facge_v2i64_f64(a: f64, b: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facge.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i64.v4f32"]
        pub fn neon_facge_i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.facge.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i64.f32"]
        pub fn neon_facge_i64_f32(a: f32, b: f32) -> i64;
        /// The `llvm.aarch64.neon.facge.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i64.v2f64"]
        pub fn neon_facge_i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.facge.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facge.i64.f64"]
        pub fn neon_facge_i64_f64(a: f64, b: f64) -> i64;
        /// The `llvm.aarch64.neon.facgt.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v16i8.v4f32"]
        pub fn neon_facgt_v16i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facgt.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v16i8.f32"]
        pub fn neon_facgt_v16i8_f32(a: f32, b: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facgt.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v16i8.v2f64"]
        pub fn neon_facgt_v16i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facgt.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v16i8.f64"]
        pub fn neon_facgt_v16i8_f64(a: f64, b: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.facgt.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i8.v4f32"]
        pub fn neon_facgt_i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.facgt.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i8.f32"]
        pub fn neon_facgt_i8_f32(a: f32, b: f32) -> i8;
        /// The `llvm.aarch64.neon.facgt.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i8.v2f64"]
        pub fn neon_facgt_i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.facgt.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i8.f64"]
        pub fn neon_facgt_i8_f64(a: f64, b: f64) -> i8;
        /// The `llvm.aarch64.neon.facgt.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v8i16.v4f32"]
        pub fn neon_facgt_v8i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facgt.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v8i16.f32"]
        pub fn neon_facgt_v8i16_f32(a: f32, b: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facgt.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v8i16.v2f64"]
        pub fn neon_facgt_v8i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facgt.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v8i16.f64"]
        pub fn neon_facgt_v8i16_f64(a: f64, b: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.facgt.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i16.v4f32"]
        pub fn neon_facgt_i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.facgt.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i16.f32"]
        pub fn neon_facgt_i16_f32(a: f32, b: f32) -> i16;
        /// The `llvm.aarch64.neon.facgt.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i16.v2f64"]
        pub fn neon_facgt_i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.facgt.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i16.f64"]
        pub fn neon_facgt_i16_f64(a: f64, b: f64) -> i16;
        /// The `llvm.aarch64.neon.facgt.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v4i32.v4f32"]
        pub fn neon_facgt_v4i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facgt.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v4i32.f32"]
        pub fn neon_facgt_v4i32_f32(a: f32, b: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facgt.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v4i32.v2f64"]
        pub fn neon_facgt_v4i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facgt.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v4i32.f64"]
        pub fn neon_facgt_v4i32_f64(a: f64, b: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.facgt.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i32.v4f32"]
        pub fn neon_facgt_i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.facgt.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i32.f32"]
        pub fn neon_facgt_i32_f32(a: f32, b: f32) -> i32;
        /// The `llvm.aarch64.neon.facgt.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i32.v2f64"]
        pub fn neon_facgt_i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.facgt.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i32.f64"]
        pub fn neon_facgt_i32_f64(a: f64, b: f64) -> i32;
        /// The `llvm.aarch64.neon.facgt.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v2i64.v4f32"]
        pub fn neon_facgt_v2i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facgt.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v2i64.f32"]
        pub fn neon_facgt_v2i64_f32(a: f32, b: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facgt.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v2i64.v2f64"]
        pub fn neon_facgt_v2i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facgt.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.v2i64.f64"]
        pub fn neon_facgt_v2i64_f64(a: f64, b: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.facgt.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i64.v4f32"]
        pub fn neon_facgt_i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.facgt.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i64.f32"]
        pub fn neon_facgt_i64_f32(a: f32, b: f32) -> i64;
        /// The `llvm.aarch64.neon.facgt.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i64.v2f64"]
        pub fn neon_facgt_i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.facgt.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.facgt.i64.f64"]
        pub fn neon_facgt_i64_f64(a: f64, b: f64) -> i64;
        /// The `llvm.aarch64.neon.sabd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v16i8"]
        pub fn neon_sabd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sabd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v8i16"]
        pub fn neon_sabd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sabd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v4i32"]
        pub fn neon_sabd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sabd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v2i64"]
        pub fn neon_sabd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sabd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v4f32"]
        pub fn neon_sabd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.sabd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sabd.v2f64"]
        pub fn neon_sabd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uabd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v16i8"]
        pub fn neon_uabd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uabd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v8i16"]
        pub fn neon_uabd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uabd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v4i32"]
        pub fn neon_uabd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uabd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v2i64"]
        pub fn neon_uabd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uabd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v4f32"]
        pub fn neon_uabd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uabd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uabd.v2f64"]
        pub fn neon_uabd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fabd.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v16i8"]
        pub fn neon_fabd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fabd.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v8i16"]
        pub fn neon_fabd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fabd.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v4i32"]
        pub fn neon_fabd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fabd.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v2i64"]
        pub fn neon_fabd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fabd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v4f32"]
        pub fn neon_fabd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fabd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fabd.v2f64"]
        pub fn neon_fabd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.sisd.fabd.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.sisd.fabd.v4f32"]
        pub fn sisd_fabd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.sisd.fabd.f32` intrinsic.
        #[link_name = "llvm.aarch64.sisd.fabd.f32"]
        pub fn sisd_fabd_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.sisd.fabd.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.sisd.fabd.v2f64"]
        pub fn sisd_fabd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.sisd.fabd.f64` intrinsic.
        #[link_name = "llvm.aarch64.sisd.fabd.f64"]
        pub fn sisd_fabd_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.smax.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v16i8"]
        pub fn neon_smax_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smax.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v8i16"]
        pub fn neon_smax_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smax.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v4i32"]
        pub fn neon_smax_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smax.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v2i64"]
        pub fn neon_smax_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smax.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v4f32"]
        pub fn neon_smax_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.smax.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smax.v2f64"]
        pub fn neon_smax_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.umax.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v16i8"]
        pub fn neon_umax_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umax.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v8i16"]
        pub fn neon_umax_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umax.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v4i32"]
        pub fn neon_umax_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umax.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v2i64"]
        pub fn neon_umax_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umax.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v4f32"]
        pub fn neon_umax_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.umax.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umax.v2f64"]
        pub fn neon_umax_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmax.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v16i8"]
        pub fn neon_fmax_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fmax.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v8i16"]
        pub fn neon_fmax_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fmax.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v4i32"]
        pub fn neon_fmax_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fmax.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v2i64"]
        pub fn neon_fmax_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fmax.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v4f32"]
        pub fn neon_fmax_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmax.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmax.v2f64"]
        pub fn neon_fmax_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v16i8"]
        pub fn neon_fmaxnmp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fmaxnmp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v8i16"]
        pub fn neon_fmaxnmp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fmaxnmp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v4i32"]
        pub fn neon_fmaxnmp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fmaxnmp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v2i64"]
        pub fn neon_fmaxnmp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fmaxnmp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v4f32"]
        pub fn neon_fmaxnmp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmp.v2f64"]
        pub fn neon_fmaxnmp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v16i8"]
        pub fn neon_smaxv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v8i16"]
        pub fn neon_smaxv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v4i32"]
        pub fn neon_smaxv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v2i64"]
        pub fn neon_smaxv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v4f32"]
        pub fn neon_smaxv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v16i8.v2f64"]
        pub fn neon_smaxv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v16i8"]
        pub fn neon_smaxv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.smaxv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v8i16"]
        pub fn neon_smaxv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.smaxv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v4i32"]
        pub fn neon_smaxv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.smaxv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v2i64"]
        pub fn neon_smaxv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.smaxv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v4f32"]
        pub fn neon_smaxv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.smaxv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i8.v2f64"]
        pub fn neon_smaxv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v16i8"]
        pub fn neon_smaxv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v8i16"]
        pub fn neon_smaxv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v4i32"]
        pub fn neon_smaxv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v2i64"]
        pub fn neon_smaxv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v4f32"]
        pub fn neon_smaxv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v8i16.v2f64"]
        pub fn neon_smaxv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v16i8"]
        pub fn neon_smaxv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.smaxv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v8i16"]
        pub fn neon_smaxv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.smaxv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v4i32"]
        pub fn neon_smaxv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.smaxv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v2i64"]
        pub fn neon_smaxv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.smaxv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v4f32"]
        pub fn neon_smaxv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.smaxv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i16.v2f64"]
        pub fn neon_smaxv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v16i8"]
        pub fn neon_smaxv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v8i16"]
        pub fn neon_smaxv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v4i32"]
        pub fn neon_smaxv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v2i64"]
        pub fn neon_smaxv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v4f32"]
        pub fn neon_smaxv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v4i32.v2f64"]
        pub fn neon_smaxv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v16i8"]
        pub fn neon_smaxv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.smaxv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v8i16"]
        pub fn neon_smaxv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.smaxv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v4i32"]
        pub fn neon_smaxv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.smaxv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v2i64"]
        pub fn neon_smaxv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.smaxv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v4f32"]
        pub fn neon_smaxv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.smaxv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i32.v2f64"]
        pub fn neon_smaxv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v16i8"]
        pub fn neon_smaxv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v8i16"]
        pub fn neon_smaxv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v4i32"]
        pub fn neon_smaxv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v2i64"]
        pub fn neon_smaxv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v4f32"]
        pub fn neon_smaxv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.v2i64.v2f64"]
        pub fn neon_smaxv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v16i8"]
        pub fn neon_smaxv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.smaxv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v8i16"]
        pub fn neon_smaxv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.smaxv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v4i32"]
        pub fn neon_smaxv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.smaxv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v2i64"]
        pub fn neon_smaxv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.smaxv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v4f32"]
        pub fn neon_smaxv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.smaxv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxv.i64.v2f64"]
        pub fn neon_smaxv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v16i8"]
        pub fn neon_umaxv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v8i16"]
        pub fn neon_umaxv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v4i32"]
        pub fn neon_umaxv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v2i64"]
        pub fn neon_umaxv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v4f32"]
        pub fn neon_umaxv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v16i8.v2f64"]
        pub fn neon_umaxv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v16i8"]
        pub fn neon_umaxv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.umaxv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v8i16"]
        pub fn neon_umaxv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.umaxv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v4i32"]
        pub fn neon_umaxv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.umaxv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v2i64"]
        pub fn neon_umaxv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.umaxv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v4f32"]
        pub fn neon_umaxv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.umaxv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i8.v2f64"]
        pub fn neon_umaxv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v16i8"]
        pub fn neon_umaxv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v8i16"]
        pub fn neon_umaxv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v4i32"]
        pub fn neon_umaxv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v2i64"]
        pub fn neon_umaxv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v4f32"]
        pub fn neon_umaxv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v8i16.v2f64"]
        pub fn neon_umaxv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v16i8"]
        pub fn neon_umaxv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.umaxv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v8i16"]
        pub fn neon_umaxv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.umaxv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v4i32"]
        pub fn neon_umaxv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.umaxv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v2i64"]
        pub fn neon_umaxv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.umaxv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v4f32"]
        pub fn neon_umaxv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.umaxv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i16.v2f64"]
        pub fn neon_umaxv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v16i8"]
        pub fn neon_umaxv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v8i16"]
        pub fn neon_umaxv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v4i32"]
        pub fn neon_umaxv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v2i64"]
        pub fn neon_umaxv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v4f32"]
        pub fn neon_umaxv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v4i32.v2f64"]
        pub fn neon_umaxv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v16i8"]
        pub fn neon_umaxv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.umaxv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v8i16"]
        pub fn neon_umaxv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.umaxv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v4i32"]
        pub fn neon_umaxv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.umaxv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v2i64"]
        pub fn neon_umaxv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.umaxv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v4f32"]
        pub fn neon_umaxv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.umaxv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i32.v2f64"]
        pub fn neon_umaxv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v16i8"]
        pub fn neon_umaxv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v8i16"]
        pub fn neon_umaxv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v4i32"]
        pub fn neon_umaxv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v2i64"]
        pub fn neon_umaxv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v4f32"]
        pub fn neon_umaxv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.v2i64.v2f64"]
        pub fn neon_umaxv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v16i8"]
        pub fn neon_umaxv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.umaxv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v8i16"]
        pub fn neon_umaxv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.umaxv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v4i32"]
        pub fn neon_umaxv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.umaxv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v2i64"]
        pub fn neon_umaxv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.umaxv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v4f32"]
        pub fn neon_umaxv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.umaxv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxv.i64.v2f64"]
        pub fn neon_umaxv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v16i8"]
        pub fn neon_fmaxv_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v8i16"]
        pub fn neon_fmaxv_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v4i32"]
        pub fn neon_fmaxv_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v2i64"]
        pub fn neon_fmaxv_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v4f32"]
        pub fn neon_fmaxv_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v4f32.v2f64"]
        pub fn neon_fmaxv_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxv.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v16i8"]
        pub fn neon_fmaxv_f32_v16i8(a: ::simdty::i8x16) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v8i16"]
        pub fn neon_fmaxv_f32_v8i16(a: ::simdty::i16x8) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v4i32"]
        pub fn neon_fmaxv_f32_v4i32(a: ::simdty::i32x4) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v2i64"]
        pub fn neon_fmaxv_f32_v2i64(a: ::simdty::i64x2) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v4f32"]
        pub fn neon_fmaxv_f32_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f32.v2f64"]
        pub fn neon_fmaxv_f32_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v16i8"]
        pub fn neon_fmaxv_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v8i16"]
        pub fn neon_fmaxv_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v4i32"]
        pub fn neon_fmaxv_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v2i64"]
        pub fn neon_fmaxv_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v4f32"]
        pub fn neon_fmaxv_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.v2f64.v2f64"]
        pub fn neon_fmaxv_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxv.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v16i8"]
        pub fn neon_fmaxv_f64_v16i8(a: ::simdty::i8x16) -> f64;
        /// The `llvm.aarch64.neon.fmaxv.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v8i16"]
        pub fn neon_fmaxv_f64_v8i16(a: ::simdty::i16x8) -> f64;
        /// The `llvm.aarch64.neon.fmaxv.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v4i32"]
        pub fn neon_fmaxv_f64_v4i32(a: ::simdty::i32x4) -> f64;
        /// The `llvm.aarch64.neon.fmaxv.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v2i64"]
        pub fn neon_fmaxv_f64_v2i64(a: ::simdty::i64x2) -> f64;
        /// The `llvm.aarch64.neon.fmaxv.f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v4f32"]
        pub fn neon_fmaxv_f64_v4f32(a: ::simdty::f32x4) -> f64;
        /// The `llvm.aarch64.neon.fmaxv.f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxv.f64.v2f64"]
        pub fn neon_fmaxv_f64_v2f64(a: ::simdty::f64x2) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v16i8"]
        pub fn neon_fmaxnmv_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v8i16"]
        pub fn neon_fmaxnmv_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v4i32"]
        pub fn neon_fmaxnmv_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v2i64"]
        pub fn neon_fmaxnmv_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v4f32"]
        pub fn neon_fmaxnmv_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v4f32.v2f64"]
        pub fn neon_fmaxnmv_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v16i8"]
        pub fn neon_fmaxnmv_f32_v16i8(a: ::simdty::i8x16) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v8i16"]
        pub fn neon_fmaxnmv_f32_v8i16(a: ::simdty::i16x8) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v4i32"]
        pub fn neon_fmaxnmv_f32_v4i32(a: ::simdty::i32x4) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v2i64"]
        pub fn neon_fmaxnmv_f32_v2i64(a: ::simdty::i64x2) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v4f32"]
        pub fn neon_fmaxnmv_f32_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f32.v2f64"]
        pub fn neon_fmaxnmv_f32_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v16i8"]
        pub fn neon_fmaxnmv_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v8i16"]
        pub fn neon_fmaxnmv_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v4i32"]
        pub fn neon_fmaxnmv_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v2i64"]
        pub fn neon_fmaxnmv_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v4f32"]
        pub fn neon_fmaxnmv_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.v2f64.v2f64"]
        pub fn neon_fmaxnmv_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v16i8"]
        pub fn neon_fmaxnmv_f64_v16i8(a: ::simdty::i8x16) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v8i16"]
        pub fn neon_fmaxnmv_f64_v8i16(a: ::simdty::i16x8) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v4i32"]
        pub fn neon_fmaxnmv_f64_v4i32(a: ::simdty::i32x4) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v2i64"]
        pub fn neon_fmaxnmv_f64_v2i64(a: ::simdty::i64x2) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v4f32"]
        pub fn neon_fmaxnmv_f64_v4f32(a: ::simdty::f32x4) -> f64;
        /// The `llvm.aarch64.neon.fmaxnmv.f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnmv.f64.v2f64"]
        pub fn neon_fmaxnmv_f64_v2f64(a: ::simdty::f64x2) -> f64;
        /// The `llvm.aarch64.neon.smin.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v16i8"]
        pub fn neon_smin_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smin.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v8i16"]
        pub fn neon_smin_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smin.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v4i32"]
        pub fn neon_smin_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smin.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v2i64"]
        pub fn neon_smin_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smin.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v4f32"]
        pub fn neon_smin_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.smin.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smin.v2f64"]
        pub fn neon_smin_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.umin.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v16i8"]
        pub fn neon_umin_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umin.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v8i16"]
        pub fn neon_umin_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umin.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v4i32"]
        pub fn neon_umin_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umin.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v2i64"]
        pub fn neon_umin_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umin.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v4f32"]
        pub fn neon_umin_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.umin.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umin.v2f64"]
        pub fn neon_umin_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmin.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v16i8"]
        pub fn neon_fmin_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fmin.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v8i16"]
        pub fn neon_fmin_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fmin.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v4i32"]
        pub fn neon_fmin_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fmin.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v2i64"]
        pub fn neon_fmin_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fmin.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v4f32"]
        pub fn neon_fmin_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmin.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmin.v2f64"]
        pub fn neon_fmin_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v16i8"]
        pub fn neon_fminnmp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fminnmp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v8i16"]
        pub fn neon_fminnmp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fminnmp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v4i32"]
        pub fn neon_fminnmp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fminnmp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v2i64"]
        pub fn neon_fminnmp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fminnmp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v4f32"]
        pub fn neon_fminnmp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmp.v2f64"]
        pub fn neon_fminnmp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnm.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnm.v4f32"]
        pub fn neon_fminnm_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnm.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnm.f32"]
        pub fn neon_fminnm_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.neon.fminnm.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnm.v2f64"]
        pub fn neon_fminnm_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnm.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnm.f64"]
        pub fn neon_fminnm_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.fmaxnm.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnm.v4f32"]
        pub fn neon_fmaxnm_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxnm.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnm.f32"]
        pub fn neon_fmaxnm_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.neon.fmaxnm.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnm.v2f64"]
        pub fn neon_fmaxnm_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxnm.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxnm.f64"]
        pub fn neon_fmaxnm_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.sminv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v16i8"]
        pub fn neon_sminv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v8i16"]
        pub fn neon_sminv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v4i32"]
        pub fn neon_sminv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v2i64"]
        pub fn neon_sminv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v4f32"]
        pub fn neon_sminv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v16i8.v2f64"]
        pub fn neon_sminv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v16i8"]
        pub fn neon_sminv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.sminv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v8i16"]
        pub fn neon_sminv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.sminv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v4i32"]
        pub fn neon_sminv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.sminv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v2i64"]
        pub fn neon_sminv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.sminv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v4f32"]
        pub fn neon_sminv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.sminv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i8.v2f64"]
        pub fn neon_sminv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v16i8"]
        pub fn neon_sminv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v8i16"]
        pub fn neon_sminv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v4i32"]
        pub fn neon_sminv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v2i64"]
        pub fn neon_sminv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v4f32"]
        pub fn neon_sminv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v8i16.v2f64"]
        pub fn neon_sminv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v16i8"]
        pub fn neon_sminv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.sminv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v8i16"]
        pub fn neon_sminv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.sminv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v4i32"]
        pub fn neon_sminv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.sminv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v2i64"]
        pub fn neon_sminv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.sminv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v4f32"]
        pub fn neon_sminv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.sminv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i16.v2f64"]
        pub fn neon_sminv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.sminv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v16i8"]
        pub fn neon_sminv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v8i16"]
        pub fn neon_sminv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v4i32"]
        pub fn neon_sminv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v2i64"]
        pub fn neon_sminv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v4f32"]
        pub fn neon_sminv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v4i32.v2f64"]
        pub fn neon_sminv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v16i8"]
        pub fn neon_sminv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.sminv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v8i16"]
        pub fn neon_sminv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.sminv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v4i32"]
        pub fn neon_sminv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.sminv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v2i64"]
        pub fn neon_sminv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.sminv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v4f32"]
        pub fn neon_sminv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.sminv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i32.v2f64"]
        pub fn neon_sminv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.sminv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v16i8"]
        pub fn neon_sminv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v8i16"]
        pub fn neon_sminv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v4i32"]
        pub fn neon_sminv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v2i64"]
        pub fn neon_sminv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v4f32"]
        pub fn neon_sminv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.v2i64.v2f64"]
        pub fn neon_sminv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v16i8"]
        pub fn neon_sminv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.sminv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v8i16"]
        pub fn neon_sminv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.sminv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v4i32"]
        pub fn neon_sminv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.sminv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v2i64"]
        pub fn neon_sminv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.sminv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v4f32"]
        pub fn neon_sminv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.sminv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminv.i64.v2f64"]
        pub fn neon_sminv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.uminv.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v16i8"]
        pub fn neon_uminv_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v8i16"]
        pub fn neon_uminv_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v4i32"]
        pub fn neon_uminv_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v2i64"]
        pub fn neon_uminv_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v4f32"]
        pub fn neon_uminv_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v16i8.v2f64"]
        pub fn neon_uminv_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminv.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v16i8"]
        pub fn neon_uminv_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.uminv.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v8i16"]
        pub fn neon_uminv_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.uminv.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v4i32"]
        pub fn neon_uminv_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.uminv.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v2i64"]
        pub fn neon_uminv_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.uminv.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v4f32"]
        pub fn neon_uminv_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.uminv.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i8.v2f64"]
        pub fn neon_uminv_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v16i8"]
        pub fn neon_uminv_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v8i16"]
        pub fn neon_uminv_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v4i32"]
        pub fn neon_uminv_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v2i64"]
        pub fn neon_uminv_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v4f32"]
        pub fn neon_uminv_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v8i16.v2f64"]
        pub fn neon_uminv_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminv.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v16i8"]
        pub fn neon_uminv_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.uminv.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v8i16"]
        pub fn neon_uminv_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.uminv.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v4i32"]
        pub fn neon_uminv_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.uminv.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v2i64"]
        pub fn neon_uminv_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.uminv.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v4f32"]
        pub fn neon_uminv_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.uminv.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i16.v2f64"]
        pub fn neon_uminv_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.uminv.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v16i8"]
        pub fn neon_uminv_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v8i16"]
        pub fn neon_uminv_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v4i32"]
        pub fn neon_uminv_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v2i64"]
        pub fn neon_uminv_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v4f32"]
        pub fn neon_uminv_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v4i32.v2f64"]
        pub fn neon_uminv_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminv.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v16i8"]
        pub fn neon_uminv_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.uminv.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v8i16"]
        pub fn neon_uminv_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.uminv.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v4i32"]
        pub fn neon_uminv_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.uminv.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v2i64"]
        pub fn neon_uminv_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.uminv.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v4f32"]
        pub fn neon_uminv_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.uminv.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i32.v2f64"]
        pub fn neon_uminv_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.uminv.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v16i8"]
        pub fn neon_uminv_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v8i16"]
        pub fn neon_uminv_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v4i32"]
        pub fn neon_uminv_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v2i64"]
        pub fn neon_uminv_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v4f32"]
        pub fn neon_uminv_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.v2i64.v2f64"]
        pub fn neon_uminv_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminv.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v16i8"]
        pub fn neon_uminv_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.uminv.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v8i16"]
        pub fn neon_uminv_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.uminv.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v4i32"]
        pub fn neon_uminv_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.uminv.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v2i64"]
        pub fn neon_uminv_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.uminv.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v4f32"]
        pub fn neon_uminv_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.uminv.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminv.i64.v2f64"]
        pub fn neon_uminv_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fminv.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v16i8"]
        pub fn neon_fminv_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v8i16"]
        pub fn neon_fminv_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v4i32"]
        pub fn neon_fminv_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v2i64"]
        pub fn neon_fminv_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v4f32"]
        pub fn neon_fminv_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v4f32.v2f64"]
        pub fn neon_fminv_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminv.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v16i8"]
        pub fn neon_fminv_f32_v16i8(a: ::simdty::i8x16) -> f32;
        /// The `llvm.aarch64.neon.fminv.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v8i16"]
        pub fn neon_fminv_f32_v8i16(a: ::simdty::i16x8) -> f32;
        /// The `llvm.aarch64.neon.fminv.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v4i32"]
        pub fn neon_fminv_f32_v4i32(a: ::simdty::i32x4) -> f32;
        /// The `llvm.aarch64.neon.fminv.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v2i64"]
        pub fn neon_fminv_f32_v2i64(a: ::simdty::i64x2) -> f32;
        /// The `llvm.aarch64.neon.fminv.f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v4f32"]
        pub fn neon_fminv_f32_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.aarch64.neon.fminv.f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f32.v2f64"]
        pub fn neon_fminv_f32_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.aarch64.neon.fminv.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v16i8"]
        pub fn neon_fminv_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v8i16"]
        pub fn neon_fminv_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v4i32"]
        pub fn neon_fminv_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v2i64"]
        pub fn neon_fminv_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v4f32"]
        pub fn neon_fminv_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.v2f64.v2f64"]
        pub fn neon_fminv_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminv.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v16i8"]
        pub fn neon_fminv_f64_v16i8(a: ::simdty::i8x16) -> f64;
        /// The `llvm.aarch64.neon.fminv.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v8i16"]
        pub fn neon_fminv_f64_v8i16(a: ::simdty::i16x8) -> f64;
        /// The `llvm.aarch64.neon.fminv.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v4i32"]
        pub fn neon_fminv_f64_v4i32(a: ::simdty::i32x4) -> f64;
        /// The `llvm.aarch64.neon.fminv.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v2i64"]
        pub fn neon_fminv_f64_v2i64(a: ::simdty::i64x2) -> f64;
        /// The `llvm.aarch64.neon.fminv.f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v4f32"]
        pub fn neon_fminv_f64_v4f32(a: ::simdty::f32x4) -> f64;
        /// The `llvm.aarch64.neon.fminv.f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminv.f64.v2f64"]
        pub fn neon_fminv_f64_v2f64(a: ::simdty::f64x2) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v16i8"]
        pub fn neon_fminnmv_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v8i16"]
        pub fn neon_fminnmv_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v4i32"]
        pub fn neon_fminnmv_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v2i64"]
        pub fn neon_fminnmv_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v4f32"]
        pub fn neon_fminnmv_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v4f32.v2f64"]
        pub fn neon_fminnmv_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminnmv.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v16i8"]
        pub fn neon_fminnmv_f32_v16i8(a: ::simdty::i8x16) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v8i16"]
        pub fn neon_fminnmv_f32_v8i16(a: ::simdty::i16x8) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v4i32"]
        pub fn neon_fminnmv_f32_v4i32(a: ::simdty::i32x4) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v2i64"]
        pub fn neon_fminnmv_f32_v2i64(a: ::simdty::i64x2) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v4f32"]
        pub fn neon_fminnmv_f32_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f32.v2f64"]
        pub fn neon_fminnmv_f32_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v16i8"]
        pub fn neon_fminnmv_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v8i16"]
        pub fn neon_fminnmv_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v4i32"]
        pub fn neon_fminnmv_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v2i64"]
        pub fn neon_fminnmv_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v4f32"]
        pub fn neon_fminnmv_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.v2f64.v2f64"]
        pub fn neon_fminnmv_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminnmv.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v16i8"]
        pub fn neon_fminnmv_f64_v16i8(a: ::simdty::i8x16) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v8i16"]
        pub fn neon_fminnmv_f64_v8i16(a: ::simdty::i16x8) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v4i32"]
        pub fn neon_fminnmv_f64_v4i32(a: ::simdty::i32x4) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v2i64"]
        pub fn neon_fminnmv_f64_v2i64(a: ::simdty::i64x2) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v4f32"]
        pub fn neon_fminnmv_f64_v4f32(a: ::simdty::f32x4) -> f64;
        /// The `llvm.aarch64.neon.fminnmv.f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminnmv.f64.v2f64"]
        pub fn neon_fminnmv_f64_v2f64(a: ::simdty::f64x2) -> f64;
        /// The `llvm.aarch64.neon.addp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v16i8"]
        pub fn neon_addp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.addp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v8i16"]
        pub fn neon_addp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.addp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v4i32"]
        pub fn neon_addp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.addp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v2i64"]
        pub fn neon_addp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.addp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v4f32"]
        pub fn neon_addp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.addp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.addp.v2f64"]
        pub fn neon_addp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v16i8"]
        pub fn neon_saddlp_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v8i16"]
        pub fn neon_saddlp_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v4i32"]
        pub fn neon_saddlp_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v2i64"]
        pub fn neon_saddlp_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v4f32"]
        pub fn neon_saddlp_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v16i8.v2f64"]
        pub fn neon_saddlp_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v16i8"]
        pub fn neon_saddlp_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v8i16"]
        pub fn neon_saddlp_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v4i32"]
        pub fn neon_saddlp_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v2i64"]
        pub fn neon_saddlp_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v4f32"]
        pub fn neon_saddlp_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v8i16.v2f64"]
        pub fn neon_saddlp_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v16i8"]
        pub fn neon_saddlp_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v8i16"]
        pub fn neon_saddlp_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v4i32"]
        pub fn neon_saddlp_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v2i64"]
        pub fn neon_saddlp_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v4f32"]
        pub fn neon_saddlp_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4i32.v2f64"]
        pub fn neon_saddlp_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v16i8"]
        pub fn neon_saddlp_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v8i16"]
        pub fn neon_saddlp_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v4i32"]
        pub fn neon_saddlp_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v2i64"]
        pub fn neon_saddlp_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v4f32"]
        pub fn neon_saddlp_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2i64.v2f64"]
        pub fn neon_saddlp_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v16i8"]
        pub fn neon_saddlp_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v8i16"]
        pub fn neon_saddlp_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v4i32"]
        pub fn neon_saddlp_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v2i64"]
        pub fn neon_saddlp_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v4f32"]
        pub fn neon_saddlp_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v4f32.v2f64"]
        pub fn neon_saddlp_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v16i8"]
        pub fn neon_saddlp_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v8i16"]
        pub fn neon_saddlp_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v4i32"]
        pub fn neon_saddlp_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v2i64"]
        pub fn neon_saddlp_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v4f32"]
        pub fn neon_saddlp_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.saddlp.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.saddlp.v2f64.v2f64"]
        pub fn neon_saddlp_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v16i8"]
        pub fn neon_uaddlp_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v8i16"]
        pub fn neon_uaddlp_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v4i32"]
        pub fn neon_uaddlp_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v2i64"]
        pub fn neon_uaddlp_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v4f32"]
        pub fn neon_uaddlp_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v16i8.v2f64"]
        pub fn neon_uaddlp_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v16i8"]
        pub fn neon_uaddlp_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v8i16"]
        pub fn neon_uaddlp_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v4i32"]
        pub fn neon_uaddlp_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v2i64"]
        pub fn neon_uaddlp_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v4f32"]
        pub fn neon_uaddlp_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v8i16.v2f64"]
        pub fn neon_uaddlp_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v16i8"]
        pub fn neon_uaddlp_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v8i16"]
        pub fn neon_uaddlp_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v4i32"]
        pub fn neon_uaddlp_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v2i64"]
        pub fn neon_uaddlp_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v4f32"]
        pub fn neon_uaddlp_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4i32.v2f64"]
        pub fn neon_uaddlp_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v16i8"]
        pub fn neon_uaddlp_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v8i16"]
        pub fn neon_uaddlp_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v4i32"]
        pub fn neon_uaddlp_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v2i64"]
        pub fn neon_uaddlp_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v4f32"]
        pub fn neon_uaddlp_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2i64.v2f64"]
        pub fn neon_uaddlp_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v16i8"]
        pub fn neon_uaddlp_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v8i16"]
        pub fn neon_uaddlp_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v4i32"]
        pub fn neon_uaddlp_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v2i64"]
        pub fn neon_uaddlp_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v4f32"]
        pub fn neon_uaddlp_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v4f32.v2f64"]
        pub fn neon_uaddlp_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v16i8"]
        pub fn neon_uaddlp_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v8i16"]
        pub fn neon_uaddlp_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v4i32"]
        pub fn neon_uaddlp_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v2i64"]
        pub fn neon_uaddlp_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v4f32"]
        pub fn neon_uaddlp_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uaddlp.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uaddlp.v2f64.v2f64"]
        pub fn neon_uaddlp_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.smaxp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v16i8"]
        pub fn neon_smaxp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.smaxp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v8i16"]
        pub fn neon_smaxp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.smaxp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v4i32"]
        pub fn neon_smaxp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.smaxp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v2i64"]
        pub fn neon_smaxp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.smaxp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v4f32"]
        pub fn neon_smaxp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.smaxp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.smaxp.v2f64"]
        pub fn neon_smaxp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.umaxp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v16i8"]
        pub fn neon_umaxp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.umaxp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v8i16"]
        pub fn neon_umaxp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.umaxp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v4i32"]
        pub fn neon_umaxp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.umaxp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v2i64"]
        pub fn neon_umaxp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.umaxp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v4f32"]
        pub fn neon_umaxp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.umaxp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.umaxp.v2f64"]
        pub fn neon_umaxp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fmaxp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v16i8"]
        pub fn neon_fmaxp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fmaxp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v8i16"]
        pub fn neon_fmaxp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fmaxp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v4i32"]
        pub fn neon_fmaxp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fmaxp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v2i64"]
        pub fn neon_fmaxp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fmaxp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v4f32"]
        pub fn neon_fmaxp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fmaxp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fmaxp.v2f64"]
        pub fn neon_fmaxp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.sminp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v16i8"]
        pub fn neon_sminp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sminp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v8i16"]
        pub fn neon_sminp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sminp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v4i32"]
        pub fn neon_sminp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sminp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v2i64"]
        pub fn neon_sminp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sminp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v4f32"]
        pub fn neon_sminp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.sminp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sminp.v2f64"]
        pub fn neon_sminp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.uminp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v16i8"]
        pub fn neon_uminp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uminp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v8i16"]
        pub fn neon_uminp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uminp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v4i32"]
        pub fn neon_uminp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uminp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v2i64"]
        pub fn neon_uminp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uminp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v4f32"]
        pub fn neon_uminp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.uminp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uminp.v2f64"]
        pub fn neon_uminp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fminp.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v16i8"]
        pub fn neon_fminp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fminp.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v8i16"]
        pub fn neon_fminp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fminp.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v4i32"]
        pub fn neon_fminp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fminp.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v2i64"]
        pub fn neon_fminp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fminp.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v4f32"]
        pub fn neon_fminp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fminp.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fminp.v2f64"]
        pub fn neon_fminp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frecps.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecps.v4f32"]
        pub fn neon_frecps_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frecps.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecps.f32"]
        pub fn neon_frecps_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.neon.frecps.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecps.v2f64"]
        pub fn neon_frecps_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frecps.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecps.f64"]
        pub fn neon_frecps_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.frsqrts.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrts.v4f32"]
        pub fn neon_frsqrts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frsqrts.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrts.f32"]
        pub fn neon_frsqrts_f32(a: f32, b: f32) -> f32;
        /// The `llvm.aarch64.neon.frsqrts.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrts.v2f64"]
        pub fn neon_frsqrts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frsqrts.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrts.f64"]
        pub fn neon_frsqrts_f64(a: f64, b: f64) -> f64;
        /// The `llvm.aarch64.neon.frecpx.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpx.v4f32"]
        pub fn neon_frecpx_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frecpx.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpx.f32"]
        pub fn neon_frecpx_f32(a: f32) -> f32;
        /// The `llvm.aarch64.neon.frecpx.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpx.v2f64"]
        pub fn neon_frecpx_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frecpx.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpx.f64"]
        pub fn neon_frecpx_f64(a: f64) -> f64;
        /// The `llvm.aarch64.neon.sqshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.v16i8"]
        pub fn neon_sqshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.i8"]
        pub fn neon_sqshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.v8i16"]
        pub fn neon_sqshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.i16"]
        pub fn neon_sqshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.v4i32"]
        pub fn neon_sqshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.i32"]
        pub fn neon_sqshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.v2i64"]
        pub fn neon_sqshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshl.i64"]
        pub fn neon_sqshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.uqshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.v16i8"]
        pub fn neon_uqshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uqshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.i8"]
        pub fn neon_uqshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.uqshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.v8i16"]
        pub fn neon_uqshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uqshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.i16"]
        pub fn neon_uqshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.uqshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.v4i32"]
        pub fn neon_uqshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uqshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.i32"]
        pub fn neon_uqshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.uqshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.v2i64"]
        pub fn neon_uqshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uqshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqshl.i64"]
        pub fn neon_uqshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.srshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.v16i8"]
        pub fn neon_srshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.srshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.i8"]
        pub fn neon_srshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.srshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.v8i16"]
        pub fn neon_srshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.srshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.i16"]
        pub fn neon_srshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.srshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.v4i32"]
        pub fn neon_srshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.srshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.i32"]
        pub fn neon_srshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.srshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.v2i64"]
        pub fn neon_srshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.srshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.srshl.i64"]
        pub fn neon_srshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.urshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.v16i8"]
        pub fn neon_urshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.urshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.i8"]
        pub fn neon_urshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.urshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.v8i16"]
        pub fn neon_urshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.urshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.i16"]
        pub fn neon_urshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.urshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.v4i32"]
        pub fn neon_urshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.urshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.i32"]
        pub fn neon_urshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.urshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.v2i64"]
        pub fn neon_urshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.urshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urshl.i64"]
        pub fn neon_urshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.sqrshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.v16i8"]
        pub fn neon_sqrshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqrshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.i8"]
        pub fn neon_sqrshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqrshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.v8i16"]
        pub fn neon_sqrshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqrshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.i16"]
        pub fn neon_sqrshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqrshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.v4i32"]
        pub fn neon_sqrshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqrshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.i32"]
        pub fn neon_sqrshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqrshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.v2i64"]
        pub fn neon_sqrshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqrshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqrshl.i64"]
        pub fn neon_sqrshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.uqrshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.v16i8"]
        pub fn neon_uqrshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.uqrshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.i8"]
        pub fn neon_uqrshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.uqrshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.v8i16"]
        pub fn neon_uqrshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.uqrshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.i16"]
        pub fn neon_uqrshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.uqrshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.v4i32"]
        pub fn neon_uqrshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.uqrshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.i32"]
        pub fn neon_uqrshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.uqrshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.v2i64"]
        pub fn neon_uqrshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.uqrshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.uqrshl.i64"]
        pub fn neon_uqrshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.sqshlu.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.v16i8"]
        pub fn neon_sqshlu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqshlu.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.i8"]
        pub fn neon_sqshlu_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sqshlu.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.v8i16"]
        pub fn neon_sqshlu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqshlu.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.i16"]
        pub fn neon_sqshlu_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sqshlu.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.v4i32"]
        pub fn neon_sqshlu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqshlu.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.i32"]
        pub fn neon_sqshlu_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sqshlu.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.v2i64"]
        pub fn neon_sqshlu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqshlu.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqshlu.i64"]
        pub fn neon_sqshlu_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.sshl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.v16i8"]
        pub fn neon_sshl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sshl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.i8"]
        pub fn neon_sshl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.sshl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.v8i16"]
        pub fn neon_sshl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sshl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.i16"]
        pub fn neon_sshl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.sshl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.v4i32"]
        pub fn neon_sshl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sshl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.i32"]
        pub fn neon_sshl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.sshl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.v2i64"]
        pub fn neon_sshl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sshl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sshl.i64"]
        pub fn neon_sshl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.ushl.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.v16i8"]
        pub fn neon_ushl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.ushl.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.i8"]
        pub fn neon_ushl_i8(a: i8, b: i8) -> i8;
        /// The `llvm.aarch64.neon.ushl.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.v8i16"]
        pub fn neon_ushl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.ushl.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.i16"]
        pub fn neon_ushl_i16(a: i16, b: i16) -> i16;
        /// The `llvm.aarch64.neon.ushl.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.v4i32"]
        pub fn neon_ushl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.ushl.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.i32"]
        pub fn neon_ushl_i32(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.ushl.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.v2i64"]
        pub fn neon_ushl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.ushl.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.ushl.i64"]
        pub fn neon_ushl_i64(a: i64, b: i64) -> i64;
        /// The `llvm.aarch64.neon.vsri.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v16i8"]
        pub fn neon_vsri_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vsri.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v8i16"]
        pub fn neon_vsri_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vsri.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v4i32"]
        pub fn neon_vsri_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vsri.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v2i64"]
        pub fn neon_vsri_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vsri.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v4f32"]
        pub fn neon_vsri_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vsri.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsri.v2f64"]
        pub fn neon_vsri_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vsli.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v16i8"]
        pub fn neon_vsli_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vsli.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v8i16"]
        pub fn neon_vsli_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vsli.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v4i32"]
        pub fn neon_vsli_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vsli.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v2i64"]
        pub fn neon_vsli_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vsli.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v4f32"]
        pub fn neon_vsli_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vsli.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vsli.v2f64"]
        pub fn neon_vsli_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.v16i8"]
        pub fn neon_scalar_sqxtn_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.i8"]
        pub fn neon_scalar_sqxtn_v16i8_i8(a: i8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.v8i16"]
        pub fn neon_scalar_sqxtn_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.i16"]
        pub fn neon_scalar_sqxtn_v16i8_i16(a: i16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.v4i32"]
        pub fn neon_scalar_sqxtn_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.i32"]
        pub fn neon_scalar_sqxtn_v16i8_i32(a: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.v2i64"]
        pub fn neon_scalar_sqxtn_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v16i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v16i8.i64"]
        pub fn neon_scalar_sqxtn_v16i8_i64(a: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.v16i8"]
        pub fn neon_scalar_sqxtn_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.i8"]
        pub fn neon_scalar_sqxtn_i8_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.v8i16"]
        pub fn neon_scalar_sqxtn_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.i16"]
        pub fn neon_scalar_sqxtn_i8_i16(a: i16) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.v4i32"]
        pub fn neon_scalar_sqxtn_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.i32"]
        pub fn neon_scalar_sqxtn_i8_i32(a: i32) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.v2i64"]
        pub fn neon_scalar_sqxtn_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i8.i64"]
        pub fn neon_scalar_sqxtn_i8_i64(a: i64) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.v16i8"]
        pub fn neon_scalar_sqxtn_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.i8"]
        pub fn neon_scalar_sqxtn_v8i16_i8(a: i8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.v8i16"]
        pub fn neon_scalar_sqxtn_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.i16"]
        pub fn neon_scalar_sqxtn_v8i16_i16(a: i16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.v4i32"]
        pub fn neon_scalar_sqxtn_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.i32"]
        pub fn neon_scalar_sqxtn_v8i16_i32(a: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.v2i64"]
        pub fn neon_scalar_sqxtn_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v8i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v8i16.i64"]
        pub fn neon_scalar_sqxtn_v8i16_i64(a: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.v16i8"]
        pub fn neon_scalar_sqxtn_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.i8"]
        pub fn neon_scalar_sqxtn_i16_i8(a: i8) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.v8i16"]
        pub fn neon_scalar_sqxtn_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.i16"]
        pub fn neon_scalar_sqxtn_i16_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.v4i32"]
        pub fn neon_scalar_sqxtn_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.i32"]
        pub fn neon_scalar_sqxtn_i16_i32(a: i32) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.v2i64"]
        pub fn neon_scalar_sqxtn_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i16.i64"]
        pub fn neon_scalar_sqxtn_i16_i64(a: i64) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.v16i8"]
        pub fn neon_scalar_sqxtn_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.i8"]
        pub fn neon_scalar_sqxtn_v4i32_i8(a: i8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.v8i16"]
        pub fn neon_scalar_sqxtn_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.i16"]
        pub fn neon_scalar_sqxtn_v4i32_i16(a: i16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.v4i32"]
        pub fn neon_scalar_sqxtn_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.i32"]
        pub fn neon_scalar_sqxtn_v4i32_i32(a: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.v2i64"]
        pub fn neon_scalar_sqxtn_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v4i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v4i32.i64"]
        pub fn neon_scalar_sqxtn_v4i32_i64(a: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.v16i8"]
        pub fn neon_scalar_sqxtn_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.i8"]
        pub fn neon_scalar_sqxtn_i32_i8(a: i8) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.v8i16"]
        pub fn neon_scalar_sqxtn_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.i16"]
        pub fn neon_scalar_sqxtn_i32_i16(a: i16) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.v4i32"]
        pub fn neon_scalar_sqxtn_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.i32"]
        pub fn neon_scalar_sqxtn_i32_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.v2i64"]
        pub fn neon_scalar_sqxtn_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i32.i64"]
        pub fn neon_scalar_sqxtn_i32_i64(a: i64) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.v16i8"]
        pub fn neon_scalar_sqxtn_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.i8"]
        pub fn neon_scalar_sqxtn_v2i64_i8(a: i8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.v8i16"]
        pub fn neon_scalar_sqxtn_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.i16"]
        pub fn neon_scalar_sqxtn_v2i64_i16(a: i16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.v4i32"]
        pub fn neon_scalar_sqxtn_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.i32"]
        pub fn neon_scalar_sqxtn_v2i64_i32(a: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.v2i64"]
        pub fn neon_scalar_sqxtn_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.v2i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.v2i64.i64"]
        pub fn neon_scalar_sqxtn_v2i64_i64(a: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.v16i8"]
        pub fn neon_scalar_sqxtn_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.i8"]
        pub fn neon_scalar_sqxtn_i64_i8(a: i8) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.v8i16"]
        pub fn neon_scalar_sqxtn_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.i16"]
        pub fn neon_scalar_sqxtn_i64_i16(a: i16) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.v4i32"]
        pub fn neon_scalar_sqxtn_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.i32"]
        pub fn neon_scalar_sqxtn_i64_i32(a: i32) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.v2i64"]
        pub fn neon_scalar_sqxtn_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtn.i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtn.i64.i64"]
        pub fn neon_scalar_sqxtn_i64_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.v16i8"]
        pub fn neon_scalar_uqxtn_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.i8"]
        pub fn neon_scalar_uqxtn_v16i8_i8(a: i8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.v8i16"]
        pub fn neon_scalar_uqxtn_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.i16"]
        pub fn neon_scalar_uqxtn_v16i8_i16(a: i16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.v4i32"]
        pub fn neon_scalar_uqxtn_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.i32"]
        pub fn neon_scalar_uqxtn_v16i8_i32(a: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.v2i64"]
        pub fn neon_scalar_uqxtn_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v16i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v16i8.i64"]
        pub fn neon_scalar_uqxtn_v16i8_i64(a: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.v16i8"]
        pub fn neon_scalar_uqxtn_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.i8"]
        pub fn neon_scalar_uqxtn_i8_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.v8i16"]
        pub fn neon_scalar_uqxtn_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.i16"]
        pub fn neon_scalar_uqxtn_i8_i16(a: i16) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.v4i32"]
        pub fn neon_scalar_uqxtn_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.i32"]
        pub fn neon_scalar_uqxtn_i8_i32(a: i32) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.v2i64"]
        pub fn neon_scalar_uqxtn_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i8.i64"]
        pub fn neon_scalar_uqxtn_i8_i64(a: i64) -> i8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.v16i8"]
        pub fn neon_scalar_uqxtn_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.i8"]
        pub fn neon_scalar_uqxtn_v8i16_i8(a: i8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.v8i16"]
        pub fn neon_scalar_uqxtn_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.i16"]
        pub fn neon_scalar_uqxtn_v8i16_i16(a: i16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.v4i32"]
        pub fn neon_scalar_uqxtn_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.i32"]
        pub fn neon_scalar_uqxtn_v8i16_i32(a: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.v2i64"]
        pub fn neon_scalar_uqxtn_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v8i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v8i16.i64"]
        pub fn neon_scalar_uqxtn_v8i16_i64(a: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.v16i8"]
        pub fn neon_scalar_uqxtn_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.i8"]
        pub fn neon_scalar_uqxtn_i16_i8(a: i8) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.v8i16"]
        pub fn neon_scalar_uqxtn_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.i16"]
        pub fn neon_scalar_uqxtn_i16_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.v4i32"]
        pub fn neon_scalar_uqxtn_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.i32"]
        pub fn neon_scalar_uqxtn_i16_i32(a: i32) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.v2i64"]
        pub fn neon_scalar_uqxtn_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i16.i64"]
        pub fn neon_scalar_uqxtn_i16_i64(a: i64) -> i16;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.v16i8"]
        pub fn neon_scalar_uqxtn_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.i8"]
        pub fn neon_scalar_uqxtn_v4i32_i8(a: i8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.v8i16"]
        pub fn neon_scalar_uqxtn_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.i16"]
        pub fn neon_scalar_uqxtn_v4i32_i16(a: i16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.v4i32"]
        pub fn neon_scalar_uqxtn_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.i32"]
        pub fn neon_scalar_uqxtn_v4i32_i32(a: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.v2i64"]
        pub fn neon_scalar_uqxtn_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v4i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v4i32.i64"]
        pub fn neon_scalar_uqxtn_v4i32_i64(a: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.v16i8"]
        pub fn neon_scalar_uqxtn_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.i8"]
        pub fn neon_scalar_uqxtn_i32_i8(a: i8) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.v8i16"]
        pub fn neon_scalar_uqxtn_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.i16"]
        pub fn neon_scalar_uqxtn_i32_i16(a: i16) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.v4i32"]
        pub fn neon_scalar_uqxtn_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.i32"]
        pub fn neon_scalar_uqxtn_i32_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.v2i64"]
        pub fn neon_scalar_uqxtn_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i32.i64"]
        pub fn neon_scalar_uqxtn_i32_i64(a: i64) -> i32;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.v16i8"]
        pub fn neon_scalar_uqxtn_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.i8"]
        pub fn neon_scalar_uqxtn_v2i64_i8(a: i8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.v8i16"]
        pub fn neon_scalar_uqxtn_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.i16"]
        pub fn neon_scalar_uqxtn_v2i64_i16(a: i16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.v4i32"]
        pub fn neon_scalar_uqxtn_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.i32"]
        pub fn neon_scalar_uqxtn_v2i64_i32(a: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.v2i64"]
        pub fn neon_scalar_uqxtn_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.v2i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.v2i64.i64"]
        pub fn neon_scalar_uqxtn_v2i64_i64(a: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.v16i8"]
        pub fn neon_scalar_uqxtn_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.i8"]
        pub fn neon_scalar_uqxtn_i64_i8(a: i8) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.v8i16"]
        pub fn neon_scalar_uqxtn_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.i16"]
        pub fn neon_scalar_uqxtn_i64_i16(a: i16) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.v4i32"]
        pub fn neon_scalar_uqxtn_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.i32"]
        pub fn neon_scalar_uqxtn_i64_i32(a: i32) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.v2i64"]
        pub fn neon_scalar_uqxtn_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.scalar.uqxtn.i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.uqxtn.i64.i64"]
        pub fn neon_scalar_uqxtn_i64_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.v16i8"]
        pub fn neon_scalar_sqxtun_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.i8"]
        pub fn neon_scalar_sqxtun_v16i8_i8(a: i8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.v8i16"]
        pub fn neon_scalar_sqxtun_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.i16"]
        pub fn neon_scalar_sqxtun_v16i8_i16(a: i16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.v4i32"]
        pub fn neon_scalar_sqxtun_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.i32"]
        pub fn neon_scalar_sqxtun_v16i8_i32(a: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.v2i64"]
        pub fn neon_scalar_sqxtun_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v16i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v16i8.i64"]
        pub fn neon_scalar_sqxtun_v16i8_i64(a: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.v16i8"]
        pub fn neon_scalar_sqxtun_i8_v16i8(a: ::simdty::i8x16) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.i8"]
        pub fn neon_scalar_sqxtun_i8_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.v8i16"]
        pub fn neon_scalar_sqxtun_i8_v8i16(a: ::simdty::i16x8) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.i16"]
        pub fn neon_scalar_sqxtun_i8_i16(a: i16) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.v4i32"]
        pub fn neon_scalar_sqxtun_i8_v4i32(a: ::simdty::i32x4) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.i32"]
        pub fn neon_scalar_sqxtun_i8_i32(a: i32) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.v2i64"]
        pub fn neon_scalar_sqxtun_i8_v2i64(a: ::simdty::i64x2) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i8.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i8.i64"]
        pub fn neon_scalar_sqxtun_i8_i64(a: i64) -> i8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.v16i8"]
        pub fn neon_scalar_sqxtun_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.i8"]
        pub fn neon_scalar_sqxtun_v8i16_i8(a: i8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.v8i16"]
        pub fn neon_scalar_sqxtun_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.i16"]
        pub fn neon_scalar_sqxtun_v8i16_i16(a: i16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.v4i32"]
        pub fn neon_scalar_sqxtun_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.i32"]
        pub fn neon_scalar_sqxtun_v8i16_i32(a: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.v2i64"]
        pub fn neon_scalar_sqxtun_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v8i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v8i16.i64"]
        pub fn neon_scalar_sqxtun_v8i16_i64(a: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.v16i8"]
        pub fn neon_scalar_sqxtun_i16_v16i8(a: ::simdty::i8x16) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.i8"]
        pub fn neon_scalar_sqxtun_i16_i8(a: i8) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.v8i16"]
        pub fn neon_scalar_sqxtun_i16_v8i16(a: ::simdty::i16x8) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.i16"]
        pub fn neon_scalar_sqxtun_i16_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.v4i32"]
        pub fn neon_scalar_sqxtun_i16_v4i32(a: ::simdty::i32x4) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.i32"]
        pub fn neon_scalar_sqxtun_i16_i32(a: i32) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.v2i64"]
        pub fn neon_scalar_sqxtun_i16_v2i64(a: ::simdty::i64x2) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i16.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i16.i64"]
        pub fn neon_scalar_sqxtun_i16_i64(a: i64) -> i16;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.v16i8"]
        pub fn neon_scalar_sqxtun_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.i8"]
        pub fn neon_scalar_sqxtun_v4i32_i8(a: i8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.v8i16"]
        pub fn neon_scalar_sqxtun_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.i16"]
        pub fn neon_scalar_sqxtun_v4i32_i16(a: i16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.v4i32"]
        pub fn neon_scalar_sqxtun_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.i32"]
        pub fn neon_scalar_sqxtun_v4i32_i32(a: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.v2i64"]
        pub fn neon_scalar_sqxtun_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v4i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v4i32.i64"]
        pub fn neon_scalar_sqxtun_v4i32_i64(a: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.v16i8"]
        pub fn neon_scalar_sqxtun_i32_v16i8(a: ::simdty::i8x16) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.i8"]
        pub fn neon_scalar_sqxtun_i32_i8(a: i8) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.v8i16"]
        pub fn neon_scalar_sqxtun_i32_v8i16(a: ::simdty::i16x8) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.i16"]
        pub fn neon_scalar_sqxtun_i32_i16(a: i16) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.v4i32"]
        pub fn neon_scalar_sqxtun_i32_v4i32(a: ::simdty::i32x4) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.i32"]
        pub fn neon_scalar_sqxtun_i32_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.v2i64"]
        pub fn neon_scalar_sqxtun_i32_v2i64(a: ::simdty::i64x2) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i32.i64"]
        pub fn neon_scalar_sqxtun_i32_i64(a: i64) -> i32;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.v16i8"]
        pub fn neon_scalar_sqxtun_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.i8"]
        pub fn neon_scalar_sqxtun_v2i64_i8(a: i8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.v8i16"]
        pub fn neon_scalar_sqxtun_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.i16"]
        pub fn neon_scalar_sqxtun_v2i64_i16(a: i16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.v4i32"]
        pub fn neon_scalar_sqxtun_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.i32"]
        pub fn neon_scalar_sqxtun_v2i64_i32(a: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.v2i64"]
        pub fn neon_scalar_sqxtun_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.v2i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.v2i64.i64"]
        pub fn neon_scalar_sqxtun_v2i64_i64(a: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.v16i8"]
        pub fn neon_scalar_sqxtun_i64_v16i8(a: ::simdty::i8x16) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.i8"]
        pub fn neon_scalar_sqxtun_i64_i8(a: i8) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.v8i16"]
        pub fn neon_scalar_sqxtun_i64_v8i16(a: ::simdty::i16x8) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.i16"]
        pub fn neon_scalar_sqxtun_i64_i16(a: i16) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.v4i32"]
        pub fn neon_scalar_sqxtun_i64_v4i32(a: ::simdty::i32x4) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.i32"]
        pub fn neon_scalar_sqxtun_i64_i32(a: i32) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.v2i64"]
        pub fn neon_scalar_sqxtun_i64_v2i64(a: ::simdty::i64x2) -> i64;
        /// The `llvm.aarch64.neon.scalar.sqxtun.i64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.scalar.sqxtun.i64.i64"]
        pub fn neon_scalar_sqxtun_i64_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.abs.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.v16i8"]
        pub fn neon_abs_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.abs.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.i8"]
        pub fn neon_abs_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.abs.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.v8i16"]
        pub fn neon_abs_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.abs.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.i16"]
        pub fn neon_abs_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.abs.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.v4i32"]
        pub fn neon_abs_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.abs.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.i32"]
        pub fn neon_abs_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.abs.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.v2i64"]
        pub fn neon_abs_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.abs.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.abs.i64"]
        pub fn neon_abs_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.sqabs.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.v16i8"]
        pub fn neon_sqabs_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqabs.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.i8"]
        pub fn neon_sqabs_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.sqabs.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.v8i16"]
        pub fn neon_sqabs_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqabs.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.i16"]
        pub fn neon_sqabs_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.sqabs.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.v4i32"]
        pub fn neon_sqabs_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqabs.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.i32"]
        pub fn neon_sqabs_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.sqabs.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.v2i64"]
        pub fn neon_sqabs_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqabs.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqabs.i64"]
        pub fn neon_sqabs_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.sqneg.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.v16i8"]
        pub fn neon_sqneg_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.sqneg.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.i8"]
        pub fn neon_sqneg_i8(a: i8) -> i8;
        /// The `llvm.aarch64.neon.sqneg.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.v8i16"]
        pub fn neon_sqneg_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.sqneg.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.i16"]
        pub fn neon_sqneg_i16(a: i16) -> i16;
        /// The `llvm.aarch64.neon.sqneg.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.v4i32"]
        pub fn neon_sqneg_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.sqneg.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.i32"]
        pub fn neon_sqneg_i32(a: i32) -> i32;
        /// The `llvm.aarch64.neon.sqneg.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.v2i64"]
        pub fn neon_sqneg_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.sqneg.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.sqneg.i64"]
        pub fn neon_sqneg_i64(a: i64) -> i64;
        /// The `llvm.aarch64.neon.cls.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v16i8"]
        pub fn neon_cls_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.cls.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v8i16"]
        pub fn neon_cls_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.cls.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v4i32"]
        pub fn neon_cls_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.cls.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v2i64"]
        pub fn neon_cls_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.cls.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v4f32"]
        pub fn neon_cls_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.cls.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.cls.v2f64"]
        pub fn neon_cls_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.urecpe.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v16i8"]
        pub fn neon_urecpe_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.urecpe.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v8i16"]
        pub fn neon_urecpe_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.urecpe.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v4i32"]
        pub fn neon_urecpe_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.urecpe.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v2i64"]
        pub fn neon_urecpe_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.urecpe.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v4f32"]
        pub fn neon_urecpe_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.urecpe.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.urecpe.v2f64"]
        pub fn neon_urecpe_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frecpe.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpe.v4f32"]
        pub fn neon_frecpe_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frecpe.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpe.f32"]
        pub fn neon_frecpe_f32(a: f32) -> f32;
        /// The `llvm.aarch64.neon.frecpe.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpe.v2f64"]
        pub fn neon_frecpe_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frecpe.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frecpe.f64"]
        pub fn neon_frecpe_f64(a: f64) -> f64;
        /// The `llvm.aarch64.neon.ursqrte.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v16i8"]
        pub fn neon_ursqrte_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.ursqrte.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v8i16"]
        pub fn neon_ursqrte_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.ursqrte.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v4i32"]
        pub fn neon_ursqrte_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.ursqrte.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v2i64"]
        pub fn neon_ursqrte_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.ursqrte.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v4f32"]
        pub fn neon_ursqrte_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.ursqrte.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.ursqrte.v2f64"]
        pub fn neon_ursqrte_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frsqrte.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrte.v4f32"]
        pub fn neon_frsqrte_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frsqrte.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrte.f32"]
        pub fn neon_frsqrte_f32(a: f32) -> f32;
        /// The `llvm.aarch64.neon.frsqrte.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrte.v2f64"]
        pub fn neon_frsqrte_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frsqrte.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frsqrte.f64"]
        pub fn neon_frsqrte_f64(a: f64) -> f64;
        /// The `llvm.aarch64.neon.rbit.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v16i8"]
        pub fn neon_rbit_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.rbit.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v8i16"]
        pub fn neon_rbit_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.rbit.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v4i32"]
        pub fn neon_rbit_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.rbit.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v2i64"]
        pub fn neon_rbit_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.rbit.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v4f32"]
        pub fn neon_rbit_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.rbit.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.rbit.v2f64"]
        pub fn neon_rbit_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfp2hf` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2hf"]
        pub fn neon_vcvtfp2hf(a: ::simdty::f32x4) -> ::simdty::i16x4;
        /// The `llvm.aarch64.neon.vcvthf2fp` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvthf2fp"]
        pub fn neon_vcvthf2fp(a: ::simdty::i16x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v16i8.v4f32"]
        pub fn neon_vcvtfp2fxs_v16i8_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v16i8.f32"]
        pub fn neon_vcvtfp2fxs_v16i8_f32(a: f32, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v16i8.v2f64"]
        pub fn neon_vcvtfp2fxs_v16i8_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v16i8.f64"]
        pub fn neon_vcvtfp2fxs_v16i8_f64(a: f64, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i8.v4f32"]
        pub fn neon_vcvtfp2fxs_i8_v4f32(a: ::simdty::f32x4, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i8.f32"]
        pub fn neon_vcvtfp2fxs_i8_f32(a: f32, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i8.v2f64"]
        pub fn neon_vcvtfp2fxs_i8_v2f64(a: ::simdty::f64x2, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i8.f64"]
        pub fn neon_vcvtfp2fxs_i8_f64(a: f64, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v8i16.v4f32"]
        pub fn neon_vcvtfp2fxs_v8i16_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v8i16.f32"]
        pub fn neon_vcvtfp2fxs_v8i16_f32(a: f32, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v8i16.v2f64"]
        pub fn neon_vcvtfp2fxs_v8i16_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v8i16.f64"]
        pub fn neon_vcvtfp2fxs_v8i16_f64(a: f64, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i16.v4f32"]
        pub fn neon_vcvtfp2fxs_i16_v4f32(a: ::simdty::f32x4, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i16.f32"]
        pub fn neon_vcvtfp2fxs_i16_f32(a: f32, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i16.v2f64"]
        pub fn neon_vcvtfp2fxs_i16_v2f64(a: ::simdty::f64x2, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i16.f64"]
        pub fn neon_vcvtfp2fxs_i16_f64(a: f64, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v4i32.v4f32"]
        pub fn neon_vcvtfp2fxs_v4i32_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v4i32.f32"]
        pub fn neon_vcvtfp2fxs_v4i32_f32(a: f32, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v4i32.v2f64"]
        pub fn neon_vcvtfp2fxs_v4i32_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v4i32.f64"]
        pub fn neon_vcvtfp2fxs_v4i32_f64(a: f64, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i32.v4f32"]
        pub fn neon_vcvtfp2fxs_i32_v4f32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i32.f32"]
        pub fn neon_vcvtfp2fxs_i32_f32(a: f32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i32.v2f64"]
        pub fn neon_vcvtfp2fxs_i32_v2f64(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i32.f64"]
        pub fn neon_vcvtfp2fxs_i32_f64(a: f64, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v2i64.v4f32"]
        pub fn neon_vcvtfp2fxs_v2i64_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v2i64.f32"]
        pub fn neon_vcvtfp2fxs_v2i64_f32(a: f32, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v2i64.v2f64"]
        pub fn neon_vcvtfp2fxs_v2i64_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.v2i64.f64"]
        pub fn neon_vcvtfp2fxs_v2i64_f64(a: f64, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i64.v4f32"]
        pub fn neon_vcvtfp2fxs_i64_v4f32(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i64.f32"]
        pub fn neon_vcvtfp2fxs_i64_f32(a: f32, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i64.v2f64"]
        pub fn neon_vcvtfp2fxs_i64_v2f64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxs.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxs.i64.f64"]
        pub fn neon_vcvtfp2fxs_i64_f64(a: f64, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v16i8.v4f32"]
        pub fn neon_vcvtfp2fxu_v16i8_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v16i8.f32"]
        pub fn neon_vcvtfp2fxu_v16i8_f32(a: f32, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v16i8.v2f64"]
        pub fn neon_vcvtfp2fxu_v16i8_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v16i8.f64"]
        pub fn neon_vcvtfp2fxu_v16i8_f64(a: f64, b: i32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i8.v4f32"]
        pub fn neon_vcvtfp2fxu_i8_v4f32(a: ::simdty::f32x4, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i8.f32"]
        pub fn neon_vcvtfp2fxu_i8_f32(a: f32, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i8.v2f64"]
        pub fn neon_vcvtfp2fxu_i8_v2f64(a: ::simdty::f64x2, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i8.f64"]
        pub fn neon_vcvtfp2fxu_i8_f64(a: f64, b: i32) -> i8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v8i16.v4f32"]
        pub fn neon_vcvtfp2fxu_v8i16_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v8i16.f32"]
        pub fn neon_vcvtfp2fxu_v8i16_f32(a: f32, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v8i16.v2f64"]
        pub fn neon_vcvtfp2fxu_v8i16_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v8i16.f64"]
        pub fn neon_vcvtfp2fxu_v8i16_f64(a: f64, b: i32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i16.v4f32"]
        pub fn neon_vcvtfp2fxu_i16_v4f32(a: ::simdty::f32x4, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i16.f32"]
        pub fn neon_vcvtfp2fxu_i16_f32(a: f32, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i16.v2f64"]
        pub fn neon_vcvtfp2fxu_i16_v2f64(a: ::simdty::f64x2, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i16.f64"]
        pub fn neon_vcvtfp2fxu_i16_f64(a: f64, b: i32) -> i16;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v4i32.v4f32"]
        pub fn neon_vcvtfp2fxu_v4i32_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v4i32.f32"]
        pub fn neon_vcvtfp2fxu_v4i32_f32(a: f32, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v4i32.v2f64"]
        pub fn neon_vcvtfp2fxu_v4i32_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v4i32.f64"]
        pub fn neon_vcvtfp2fxu_v4i32_f64(a: f64, b: i32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i32.v4f32"]
        pub fn neon_vcvtfp2fxu_i32_v4f32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i32.f32"]
        pub fn neon_vcvtfp2fxu_i32_f32(a: f32, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i32.v2f64"]
        pub fn neon_vcvtfp2fxu_i32_v2f64(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i32.f64"]
        pub fn neon_vcvtfp2fxu_i32_f64(a: f64, b: i32) -> i32;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v2i64.v4f32"]
        pub fn neon_vcvtfp2fxu_v2i64_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v2i64.f32"]
        pub fn neon_vcvtfp2fxu_v2i64_f32(a: f32, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v2i64.v2f64"]
        pub fn neon_vcvtfp2fxu_v2i64_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.v2i64.f64"]
        pub fn neon_vcvtfp2fxu_v2i64_f64(a: f64, b: i32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i64.v4f32"]
        pub fn neon_vcvtfp2fxu_i64_v4f32(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i64.f32"]
        pub fn neon_vcvtfp2fxu_i64_f32(a: f32, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i64.v2f64"]
        pub fn neon_vcvtfp2fxu_i64_v2f64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfp2fxu.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfp2fxu.i64.f64"]
        pub fn neon_vcvtfp2fxu_i64_f64(a: f64, b: i32) -> i64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.v16i8"]
        pub fn neon_vcvtfxs2fp_v4f32_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.i8"]
        pub fn neon_vcvtfxs2fp_v4f32_i8(a: i8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.v8i16"]
        pub fn neon_vcvtfxs2fp_v4f32_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.i16"]
        pub fn neon_vcvtfxs2fp_v4f32_i16(a: i16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.v4i32"]
        pub fn neon_vcvtfxs2fp_v4f32_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.i32"]
        pub fn neon_vcvtfxs2fp_v4f32_i32(a: i32, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.v2i64"]
        pub fn neon_vcvtfxs2fp_v4f32_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v4f32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v4f32.i64"]
        pub fn neon_vcvtfxs2fp_v4f32_i64(a: i64, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.v16i8"]
        pub fn neon_vcvtfxs2fp_f32_v16i8(a: ::simdty::i8x16, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.i8"]
        pub fn neon_vcvtfxs2fp_f32_i8(a: i8, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.v8i16"]
        pub fn neon_vcvtfxs2fp_f32_v8i16(a: ::simdty::i16x8, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.i16"]
        pub fn neon_vcvtfxs2fp_f32_i16(a: i16, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.v4i32"]
        pub fn neon_vcvtfxs2fp_f32_v4i32(a: ::simdty::i32x4, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.i32"]
        pub fn neon_vcvtfxs2fp_f32_i32(a: i32, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.v2i64"]
        pub fn neon_vcvtfxs2fp_f32_v2i64(a: ::simdty::i64x2, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f32.i64"]
        pub fn neon_vcvtfxs2fp_f32_i64(a: i64, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.v16i8"]
        pub fn neon_vcvtfxs2fp_v2f64_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.i8"]
        pub fn neon_vcvtfxs2fp_v2f64_i8(a: i8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.v8i16"]
        pub fn neon_vcvtfxs2fp_v2f64_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.i16"]
        pub fn neon_vcvtfxs2fp_v2f64_i16(a: i16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.v4i32"]
        pub fn neon_vcvtfxs2fp_v2f64_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.i32"]
        pub fn neon_vcvtfxs2fp_v2f64_i32(a: i32, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.v2i64"]
        pub fn neon_vcvtfxs2fp_v2f64_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.v2f64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.v2f64.i64"]
        pub fn neon_vcvtfxs2fp_v2f64_i64(a: i64, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.v16i8"]
        pub fn neon_vcvtfxs2fp_f64_v16i8(a: ::simdty::i8x16, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.i8"]
        pub fn neon_vcvtfxs2fp_f64_i8(a: i8, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.v8i16"]
        pub fn neon_vcvtfxs2fp_f64_v8i16(a: ::simdty::i16x8, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.i16"]
        pub fn neon_vcvtfxs2fp_f64_i16(a: i16, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.v4i32"]
        pub fn neon_vcvtfxs2fp_f64_v4i32(a: ::simdty::i32x4, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.i32"]
        pub fn neon_vcvtfxs2fp_f64_i32(a: i32, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.v2i64"]
        pub fn neon_vcvtfxs2fp_f64_v2i64(a: ::simdty::i64x2, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxs2fp.f64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxs2fp.f64.i64"]
        pub fn neon_vcvtfxs2fp_f64_i64(a: i64, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.v16i8"]
        pub fn neon_vcvtfxu2fp_v4f32_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.i8"]
        pub fn neon_vcvtfxu2fp_v4f32_i8(a: i8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.v8i16"]
        pub fn neon_vcvtfxu2fp_v4f32_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.i16"]
        pub fn neon_vcvtfxu2fp_v4f32_i16(a: i16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.v4i32"]
        pub fn neon_vcvtfxu2fp_v4f32_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.i32"]
        pub fn neon_vcvtfxu2fp_v4f32_i32(a: i32, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.v2i64"]
        pub fn neon_vcvtfxu2fp_v4f32_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v4f32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v4f32.i64"]
        pub fn neon_vcvtfxu2fp_v4f32_i64(a: i64, b: i32) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.v16i8"]
        pub fn neon_vcvtfxu2fp_f32_v16i8(a: ::simdty::i8x16, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.i8"]
        pub fn neon_vcvtfxu2fp_f32_i8(a: i8, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.v8i16"]
        pub fn neon_vcvtfxu2fp_f32_v8i16(a: ::simdty::i16x8, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.i16"]
        pub fn neon_vcvtfxu2fp_f32_i16(a: i16, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.v4i32"]
        pub fn neon_vcvtfxu2fp_f32_v4i32(a: ::simdty::i32x4, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.i32"]
        pub fn neon_vcvtfxu2fp_f32_i32(a: i32, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.v2i64"]
        pub fn neon_vcvtfxu2fp_f32_v2i64(a: ::simdty::i64x2, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f32.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f32.i64"]
        pub fn neon_vcvtfxu2fp_f32_i64(a: i64, b: i32) -> f32;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.v16i8"]
        pub fn neon_vcvtfxu2fp_v2f64_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.i8"]
        pub fn neon_vcvtfxu2fp_v2f64_i8(a: i8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.v8i16"]
        pub fn neon_vcvtfxu2fp_v2f64_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.i16"]
        pub fn neon_vcvtfxu2fp_v2f64_i16(a: i16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.v4i32"]
        pub fn neon_vcvtfxu2fp_v2f64_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.i32"]
        pub fn neon_vcvtfxu2fp_v2f64_i32(a: i32, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.v2i64"]
        pub fn neon_vcvtfxu2fp_v2f64_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.v2f64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.v2f64.i64"]
        pub fn neon_vcvtfxu2fp_v2f64_i64(a: i64, b: i32) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.v16i8"]
        pub fn neon_vcvtfxu2fp_f64_v16i8(a: ::simdty::i8x16, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.i8"]
        pub fn neon_vcvtfxu2fp_f64_i8(a: i8, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.v8i16"]
        pub fn neon_vcvtfxu2fp_f64_v8i16(a: ::simdty::i16x8, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.i16"]
        pub fn neon_vcvtfxu2fp_f64_i16(a: i16, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.v4i32"]
        pub fn neon_vcvtfxu2fp_f64_v4i32(a: ::simdty::i32x4, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.i32"]
        pub fn neon_vcvtfxu2fp_f64_i32(a: i32, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.v2i64"]
        pub fn neon_vcvtfxu2fp_f64_v2i64(a: ::simdty::i64x2, b: i32) -> f64;
        /// The `llvm.aarch64.neon.vcvtfxu2fp.f64.i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcvtfxu2fp.f64.i64"]
        pub fn neon_vcvtfxu2fp_f64_i64(a: i64, b: i32) -> f64;
        /// The `llvm.aarch64.neon.fcvtas.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v16i8.v4f32"]
        pub fn neon_fcvtas_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtas.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v16i8.f32"]
        pub fn neon_fcvtas_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtas.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v16i8.v2f64"]
        pub fn neon_fcvtas_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtas.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v16i8.f64"]
        pub fn neon_fcvtas_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtas.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i8.v4f32"]
        pub fn neon_fcvtas_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtas.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i8.f32"]
        pub fn neon_fcvtas_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtas.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i8.v2f64"]
        pub fn neon_fcvtas_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtas.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i8.f64"]
        pub fn neon_fcvtas_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtas.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v8i16.v4f32"]
        pub fn neon_fcvtas_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtas.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v8i16.f32"]
        pub fn neon_fcvtas_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtas.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v8i16.v2f64"]
        pub fn neon_fcvtas_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtas.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v8i16.f64"]
        pub fn neon_fcvtas_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtas.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i16.v4f32"]
        pub fn neon_fcvtas_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtas.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i16.f32"]
        pub fn neon_fcvtas_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtas.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i16.v2f64"]
        pub fn neon_fcvtas_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtas.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i16.f64"]
        pub fn neon_fcvtas_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtas.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v4i32.v4f32"]
        pub fn neon_fcvtas_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtas.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v4i32.f32"]
        pub fn neon_fcvtas_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtas.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v4i32.v2f64"]
        pub fn neon_fcvtas_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtas.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v4i32.f64"]
        pub fn neon_fcvtas_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtas.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i32.v4f32"]
        pub fn neon_fcvtas_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtas.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i32.f32"]
        pub fn neon_fcvtas_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtas.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i32.v2f64"]
        pub fn neon_fcvtas_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtas.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i32.f64"]
        pub fn neon_fcvtas_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtas.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v2i64.v4f32"]
        pub fn neon_fcvtas_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtas.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v2i64.f32"]
        pub fn neon_fcvtas_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtas.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v2i64.v2f64"]
        pub fn neon_fcvtas_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtas.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.v2i64.f64"]
        pub fn neon_fcvtas_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtas.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i64.v4f32"]
        pub fn neon_fcvtas_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtas.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i64.f32"]
        pub fn neon_fcvtas_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtas.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i64.v2f64"]
        pub fn neon_fcvtas_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtas.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtas.i64.f64"]
        pub fn neon_fcvtas_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtau.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v16i8.v4f32"]
        pub fn neon_fcvtau_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtau.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v16i8.f32"]
        pub fn neon_fcvtau_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtau.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v16i8.v2f64"]
        pub fn neon_fcvtau_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtau.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v16i8.f64"]
        pub fn neon_fcvtau_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtau.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i8.v4f32"]
        pub fn neon_fcvtau_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtau.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i8.f32"]
        pub fn neon_fcvtau_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtau.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i8.v2f64"]
        pub fn neon_fcvtau_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtau.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i8.f64"]
        pub fn neon_fcvtau_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtau.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v8i16.v4f32"]
        pub fn neon_fcvtau_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtau.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v8i16.f32"]
        pub fn neon_fcvtau_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtau.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v8i16.v2f64"]
        pub fn neon_fcvtau_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtau.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v8i16.f64"]
        pub fn neon_fcvtau_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtau.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i16.v4f32"]
        pub fn neon_fcvtau_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtau.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i16.f32"]
        pub fn neon_fcvtau_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtau.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i16.v2f64"]
        pub fn neon_fcvtau_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtau.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i16.f64"]
        pub fn neon_fcvtau_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtau.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v4i32.v4f32"]
        pub fn neon_fcvtau_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtau.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v4i32.f32"]
        pub fn neon_fcvtau_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtau.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v4i32.v2f64"]
        pub fn neon_fcvtau_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtau.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v4i32.f64"]
        pub fn neon_fcvtau_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtau.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i32.v4f32"]
        pub fn neon_fcvtau_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtau.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i32.f32"]
        pub fn neon_fcvtau_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtau.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i32.v2f64"]
        pub fn neon_fcvtau_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtau.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i32.f64"]
        pub fn neon_fcvtau_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtau.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v2i64.v4f32"]
        pub fn neon_fcvtau_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtau.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v2i64.f32"]
        pub fn neon_fcvtau_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtau.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v2i64.v2f64"]
        pub fn neon_fcvtau_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtau.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.v2i64.f64"]
        pub fn neon_fcvtau_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtau.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i64.v4f32"]
        pub fn neon_fcvtau_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtau.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i64.f32"]
        pub fn neon_fcvtau_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtau.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i64.v2f64"]
        pub fn neon_fcvtau_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtau.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtau.i64.f64"]
        pub fn neon_fcvtau_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtms.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v16i8.v4f32"]
        pub fn neon_fcvtms_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtms.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v16i8.f32"]
        pub fn neon_fcvtms_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtms.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v16i8.v2f64"]
        pub fn neon_fcvtms_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtms.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v16i8.f64"]
        pub fn neon_fcvtms_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtms.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i8.v4f32"]
        pub fn neon_fcvtms_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtms.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i8.f32"]
        pub fn neon_fcvtms_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtms.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i8.v2f64"]
        pub fn neon_fcvtms_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtms.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i8.f64"]
        pub fn neon_fcvtms_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtms.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v8i16.v4f32"]
        pub fn neon_fcvtms_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtms.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v8i16.f32"]
        pub fn neon_fcvtms_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtms.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v8i16.v2f64"]
        pub fn neon_fcvtms_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtms.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v8i16.f64"]
        pub fn neon_fcvtms_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtms.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i16.v4f32"]
        pub fn neon_fcvtms_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtms.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i16.f32"]
        pub fn neon_fcvtms_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtms.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i16.v2f64"]
        pub fn neon_fcvtms_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtms.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i16.f64"]
        pub fn neon_fcvtms_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtms.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v4i32.v4f32"]
        pub fn neon_fcvtms_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtms.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v4i32.f32"]
        pub fn neon_fcvtms_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtms.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v4i32.v2f64"]
        pub fn neon_fcvtms_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtms.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v4i32.f64"]
        pub fn neon_fcvtms_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtms.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i32.v4f32"]
        pub fn neon_fcvtms_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtms.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i32.f32"]
        pub fn neon_fcvtms_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtms.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i32.v2f64"]
        pub fn neon_fcvtms_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtms.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i32.f64"]
        pub fn neon_fcvtms_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtms.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v2i64.v4f32"]
        pub fn neon_fcvtms_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtms.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v2i64.f32"]
        pub fn neon_fcvtms_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtms.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v2i64.v2f64"]
        pub fn neon_fcvtms_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtms.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.v2i64.f64"]
        pub fn neon_fcvtms_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtms.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i64.v4f32"]
        pub fn neon_fcvtms_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtms.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i64.f32"]
        pub fn neon_fcvtms_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtms.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i64.v2f64"]
        pub fn neon_fcvtms_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtms.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtms.i64.f64"]
        pub fn neon_fcvtms_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtmu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v16i8.v4f32"]
        pub fn neon_fcvtmu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtmu.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v16i8.f32"]
        pub fn neon_fcvtmu_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtmu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v16i8.v2f64"]
        pub fn neon_fcvtmu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtmu.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v16i8.f64"]
        pub fn neon_fcvtmu_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtmu.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i8.v4f32"]
        pub fn neon_fcvtmu_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtmu.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i8.f32"]
        pub fn neon_fcvtmu_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtmu.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i8.v2f64"]
        pub fn neon_fcvtmu_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtmu.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i8.f64"]
        pub fn neon_fcvtmu_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtmu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v8i16.v4f32"]
        pub fn neon_fcvtmu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtmu.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v8i16.f32"]
        pub fn neon_fcvtmu_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtmu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v8i16.v2f64"]
        pub fn neon_fcvtmu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtmu.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v8i16.f64"]
        pub fn neon_fcvtmu_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtmu.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i16.v4f32"]
        pub fn neon_fcvtmu_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtmu.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i16.f32"]
        pub fn neon_fcvtmu_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtmu.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i16.v2f64"]
        pub fn neon_fcvtmu_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtmu.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i16.f64"]
        pub fn neon_fcvtmu_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtmu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v4i32.v4f32"]
        pub fn neon_fcvtmu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtmu.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v4i32.f32"]
        pub fn neon_fcvtmu_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtmu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v4i32.v2f64"]
        pub fn neon_fcvtmu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtmu.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v4i32.f64"]
        pub fn neon_fcvtmu_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtmu.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i32.v4f32"]
        pub fn neon_fcvtmu_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtmu.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i32.f32"]
        pub fn neon_fcvtmu_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtmu.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i32.v2f64"]
        pub fn neon_fcvtmu_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtmu.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i32.f64"]
        pub fn neon_fcvtmu_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtmu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v2i64.v4f32"]
        pub fn neon_fcvtmu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtmu.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v2i64.f32"]
        pub fn neon_fcvtmu_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtmu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v2i64.v2f64"]
        pub fn neon_fcvtmu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtmu.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.v2i64.f64"]
        pub fn neon_fcvtmu_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtmu.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i64.v4f32"]
        pub fn neon_fcvtmu_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtmu.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i64.f32"]
        pub fn neon_fcvtmu_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtmu.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i64.v2f64"]
        pub fn neon_fcvtmu_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtmu.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtmu.i64.f64"]
        pub fn neon_fcvtmu_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtns.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v16i8.v4f32"]
        pub fn neon_fcvtns_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtns.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v16i8.f32"]
        pub fn neon_fcvtns_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtns.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v16i8.v2f64"]
        pub fn neon_fcvtns_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtns.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v16i8.f64"]
        pub fn neon_fcvtns_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtns.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i8.v4f32"]
        pub fn neon_fcvtns_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtns.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i8.f32"]
        pub fn neon_fcvtns_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtns.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i8.v2f64"]
        pub fn neon_fcvtns_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtns.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i8.f64"]
        pub fn neon_fcvtns_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtns.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v8i16.v4f32"]
        pub fn neon_fcvtns_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtns.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v8i16.f32"]
        pub fn neon_fcvtns_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtns.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v8i16.v2f64"]
        pub fn neon_fcvtns_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtns.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v8i16.f64"]
        pub fn neon_fcvtns_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtns.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i16.v4f32"]
        pub fn neon_fcvtns_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtns.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i16.f32"]
        pub fn neon_fcvtns_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtns.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i16.v2f64"]
        pub fn neon_fcvtns_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtns.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i16.f64"]
        pub fn neon_fcvtns_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtns.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v4i32.v4f32"]
        pub fn neon_fcvtns_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtns.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v4i32.f32"]
        pub fn neon_fcvtns_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtns.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v4i32.v2f64"]
        pub fn neon_fcvtns_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtns.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v4i32.f64"]
        pub fn neon_fcvtns_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtns.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i32.v4f32"]
        pub fn neon_fcvtns_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtns.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i32.f32"]
        pub fn neon_fcvtns_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtns.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i32.v2f64"]
        pub fn neon_fcvtns_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtns.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i32.f64"]
        pub fn neon_fcvtns_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtns.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v2i64.v4f32"]
        pub fn neon_fcvtns_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtns.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v2i64.f32"]
        pub fn neon_fcvtns_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtns.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v2i64.v2f64"]
        pub fn neon_fcvtns_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtns.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.v2i64.f64"]
        pub fn neon_fcvtns_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtns.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i64.v4f32"]
        pub fn neon_fcvtns_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtns.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i64.f32"]
        pub fn neon_fcvtns_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtns.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i64.v2f64"]
        pub fn neon_fcvtns_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtns.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtns.i64.f64"]
        pub fn neon_fcvtns_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtnu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v16i8.v4f32"]
        pub fn neon_fcvtnu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtnu.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v16i8.f32"]
        pub fn neon_fcvtnu_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtnu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v16i8.v2f64"]
        pub fn neon_fcvtnu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtnu.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v16i8.f64"]
        pub fn neon_fcvtnu_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtnu.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i8.v4f32"]
        pub fn neon_fcvtnu_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtnu.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i8.f32"]
        pub fn neon_fcvtnu_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtnu.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i8.v2f64"]
        pub fn neon_fcvtnu_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtnu.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i8.f64"]
        pub fn neon_fcvtnu_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtnu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v8i16.v4f32"]
        pub fn neon_fcvtnu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtnu.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v8i16.f32"]
        pub fn neon_fcvtnu_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtnu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v8i16.v2f64"]
        pub fn neon_fcvtnu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtnu.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v8i16.f64"]
        pub fn neon_fcvtnu_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtnu.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i16.v4f32"]
        pub fn neon_fcvtnu_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtnu.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i16.f32"]
        pub fn neon_fcvtnu_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtnu.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i16.v2f64"]
        pub fn neon_fcvtnu_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtnu.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i16.f64"]
        pub fn neon_fcvtnu_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtnu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v4i32.v4f32"]
        pub fn neon_fcvtnu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtnu.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v4i32.f32"]
        pub fn neon_fcvtnu_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtnu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v4i32.v2f64"]
        pub fn neon_fcvtnu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtnu.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v4i32.f64"]
        pub fn neon_fcvtnu_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtnu.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i32.v4f32"]
        pub fn neon_fcvtnu_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtnu.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i32.f32"]
        pub fn neon_fcvtnu_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtnu.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i32.v2f64"]
        pub fn neon_fcvtnu_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtnu.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i32.f64"]
        pub fn neon_fcvtnu_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtnu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v2i64.v4f32"]
        pub fn neon_fcvtnu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtnu.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v2i64.f32"]
        pub fn neon_fcvtnu_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtnu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v2i64.v2f64"]
        pub fn neon_fcvtnu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtnu.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.v2i64.f64"]
        pub fn neon_fcvtnu_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtnu.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i64.v4f32"]
        pub fn neon_fcvtnu_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtnu.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i64.f32"]
        pub fn neon_fcvtnu_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtnu.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i64.v2f64"]
        pub fn neon_fcvtnu_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtnu.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtnu.i64.f64"]
        pub fn neon_fcvtnu_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtps.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v16i8.v4f32"]
        pub fn neon_fcvtps_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtps.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v16i8.f32"]
        pub fn neon_fcvtps_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtps.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v16i8.v2f64"]
        pub fn neon_fcvtps_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtps.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v16i8.f64"]
        pub fn neon_fcvtps_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtps.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i8.v4f32"]
        pub fn neon_fcvtps_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtps.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i8.f32"]
        pub fn neon_fcvtps_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtps.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i8.v2f64"]
        pub fn neon_fcvtps_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtps.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i8.f64"]
        pub fn neon_fcvtps_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtps.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v8i16.v4f32"]
        pub fn neon_fcvtps_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtps.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v8i16.f32"]
        pub fn neon_fcvtps_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtps.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v8i16.v2f64"]
        pub fn neon_fcvtps_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtps.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v8i16.f64"]
        pub fn neon_fcvtps_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtps.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i16.v4f32"]
        pub fn neon_fcvtps_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtps.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i16.f32"]
        pub fn neon_fcvtps_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtps.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i16.v2f64"]
        pub fn neon_fcvtps_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtps.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i16.f64"]
        pub fn neon_fcvtps_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtps.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v4i32.v4f32"]
        pub fn neon_fcvtps_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtps.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v4i32.f32"]
        pub fn neon_fcvtps_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtps.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v4i32.v2f64"]
        pub fn neon_fcvtps_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtps.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v4i32.f64"]
        pub fn neon_fcvtps_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtps.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i32.v4f32"]
        pub fn neon_fcvtps_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtps.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i32.f32"]
        pub fn neon_fcvtps_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtps.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i32.v2f64"]
        pub fn neon_fcvtps_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtps.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i32.f64"]
        pub fn neon_fcvtps_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtps.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v2i64.v4f32"]
        pub fn neon_fcvtps_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtps.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v2i64.f32"]
        pub fn neon_fcvtps_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtps.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v2i64.v2f64"]
        pub fn neon_fcvtps_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtps.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.v2i64.f64"]
        pub fn neon_fcvtps_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtps.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i64.v4f32"]
        pub fn neon_fcvtps_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtps.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i64.f32"]
        pub fn neon_fcvtps_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtps.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i64.v2f64"]
        pub fn neon_fcvtps_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtps.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtps.i64.f64"]
        pub fn neon_fcvtps_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtpu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v16i8.v4f32"]
        pub fn neon_fcvtpu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtpu.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v16i8.f32"]
        pub fn neon_fcvtpu_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtpu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v16i8.v2f64"]
        pub fn neon_fcvtpu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtpu.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v16i8.f64"]
        pub fn neon_fcvtpu_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtpu.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i8.v4f32"]
        pub fn neon_fcvtpu_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtpu.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i8.f32"]
        pub fn neon_fcvtpu_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtpu.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i8.v2f64"]
        pub fn neon_fcvtpu_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtpu.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i8.f64"]
        pub fn neon_fcvtpu_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtpu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v8i16.v4f32"]
        pub fn neon_fcvtpu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtpu.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v8i16.f32"]
        pub fn neon_fcvtpu_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtpu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v8i16.v2f64"]
        pub fn neon_fcvtpu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtpu.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v8i16.f64"]
        pub fn neon_fcvtpu_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtpu.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i16.v4f32"]
        pub fn neon_fcvtpu_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtpu.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i16.f32"]
        pub fn neon_fcvtpu_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtpu.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i16.v2f64"]
        pub fn neon_fcvtpu_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtpu.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i16.f64"]
        pub fn neon_fcvtpu_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtpu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v4i32.v4f32"]
        pub fn neon_fcvtpu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtpu.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v4i32.f32"]
        pub fn neon_fcvtpu_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtpu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v4i32.v2f64"]
        pub fn neon_fcvtpu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtpu.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v4i32.f64"]
        pub fn neon_fcvtpu_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtpu.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i32.v4f32"]
        pub fn neon_fcvtpu_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtpu.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i32.f32"]
        pub fn neon_fcvtpu_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtpu.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i32.v2f64"]
        pub fn neon_fcvtpu_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtpu.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i32.f64"]
        pub fn neon_fcvtpu_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtpu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v2i64.v4f32"]
        pub fn neon_fcvtpu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtpu.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v2i64.f32"]
        pub fn neon_fcvtpu_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtpu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v2i64.v2f64"]
        pub fn neon_fcvtpu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtpu.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.v2i64.f64"]
        pub fn neon_fcvtpu_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtpu.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i64.v4f32"]
        pub fn neon_fcvtpu_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtpu.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i64.f32"]
        pub fn neon_fcvtpu_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtpu.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i64.v2f64"]
        pub fn neon_fcvtpu_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtpu.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtpu.i64.f64"]
        pub fn neon_fcvtpu_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtzs.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v16i8.v4f32"]
        pub fn neon_fcvtzs_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzs.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v16i8.f32"]
        pub fn neon_fcvtzs_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzs.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v16i8.v2f64"]
        pub fn neon_fcvtzs_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzs.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v16i8.f64"]
        pub fn neon_fcvtzs_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzs.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i8.v4f32"]
        pub fn neon_fcvtzs_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtzs.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i8.f32"]
        pub fn neon_fcvtzs_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtzs.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i8.v2f64"]
        pub fn neon_fcvtzs_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtzs.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i8.f64"]
        pub fn neon_fcvtzs_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtzs.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v8i16.v4f32"]
        pub fn neon_fcvtzs_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzs.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v8i16.f32"]
        pub fn neon_fcvtzs_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzs.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v8i16.v2f64"]
        pub fn neon_fcvtzs_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzs.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v8i16.f64"]
        pub fn neon_fcvtzs_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzs.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i16.v4f32"]
        pub fn neon_fcvtzs_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtzs.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i16.f32"]
        pub fn neon_fcvtzs_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtzs.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i16.v2f64"]
        pub fn neon_fcvtzs_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtzs.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i16.f64"]
        pub fn neon_fcvtzs_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtzs.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v4i32.v4f32"]
        pub fn neon_fcvtzs_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzs.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v4i32.f32"]
        pub fn neon_fcvtzs_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzs.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v4i32.v2f64"]
        pub fn neon_fcvtzs_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzs.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v4i32.f64"]
        pub fn neon_fcvtzs_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzs.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i32.v4f32"]
        pub fn neon_fcvtzs_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtzs.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i32.f32"]
        pub fn neon_fcvtzs_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtzs.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i32.v2f64"]
        pub fn neon_fcvtzs_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtzs.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i32.f64"]
        pub fn neon_fcvtzs_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtzs.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v2i64.v4f32"]
        pub fn neon_fcvtzs_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzs.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v2i64.f32"]
        pub fn neon_fcvtzs_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzs.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v2i64.v2f64"]
        pub fn neon_fcvtzs_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzs.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.v2i64.f64"]
        pub fn neon_fcvtzs_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzs.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i64.v4f32"]
        pub fn neon_fcvtzs_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtzs.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i64.f32"]
        pub fn neon_fcvtzs_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtzs.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i64.v2f64"]
        pub fn neon_fcvtzs_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtzs.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzs.i64.f64"]
        pub fn neon_fcvtzs_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.fcvtzu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v16i8.v4f32"]
        pub fn neon_fcvtzu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzu.v16i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v16i8.f32"]
        pub fn neon_fcvtzu_v16i8_f32(a: f32) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v16i8.v2f64"]
        pub fn neon_fcvtzu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzu.v16i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v16i8.f64"]
        pub fn neon_fcvtzu_v16i8_f64(a: f64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtzu.i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i8.v4f32"]
        pub fn neon_fcvtzu_i8_v4f32(a: ::simdty::f32x4) -> i8;
        /// The `llvm.aarch64.neon.fcvtzu.i8.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i8.f32"]
        pub fn neon_fcvtzu_i8_f32(a: f32) -> i8;
        /// The `llvm.aarch64.neon.fcvtzu.i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i8.v2f64"]
        pub fn neon_fcvtzu_i8_v2f64(a: ::simdty::f64x2) -> i8;
        /// The `llvm.aarch64.neon.fcvtzu.i8.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i8.f64"]
        pub fn neon_fcvtzu_i8_f64(a: f64) -> i8;
        /// The `llvm.aarch64.neon.fcvtzu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v8i16.v4f32"]
        pub fn neon_fcvtzu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzu.v8i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v8i16.f32"]
        pub fn neon_fcvtzu_v8i16_f32(a: f32) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v8i16.v2f64"]
        pub fn neon_fcvtzu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzu.v8i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v8i16.f64"]
        pub fn neon_fcvtzu_v8i16_f64(a: f64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtzu.i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i16.v4f32"]
        pub fn neon_fcvtzu_i16_v4f32(a: ::simdty::f32x4) -> i16;
        /// The `llvm.aarch64.neon.fcvtzu.i16.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i16.f32"]
        pub fn neon_fcvtzu_i16_f32(a: f32) -> i16;
        /// The `llvm.aarch64.neon.fcvtzu.i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i16.v2f64"]
        pub fn neon_fcvtzu_i16_v2f64(a: ::simdty::f64x2) -> i16;
        /// The `llvm.aarch64.neon.fcvtzu.i16.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i16.f64"]
        pub fn neon_fcvtzu_i16_f64(a: f64) -> i16;
        /// The `llvm.aarch64.neon.fcvtzu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v4i32.v4f32"]
        pub fn neon_fcvtzu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzu.v4i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v4i32.f32"]
        pub fn neon_fcvtzu_v4i32_f32(a: f32) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v4i32.v2f64"]
        pub fn neon_fcvtzu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzu.v4i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v4i32.f64"]
        pub fn neon_fcvtzu_v4i32_f64(a: f64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtzu.i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i32.v4f32"]
        pub fn neon_fcvtzu_i32_v4f32(a: ::simdty::f32x4) -> i32;
        /// The `llvm.aarch64.neon.fcvtzu.i32.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i32.f32"]
        pub fn neon_fcvtzu_i32_f32(a: f32) -> i32;
        /// The `llvm.aarch64.neon.fcvtzu.i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i32.v2f64"]
        pub fn neon_fcvtzu_i32_v2f64(a: ::simdty::f64x2) -> i32;
        /// The `llvm.aarch64.neon.fcvtzu.i32.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i32.f64"]
        pub fn neon_fcvtzu_i32_f64(a: f64) -> i32;
        /// The `llvm.aarch64.neon.fcvtzu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v2i64.v4f32"]
        pub fn neon_fcvtzu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzu.v2i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v2i64.f32"]
        pub fn neon_fcvtzu_v2i64_f32(a: f32) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v2i64.v2f64"]
        pub fn neon_fcvtzu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzu.v2i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.v2i64.f64"]
        pub fn neon_fcvtzu_v2i64_f64(a: f64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtzu.i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i64.v4f32"]
        pub fn neon_fcvtzu_i64_v4f32(a: ::simdty::f32x4) -> i64;
        /// The `llvm.aarch64.neon.fcvtzu.i64.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i64.f32"]
        pub fn neon_fcvtzu_i64_f32(a: f32) -> i64;
        /// The `llvm.aarch64.neon.fcvtzu.i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i64.v2f64"]
        pub fn neon_fcvtzu_i64_v2f64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.aarch64.neon.fcvtzu.i64.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtzu.i64.f64"]
        pub fn neon_fcvtzu_i64_f64(a: f64) -> i64;
        /// The `llvm.aarch64.neon.frintn.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frintn.v4f32"]
        pub fn neon_frintn_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.frintn.f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.frintn.f32"]
        pub fn neon_frintn_f32(a: f32) -> f32;
        /// The `llvm.aarch64.neon.frintn.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frintn.v2f64"]
        pub fn neon_frintn_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.frintn.f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.frintn.f64"]
        pub fn neon_frintn_f64(a: f64) -> f64;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v16i8"]
        pub fn neon_fcvtxn_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v8i16"]
        pub fn neon_fcvtxn_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v4i32"]
        pub fn neon_fcvtxn_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v2i64"]
        pub fn neon_fcvtxn_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v4f32"]
        pub fn neon_fcvtxn_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v16i8.v2f64"]
        pub fn neon_fcvtxn_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v16i8"]
        pub fn neon_fcvtxn_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v8i16"]
        pub fn neon_fcvtxn_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v4i32"]
        pub fn neon_fcvtxn_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v2i64"]
        pub fn neon_fcvtxn_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v4f32"]
        pub fn neon_fcvtxn_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v8i16.v2f64"]
        pub fn neon_fcvtxn_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v16i8"]
        pub fn neon_fcvtxn_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v8i16"]
        pub fn neon_fcvtxn_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v4i32"]
        pub fn neon_fcvtxn_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v2i64"]
        pub fn neon_fcvtxn_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v4f32"]
        pub fn neon_fcvtxn_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4i32.v2f64"]
        pub fn neon_fcvtxn_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v16i8"]
        pub fn neon_fcvtxn_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v8i16"]
        pub fn neon_fcvtxn_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v4i32"]
        pub fn neon_fcvtxn_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v2i64"]
        pub fn neon_fcvtxn_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v4f32"]
        pub fn neon_fcvtxn_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2i64.v2f64"]
        pub fn neon_fcvtxn_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v16i8"]
        pub fn neon_fcvtxn_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v8i16"]
        pub fn neon_fcvtxn_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v4i32"]
        pub fn neon_fcvtxn_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v2i64"]
        pub fn neon_fcvtxn_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v4f32"]
        pub fn neon_fcvtxn_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v4f32.v2f64"]
        pub fn neon_fcvtxn_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v16i8"]
        pub fn neon_fcvtxn_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v8i16"]
        pub fn neon_fcvtxn_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v4i32"]
        pub fn neon_fcvtxn_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v2i64"]
        pub fn neon_fcvtxn_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v4f32"]
        pub fn neon_fcvtxn_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.fcvtxn.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.fcvtxn.v2f64.v2f64"]
        pub fn neon_fcvtxn_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.sisd.fcvtxn` intrinsic.
        #[link_name = "llvm.aarch64.sisd.fcvtxn"]
        pub fn sisd_fcvtxn(a: f64) -> f32;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v16i8"]
        pub fn neon_vcopy_lane_v16i8_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v8i16"]
        pub fn neon_vcopy_lane_v16i8_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v4i32"]
        pub fn neon_vcopy_lane_v16i8_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v2i64"]
        pub fn neon_vcopy_lane_v16i8_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v4f32"]
        pub fn neon_vcopy_lane_v16i8_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v16i8.v2f64"]
        pub fn neon_vcopy_lane_v16i8_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::i8x16, d: i64) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v16i8"]
        pub fn neon_vcopy_lane_v8i16_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v8i16"]
        pub fn neon_vcopy_lane_v8i16_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v4i32"]
        pub fn neon_vcopy_lane_v8i16_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v2i64"]
        pub fn neon_vcopy_lane_v8i16_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v4f32"]
        pub fn neon_vcopy_lane_v8i16_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v8i16.v2f64"]
        pub fn neon_vcopy_lane_v8i16_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::i16x8, d: i64) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v16i8"]
        pub fn neon_vcopy_lane_v4i32_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v8i16"]
        pub fn neon_vcopy_lane_v4i32_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v4i32"]
        pub fn neon_vcopy_lane_v4i32_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v2i64"]
        pub fn neon_vcopy_lane_v4i32_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v4f32"]
        pub fn neon_vcopy_lane_v4i32_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4i32.v2f64"]
        pub fn neon_vcopy_lane_v4i32_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::i32x4, d: i64) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v16i8"]
        pub fn neon_vcopy_lane_v2i64_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v8i16"]
        pub fn neon_vcopy_lane_v2i64_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v4i32"]
        pub fn neon_vcopy_lane_v2i64_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v2i64"]
        pub fn neon_vcopy_lane_v2i64_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v4f32"]
        pub fn neon_vcopy_lane_v2i64_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2i64.v2f64"]
        pub fn neon_vcopy_lane_v2i64_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::i64x2, d: i64) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v16i8"]
        pub fn neon_vcopy_lane_v4f32_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v8i16"]
        pub fn neon_vcopy_lane_v4f32_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v4i32"]
        pub fn neon_vcopy_lane_v4f32_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v2i64"]
        pub fn neon_vcopy_lane_v4f32_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v4f32"]
        pub fn neon_vcopy_lane_v4f32_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v4f32.v2f64"]
        pub fn neon_vcopy_lane_v4f32_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::f32x4, d: i64) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v16i8"]
        pub fn neon_vcopy_lane_v2f64_v16i8(a: ::simdty::i8x16, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v8i16"]
        pub fn neon_vcopy_lane_v2f64_v8i16(a: ::simdty::i16x8, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v4i32"]
        pub fn neon_vcopy_lane_v2f64_v4i32(a: ::simdty::i32x4, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v2i64"]
        pub fn neon_vcopy_lane_v2f64_v2i64(a: ::simdty::i64x2, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v4f32"]
        pub fn neon_vcopy_lane_v2f64_v4f32(a: ::simdty::f32x4, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.vcopy.lane.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.vcopy.lane.v2f64.v2f64"]
        pub fn neon_vcopy_lane_v2f64_v2f64(a: ::simdty::f64x2, b: i64, c: ::simdty::f64x2, d: i64) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.st1x2.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v16i8"]
        pub fn neon_st1x2_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st1x2.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v8i16"]
        pub fn neon_st1x2_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st1x2.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v4i32"]
        pub fn neon_st1x2_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st1x2.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v2i64"]
        pub fn neon_st1x2_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st1x2.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v4f32"]
        pub fn neon_st1x2_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st1x2.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x2.v2f64"]
        pub fn neon_st1x2_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st1x3.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v16i8"]
        pub fn neon_st1x3_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st1x3.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v8i16"]
        pub fn neon_st1x3_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st1x3.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v4i32"]
        pub fn neon_st1x3_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st1x3.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v2i64"]
        pub fn neon_st1x3_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st1x3.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v4f32"]
        pub fn neon_st1x3_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st1x3.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x3.v2f64"]
        pub fn neon_st1x3_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st1x4.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v16i8"]
        pub fn neon_st1x4_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st1x4.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v8i16"]
        pub fn neon_st1x4_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st1x4.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v4i32"]
        pub fn neon_st1x4_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st1x4.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v2i64"]
        pub fn neon_st1x4_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st1x4.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v4f32"]
        pub fn neon_st1x4_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st1x4.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st1x4.v2f64"]
        pub fn neon_st1x4_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st2.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v16i8"]
        pub fn neon_st2_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st2.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v8i16"]
        pub fn neon_st2_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st2.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v4i32"]
        pub fn neon_st2_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st2.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v2i64"]
        pub fn neon_st2_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st2.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v4f32"]
        pub fn neon_st2_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st2.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2.v2f64"]
        pub fn neon_st2_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st3.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v16i8"]
        pub fn neon_st3_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st3.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v8i16"]
        pub fn neon_st3_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st3.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v4i32"]
        pub fn neon_st3_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st3.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v2i64"]
        pub fn neon_st3_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st3.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v4f32"]
        pub fn neon_st3_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st3.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3.v2f64"]
        pub fn neon_st3_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st4.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v16i8"]
        pub fn neon_st4_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: *mut ::simdty::i8x16) -> ();
        /// The `llvm.aarch64.neon.st4.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v8i16"]
        pub fn neon_st4_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: *mut ::simdty::i16x8) -> ();
        /// The `llvm.aarch64.neon.st4.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v4i32"]
        pub fn neon_st4_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: *mut ::simdty::i32x4) -> ();
        /// The `llvm.aarch64.neon.st4.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v2i64"]
        pub fn neon_st4_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: *mut ::simdty::i64x2) -> ();
        /// The `llvm.aarch64.neon.st4.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v4f32"]
        pub fn neon_st4_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: *mut ::simdty::f32x4) -> ();
        /// The `llvm.aarch64.neon.st4.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4.v2f64"]
        pub fn neon_st4_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: *mut ::simdty::f64x2) -> ();
        /// The `llvm.aarch64.neon.st2lane.v16i8.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v16i8.p0i8"]
        pub fn neon_st2lane_v16i8_p0i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st2lane.v8i16.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v8i16.p0i8"]
        pub fn neon_st2lane_v8i16_p0i8(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st2lane.v4i32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v4i32.p0i8"]
        pub fn neon_st2lane_v4i32_p0i8(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st2lane.v2i64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v2i64.p0i8"]
        pub fn neon_st2lane_v2i64_p0i8(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st2lane.v4f32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v4f32.p0i8"]
        pub fn neon_st2lane_v4f32_p0i8(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st2lane.v2f64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st2lane.v2f64.p0i8"]
        pub fn neon_st2lane_v2f64_p0i8(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i64, d: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v16i8.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v16i8.p0i8"]
        pub fn neon_st3lane_v16i8_p0i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v8i16.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v8i16.p0i8"]
        pub fn neon_st3lane_v8i16_p0i8(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v4i32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v4i32.p0i8"]
        pub fn neon_st3lane_v4i32_p0i8(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v2i64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v2i64.p0i8"]
        pub fn neon_st3lane_v2i64_p0i8(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v4f32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v4f32.p0i8"]
        pub fn neon_st3lane_v4f32_p0i8(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st3lane.v2f64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st3lane.v2f64.p0i8"]
        pub fn neon_st3lane_v2f64_p0i8(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i64, e: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v16i8.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v16i8.p0i8"]
        pub fn neon_st4lane_v16i8_p0i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v8i16.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v8i16.p0i8"]
        pub fn neon_st4lane_v8i16_p0i8(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v4i32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v4i32.p0i8"]
        pub fn neon_st4lane_v4i32_p0i8(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v2i64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v2i64.p0i8"]
        pub fn neon_st4lane_v2i64_p0i8(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v4f32.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v4f32.p0i8"]
        pub fn neon_st4lane_v4f32_p0i8(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.st4lane.v2f64.p0i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.st4lane.v2f64.p0i8"]
        pub fn neon_st4lane_v2f64_p0i8(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: i64, f: *mut i8) -> ();
        /// The `llvm.aarch64.neon.tbl1.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v16i8"]
        pub fn neon_tbl1_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbl1.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v8i16"]
        pub fn neon_tbl1_v8i16(a: ::simdty::i8x16, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbl1.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v4i32"]
        pub fn neon_tbl1_v4i32(a: ::simdty::i8x16, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbl1.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v2i64"]
        pub fn neon_tbl1_v2i64(a: ::simdty::i8x16, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbl1.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v4f32"]
        pub fn neon_tbl1_v4f32(a: ::simdty::i8x16, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbl1.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl1.v2f64"]
        pub fn neon_tbl1_v2f64(a: ::simdty::i8x16, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbl2.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v16i8"]
        pub fn neon_tbl2_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbl2.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v8i16"]
        pub fn neon_tbl2_v8i16(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbl2.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v4i32"]
        pub fn neon_tbl2_v4i32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbl2.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v2i64"]
        pub fn neon_tbl2_v2i64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbl2.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v4f32"]
        pub fn neon_tbl2_v4f32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbl2.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl2.v2f64"]
        pub fn neon_tbl2_v2f64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbl3.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v16i8"]
        pub fn neon_tbl3_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbl3.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v8i16"]
        pub fn neon_tbl3_v8i16(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbl3.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v4i32"]
        pub fn neon_tbl3_v4i32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbl3.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v2i64"]
        pub fn neon_tbl3_v2i64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbl3.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v4f32"]
        pub fn neon_tbl3_v4f32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbl3.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl3.v2f64"]
        pub fn neon_tbl3_v2f64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbl4.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v16i8"]
        pub fn neon_tbl4_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbl4.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v8i16"]
        pub fn neon_tbl4_v8i16(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbl4.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v4i32"]
        pub fn neon_tbl4_v4i32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbl4.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v2i64"]
        pub fn neon_tbl4_v2i64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbl4.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v4f32"]
        pub fn neon_tbl4_v4f32(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbl4.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbl4.v2f64"]
        pub fn neon_tbl4_v2f64(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbx1.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v16i8"]
        pub fn neon_tbx1_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbx1.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v8i16"]
        pub fn neon_tbx1_v8i16(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbx1.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v4i32"]
        pub fn neon_tbx1_v4i32(a: ::simdty::i32x4, b: ::simdty::i8x16, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbx1.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v2i64"]
        pub fn neon_tbx1_v2i64(a: ::simdty::i64x2, b: ::simdty::i8x16, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbx1.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v4f32"]
        pub fn neon_tbx1_v4f32(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbx1.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx1.v2f64"]
        pub fn neon_tbx1_v2f64(a: ::simdty::f64x2, b: ::simdty::i8x16, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbx2.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v16i8"]
        pub fn neon_tbx2_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbx2.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v8i16"]
        pub fn neon_tbx2_v8i16(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbx2.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v4i32"]
        pub fn neon_tbx2_v4i32(a: ::simdty::i32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbx2.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v2i64"]
        pub fn neon_tbx2_v2i64(a: ::simdty::i64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbx2.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v4f32"]
        pub fn neon_tbx2_v4f32(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbx2.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx2.v2f64"]
        pub fn neon_tbx2_v2f64(a: ::simdty::f64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbx3.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v16i8"]
        pub fn neon_tbx3_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbx3.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v8i16"]
        pub fn neon_tbx3_v8i16(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbx3.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v4i32"]
        pub fn neon_tbx3_v4i32(a: ::simdty::i32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbx3.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v2i64"]
        pub fn neon_tbx3_v2i64(a: ::simdty::i64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbx3.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v4f32"]
        pub fn neon_tbx3_v4f32(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbx3.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx3.v2f64"]
        pub fn neon_tbx3_v2f64(a: ::simdty::f64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.neon.tbx4.v16i8` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v16i8"]
        pub fn neon_tbx4_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.neon.tbx4.v8i16` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v8i16"]
        pub fn neon_tbx4_v8i16(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.aarch64.neon.tbx4.v4i32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v4i32"]
        pub fn neon_tbx4_v4i32(a: ::simdty::i32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.neon.tbx4.v2i64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v2i64"]
        pub fn neon_tbx4_v2i64(a: ::simdty::i64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.aarch64.neon.tbx4.v4f32` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v4f32"]
        pub fn neon_tbx4_v4f32(a: ::simdty::f32x4, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.aarch64.neon.tbx4.v2f64` intrinsic.
        #[link_name = "llvm.aarch64.neon.tbx4.v2f64"]
        pub fn neon_tbx4_v2f64(a: ::simdty::f64x2, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.aarch64.crypto.aese` intrinsic.
        #[link_name = "llvm.aarch64.crypto.aese"]
        pub fn crypto_aese(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.crypto.aesd` intrinsic.
        #[link_name = "llvm.aarch64.crypto.aesd"]
        pub fn crypto_aesd(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.crypto.aesmc` intrinsic.
        #[link_name = "llvm.aarch64.crypto.aesmc"]
        pub fn crypto_aesmc(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.crypto.aesimc` intrinsic.
        #[link_name = "llvm.aarch64.crypto.aesimc"]
        pub fn crypto_aesimc(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.aarch64.crypto.sha1c` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1c"]
        pub fn crypto_sha1c(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha1p` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1p"]
        pub fn crypto_sha1p(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha1m` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1m"]
        pub fn crypto_sha1m(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha1h` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1h"]
        pub fn crypto_sha1h(a: i32) -> i32;
        /// The `llvm.aarch64.crypto.sha1su0` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1su0"]
        pub fn crypto_sha1su0(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha1su1` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha1su1"]
        pub fn crypto_sha1su1(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha256h` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha256h"]
        pub fn crypto_sha256h(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha256h2` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha256h2"]
        pub fn crypto_sha256h2(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha256su0` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha256su0"]
        pub fn crypto_sha256su0(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crypto.sha256su1` intrinsic.
        #[link_name = "llvm.aarch64.crypto.sha256su1"]
        pub fn crypto_sha256su1(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.aarch64.crc32b` intrinsic.
        #[link_name = "llvm.aarch64.crc32b"]
        pub fn crc32b(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32cb` intrinsic.
        #[link_name = "llvm.aarch64.crc32cb"]
        pub fn crc32cb(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32h` intrinsic.
        #[link_name = "llvm.aarch64.crc32h"]
        pub fn crc32h(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32ch` intrinsic.
        #[link_name = "llvm.aarch64.crc32ch"]
        pub fn crc32ch(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32w` intrinsic.
        #[link_name = "llvm.aarch64.crc32w"]
        pub fn crc32w(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32cw` intrinsic.
        #[link_name = "llvm.aarch64.crc32cw"]
        pub fn crc32cw(a: i32, b: i32) -> i32;
        /// The `llvm.aarch64.crc32x` intrinsic.
        #[link_name = "llvm.aarch64.crc32x"]
        pub fn crc32x(a: i32, b: i64) -> i32;
        /// The `llvm.aarch64.crc32cx` intrinsic.
        #[link_name = "llvm.aarch64.crc32cx"]
        pub fn crc32cx(a: i32, b: i64) -> i32;
    }
}
/// LLVM intrinsics for the arm architecture.
pub mod arm {
    extern {
        /// The `llvm.arm.space` intrinsic.
        #[link_name = "llvm.arm.space"]
        pub fn space(a: i32, b: i32) -> i32;
        /// The `llvm.arm.qadd` intrinsic; known as `__builtin_arm_qadd` in GCC.
        #[link_name = "llvm.arm.qadd"]
        pub fn qadd(a: i32, b: i32) -> i32;
        /// The `llvm.arm.qsub` intrinsic; known as `__builtin_arm_qsub` in GCC.
        #[link_name = "llvm.arm.qsub"]
        pub fn qsub(a: i32, b: i32) -> i32;
        /// The `llvm.arm.ssat` intrinsic; known as `__builtin_arm_ssat` in GCC.
        #[link_name = "llvm.arm.ssat"]
        pub fn ssat(a: i32, b: i32) -> i32;
        /// The `llvm.arm.usat` intrinsic; known as `__builtin_arm_usat` in GCC.
        #[link_name = "llvm.arm.usat"]
        pub fn usat(a: i32, b: i32) -> i32;
        /// The `llvm.arm.ldrex.p0i8` intrinsic.
        #[link_name = "llvm.arm.ldrex.p0i8"]
        pub fn ldrex_p0i8(a: *mut i8) -> i32;
        /// The `llvm.arm.strex.p0i8` intrinsic.
        #[link_name = "llvm.arm.strex.p0i8"]
        pub fn strex_p0i8(a: i32, b: *mut i8) -> i32;
        /// The `llvm.arm.ldaex.p0i8` intrinsic.
        #[link_name = "llvm.arm.ldaex.p0i8"]
        pub fn ldaex_p0i8(a: *mut i8) -> i32;
        /// The `llvm.arm.stlex.p0i8` intrinsic.
        #[link_name = "llvm.arm.stlex.p0i8"]
        pub fn stlex_p0i8(a: i32, b: *mut i8) -> i32;
        /// The `llvm.arm.clrex` intrinsic.
        #[link_name = "llvm.arm.clrex"]
        pub fn clrex() -> ();
        /// The `llvm.arm.strexd` intrinsic.
        #[link_name = "llvm.arm.strexd"]
        pub fn strexd(a: i32, b: i32, c: *mut i8) -> i32;
        /// The `llvm.arm.stlexd` intrinsic.
        #[link_name = "llvm.arm.stlexd"]
        pub fn stlexd(a: i32, b: i32, c: *mut i8) -> i32;
        /// The `llvm.arm.dmb` intrinsic; known as `__builtin_arm_dmb` in GCC.
        #[link_name = "llvm.arm.dmb"]
        pub fn dmb(a: i32) -> ();
        /// The `llvm.arm.dsb` intrinsic; known as `__builtin_arm_dsb` in GCC.
        #[link_name = "llvm.arm.dsb"]
        pub fn dsb(a: i32) -> ();
        /// The `llvm.arm.isb` intrinsic; known as `__builtin_arm_isb` in GCC.
        #[link_name = "llvm.arm.isb"]
        pub fn isb(a: i32) -> ();
        /// The `llvm.arm.get.fpscr` intrinsic; known as `__builtin_arm_get_fpscr` in GCC.
        #[link_name = "llvm.arm.get.fpscr"]
        pub fn get_fpscr() -> i32;
        /// The `llvm.arm.set.fpscr` intrinsic; known as `__builtin_arm_set_fpscr` in GCC.
        #[link_name = "llvm.arm.set.fpscr"]
        pub fn set_fpscr(a: i32) -> ();
        /// The `llvm.arm.vcvtr.v4f32` intrinsic.
        #[link_name = "llvm.arm.vcvtr.v4f32"]
        pub fn vcvtr_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.arm.vcvtr.f32` intrinsic.
        #[link_name = "llvm.arm.vcvtr.f32"]
        pub fn vcvtr_f32(a: f32) -> f32;
        /// The `llvm.arm.vcvtr.v2f64` intrinsic.
        #[link_name = "llvm.arm.vcvtr.v2f64"]
        pub fn vcvtr_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.arm.vcvtr.f64` intrinsic.
        #[link_name = "llvm.arm.vcvtr.f64"]
        pub fn vcvtr_f64(a: f64) -> f32;
        /// The `llvm.arm.vcvtru.v4f32` intrinsic.
        #[link_name = "llvm.arm.vcvtru.v4f32"]
        pub fn vcvtru_v4f32(a: ::simdty::f32x4) -> f32;
        /// The `llvm.arm.vcvtru.f32` intrinsic.
        #[link_name = "llvm.arm.vcvtru.f32"]
        pub fn vcvtru_f32(a: f32) -> f32;
        /// The `llvm.arm.vcvtru.v2f64` intrinsic.
        #[link_name = "llvm.arm.vcvtru.v2f64"]
        pub fn vcvtru_v2f64(a: ::simdty::f64x2) -> f32;
        /// The `llvm.arm.vcvtru.f64` intrinsic.
        #[link_name = "llvm.arm.vcvtru.f64"]
        pub fn vcvtru_f64(a: f64) -> f32;
        /// The `llvm.arm.ldc` intrinsic; known as `__builtin_arm_ldc` in GCC.
        #[link_name = "llvm.arm.ldc"]
        pub fn ldc(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.ldcl` intrinsic; known as `__builtin_arm_ldcl` in GCC.
        #[link_name = "llvm.arm.ldcl"]
        pub fn ldcl(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.ldc2` intrinsic; known as `__builtin_arm_ldc2` in GCC.
        #[link_name = "llvm.arm.ldc2"]
        pub fn ldc2(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.ldc2l` intrinsic; known as `__builtin_arm_ldc2l` in GCC.
        #[link_name = "llvm.arm.ldc2l"]
        pub fn ldc2l(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.stc` intrinsic; known as `__builtin_arm_stc` in GCC.
        #[link_name = "llvm.arm.stc"]
        pub fn stc(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.stcl` intrinsic; known as `__builtin_arm_stcl` in GCC.
        #[link_name = "llvm.arm.stcl"]
        pub fn stcl(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.stc2` intrinsic; known as `__builtin_arm_stc2` in GCC.
        #[link_name = "llvm.arm.stc2"]
        pub fn stc2(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.stc2l` intrinsic; known as `__builtin_arm_stc2l` in GCC.
        #[link_name = "llvm.arm.stc2l"]
        pub fn stc2l(a: i32, b: i32, c: *mut i8) -> ();
        /// The `llvm.arm.mcr` intrinsic; known as `__builtin_arm_mcr` in GCC.
        #[link_name = "llvm.arm.mcr"]
        pub fn mcr(a: i32, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.arm.mcr2` intrinsic; known as `__builtin_arm_mcr2` in GCC.
        #[link_name = "llvm.arm.mcr2"]
        pub fn mcr2(a: i32, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.arm.mrc` intrinsic; known as `__builtin_arm_mrc` in GCC.
        #[link_name = "llvm.arm.mrc"]
        pub fn mrc(a: i32, b: i32, c: i32, d: i32, e: i32) -> i32;
        /// The `llvm.arm.mrc2` intrinsic; known as `__builtin_arm_mrc2` in GCC.
        #[link_name = "llvm.arm.mrc2"]
        pub fn mrc2(a: i32, b: i32, c: i32, d: i32, e: i32) -> i32;
        /// The `llvm.arm.cdp` intrinsic; known as `__builtin_arm_cdp` in GCC.
        #[link_name = "llvm.arm.cdp"]
        pub fn cdp(a: i32, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.arm.cdp2` intrinsic; known as `__builtin_arm_cdp2` in GCC.
        #[link_name = "llvm.arm.cdp2"]
        pub fn cdp2(a: i32, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.arm.mcrr` intrinsic.
        #[link_name = "llvm.arm.mcrr"]
        pub fn mcrr(a: i32, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.arm.mcrr2` intrinsic.
        #[link_name = "llvm.arm.mcrr2"]
        pub fn mcrr2(a: i32, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.arm.crc32b` intrinsic.
        #[link_name = "llvm.arm.crc32b"]
        pub fn crc32b(a: i32, b: i32) -> i32;
        /// The `llvm.arm.crc32cb` intrinsic.
        #[link_name = "llvm.arm.crc32cb"]
        pub fn crc32cb(a: i32, b: i32) -> i32;
        /// The `llvm.arm.crc32h` intrinsic.
        #[link_name = "llvm.arm.crc32h"]
        pub fn crc32h(a: i32, b: i32) -> i32;
        /// The `llvm.arm.crc32ch` intrinsic.
        #[link_name = "llvm.arm.crc32ch"]
        pub fn crc32ch(a: i32, b: i32) -> i32;
        /// The `llvm.arm.crc32w` intrinsic.
        #[link_name = "llvm.arm.crc32w"]
        pub fn crc32w(a: i32, b: i32) -> i32;
        /// The `llvm.arm.crc32cw` intrinsic.
        #[link_name = "llvm.arm.crc32cw"]
        pub fn crc32cw(a: i32, b: i32) -> i32;
        /// The `llvm.arm.hint` intrinsic.
        #[link_name = "llvm.arm.hint"]
        pub fn hint(a: i32) -> ();
        /// The `llvm.arm.dbg` intrinsic.
        #[link_name = "llvm.arm.dbg"]
        pub fn dbg(a: i32) -> ();
        /// The `llvm.arm.rbit` intrinsic.
        #[link_name = "llvm.arm.rbit"]
        pub fn rbit(a: i32) -> i32;
        /// The `llvm.arm.undefined` intrinsic.
        #[link_name = "llvm.arm.undefined"]
        pub fn undefined(a: i32) -> ();
        /// The `llvm.arm.neon.vhadds.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v16i8"]
        pub fn neon_vhadds_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vhadds.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v8i16"]
        pub fn neon_vhadds_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vhadds.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v4i32"]
        pub fn neon_vhadds_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vhadds.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v2i64"]
        pub fn neon_vhadds_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vhadds.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v4f32"]
        pub fn neon_vhadds_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vhadds.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vhadds.v2f64"]
        pub fn neon_vhadds_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vhaddu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v16i8"]
        pub fn neon_vhaddu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vhaddu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v8i16"]
        pub fn neon_vhaddu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vhaddu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v4i32"]
        pub fn neon_vhaddu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vhaddu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v2i64"]
        pub fn neon_vhaddu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vhaddu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v4f32"]
        pub fn neon_vhaddu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vhaddu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vhaddu.v2f64"]
        pub fn neon_vhaddu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrhadds.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v16i8"]
        pub fn neon_vrhadds_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrhadds.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v8i16"]
        pub fn neon_vrhadds_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrhadds.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v4i32"]
        pub fn neon_vrhadds_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrhadds.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v2i64"]
        pub fn neon_vrhadds_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrhadds.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v4f32"]
        pub fn neon_vrhadds_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrhadds.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrhadds.v2f64"]
        pub fn neon_vrhadds_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrhaddu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v16i8"]
        pub fn neon_vrhaddu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrhaddu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v8i16"]
        pub fn neon_vrhaddu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrhaddu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v4i32"]
        pub fn neon_vrhaddu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrhaddu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v2i64"]
        pub fn neon_vrhaddu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrhaddu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v4f32"]
        pub fn neon_vrhaddu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrhaddu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrhaddu.v2f64"]
        pub fn neon_vrhaddu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqadds.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v16i8"]
        pub fn neon_vqadds_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqadds.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v8i16"]
        pub fn neon_vqadds_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqadds.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v4i32"]
        pub fn neon_vqadds_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqadds.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v2i64"]
        pub fn neon_vqadds_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqadds.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v4f32"]
        pub fn neon_vqadds_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqadds.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqadds.v2f64"]
        pub fn neon_vqadds_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqaddu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v16i8"]
        pub fn neon_vqaddu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqaddu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v8i16"]
        pub fn neon_vqaddu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqaddu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v4i32"]
        pub fn neon_vqaddu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqaddu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v2i64"]
        pub fn neon_vqaddu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqaddu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v4f32"]
        pub fn neon_vqaddu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqaddu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqaddu.v2f64"]
        pub fn neon_vqaddu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vmulp.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v16i8"]
        pub fn neon_vmulp_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vmulp.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v8i16"]
        pub fn neon_vmulp_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vmulp.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v4i32"]
        pub fn neon_vmulp_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vmulp.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v2i64"]
        pub fn neon_vmulp_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vmulp.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v4f32"]
        pub fn neon_vmulp_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vmulp.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vmulp.v2f64"]
        pub fn neon_vmulp_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqdmulh.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v16i8"]
        pub fn neon_vqdmulh_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqdmulh.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v8i16"]
        pub fn neon_vqdmulh_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqdmulh.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v4i32"]
        pub fn neon_vqdmulh_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqdmulh.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v2i64"]
        pub fn neon_vqdmulh_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqdmulh.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v4f32"]
        pub fn neon_vqdmulh_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqdmulh.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqdmulh.v2f64"]
        pub fn neon_vqdmulh_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqrdmulh.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v16i8"]
        pub fn neon_vqrdmulh_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqrdmulh.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v8i16"]
        pub fn neon_vqrdmulh_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqrdmulh.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v4i32"]
        pub fn neon_vqrdmulh_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqrdmulh.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v2i64"]
        pub fn neon_vqrdmulh_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqrdmulh.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v4f32"]
        pub fn neon_vqrdmulh_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqrdmulh.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrdmulh.v2f64"]
        pub fn neon_vqrdmulh_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vmaxs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v16i8"]
        pub fn neon_vmaxs_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vmaxs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v8i16"]
        pub fn neon_vmaxs_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vmaxs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v4i32"]
        pub fn neon_vmaxs_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vmaxs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v2i64"]
        pub fn neon_vmaxs_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vmaxs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v4f32"]
        pub fn neon_vmaxs_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vmaxs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxs.v2f64"]
        pub fn neon_vmaxs_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vmaxu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v16i8"]
        pub fn neon_vmaxu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vmaxu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v8i16"]
        pub fn neon_vmaxu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vmaxu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v4i32"]
        pub fn neon_vmaxu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vmaxu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v2i64"]
        pub fn neon_vmaxu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vmaxu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v4f32"]
        pub fn neon_vmaxu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vmaxu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxu.v2f64"]
        pub fn neon_vmaxu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vmaxnm.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v16i8"]
        pub fn neon_vmaxnm_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vmaxnm.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v8i16"]
        pub fn neon_vmaxnm_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vmaxnm.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v4i32"]
        pub fn neon_vmaxnm_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vmaxnm.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v2i64"]
        pub fn neon_vmaxnm_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vmaxnm.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v4f32"]
        pub fn neon_vmaxnm_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vmaxnm.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vmaxnm.v2f64"]
        pub fn neon_vmaxnm_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vmins.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v16i8"]
        pub fn neon_vmins_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vmins.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v8i16"]
        pub fn neon_vmins_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vmins.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v4i32"]
        pub fn neon_vmins_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vmins.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v2i64"]
        pub fn neon_vmins_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vmins.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v4f32"]
        pub fn neon_vmins_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vmins.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vmins.v2f64"]
        pub fn neon_vmins_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vminu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v16i8"]
        pub fn neon_vminu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vminu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v8i16"]
        pub fn neon_vminu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vminu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v4i32"]
        pub fn neon_vminu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vminu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v2i64"]
        pub fn neon_vminu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vminu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v4f32"]
        pub fn neon_vminu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vminu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vminu.v2f64"]
        pub fn neon_vminu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vminnm.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v16i8"]
        pub fn neon_vminnm_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vminnm.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v8i16"]
        pub fn neon_vminnm_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vminnm.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v4i32"]
        pub fn neon_vminnm_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vminnm.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v2i64"]
        pub fn neon_vminnm_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vminnm.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v4f32"]
        pub fn neon_vminnm_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vminnm.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vminnm.v2f64"]
        pub fn neon_vminnm_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrecps.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v16i8"]
        pub fn neon_vrecps_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrecps.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v8i16"]
        pub fn neon_vrecps_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrecps.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v4i32"]
        pub fn neon_vrecps_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrecps.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v2i64"]
        pub fn neon_vrecps_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrecps.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v4f32"]
        pub fn neon_vrecps_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrecps.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrecps.v2f64"]
        pub fn neon_vrecps_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrsqrts.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v16i8"]
        pub fn neon_vrsqrts_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrsqrts.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v8i16"]
        pub fn neon_vrsqrts_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrsqrts.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v4i32"]
        pub fn neon_vrsqrts_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrsqrts.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v2i64"]
        pub fn neon_vrsqrts_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrsqrts.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v4f32"]
        pub fn neon_vrsqrts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrsqrts.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrts.v2f64"]
        pub fn neon_vrsqrts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vhsubs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v16i8"]
        pub fn neon_vhsubs_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vhsubs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v8i16"]
        pub fn neon_vhsubs_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vhsubs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v4i32"]
        pub fn neon_vhsubs_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vhsubs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v2i64"]
        pub fn neon_vhsubs_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vhsubs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v4f32"]
        pub fn neon_vhsubs_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vhsubs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubs.v2f64"]
        pub fn neon_vhsubs_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vhsubu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v16i8"]
        pub fn neon_vhsubu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vhsubu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v8i16"]
        pub fn neon_vhsubu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vhsubu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v4i32"]
        pub fn neon_vhsubu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vhsubu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v2i64"]
        pub fn neon_vhsubu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vhsubu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v4f32"]
        pub fn neon_vhsubu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vhsubu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vhsubu.v2f64"]
        pub fn neon_vhsubu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqsubs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v16i8"]
        pub fn neon_vqsubs_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqsubs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v8i16"]
        pub fn neon_vqsubs_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqsubs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v4i32"]
        pub fn neon_vqsubs_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqsubs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v2i64"]
        pub fn neon_vqsubs_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqsubs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v4f32"]
        pub fn neon_vqsubs_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqsubs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubs.v2f64"]
        pub fn neon_vqsubs_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqsubu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v16i8"]
        pub fn neon_vqsubu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqsubu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v8i16"]
        pub fn neon_vqsubu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqsubu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v4i32"]
        pub fn neon_vqsubu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqsubu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v2i64"]
        pub fn neon_vqsubu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqsubu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v4f32"]
        pub fn neon_vqsubu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqsubu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqsubu.v2f64"]
        pub fn neon_vqsubu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v16i8"]
        pub fn neon_vacge_v16i8_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v8i16"]
        pub fn neon_vacge_v16i8_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v4i32"]
        pub fn neon_vacge_v16i8_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v2i64"]
        pub fn neon_vacge_v16i8_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v4f32"]
        pub fn neon_vacge_v16i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v16i8.v2f64"]
        pub fn neon_vacge_v16i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacge.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v16i8"]
        pub fn neon_vacge_v8i16_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v8i16"]
        pub fn neon_vacge_v8i16_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v4i32"]
        pub fn neon_vacge_v8i16_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v2i64"]
        pub fn neon_vacge_v8i16_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v4f32"]
        pub fn neon_vacge_v8i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v8i16.v2f64"]
        pub fn neon_vacge_v8i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacge.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v16i8"]
        pub fn neon_vacge_v4i32_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v8i16"]
        pub fn neon_vacge_v4i32_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v4i32"]
        pub fn neon_vacge_v4i32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v2i64"]
        pub fn neon_vacge_v4i32_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v4f32"]
        pub fn neon_vacge_v4i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4i32.v2f64"]
        pub fn neon_vacge_v4i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacge.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v16i8"]
        pub fn neon_vacge_v2i64_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v8i16"]
        pub fn neon_vacge_v2i64_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v4i32"]
        pub fn neon_vacge_v2i64_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v2i64"]
        pub fn neon_vacge_v2i64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v4f32"]
        pub fn neon_vacge_v2i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2i64.v2f64"]
        pub fn neon_vacge_v2i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacge.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v16i8"]
        pub fn neon_vacge_v4f32_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v8i16"]
        pub fn neon_vacge_v4f32_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v4i32"]
        pub fn neon_vacge_v4f32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v2i64"]
        pub fn neon_vacge_v4f32_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v4f32"]
        pub fn neon_vacge_v4f32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v4f32.v2f64"]
        pub fn neon_vacge_v4f32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacge.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v16i8"]
        pub fn neon_vacge_v2f64_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v8i16"]
        pub fn neon_vacge_v2f64_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v4i32"]
        pub fn neon_vacge_v2f64_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v2i64"]
        pub fn neon_vacge_v2f64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v4f32"]
        pub fn neon_vacge_v2f64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacge.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacge.v2f64.v2f64"]
        pub fn neon_vacge_v2f64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v16i8"]
        pub fn neon_vacgt_v16i8_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v8i16"]
        pub fn neon_vacgt_v16i8_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v4i32"]
        pub fn neon_vacgt_v16i8_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v2i64"]
        pub fn neon_vacgt_v16i8_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v4f32"]
        pub fn neon_vacgt_v16i8_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v16i8.v2f64"]
        pub fn neon_vacgt_v16i8_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vacgt.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v16i8"]
        pub fn neon_vacgt_v8i16_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v8i16"]
        pub fn neon_vacgt_v8i16_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v4i32"]
        pub fn neon_vacgt_v8i16_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v2i64"]
        pub fn neon_vacgt_v8i16_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v4f32"]
        pub fn neon_vacgt_v8i16_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v8i16.v2f64"]
        pub fn neon_vacgt_v8i16_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vacgt.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v16i8"]
        pub fn neon_vacgt_v4i32_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v8i16"]
        pub fn neon_vacgt_v4i32_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v4i32"]
        pub fn neon_vacgt_v4i32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v2i64"]
        pub fn neon_vacgt_v4i32_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v4f32"]
        pub fn neon_vacgt_v4i32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4i32.v2f64"]
        pub fn neon_vacgt_v4i32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vacgt.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v16i8"]
        pub fn neon_vacgt_v2i64_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v8i16"]
        pub fn neon_vacgt_v2i64_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v4i32"]
        pub fn neon_vacgt_v2i64_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v2i64"]
        pub fn neon_vacgt_v2i64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v4f32"]
        pub fn neon_vacgt_v2i64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2i64.v2f64"]
        pub fn neon_vacgt_v2i64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vacgt.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v16i8"]
        pub fn neon_vacgt_v4f32_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v8i16"]
        pub fn neon_vacgt_v4f32_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v4i32"]
        pub fn neon_vacgt_v4f32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v2i64"]
        pub fn neon_vacgt_v4f32_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v4f32"]
        pub fn neon_vacgt_v4f32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v4f32.v2f64"]
        pub fn neon_vacgt_v4f32_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vacgt.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v16i8"]
        pub fn neon_vacgt_v2f64_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v8i16"]
        pub fn neon_vacgt_v2f64_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v4i32"]
        pub fn neon_vacgt_v2f64_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v2i64"]
        pub fn neon_vacgt_v2f64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v4f32"]
        pub fn neon_vacgt_v2f64_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vacgt.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vacgt.v2f64.v2f64"]
        pub fn neon_vacgt_v2f64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vabds.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v16i8"]
        pub fn neon_vabds_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vabds.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v8i16"]
        pub fn neon_vabds_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vabds.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v4i32"]
        pub fn neon_vabds_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vabds.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v2i64"]
        pub fn neon_vabds_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vabds.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v4f32"]
        pub fn neon_vabds_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vabds.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vabds.v2f64"]
        pub fn neon_vabds_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vabdu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v16i8"]
        pub fn neon_vabdu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vabdu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v8i16"]
        pub fn neon_vabdu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vabdu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v4i32"]
        pub fn neon_vabdu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vabdu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v2i64"]
        pub fn neon_vabdu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vabdu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v4f32"]
        pub fn neon_vabdu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vabdu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vabdu.v2f64"]
        pub fn neon_vabdu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadd.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v16i8"]
        pub fn neon_vpadd_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadd.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v8i16"]
        pub fn neon_vpadd_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadd.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v4i32"]
        pub fn neon_vpadd_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadd.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v2i64"]
        pub fn neon_vpadd_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadd.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v4f32"]
        pub fn neon_vpadd_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadd.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadd.v2f64"]
        pub fn neon_vpadd_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v16i8"]
        pub fn neon_vpaddls_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v8i16"]
        pub fn neon_vpaddls_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v4i32"]
        pub fn neon_vpaddls_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v2i64"]
        pub fn neon_vpaddls_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v4f32"]
        pub fn neon_vpaddls_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v16i8.v2f64"]
        pub fn neon_vpaddls_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddls.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v16i8"]
        pub fn neon_vpaddls_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v8i16"]
        pub fn neon_vpaddls_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v4i32"]
        pub fn neon_vpaddls_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v2i64"]
        pub fn neon_vpaddls_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v4f32"]
        pub fn neon_vpaddls_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v8i16.v2f64"]
        pub fn neon_vpaddls_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddls.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v16i8"]
        pub fn neon_vpaddls_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v8i16"]
        pub fn neon_vpaddls_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v4i32"]
        pub fn neon_vpaddls_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v2i64"]
        pub fn neon_vpaddls_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v4f32"]
        pub fn neon_vpaddls_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4i32.v2f64"]
        pub fn neon_vpaddls_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddls.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v16i8"]
        pub fn neon_vpaddls_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v8i16"]
        pub fn neon_vpaddls_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v4i32"]
        pub fn neon_vpaddls_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v2i64"]
        pub fn neon_vpaddls_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v4f32"]
        pub fn neon_vpaddls_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2i64.v2f64"]
        pub fn neon_vpaddls_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddls.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v16i8"]
        pub fn neon_vpaddls_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v8i16"]
        pub fn neon_vpaddls_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v4i32"]
        pub fn neon_vpaddls_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v2i64"]
        pub fn neon_vpaddls_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v4f32"]
        pub fn neon_vpaddls_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v4f32.v2f64"]
        pub fn neon_vpaddls_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddls.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v16i8"]
        pub fn neon_vpaddls_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v8i16"]
        pub fn neon_vpaddls_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v4i32"]
        pub fn neon_vpaddls_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v2i64"]
        pub fn neon_vpaddls_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v4f32"]
        pub fn neon_vpaddls_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddls.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddls.v2f64.v2f64"]
        pub fn neon_vpaddls_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v16i8"]
        pub fn neon_vpaddlu_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v8i16"]
        pub fn neon_vpaddlu_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v4i32"]
        pub fn neon_vpaddlu_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v2i64"]
        pub fn neon_vpaddlu_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v4f32"]
        pub fn neon_vpaddlu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v16i8.v2f64"]
        pub fn neon_vpaddlu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v16i8"]
        pub fn neon_vpaddlu_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v8i16"]
        pub fn neon_vpaddlu_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v4i32"]
        pub fn neon_vpaddlu_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v2i64"]
        pub fn neon_vpaddlu_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v4f32"]
        pub fn neon_vpaddlu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v8i16.v2f64"]
        pub fn neon_vpaddlu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v16i8"]
        pub fn neon_vpaddlu_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v8i16"]
        pub fn neon_vpaddlu_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v4i32"]
        pub fn neon_vpaddlu_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v2i64"]
        pub fn neon_vpaddlu_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v4f32"]
        pub fn neon_vpaddlu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4i32.v2f64"]
        pub fn neon_vpaddlu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v16i8"]
        pub fn neon_vpaddlu_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v8i16"]
        pub fn neon_vpaddlu_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v4i32"]
        pub fn neon_vpaddlu_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v2i64"]
        pub fn neon_vpaddlu_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v4f32"]
        pub fn neon_vpaddlu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2i64.v2f64"]
        pub fn neon_vpaddlu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v16i8"]
        pub fn neon_vpaddlu_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v8i16"]
        pub fn neon_vpaddlu_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v4i32"]
        pub fn neon_vpaddlu_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v2i64"]
        pub fn neon_vpaddlu_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v4f32"]
        pub fn neon_vpaddlu_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v4f32.v2f64"]
        pub fn neon_vpaddlu_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v16i8"]
        pub fn neon_vpaddlu_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v8i16"]
        pub fn neon_vpaddlu_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v4i32"]
        pub fn neon_vpaddlu_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v2i64"]
        pub fn neon_vpaddlu_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v4f32"]
        pub fn neon_vpaddlu_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpaddlu.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpaddlu.v2f64.v2f64"]
        pub fn neon_vpaddlu_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v16i8"]
        pub fn neon_vpadals_v16i8_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v8i16"]
        pub fn neon_vpadals_v16i8_v8i16(a: ::simdty::i8x16, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v4i32"]
        pub fn neon_vpadals_v16i8_v4i32(a: ::simdty::i8x16, b: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v2i64"]
        pub fn neon_vpadals_v16i8_v2i64(a: ::simdty::i8x16, b: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v4f32"]
        pub fn neon_vpadals_v16i8_v4f32(a: ::simdty::i8x16, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v16i8.v2f64"]
        pub fn neon_vpadals_v16i8_v2f64(a: ::simdty::i8x16, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadals.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v16i8"]
        pub fn neon_vpadals_v8i16_v16i8(a: ::simdty::i16x8, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v8i16"]
        pub fn neon_vpadals_v8i16_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v4i32"]
        pub fn neon_vpadals_v8i16_v4i32(a: ::simdty::i16x8, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v2i64"]
        pub fn neon_vpadals_v8i16_v2i64(a: ::simdty::i16x8, b: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v4f32"]
        pub fn neon_vpadals_v8i16_v4f32(a: ::simdty::i16x8, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v8i16.v2f64"]
        pub fn neon_vpadals_v8i16_v2f64(a: ::simdty::i16x8, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadals.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v16i8"]
        pub fn neon_vpadals_v4i32_v16i8(a: ::simdty::i32x4, b: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v8i16"]
        pub fn neon_vpadals_v4i32_v8i16(a: ::simdty::i32x4, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v4i32"]
        pub fn neon_vpadals_v4i32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v2i64"]
        pub fn neon_vpadals_v4i32_v2i64(a: ::simdty::i32x4, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v4f32"]
        pub fn neon_vpadals_v4i32_v4f32(a: ::simdty::i32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4i32.v2f64"]
        pub fn neon_vpadals_v4i32_v2f64(a: ::simdty::i32x4, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadals.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v16i8"]
        pub fn neon_vpadals_v2i64_v16i8(a: ::simdty::i64x2, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v8i16"]
        pub fn neon_vpadals_v2i64_v8i16(a: ::simdty::i64x2, b: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v4i32"]
        pub fn neon_vpadals_v2i64_v4i32(a: ::simdty::i64x2, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v2i64"]
        pub fn neon_vpadals_v2i64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v4f32"]
        pub fn neon_vpadals_v2i64_v4f32(a: ::simdty::i64x2, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2i64.v2f64"]
        pub fn neon_vpadals_v2i64_v2f64(a: ::simdty::i64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadals.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v16i8"]
        pub fn neon_vpadals_v4f32_v16i8(a: ::simdty::f32x4, b: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v8i16"]
        pub fn neon_vpadals_v4f32_v8i16(a: ::simdty::f32x4, b: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v4i32"]
        pub fn neon_vpadals_v4f32_v4i32(a: ::simdty::f32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v2i64"]
        pub fn neon_vpadals_v4f32_v2i64(a: ::simdty::f32x4, b: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v4f32"]
        pub fn neon_vpadals_v4f32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v4f32.v2f64"]
        pub fn neon_vpadals_v4f32_v2f64(a: ::simdty::f32x4, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadals.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v16i8"]
        pub fn neon_vpadals_v2f64_v16i8(a: ::simdty::f64x2, b: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v8i16"]
        pub fn neon_vpadals_v2f64_v8i16(a: ::simdty::f64x2, b: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v4i32"]
        pub fn neon_vpadals_v2f64_v4i32(a: ::simdty::f64x2, b: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v2i64"]
        pub fn neon_vpadals_v2f64_v2i64(a: ::simdty::f64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v4f32"]
        pub fn neon_vpadals_v2f64_v4f32(a: ::simdty::f64x2, b: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadals.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadals.v2f64.v2f64"]
        pub fn neon_vpadals_v2f64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v16i8"]
        pub fn neon_vpadalu_v16i8_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v8i16"]
        pub fn neon_vpadalu_v16i8_v8i16(a: ::simdty::i8x16, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v4i32"]
        pub fn neon_vpadalu_v16i8_v4i32(a: ::simdty::i8x16, b: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v2i64"]
        pub fn neon_vpadalu_v16i8_v2i64(a: ::simdty::i8x16, b: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v4f32"]
        pub fn neon_vpadalu_v16i8_v4f32(a: ::simdty::i8x16, b: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v16i8.v2f64"]
        pub fn neon_vpadalu_v16i8_v2f64(a: ::simdty::i8x16, b: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpadalu.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v16i8"]
        pub fn neon_vpadalu_v8i16_v16i8(a: ::simdty::i16x8, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v8i16"]
        pub fn neon_vpadalu_v8i16_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v4i32"]
        pub fn neon_vpadalu_v8i16_v4i32(a: ::simdty::i16x8, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v2i64"]
        pub fn neon_vpadalu_v8i16_v2i64(a: ::simdty::i16x8, b: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v4f32"]
        pub fn neon_vpadalu_v8i16_v4f32(a: ::simdty::i16x8, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v8i16.v2f64"]
        pub fn neon_vpadalu_v8i16_v2f64(a: ::simdty::i16x8, b: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpadalu.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v16i8"]
        pub fn neon_vpadalu_v4i32_v16i8(a: ::simdty::i32x4, b: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v8i16"]
        pub fn neon_vpadalu_v4i32_v8i16(a: ::simdty::i32x4, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v4i32"]
        pub fn neon_vpadalu_v4i32_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v2i64"]
        pub fn neon_vpadalu_v4i32_v2i64(a: ::simdty::i32x4, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v4f32"]
        pub fn neon_vpadalu_v4i32_v4f32(a: ::simdty::i32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4i32.v2f64"]
        pub fn neon_vpadalu_v4i32_v2f64(a: ::simdty::i32x4, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpadalu.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v16i8"]
        pub fn neon_vpadalu_v2i64_v16i8(a: ::simdty::i64x2, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v8i16"]
        pub fn neon_vpadalu_v2i64_v8i16(a: ::simdty::i64x2, b: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v4i32"]
        pub fn neon_vpadalu_v2i64_v4i32(a: ::simdty::i64x2, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v2i64"]
        pub fn neon_vpadalu_v2i64_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v4f32"]
        pub fn neon_vpadalu_v2i64_v4f32(a: ::simdty::i64x2, b: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2i64.v2f64"]
        pub fn neon_vpadalu_v2i64_v2f64(a: ::simdty::i64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpadalu.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v16i8"]
        pub fn neon_vpadalu_v4f32_v16i8(a: ::simdty::f32x4, b: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v8i16"]
        pub fn neon_vpadalu_v4f32_v8i16(a: ::simdty::f32x4, b: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v4i32"]
        pub fn neon_vpadalu_v4f32_v4i32(a: ::simdty::f32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v2i64"]
        pub fn neon_vpadalu_v4f32_v2i64(a: ::simdty::f32x4, b: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v4f32"]
        pub fn neon_vpadalu_v4f32_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v4f32.v2f64"]
        pub fn neon_vpadalu_v4f32_v2f64(a: ::simdty::f32x4, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpadalu.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v16i8"]
        pub fn neon_vpadalu_v2f64_v16i8(a: ::simdty::f64x2, b: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v8i16"]
        pub fn neon_vpadalu_v2f64_v8i16(a: ::simdty::f64x2, b: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v4i32"]
        pub fn neon_vpadalu_v2f64_v4i32(a: ::simdty::f64x2, b: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v2i64"]
        pub fn neon_vpadalu_v2f64_v2i64(a: ::simdty::f64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v4f32"]
        pub fn neon_vpadalu_v2f64_v4f32(a: ::simdty::f64x2, b: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpadalu.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpadalu.v2f64.v2f64"]
        pub fn neon_vpadalu_v2f64_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpmaxs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v16i8"]
        pub fn neon_vpmaxs_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpmaxs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v8i16"]
        pub fn neon_vpmaxs_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpmaxs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v4i32"]
        pub fn neon_vpmaxs_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpmaxs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v2i64"]
        pub fn neon_vpmaxs_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpmaxs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v4f32"]
        pub fn neon_vpmaxs_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpmaxs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxs.v2f64"]
        pub fn neon_vpmaxs_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpmaxu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v16i8"]
        pub fn neon_vpmaxu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpmaxu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v8i16"]
        pub fn neon_vpmaxu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpmaxu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v4i32"]
        pub fn neon_vpmaxu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpmaxu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v2i64"]
        pub fn neon_vpmaxu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpmaxu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v4f32"]
        pub fn neon_vpmaxu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpmaxu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmaxu.v2f64"]
        pub fn neon_vpmaxu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpmins.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v16i8"]
        pub fn neon_vpmins_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpmins.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v8i16"]
        pub fn neon_vpmins_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpmins.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v4i32"]
        pub fn neon_vpmins_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpmins.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v2i64"]
        pub fn neon_vpmins_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpmins.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v4f32"]
        pub fn neon_vpmins_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpmins.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpmins.v2f64"]
        pub fn neon_vpmins_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vpminu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v16i8"]
        pub fn neon_vpminu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vpminu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v8i16"]
        pub fn neon_vpminu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vpminu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v4i32"]
        pub fn neon_vpminu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vpminu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v2i64"]
        pub fn neon_vpminu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vpminu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v4f32"]
        pub fn neon_vpminu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vpminu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vpminu.v2f64"]
        pub fn neon_vpminu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vshifts.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v16i8"]
        pub fn neon_vshifts_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vshifts.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v8i16"]
        pub fn neon_vshifts_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vshifts.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v4i32"]
        pub fn neon_vshifts_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vshifts.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v2i64"]
        pub fn neon_vshifts_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vshifts.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v4f32"]
        pub fn neon_vshifts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vshifts.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vshifts.v2f64"]
        pub fn neon_vshifts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vshiftu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v16i8"]
        pub fn neon_vshiftu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vshiftu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v8i16"]
        pub fn neon_vshiftu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vshiftu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v4i32"]
        pub fn neon_vshiftu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vshiftu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v2i64"]
        pub fn neon_vshiftu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vshiftu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v4f32"]
        pub fn neon_vshiftu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vshiftu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftu.v2f64"]
        pub fn neon_vshiftu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrshifts.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v16i8"]
        pub fn neon_vrshifts_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrshifts.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v8i16"]
        pub fn neon_vrshifts_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrshifts.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v4i32"]
        pub fn neon_vrshifts_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrshifts.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v2i64"]
        pub fn neon_vrshifts_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrshifts.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v4f32"]
        pub fn neon_vrshifts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrshifts.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrshifts.v2f64"]
        pub fn neon_vrshifts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrshiftu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v16i8"]
        pub fn neon_vrshiftu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrshiftu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v8i16"]
        pub fn neon_vrshiftu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrshiftu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v4i32"]
        pub fn neon_vrshiftu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrshiftu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v2i64"]
        pub fn neon_vrshiftu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrshiftu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v4f32"]
        pub fn neon_vrshiftu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrshiftu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrshiftu.v2f64"]
        pub fn neon_vrshiftu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqshifts.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v16i8"]
        pub fn neon_vqshifts_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqshifts.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v8i16"]
        pub fn neon_vqshifts_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqshifts.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v4i32"]
        pub fn neon_vqshifts_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqshifts.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v2i64"]
        pub fn neon_vqshifts_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqshifts.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v4f32"]
        pub fn neon_vqshifts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqshifts.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshifts.v2f64"]
        pub fn neon_vqshifts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqshiftu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v16i8"]
        pub fn neon_vqshiftu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqshiftu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v8i16"]
        pub fn neon_vqshiftu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqshiftu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v4i32"]
        pub fn neon_vqshiftu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqshiftu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v2i64"]
        pub fn neon_vqshiftu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqshiftu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v4f32"]
        pub fn neon_vqshiftu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqshiftu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftu.v2f64"]
        pub fn neon_vqshiftu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqshiftsu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v16i8"]
        pub fn neon_vqshiftsu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqshiftsu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v8i16"]
        pub fn neon_vqshiftsu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqshiftsu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v4i32"]
        pub fn neon_vqshiftsu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqshiftsu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v2i64"]
        pub fn neon_vqshiftsu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqshiftsu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v4f32"]
        pub fn neon_vqshiftsu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqshiftsu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqshiftsu.v2f64"]
        pub fn neon_vqshiftsu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqrshifts.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v16i8"]
        pub fn neon_vqrshifts_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqrshifts.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v8i16"]
        pub fn neon_vqrshifts_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqrshifts.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v4i32"]
        pub fn neon_vqrshifts_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqrshifts.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v2i64"]
        pub fn neon_vqrshifts_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqrshifts.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v4f32"]
        pub fn neon_vqrshifts_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqrshifts.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshifts.v2f64"]
        pub fn neon_vqrshifts_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqrshiftu.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v16i8"]
        pub fn neon_vqrshiftu_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqrshiftu.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v8i16"]
        pub fn neon_vqrshiftu_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqrshiftu.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v4i32"]
        pub fn neon_vqrshiftu_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqrshiftu.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v2i64"]
        pub fn neon_vqrshiftu_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqrshiftu.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v4f32"]
        pub fn neon_vqrshiftu_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqrshiftu.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqrshiftu.v2f64"]
        pub fn neon_vqrshiftu_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vshiftins.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v16i8"]
        pub fn neon_vshiftins_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vshiftins.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v8i16"]
        pub fn neon_vshiftins_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vshiftins.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v4i32"]
        pub fn neon_vshiftins_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vshiftins.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v2i64"]
        pub fn neon_vshiftins_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vshiftins.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v4f32"]
        pub fn neon_vshiftins_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vshiftins.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vshiftins.v2f64"]
        pub fn neon_vshiftins_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vabs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v16i8"]
        pub fn neon_vabs_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vabs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v8i16"]
        pub fn neon_vabs_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vabs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v4i32"]
        pub fn neon_vabs_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vabs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v2i64"]
        pub fn neon_vabs_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vabs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v4f32"]
        pub fn neon_vabs_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vabs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vabs.v2f64"]
        pub fn neon_vabs_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqabs.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v16i8"]
        pub fn neon_vqabs_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqabs.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v8i16"]
        pub fn neon_vqabs_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqabs.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v4i32"]
        pub fn neon_vqabs_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqabs.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v2i64"]
        pub fn neon_vqabs_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqabs.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v4f32"]
        pub fn neon_vqabs_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqabs.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqabs.v2f64"]
        pub fn neon_vqabs_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vqneg.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v16i8"]
        pub fn neon_vqneg_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vqneg.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v8i16"]
        pub fn neon_vqneg_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vqneg.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v4i32"]
        pub fn neon_vqneg_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vqneg.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v2i64"]
        pub fn neon_vqneg_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vqneg.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v4f32"]
        pub fn neon_vqneg_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vqneg.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vqneg.v2f64"]
        pub fn neon_vqneg_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcls.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v16i8"]
        pub fn neon_vcls_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcls.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v8i16"]
        pub fn neon_vcls_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcls.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v4i32"]
        pub fn neon_vcls_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcls.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v2i64"]
        pub fn neon_vcls_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcls.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v4f32"]
        pub fn neon_vcls_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcls.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcls.v2f64"]
        pub fn neon_vcls_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrecpe.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v16i8"]
        pub fn neon_vrecpe_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrecpe.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v8i16"]
        pub fn neon_vrecpe_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrecpe.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v4i32"]
        pub fn neon_vrecpe_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrecpe.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v2i64"]
        pub fn neon_vrecpe_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrecpe.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v4f32"]
        pub fn neon_vrecpe_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrecpe.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrecpe.v2f64"]
        pub fn neon_vrecpe_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrsqrte.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v16i8"]
        pub fn neon_vrsqrte_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrsqrte.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v8i16"]
        pub fn neon_vrsqrte_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrsqrte.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v4i32"]
        pub fn neon_vrsqrte_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrsqrte.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v2i64"]
        pub fn neon_vrsqrte_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrsqrte.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v4f32"]
        pub fn neon_vrsqrte_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrsqrte.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrsqrte.v2f64"]
        pub fn neon_vrsqrte_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v16i8"]
        pub fn neon_vcvtau_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v8i16"]
        pub fn neon_vcvtau_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v4i32"]
        pub fn neon_vcvtau_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v2i64"]
        pub fn neon_vcvtau_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v4f32"]
        pub fn neon_vcvtau_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v16i8.v2f64"]
        pub fn neon_vcvtau_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtau.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v16i8"]
        pub fn neon_vcvtau_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v8i16"]
        pub fn neon_vcvtau_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v4i32"]
        pub fn neon_vcvtau_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v2i64"]
        pub fn neon_vcvtau_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v4f32"]
        pub fn neon_vcvtau_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v8i16.v2f64"]
        pub fn neon_vcvtau_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtau.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v16i8"]
        pub fn neon_vcvtau_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v8i16"]
        pub fn neon_vcvtau_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v4i32"]
        pub fn neon_vcvtau_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v2i64"]
        pub fn neon_vcvtau_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v4f32"]
        pub fn neon_vcvtau_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4i32.v2f64"]
        pub fn neon_vcvtau_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtau.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v16i8"]
        pub fn neon_vcvtau_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v8i16"]
        pub fn neon_vcvtau_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v4i32"]
        pub fn neon_vcvtau_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v2i64"]
        pub fn neon_vcvtau_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v4f32"]
        pub fn neon_vcvtau_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2i64.v2f64"]
        pub fn neon_vcvtau_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtau.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v16i8"]
        pub fn neon_vcvtau_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v8i16"]
        pub fn neon_vcvtau_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v4i32"]
        pub fn neon_vcvtau_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v2i64"]
        pub fn neon_vcvtau_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v4f32"]
        pub fn neon_vcvtau_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v4f32.v2f64"]
        pub fn neon_vcvtau_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtau.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v16i8"]
        pub fn neon_vcvtau_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v8i16"]
        pub fn neon_vcvtau_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v4i32"]
        pub fn neon_vcvtau_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v2i64"]
        pub fn neon_vcvtau_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v4f32"]
        pub fn neon_vcvtau_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtau.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtau.v2f64.v2f64"]
        pub fn neon_vcvtau_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v16i8"]
        pub fn neon_vcvtas_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v8i16"]
        pub fn neon_vcvtas_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v4i32"]
        pub fn neon_vcvtas_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v2i64"]
        pub fn neon_vcvtas_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v4f32"]
        pub fn neon_vcvtas_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v16i8.v2f64"]
        pub fn neon_vcvtas_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtas.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v16i8"]
        pub fn neon_vcvtas_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v8i16"]
        pub fn neon_vcvtas_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v4i32"]
        pub fn neon_vcvtas_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v2i64"]
        pub fn neon_vcvtas_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v4f32"]
        pub fn neon_vcvtas_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v8i16.v2f64"]
        pub fn neon_vcvtas_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtas.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v16i8"]
        pub fn neon_vcvtas_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v8i16"]
        pub fn neon_vcvtas_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v4i32"]
        pub fn neon_vcvtas_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v2i64"]
        pub fn neon_vcvtas_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v4f32"]
        pub fn neon_vcvtas_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4i32.v2f64"]
        pub fn neon_vcvtas_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtas.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v16i8"]
        pub fn neon_vcvtas_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v8i16"]
        pub fn neon_vcvtas_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v4i32"]
        pub fn neon_vcvtas_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v2i64"]
        pub fn neon_vcvtas_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v4f32"]
        pub fn neon_vcvtas_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2i64.v2f64"]
        pub fn neon_vcvtas_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtas.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v16i8"]
        pub fn neon_vcvtas_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v8i16"]
        pub fn neon_vcvtas_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v4i32"]
        pub fn neon_vcvtas_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v2i64"]
        pub fn neon_vcvtas_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v4f32"]
        pub fn neon_vcvtas_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v4f32.v2f64"]
        pub fn neon_vcvtas_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtas.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v16i8"]
        pub fn neon_vcvtas_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v8i16"]
        pub fn neon_vcvtas_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v4i32"]
        pub fn neon_vcvtas_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v2i64"]
        pub fn neon_vcvtas_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v4f32"]
        pub fn neon_vcvtas_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtas.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtas.v2f64.v2f64"]
        pub fn neon_vcvtas_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v16i8"]
        pub fn neon_vcvtnu_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v8i16"]
        pub fn neon_vcvtnu_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v4i32"]
        pub fn neon_vcvtnu_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v2i64"]
        pub fn neon_vcvtnu_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v4f32"]
        pub fn neon_vcvtnu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v16i8.v2f64"]
        pub fn neon_vcvtnu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v16i8"]
        pub fn neon_vcvtnu_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v8i16"]
        pub fn neon_vcvtnu_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v4i32"]
        pub fn neon_vcvtnu_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v2i64"]
        pub fn neon_vcvtnu_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v4f32"]
        pub fn neon_vcvtnu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v8i16.v2f64"]
        pub fn neon_vcvtnu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v16i8"]
        pub fn neon_vcvtnu_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v8i16"]
        pub fn neon_vcvtnu_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v4i32"]
        pub fn neon_vcvtnu_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v2i64"]
        pub fn neon_vcvtnu_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v4f32"]
        pub fn neon_vcvtnu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4i32.v2f64"]
        pub fn neon_vcvtnu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v16i8"]
        pub fn neon_vcvtnu_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v8i16"]
        pub fn neon_vcvtnu_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v4i32"]
        pub fn neon_vcvtnu_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v2i64"]
        pub fn neon_vcvtnu_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v4f32"]
        pub fn neon_vcvtnu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2i64.v2f64"]
        pub fn neon_vcvtnu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v16i8"]
        pub fn neon_vcvtnu_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v8i16"]
        pub fn neon_vcvtnu_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v4i32"]
        pub fn neon_vcvtnu_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v2i64"]
        pub fn neon_vcvtnu_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v4f32"]
        pub fn neon_vcvtnu_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v4f32.v2f64"]
        pub fn neon_vcvtnu_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v16i8"]
        pub fn neon_vcvtnu_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v8i16"]
        pub fn neon_vcvtnu_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v4i32"]
        pub fn neon_vcvtnu_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v2i64"]
        pub fn neon_vcvtnu_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v4f32"]
        pub fn neon_vcvtnu_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtnu.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtnu.v2f64.v2f64"]
        pub fn neon_vcvtnu_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v16i8"]
        pub fn neon_vcvtns_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v8i16"]
        pub fn neon_vcvtns_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v4i32"]
        pub fn neon_vcvtns_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v2i64"]
        pub fn neon_vcvtns_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v4f32"]
        pub fn neon_vcvtns_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v16i8.v2f64"]
        pub fn neon_vcvtns_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtns.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v16i8"]
        pub fn neon_vcvtns_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v8i16"]
        pub fn neon_vcvtns_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v4i32"]
        pub fn neon_vcvtns_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v2i64"]
        pub fn neon_vcvtns_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v4f32"]
        pub fn neon_vcvtns_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v8i16.v2f64"]
        pub fn neon_vcvtns_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtns.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v16i8"]
        pub fn neon_vcvtns_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v8i16"]
        pub fn neon_vcvtns_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v4i32"]
        pub fn neon_vcvtns_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v2i64"]
        pub fn neon_vcvtns_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v4f32"]
        pub fn neon_vcvtns_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4i32.v2f64"]
        pub fn neon_vcvtns_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtns.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v16i8"]
        pub fn neon_vcvtns_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v8i16"]
        pub fn neon_vcvtns_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v4i32"]
        pub fn neon_vcvtns_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v2i64"]
        pub fn neon_vcvtns_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v4f32"]
        pub fn neon_vcvtns_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2i64.v2f64"]
        pub fn neon_vcvtns_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtns.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v16i8"]
        pub fn neon_vcvtns_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v8i16"]
        pub fn neon_vcvtns_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v4i32"]
        pub fn neon_vcvtns_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v2i64"]
        pub fn neon_vcvtns_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v4f32"]
        pub fn neon_vcvtns_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v4f32.v2f64"]
        pub fn neon_vcvtns_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtns.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v16i8"]
        pub fn neon_vcvtns_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v8i16"]
        pub fn neon_vcvtns_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v4i32"]
        pub fn neon_vcvtns_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v2i64"]
        pub fn neon_vcvtns_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v4f32"]
        pub fn neon_vcvtns_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtns.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtns.v2f64.v2f64"]
        pub fn neon_vcvtns_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v16i8"]
        pub fn neon_vcvtpu_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v8i16"]
        pub fn neon_vcvtpu_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v4i32"]
        pub fn neon_vcvtpu_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v2i64"]
        pub fn neon_vcvtpu_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v4f32"]
        pub fn neon_vcvtpu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v16i8.v2f64"]
        pub fn neon_vcvtpu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v16i8"]
        pub fn neon_vcvtpu_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v8i16"]
        pub fn neon_vcvtpu_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v4i32"]
        pub fn neon_vcvtpu_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v2i64"]
        pub fn neon_vcvtpu_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v4f32"]
        pub fn neon_vcvtpu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v8i16.v2f64"]
        pub fn neon_vcvtpu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v16i8"]
        pub fn neon_vcvtpu_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v8i16"]
        pub fn neon_vcvtpu_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v4i32"]
        pub fn neon_vcvtpu_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v2i64"]
        pub fn neon_vcvtpu_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v4f32"]
        pub fn neon_vcvtpu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4i32.v2f64"]
        pub fn neon_vcvtpu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v16i8"]
        pub fn neon_vcvtpu_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v8i16"]
        pub fn neon_vcvtpu_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v4i32"]
        pub fn neon_vcvtpu_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v2i64"]
        pub fn neon_vcvtpu_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v4f32"]
        pub fn neon_vcvtpu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2i64.v2f64"]
        pub fn neon_vcvtpu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v16i8"]
        pub fn neon_vcvtpu_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v8i16"]
        pub fn neon_vcvtpu_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v4i32"]
        pub fn neon_vcvtpu_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v2i64"]
        pub fn neon_vcvtpu_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v4f32"]
        pub fn neon_vcvtpu_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v4f32.v2f64"]
        pub fn neon_vcvtpu_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v16i8"]
        pub fn neon_vcvtpu_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v8i16"]
        pub fn neon_vcvtpu_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v4i32"]
        pub fn neon_vcvtpu_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v2i64"]
        pub fn neon_vcvtpu_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v4f32"]
        pub fn neon_vcvtpu_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtpu.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtpu.v2f64.v2f64"]
        pub fn neon_vcvtpu_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v16i8"]
        pub fn neon_vcvtps_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v8i16"]
        pub fn neon_vcvtps_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v4i32"]
        pub fn neon_vcvtps_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v2i64"]
        pub fn neon_vcvtps_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v4f32"]
        pub fn neon_vcvtps_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v16i8.v2f64"]
        pub fn neon_vcvtps_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtps.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v16i8"]
        pub fn neon_vcvtps_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v8i16"]
        pub fn neon_vcvtps_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v4i32"]
        pub fn neon_vcvtps_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v2i64"]
        pub fn neon_vcvtps_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v4f32"]
        pub fn neon_vcvtps_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v8i16.v2f64"]
        pub fn neon_vcvtps_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtps.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v16i8"]
        pub fn neon_vcvtps_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v8i16"]
        pub fn neon_vcvtps_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v4i32"]
        pub fn neon_vcvtps_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v2i64"]
        pub fn neon_vcvtps_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v4f32"]
        pub fn neon_vcvtps_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4i32.v2f64"]
        pub fn neon_vcvtps_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtps.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v16i8"]
        pub fn neon_vcvtps_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v8i16"]
        pub fn neon_vcvtps_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v4i32"]
        pub fn neon_vcvtps_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v2i64"]
        pub fn neon_vcvtps_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v4f32"]
        pub fn neon_vcvtps_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2i64.v2f64"]
        pub fn neon_vcvtps_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtps.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v16i8"]
        pub fn neon_vcvtps_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v8i16"]
        pub fn neon_vcvtps_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v4i32"]
        pub fn neon_vcvtps_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v2i64"]
        pub fn neon_vcvtps_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v4f32"]
        pub fn neon_vcvtps_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v4f32.v2f64"]
        pub fn neon_vcvtps_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtps.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v16i8"]
        pub fn neon_vcvtps_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v8i16"]
        pub fn neon_vcvtps_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v4i32"]
        pub fn neon_vcvtps_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v2i64"]
        pub fn neon_vcvtps_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v4f32"]
        pub fn neon_vcvtps_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtps.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtps.v2f64.v2f64"]
        pub fn neon_vcvtps_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v16i8"]
        pub fn neon_vcvtmu_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v8i16"]
        pub fn neon_vcvtmu_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v4i32"]
        pub fn neon_vcvtmu_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v2i64"]
        pub fn neon_vcvtmu_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v4f32"]
        pub fn neon_vcvtmu_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v16i8.v2f64"]
        pub fn neon_vcvtmu_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v16i8"]
        pub fn neon_vcvtmu_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v8i16"]
        pub fn neon_vcvtmu_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v4i32"]
        pub fn neon_vcvtmu_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v2i64"]
        pub fn neon_vcvtmu_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v4f32"]
        pub fn neon_vcvtmu_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v8i16.v2f64"]
        pub fn neon_vcvtmu_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v16i8"]
        pub fn neon_vcvtmu_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v8i16"]
        pub fn neon_vcvtmu_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v4i32"]
        pub fn neon_vcvtmu_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v2i64"]
        pub fn neon_vcvtmu_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v4f32"]
        pub fn neon_vcvtmu_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4i32.v2f64"]
        pub fn neon_vcvtmu_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v16i8"]
        pub fn neon_vcvtmu_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v8i16"]
        pub fn neon_vcvtmu_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v4i32"]
        pub fn neon_vcvtmu_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v2i64"]
        pub fn neon_vcvtmu_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v4f32"]
        pub fn neon_vcvtmu_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2i64.v2f64"]
        pub fn neon_vcvtmu_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v16i8"]
        pub fn neon_vcvtmu_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v8i16"]
        pub fn neon_vcvtmu_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v4i32"]
        pub fn neon_vcvtmu_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v2i64"]
        pub fn neon_vcvtmu_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v4f32"]
        pub fn neon_vcvtmu_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v4f32.v2f64"]
        pub fn neon_vcvtmu_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v16i8"]
        pub fn neon_vcvtmu_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v8i16"]
        pub fn neon_vcvtmu_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v4i32"]
        pub fn neon_vcvtmu_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v2i64"]
        pub fn neon_vcvtmu_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v4f32"]
        pub fn neon_vcvtmu_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtmu.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtmu.v2f64.v2f64"]
        pub fn neon_vcvtmu_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v16i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v16i8"]
        pub fn neon_vcvtms_v16i8_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v16i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v8i16"]
        pub fn neon_vcvtms_v16i8_v8i16(a: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v16i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v4i32"]
        pub fn neon_vcvtms_v16i8_v4i32(a: ::simdty::i32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v16i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v2i64"]
        pub fn neon_vcvtms_v16i8_v2i64(a: ::simdty::i64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v4f32"]
        pub fn neon_vcvtms_v16i8_v4f32(a: ::simdty::f32x4) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v16i8.v2f64"]
        pub fn neon_vcvtms_v16i8_v2f64(a: ::simdty::f64x2) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtms.v8i16.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v16i8"]
        pub fn neon_vcvtms_v8i16_v16i8(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v8i16.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v8i16"]
        pub fn neon_vcvtms_v8i16_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v8i16.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v4i32"]
        pub fn neon_vcvtms_v8i16_v4i32(a: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v8i16.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v2i64"]
        pub fn neon_vcvtms_v8i16_v2i64(a: ::simdty::i64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v4f32"]
        pub fn neon_vcvtms_v8i16_v4f32(a: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v8i16.v2f64"]
        pub fn neon_vcvtms_v8i16_v2f64(a: ::simdty::f64x2) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtms.v4i32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v16i8"]
        pub fn neon_vcvtms_v4i32_v16i8(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v4i32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v8i16"]
        pub fn neon_vcvtms_v4i32_v8i16(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v4i32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v4i32"]
        pub fn neon_vcvtms_v4i32_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v4i32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v2i64"]
        pub fn neon_vcvtms_v4i32_v2i64(a: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v4f32"]
        pub fn neon_vcvtms_v4i32_v4f32(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4i32.v2f64"]
        pub fn neon_vcvtms_v4i32_v2f64(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtms.v2i64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v16i8"]
        pub fn neon_vcvtms_v2i64_v16i8(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v2i64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v8i16"]
        pub fn neon_vcvtms_v2i64_v8i16(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v2i64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v4i32"]
        pub fn neon_vcvtms_v2i64_v4i32(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v2i64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v2i64"]
        pub fn neon_vcvtms_v2i64_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v4f32"]
        pub fn neon_vcvtms_v2i64_v4f32(a: ::simdty::f32x4) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2i64.v2f64"]
        pub fn neon_vcvtms_v2i64_v2f64(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtms.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v16i8"]
        pub fn neon_vcvtms_v4f32_v16i8(a: ::simdty::i8x16) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v8i16"]
        pub fn neon_vcvtms_v4f32_v8i16(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v4i32"]
        pub fn neon_vcvtms_v4f32_v4i32(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v2i64"]
        pub fn neon_vcvtms_v4f32_v2i64(a: ::simdty::i64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v4f32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v4f32"]
        pub fn neon_vcvtms_v4f32_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v4f32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v4f32.v2f64"]
        pub fn neon_vcvtms_v4f32_v2f64(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtms.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v16i8"]
        pub fn neon_vcvtms_v2f64_v16i8(a: ::simdty::i8x16) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v8i16"]
        pub fn neon_vcvtms_v2f64_v8i16(a: ::simdty::i16x8) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v4i32"]
        pub fn neon_vcvtms_v2f64_v4i32(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v2i64"]
        pub fn neon_vcvtms_v2f64_v2i64(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v2f64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v4f32"]
        pub fn neon_vcvtms_v2f64_v4f32(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtms.v2f64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtms.v2f64.v2f64"]
        pub fn neon_vcvtms_v2f64_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfp2fxs.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v16i8.v4f32"]
        pub fn neon_vcvtfp2fxs_v16i8_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxs.v16i8.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v16i8.f32"]
        pub fn neon_vcvtfp2fxs_v16i8_f32(a: f32, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxs.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v16i8.v2f64"]
        pub fn neon_vcvtfp2fxs_v16i8_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxs.v16i8.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v16i8.f64"]
        pub fn neon_vcvtfp2fxs_v16i8_f64(a: f64, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxs.i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i8.v4f32"]
        pub fn neon_vcvtfp2fxs_i8_v4f32(a: ::simdty::f32x4, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxs.i8.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i8.f32"]
        pub fn neon_vcvtfp2fxs_i8_f32(a: f32, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxs.i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i8.v2f64"]
        pub fn neon_vcvtfp2fxs_i8_v2f64(a: ::simdty::f64x2, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxs.i8.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i8.f64"]
        pub fn neon_vcvtfp2fxs_i8_f64(a: f64, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxs.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v8i16.v4f32"]
        pub fn neon_vcvtfp2fxs_v8i16_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxs.v8i16.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v8i16.f32"]
        pub fn neon_vcvtfp2fxs_v8i16_f32(a: f32, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxs.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v8i16.v2f64"]
        pub fn neon_vcvtfp2fxs_v8i16_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxs.v8i16.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v8i16.f64"]
        pub fn neon_vcvtfp2fxs_v8i16_f64(a: f64, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxs.i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i16.v4f32"]
        pub fn neon_vcvtfp2fxs_i16_v4f32(a: ::simdty::f32x4, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxs.i16.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i16.f32"]
        pub fn neon_vcvtfp2fxs_i16_f32(a: f32, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxs.i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i16.v2f64"]
        pub fn neon_vcvtfp2fxs_i16_v2f64(a: ::simdty::f64x2, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxs.i16.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i16.f64"]
        pub fn neon_vcvtfp2fxs_i16_f64(a: f64, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxs.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v4i32.v4f32"]
        pub fn neon_vcvtfp2fxs_v4i32_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxs.v4i32.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v4i32.f32"]
        pub fn neon_vcvtfp2fxs_v4i32_f32(a: f32, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxs.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v4i32.v2f64"]
        pub fn neon_vcvtfp2fxs_v4i32_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxs.v4i32.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v4i32.f64"]
        pub fn neon_vcvtfp2fxs_v4i32_f64(a: f64, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxs.i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i32.v4f32"]
        pub fn neon_vcvtfp2fxs_i32_v4f32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxs.i32.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i32.f32"]
        pub fn neon_vcvtfp2fxs_i32_f32(a: f32, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxs.i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i32.v2f64"]
        pub fn neon_vcvtfp2fxs_i32_v2f64(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxs.i32.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i32.f64"]
        pub fn neon_vcvtfp2fxs_i32_f64(a: f64, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxs.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v2i64.v4f32"]
        pub fn neon_vcvtfp2fxs_v2i64_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxs.v2i64.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v2i64.f32"]
        pub fn neon_vcvtfp2fxs_v2i64_f32(a: f32, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxs.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v2i64.v2f64"]
        pub fn neon_vcvtfp2fxs_v2i64_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxs.v2i64.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.v2i64.f64"]
        pub fn neon_vcvtfp2fxs_v2i64_f64(a: f64, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxs.i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i64.v4f32"]
        pub fn neon_vcvtfp2fxs_i64_v4f32(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxs.i64.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i64.f32"]
        pub fn neon_vcvtfp2fxs_i64_f32(a: f32, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxs.i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i64.v2f64"]
        pub fn neon_vcvtfp2fxs_i64_v2f64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxs.i64.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxs.i64.f64"]
        pub fn neon_vcvtfp2fxs_i64_f64(a: f64, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxu.v16i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v16i8.v4f32"]
        pub fn neon_vcvtfp2fxu_v16i8_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxu.v16i8.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v16i8.f32"]
        pub fn neon_vcvtfp2fxu_v16i8_f32(a: f32, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxu.v16i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v16i8.v2f64"]
        pub fn neon_vcvtfp2fxu_v16i8_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxu.v16i8.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v16i8.f64"]
        pub fn neon_vcvtfp2fxu_v16i8_f64(a: f64, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vcvtfp2fxu.i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i8.v4f32"]
        pub fn neon_vcvtfp2fxu_i8_v4f32(a: ::simdty::f32x4, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxu.i8.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i8.f32"]
        pub fn neon_vcvtfp2fxu_i8_f32(a: f32, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxu.i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i8.v2f64"]
        pub fn neon_vcvtfp2fxu_i8_v2f64(a: ::simdty::f64x2, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxu.i8.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i8.f64"]
        pub fn neon_vcvtfp2fxu_i8_f64(a: f64, b: i32) -> i8;
        /// The `llvm.arm.neon.vcvtfp2fxu.v8i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v8i16.v4f32"]
        pub fn neon_vcvtfp2fxu_v8i16_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxu.v8i16.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v8i16.f32"]
        pub fn neon_vcvtfp2fxu_v8i16_f32(a: f32, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxu.v8i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v8i16.v2f64"]
        pub fn neon_vcvtfp2fxu_v8i16_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxu.v8i16.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v8i16.f64"]
        pub fn neon_vcvtfp2fxu_v8i16_f64(a: f64, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vcvtfp2fxu.i16.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i16.v4f32"]
        pub fn neon_vcvtfp2fxu_i16_v4f32(a: ::simdty::f32x4, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxu.i16.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i16.f32"]
        pub fn neon_vcvtfp2fxu_i16_f32(a: f32, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxu.i16.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i16.v2f64"]
        pub fn neon_vcvtfp2fxu_i16_v2f64(a: ::simdty::f64x2, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxu.i16.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i16.f64"]
        pub fn neon_vcvtfp2fxu_i16_f64(a: f64, b: i32) -> i16;
        /// The `llvm.arm.neon.vcvtfp2fxu.v4i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v4i32.v4f32"]
        pub fn neon_vcvtfp2fxu_v4i32_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxu.v4i32.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v4i32.f32"]
        pub fn neon_vcvtfp2fxu_v4i32_f32(a: f32, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxu.v4i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v4i32.v2f64"]
        pub fn neon_vcvtfp2fxu_v4i32_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxu.v4i32.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v4i32.f64"]
        pub fn neon_vcvtfp2fxu_v4i32_f64(a: f64, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vcvtfp2fxu.i32.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i32.v4f32"]
        pub fn neon_vcvtfp2fxu_i32_v4f32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxu.i32.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i32.f32"]
        pub fn neon_vcvtfp2fxu_i32_f32(a: f32, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxu.i32.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i32.v2f64"]
        pub fn neon_vcvtfp2fxu_i32_v2f64(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxu.i32.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i32.f64"]
        pub fn neon_vcvtfp2fxu_i32_f64(a: f64, b: i32) -> i32;
        /// The `llvm.arm.neon.vcvtfp2fxu.v2i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v2i64.v4f32"]
        pub fn neon_vcvtfp2fxu_v2i64_v4f32(a: ::simdty::f32x4, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxu.v2i64.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v2i64.f32"]
        pub fn neon_vcvtfp2fxu_v2i64_f32(a: f32, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxu.v2i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v2i64.v2f64"]
        pub fn neon_vcvtfp2fxu_v2i64_v2f64(a: ::simdty::f64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxu.v2i64.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.v2i64.f64"]
        pub fn neon_vcvtfp2fxu_v2i64_f64(a: f64, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vcvtfp2fxu.i64.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i64.v4f32"]
        pub fn neon_vcvtfp2fxu_i64_v4f32(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxu.i64.f32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i64.f32"]
        pub fn neon_vcvtfp2fxu_i64_f32(a: f32, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxu.i64.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i64.v2f64"]
        pub fn neon_vcvtfp2fxu_i64_v2f64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfp2fxu.i64.f64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2fxu.i64.f64"]
        pub fn neon_vcvtfp2fxu_i64_f64(a: f64, b: i32) -> i64;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.v16i8"]
        pub fn neon_vcvtfxs2fp_v4f32_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.i8"]
        pub fn neon_vcvtfxs2fp_v4f32_i8(a: i8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.v8i16"]
        pub fn neon_vcvtfxs2fp_v4f32_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.i16"]
        pub fn neon_vcvtfxs2fp_v4f32_i16(a: i16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.v4i32"]
        pub fn neon_vcvtfxs2fp_v4f32_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.i32"]
        pub fn neon_vcvtfxs2fp_v4f32_i32(a: i32, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.v2i64"]
        pub fn neon_vcvtfxs2fp_v4f32_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.v4f32.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v4f32.i64"]
        pub fn neon_vcvtfxs2fp_v4f32_i64(a: i64, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.v16i8"]
        pub fn neon_vcvtfxs2fp_f32_v16i8(a: ::simdty::i8x16, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.i8"]
        pub fn neon_vcvtfxs2fp_f32_i8(a: i8, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.v8i16"]
        pub fn neon_vcvtfxs2fp_f32_v8i16(a: ::simdty::i16x8, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.i16"]
        pub fn neon_vcvtfxs2fp_f32_i16(a: i16, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.v4i32"]
        pub fn neon_vcvtfxs2fp_f32_v4i32(a: ::simdty::i32x4, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.i32"]
        pub fn neon_vcvtfxs2fp_f32_i32(a: i32, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.v2i64"]
        pub fn neon_vcvtfxs2fp_f32_v2i64(a: ::simdty::i64x2, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.f32.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f32.i64"]
        pub fn neon_vcvtfxs2fp_f32_i64(a: i64, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.v16i8"]
        pub fn neon_vcvtfxs2fp_v2f64_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.i8"]
        pub fn neon_vcvtfxs2fp_v2f64_i8(a: i8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.v8i16"]
        pub fn neon_vcvtfxs2fp_v2f64_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.i16"]
        pub fn neon_vcvtfxs2fp_v2f64_i16(a: i16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.v4i32"]
        pub fn neon_vcvtfxs2fp_v2f64_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.i32"]
        pub fn neon_vcvtfxs2fp_v2f64_i32(a: i32, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.v2i64"]
        pub fn neon_vcvtfxs2fp_v2f64_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.v2f64.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.v2f64.i64"]
        pub fn neon_vcvtfxs2fp_v2f64_i64(a: i64, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.v16i8"]
        pub fn neon_vcvtfxs2fp_f64_v16i8(a: ::simdty::i8x16, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.i8"]
        pub fn neon_vcvtfxs2fp_f64_i8(a: i8, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.v8i16"]
        pub fn neon_vcvtfxs2fp_f64_v8i16(a: ::simdty::i16x8, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.i16"]
        pub fn neon_vcvtfxs2fp_f64_i16(a: i16, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.v4i32"]
        pub fn neon_vcvtfxs2fp_f64_v4i32(a: ::simdty::i32x4, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.i32"]
        pub fn neon_vcvtfxs2fp_f64_i32(a: i32, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.v2i64"]
        pub fn neon_vcvtfxs2fp_f64_v2i64(a: ::simdty::i64x2, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxs2fp.f64.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxs2fp.f64.i64"]
        pub fn neon_vcvtfxs2fp_f64_i64(a: i64, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.v16i8"]
        pub fn neon_vcvtfxu2fp_v4f32_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.i8"]
        pub fn neon_vcvtfxu2fp_v4f32_i8(a: i8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.v8i16"]
        pub fn neon_vcvtfxu2fp_v4f32_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.i16"]
        pub fn neon_vcvtfxu2fp_v4f32_i16(a: i16, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.v4i32"]
        pub fn neon_vcvtfxu2fp_v4f32_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.i32"]
        pub fn neon_vcvtfxu2fp_v4f32_i32(a: i32, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.v2i64"]
        pub fn neon_vcvtfxu2fp_v4f32_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.v4f32.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v4f32.i64"]
        pub fn neon_vcvtfxu2fp_v4f32_i64(a: i64, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.v16i8"]
        pub fn neon_vcvtfxu2fp_f32_v16i8(a: ::simdty::i8x16, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.i8"]
        pub fn neon_vcvtfxu2fp_f32_i8(a: i8, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.v8i16"]
        pub fn neon_vcvtfxu2fp_f32_v8i16(a: ::simdty::i16x8, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.i16"]
        pub fn neon_vcvtfxu2fp_f32_i16(a: i16, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.v4i32"]
        pub fn neon_vcvtfxu2fp_f32_v4i32(a: ::simdty::i32x4, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.i32"]
        pub fn neon_vcvtfxu2fp_f32_i32(a: i32, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.v2i64"]
        pub fn neon_vcvtfxu2fp_f32_v2i64(a: ::simdty::i64x2, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.f32.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f32.i64"]
        pub fn neon_vcvtfxu2fp_f32_i64(a: i64, b: i32) -> f32;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.v16i8"]
        pub fn neon_vcvtfxu2fp_v2f64_v16i8(a: ::simdty::i8x16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.i8"]
        pub fn neon_vcvtfxu2fp_v2f64_i8(a: i8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.v8i16"]
        pub fn neon_vcvtfxu2fp_v2f64_v8i16(a: ::simdty::i16x8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.i16"]
        pub fn neon_vcvtfxu2fp_v2f64_i16(a: i16, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.v4i32"]
        pub fn neon_vcvtfxu2fp_v2f64_v4i32(a: ::simdty::i32x4, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.i32"]
        pub fn neon_vcvtfxu2fp_v2f64_i32(a: i32, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.v2i64"]
        pub fn neon_vcvtfxu2fp_v2f64_v2i64(a: ::simdty::i64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.v2f64.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.v2f64.i64"]
        pub fn neon_vcvtfxu2fp_v2f64_i64(a: i64, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.v16i8"]
        pub fn neon_vcvtfxu2fp_f64_v16i8(a: ::simdty::i8x16, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.i8` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.i8"]
        pub fn neon_vcvtfxu2fp_f64_i8(a: i8, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.v8i16"]
        pub fn neon_vcvtfxu2fp_f64_v8i16(a: ::simdty::i16x8, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.i16` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.i16"]
        pub fn neon_vcvtfxu2fp_f64_i16(a: i16, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.v4i32"]
        pub fn neon_vcvtfxu2fp_f64_v4i32(a: ::simdty::i32x4, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.i32` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.i32"]
        pub fn neon_vcvtfxu2fp_f64_i32(a: i32, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.v2i64"]
        pub fn neon_vcvtfxu2fp_f64_v2i64(a: ::simdty::i64x2, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfxu2fp.f64.i64` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfxu2fp.f64.i64"]
        pub fn neon_vcvtfxu2fp_f64_i64(a: i64, b: i32) -> f64;
        /// The `llvm.arm.neon.vcvtfp2hf` intrinsic.
        #[link_name = "llvm.arm.neon.vcvtfp2hf"]
        pub fn neon_vcvtfp2hf(a: ::simdty::f32x4) -> ::simdty::i16x4;
        /// The `llvm.arm.neon.vcvthf2fp` intrinsic.
        #[link_name = "llvm.arm.neon.vcvthf2fp"]
        pub fn neon_vcvthf2fp(a: ::simdty::i16x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vtbl1` intrinsic.
        #[link_name = "llvm.arm.neon.vtbl1"]
        pub fn neon_vtbl1(a: ::simdty::i8x8, b: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbl2` intrinsic.
        #[link_name = "llvm.arm.neon.vtbl2"]
        pub fn neon_vtbl2(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbl3` intrinsic.
        #[link_name = "llvm.arm.neon.vtbl3"]
        pub fn neon_vtbl3(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8, d: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbl4` intrinsic.
        #[link_name = "llvm.arm.neon.vtbl4"]
        pub fn neon_vtbl4(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8, d: ::simdty::i8x8, e: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbx1` intrinsic.
        #[link_name = "llvm.arm.neon.vtbx1"]
        pub fn neon_vtbx1(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbx2` intrinsic.
        #[link_name = "llvm.arm.neon.vtbx2"]
        pub fn neon_vtbx2(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8, d: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbx3` intrinsic.
        #[link_name = "llvm.arm.neon.vtbx3"]
        pub fn neon_vtbx3(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8, d: ::simdty::i8x8, e: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vtbx4` intrinsic.
        #[link_name = "llvm.arm.neon.vtbx4"]
        pub fn neon_vtbx4(a: ::simdty::i8x8, b: ::simdty::i8x8, c: ::simdty::i8x8, d: ::simdty::i8x8, e: ::simdty::i8x8, f: ::simdty::i8x8) -> ::simdty::i8x8;
        /// The `llvm.arm.neon.vrintn.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v16i8"]
        pub fn neon_vrintn_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrintn.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v8i16"]
        pub fn neon_vrintn_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrintn.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v4i32"]
        pub fn neon_vrintn_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrintn.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v2i64"]
        pub fn neon_vrintn_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrintn.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v4f32"]
        pub fn neon_vrintn_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrintn.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintn.v2f64"]
        pub fn neon_vrintn_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrintx.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v16i8"]
        pub fn neon_vrintx_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrintx.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v8i16"]
        pub fn neon_vrintx_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrintx.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v4i32"]
        pub fn neon_vrintx_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrintx.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v2i64"]
        pub fn neon_vrintx_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrintx.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v4f32"]
        pub fn neon_vrintx_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrintx.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintx.v2f64"]
        pub fn neon_vrintx_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrinta.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v16i8"]
        pub fn neon_vrinta_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrinta.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v8i16"]
        pub fn neon_vrinta_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrinta.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v4i32"]
        pub fn neon_vrinta_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrinta.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v2i64"]
        pub fn neon_vrinta_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrinta.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v4f32"]
        pub fn neon_vrinta_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrinta.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrinta.v2f64"]
        pub fn neon_vrinta_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrintz.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v16i8"]
        pub fn neon_vrintz_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrintz.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v8i16"]
        pub fn neon_vrintz_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrintz.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v4i32"]
        pub fn neon_vrintz_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrintz.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v2i64"]
        pub fn neon_vrintz_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrintz.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v4f32"]
        pub fn neon_vrintz_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrintz.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintz.v2f64"]
        pub fn neon_vrintz_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrintm.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v16i8"]
        pub fn neon_vrintm_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrintm.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v8i16"]
        pub fn neon_vrintm_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrintm.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v4i32"]
        pub fn neon_vrintm_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrintm.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v2i64"]
        pub fn neon_vrintm_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrintm.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v4f32"]
        pub fn neon_vrintm_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrintm.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintm.v2f64"]
        pub fn neon_vrintm_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vrintp.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v16i8"]
        pub fn neon_vrintp_v16i8(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vrintp.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v8i16"]
        pub fn neon_vrintp_v8i16(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vrintp.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v4i32"]
        pub fn neon_vrintp_v4i32(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vrintp.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v2i64"]
        pub fn neon_vrintp_v2i64(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vrintp.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v4f32"]
        pub fn neon_vrintp_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vrintp.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vrintp.v2f64"]
        pub fn neon_vrintp_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vld1.v16i8.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v16i8.p0i8"]
        pub fn neon_vld1_v16i8_p0i8(a: *mut i8, b: i32) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vld1.v8i16.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v8i16.p0i8"]
        pub fn neon_vld1_v8i16_p0i8(a: *mut i8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vld1.v4i32.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v4i32.p0i8"]
        pub fn neon_vld1_v4i32_p0i8(a: *mut i8, b: i32) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vld1.v2i64.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v2i64.p0i8"]
        pub fn neon_vld1_v2i64_p0i8(a: *mut i8, b: i32) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vld1.v4f32.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v4f32.p0i8"]
        pub fn neon_vld1_v4f32_p0i8(a: *mut i8, b: i32) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vld1.v2f64.p0i8` intrinsic.
        #[link_name = "llvm.arm.neon.vld1.v2f64.p0i8"]
        pub fn neon_vld1_v2f64_p0i8(a: *mut i8, b: i32) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.vst1.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v16i8"]
        pub fn neon_vst1_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: i32) -> ();
        /// The `llvm.arm.neon.vst1.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v8i16"]
        pub fn neon_vst1_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: i32) -> ();
        /// The `llvm.arm.neon.vst1.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v4i32"]
        pub fn neon_vst1_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: i32) -> ();
        /// The `llvm.arm.neon.vst1.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v2i64"]
        pub fn neon_vst1_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: i32) -> ();
        /// The `llvm.arm.neon.vst1.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v4f32"]
        pub fn neon_vst1_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: i32) -> ();
        /// The `llvm.arm.neon.vst1.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst1.p0i8.v2f64"]
        pub fn neon_vst1_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v16i8"]
        pub fn neon_vst2_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v8i16"]
        pub fn neon_vst2_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v4i32"]
        pub fn neon_vst2_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v2i64"]
        pub fn neon_vst2_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v4f32"]
        pub fn neon_vst2_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i32) -> ();
        /// The `llvm.arm.neon.vst2.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst2.p0i8.v2f64"]
        pub fn neon_vst2_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v16i8"]
        pub fn neon_vst3_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v8i16"]
        pub fn neon_vst3_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v4i32"]
        pub fn neon_vst3_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v2i64"]
        pub fn neon_vst3_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v4f32"]
        pub fn neon_vst3_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: i32) -> ();
        /// The `llvm.arm.neon.vst3.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst3.p0i8.v2f64"]
        pub fn neon_vst3_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v16i8"]
        pub fn neon_vst4_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v8i16"]
        pub fn neon_vst4_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: ::simdty::i16x8, f: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v4i32"]
        pub fn neon_vst4_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: ::simdty::i32x4, f: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v2i64"]
        pub fn neon_vst4_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: ::simdty::i64x2, f: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v4f32"]
        pub fn neon_vst4_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: ::simdty::f32x4, f: i32) -> ();
        /// The `llvm.arm.neon.vst4.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst4.p0i8.v2f64"]
        pub fn neon_vst4_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: ::simdty::f64x2, f: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v16i8"]
        pub fn neon_vst2lane_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v8i16"]
        pub fn neon_vst2lane_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v4i32"]
        pub fn neon_vst2lane_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v2i64"]
        pub fn neon_vst2lane_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v4f32"]
        pub fn neon_vst2lane_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst2lane.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst2lane.p0i8.v2f64"]
        pub fn neon_vst2lane_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i32, e: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v16i8"]
        pub fn neon_vst3lane_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v8i16"]
        pub fn neon_vst3lane_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v4i32"]
        pub fn neon_vst3lane_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v2i64"]
        pub fn neon_vst3lane_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v4f32"]
        pub fn neon_vst3lane_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst3lane.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst3lane.p0i8.v2f64"]
        pub fn neon_vst3lane_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: i32, f: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v16i8"]
        pub fn neon_vst4lane_p0i8_v16i8(a: *mut i8, b: ::simdty::i8x16, c: ::simdty::i8x16, d: ::simdty::i8x16, e: ::simdty::i8x16, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v8i16"]
        pub fn neon_vst4lane_p0i8_v8i16(a: *mut i8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: ::simdty::i16x8, e: ::simdty::i16x8, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v4i32"]
        pub fn neon_vst4lane_p0i8_v4i32(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4, d: ::simdty::i32x4, e: ::simdty::i32x4, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v2i64"]
        pub fn neon_vst4lane_p0i8_v2i64(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2, d: ::simdty::i64x2, e: ::simdty::i64x2, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v4f32"]
        pub fn neon_vst4lane_p0i8_v4f32(a: *mut i8, b: ::simdty::f32x4, c: ::simdty::f32x4, d: ::simdty::f32x4, e: ::simdty::f32x4, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vst4lane.p0i8.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vst4lane.p0i8.v2f64"]
        pub fn neon_vst4lane_p0i8_v2f64(a: *mut i8, b: ::simdty::f64x2, c: ::simdty::f64x2, d: ::simdty::f64x2, e: ::simdty::f64x2, f: i32, g: i32) -> ();
        /// The `llvm.arm.neon.vbsl.v16i8` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v16i8"]
        pub fn neon_vbsl_v16i8(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.vbsl.v8i16` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v8i16"]
        pub fn neon_vbsl_v8i16(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.arm.neon.vbsl.v4i32` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v4i32"]
        pub fn neon_vbsl_v4i32(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.vbsl.v2i64` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v2i64"]
        pub fn neon_vbsl_v2i64(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.arm.neon.vbsl.v4f32` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v4f32"]
        pub fn neon_vbsl_v4f32(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.arm.neon.vbsl.v2f64` intrinsic.
        #[link_name = "llvm.arm.neon.vbsl.v2f64"]
        pub fn neon_vbsl_v2f64(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.arm.neon.aesd` intrinsic.
        #[link_name = "llvm.arm.neon.aesd"]
        pub fn neon_aesd(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.aese` intrinsic.
        #[link_name = "llvm.arm.neon.aese"]
        pub fn neon_aese(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.aesimc` intrinsic.
        #[link_name = "llvm.arm.neon.aesimc"]
        pub fn neon_aesimc(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.aesmc` intrinsic.
        #[link_name = "llvm.arm.neon.aesmc"]
        pub fn neon_aesmc(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.arm.neon.sha1h` intrinsic.
        #[link_name = "llvm.arm.neon.sha1h"]
        pub fn neon_sha1h(a: i32) -> i32;
        /// The `llvm.arm.neon.sha1su1` intrinsic.
        #[link_name = "llvm.arm.neon.sha1su1"]
        pub fn neon_sha1su1(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha256su0` intrinsic.
        #[link_name = "llvm.arm.neon.sha256su0"]
        pub fn neon_sha256su0(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha1c` intrinsic.
        #[link_name = "llvm.arm.neon.sha1c"]
        pub fn neon_sha1c(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha1m` intrinsic.
        #[link_name = "llvm.arm.neon.sha1m"]
        pub fn neon_sha1m(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha1p` intrinsic.
        #[link_name = "llvm.arm.neon.sha1p"]
        pub fn neon_sha1p(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha1su0` intrinsic.
        #[link_name = "llvm.arm.neon.sha1su0"]
        pub fn neon_sha1su0(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha256h` intrinsic.
        #[link_name = "llvm.arm.neon.sha256h"]
        pub fn neon_sha256h(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha256h2` intrinsic.
        #[link_name = "llvm.arm.neon.sha256h2"]
        pub fn neon_sha256h2(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.arm.neon.sha256su1` intrinsic.
        #[link_name = "llvm.arm.neon.sha256su1"]
        pub fn neon_sha256su1(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
    }
}
/// LLVM intrinsics for the hexagon architecture.
pub mod hexagon {
    extern {
        /// The `llvm.hexagon.SI.to.SXTHI.asrh` intrinsic; known as `__builtin_SI_to_SXTHI_asrh` in GCC.
        #[link_name = "llvm.hexagon.SI.to.SXTHI.asrh"]
        pub fn SI_to_SXTHI_asrh(a: i32) -> i32;
        /// The `llvm.hexagon.brev.ldd` intrinsic; known as `__builtin_brev_ldd` in GCC.
        #[link_name = "llvm.hexagon.brev.ldd"]
        pub fn brev_ldd(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.ldw` intrinsic; known as `__builtin_brev_ldw` in GCC.
        #[link_name = "llvm.hexagon.brev.ldw"]
        pub fn brev_ldw(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.ldh` intrinsic; known as `__builtin_brev_ldh` in GCC.
        #[link_name = "llvm.hexagon.brev.ldh"]
        pub fn brev_ldh(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.lduh` intrinsic; known as `__builtin_brev_lduh` in GCC.
        #[link_name = "llvm.hexagon.brev.lduh"]
        pub fn brev_lduh(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.ldb` intrinsic; known as `__builtin_brev_ldb` in GCC.
        #[link_name = "llvm.hexagon.brev.ldb"]
        pub fn brev_ldb(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.ldub` intrinsic; known as `__builtin_brev_ldub` in GCC.
        #[link_name = "llvm.hexagon.brev.ldub"]
        pub fn brev_ldub(a: *mut i8, b: *mut i8, c: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.ldd` intrinsic; known as `__builtin_circ_ldd` in GCC.
        #[link_name = "llvm.hexagon.circ.ldd"]
        pub fn circ_ldd(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.ldw` intrinsic; known as `__builtin_circ_ldw` in GCC.
        #[link_name = "llvm.hexagon.circ.ldw"]
        pub fn circ_ldw(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.ldh` intrinsic; known as `__builtin_circ_ldh` in GCC.
        #[link_name = "llvm.hexagon.circ.ldh"]
        pub fn circ_ldh(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.lduh` intrinsic; known as `__builtin_circ_lduh` in GCC.
        #[link_name = "llvm.hexagon.circ.lduh"]
        pub fn circ_lduh(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.ldb` intrinsic; known as `__builtin_circ_ldb` in GCC.
        #[link_name = "llvm.hexagon.circ.ldb"]
        pub fn circ_ldb(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.ldub` intrinsic; known as `__builtin_circ_ldub` in GCC.
        #[link_name = "llvm.hexagon.circ.ldub"]
        pub fn circ_ldub(a: *mut i8, b: *mut i8, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.stb` intrinsic; known as `__builtin_brev_stb` in GCC.
        #[link_name = "llvm.hexagon.brev.stb"]
        pub fn brev_stb(a: *mut i8, b: i32, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.sthhi` intrinsic; known as `__builtin_brev_sthhi` in GCC.
        #[link_name = "llvm.hexagon.brev.sthhi"]
        pub fn brev_sthhi(a: *mut i8, b: i32, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.sth` intrinsic; known as `__builtin_brev_sth` in GCC.
        #[link_name = "llvm.hexagon.brev.sth"]
        pub fn brev_sth(a: *mut i8, b: i32, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.stw` intrinsic; known as `__builtin_brev_stw` in GCC.
        #[link_name = "llvm.hexagon.brev.stw"]
        pub fn brev_stw(a: *mut i8, b: i32, c: i32) -> *mut i8;
        /// The `llvm.hexagon.brev.std` intrinsic; known as `__builtin_brev_std` in GCC.
        #[link_name = "llvm.hexagon.brev.std"]
        pub fn brev_std(a: *mut i8, b: i64, c: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.std` intrinsic; known as `__builtin_circ_std` in GCC.
        #[link_name = "llvm.hexagon.circ.std"]
        pub fn circ_std(a: *mut i8, b: i64, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.stw` intrinsic; known as `__builtin_circ_stw` in GCC.
        #[link_name = "llvm.hexagon.circ.stw"]
        pub fn circ_stw(a: *mut i8, b: i32, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.sth` intrinsic; known as `__builtin_circ_sth` in GCC.
        #[link_name = "llvm.hexagon.circ.sth"]
        pub fn circ_sth(a: *mut i8, b: i32, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.sthhi` intrinsic; known as `__builtin_circ_sthhi` in GCC.
        #[link_name = "llvm.hexagon.circ.sthhi"]
        pub fn circ_sthhi(a: *mut i8, b: i32, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.circ.stb` intrinsic; known as `__builtin_circ_stb` in GCC.
        #[link_name = "llvm.hexagon.circ.stb"]
        pub fn circ_stb(a: *mut i8, b: i32, c: i32, d: i32) -> *mut i8;
        /// The `llvm.hexagon.mm256i.vaddw` intrinsic; known as `__builtin__mm256i_vaddw` in GCC.
        #[link_name = "llvm.hexagon.mm256i.vaddw"]
        pub fn mm256i_vaddw(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.hexagon.C2.cmpeq` intrinsic; known as `__builtin_HEXAGON_C2_cmpeq` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpeq"]
        pub fn C2_cmpeq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgt` intrinsic; known as `__builtin_HEXAGON_C2_cmpgt` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgt"]
        pub fn C2_cmpgt(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgtu` intrinsic; known as `__builtin_HEXAGON_C2_cmpgtu` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgtu"]
        pub fn C2_cmpgtu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpeqp` intrinsic; known as `__builtin_HEXAGON_C2_cmpeqp` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpeqp"]
        pub fn C2_cmpeqp(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.C2.cmpgtp` intrinsic; known as `__builtin_HEXAGON_C2_cmpgtp` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgtp"]
        pub fn C2_cmpgtp(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.C2.cmpgtup` intrinsic; known as `__builtin_HEXAGON_C2_cmpgtup` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgtup"]
        pub fn C2_cmpgtup(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.rcmpeqi` intrinsic; known as `__builtin_HEXAGON_A4_rcmpeqi` in GCC.
        #[link_name = "llvm.hexagon.A4.rcmpeqi"]
        pub fn A4_rcmpeqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.rcmpneqi` intrinsic; known as `__builtin_HEXAGON_A4_rcmpneqi` in GCC.
        #[link_name = "llvm.hexagon.A4.rcmpneqi"]
        pub fn A4_rcmpneqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.rcmpeq` intrinsic; known as `__builtin_HEXAGON_A4_rcmpeq` in GCC.
        #[link_name = "llvm.hexagon.A4.rcmpeq"]
        pub fn A4_rcmpeq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.rcmpneq` intrinsic; known as `__builtin_HEXAGON_A4_rcmpneq` in GCC.
        #[link_name = "llvm.hexagon.A4.rcmpneq"]
        pub fn A4_rcmpneq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.bitsset` intrinsic; known as `__builtin_HEXAGON_C2_bitsset` in GCC.
        #[link_name = "llvm.hexagon.C2.bitsset"]
        pub fn C2_bitsset(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.bitsclr` intrinsic; known as `__builtin_HEXAGON_C2_bitsclr` in GCC.
        #[link_name = "llvm.hexagon.C2.bitsclr"]
        pub fn C2_bitsclr(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.nbitsset` intrinsic; known as `__builtin_HEXAGON_C4_nbitsset` in GCC.
        #[link_name = "llvm.hexagon.C4.nbitsset"]
        pub fn C4_nbitsset(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.nbitsclr` intrinsic; known as `__builtin_HEXAGON_C4_nbitsclr` in GCC.
        #[link_name = "llvm.hexagon.C4.nbitsclr"]
        pub fn C4_nbitsclr(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpeqi` intrinsic; known as `__builtin_HEXAGON_C2_cmpeqi` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpeqi"]
        pub fn C2_cmpeqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgti` intrinsic; known as `__builtin_HEXAGON_C2_cmpgti` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgti"]
        pub fn C2_cmpgti(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgtui` intrinsic; known as `__builtin_HEXAGON_C2_cmpgtui` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgtui"]
        pub fn C2_cmpgtui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgei` intrinsic; known as `__builtin_HEXAGON_C2_cmpgei` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgei"]
        pub fn C2_cmpgei(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpgeui` intrinsic; known as `__builtin_HEXAGON_C2_cmpgeui` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpgeui"]
        pub fn C2_cmpgeui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmplt` intrinsic; known as `__builtin_HEXAGON_C2_cmplt` in GCC.
        #[link_name = "llvm.hexagon.C2.cmplt"]
        pub fn C2_cmplt(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.cmpltu` intrinsic; known as `__builtin_HEXAGON_C2_cmpltu` in GCC.
        #[link_name = "llvm.hexagon.C2.cmpltu"]
        pub fn C2_cmpltu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.bitsclri` intrinsic; known as `__builtin_HEXAGON_C2_bitsclri` in GCC.
        #[link_name = "llvm.hexagon.C2.bitsclri"]
        pub fn C2_bitsclri(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.nbitsclri` intrinsic; known as `__builtin_HEXAGON_C4_nbitsclri` in GCC.
        #[link_name = "llvm.hexagon.C4.nbitsclri"]
        pub fn C4_nbitsclri(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmpneqi` intrinsic; known as `__builtin_HEXAGON_C4_cmpneqi` in GCC.
        #[link_name = "llvm.hexagon.C4.cmpneqi"]
        pub fn C4_cmpneqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmpltei` intrinsic; known as `__builtin_HEXAGON_C4_cmpltei` in GCC.
        #[link_name = "llvm.hexagon.C4.cmpltei"]
        pub fn C4_cmpltei(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmplteui` intrinsic; known as `__builtin_HEXAGON_C4_cmplteui` in GCC.
        #[link_name = "llvm.hexagon.C4.cmplteui"]
        pub fn C4_cmplteui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmpneq` intrinsic; known as `__builtin_HEXAGON_C4_cmpneq` in GCC.
        #[link_name = "llvm.hexagon.C4.cmpneq"]
        pub fn C4_cmpneq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmplte` intrinsic; known as `__builtin_HEXAGON_C4_cmplte` in GCC.
        #[link_name = "llvm.hexagon.C4.cmplte"]
        pub fn C4_cmplte(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.cmplteu` intrinsic; known as `__builtin_HEXAGON_C4_cmplteu` in GCC.
        #[link_name = "llvm.hexagon.C4.cmplteu"]
        pub fn C4_cmplteu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.and` intrinsic; known as `__builtin_HEXAGON_C2_and` in GCC.
        #[link_name = "llvm.hexagon.C2.and"]
        pub fn C2_and(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.or` intrinsic; known as `__builtin_HEXAGON_C2_or` in GCC.
        #[link_name = "llvm.hexagon.C2.or"]
        pub fn C2_or(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.xor` intrinsic; known as `__builtin_HEXAGON_C2_xor` in GCC.
        #[link_name = "llvm.hexagon.C2.xor"]
        pub fn C2_xor(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.andn` intrinsic; known as `__builtin_HEXAGON_C2_andn` in GCC.
        #[link_name = "llvm.hexagon.C2.andn"]
        pub fn C2_andn(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.not` intrinsic; known as `__builtin_HEXAGON_C2_not` in GCC.
        #[link_name = "llvm.hexagon.C2.not"]
        pub fn C2_not(a: i32) -> i32;
        /// The `llvm.hexagon.C2.orn` intrinsic; known as `__builtin_HEXAGON_C2_orn` in GCC.
        #[link_name = "llvm.hexagon.C2.orn"]
        pub fn C2_orn(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.and.and` intrinsic; known as `__builtin_HEXAGON_C4_and_and` in GCC.
        #[link_name = "llvm.hexagon.C4.and.and"]
        pub fn C4_and_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.and.or` intrinsic; known as `__builtin_HEXAGON_C4_and_or` in GCC.
        #[link_name = "llvm.hexagon.C4.and.or"]
        pub fn C4_and_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.or.and` intrinsic; known as `__builtin_HEXAGON_C4_or_and` in GCC.
        #[link_name = "llvm.hexagon.C4.or.and"]
        pub fn C4_or_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.or.or` intrinsic; known as `__builtin_HEXAGON_C4_or_or` in GCC.
        #[link_name = "llvm.hexagon.C4.or.or"]
        pub fn C4_or_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.and.andn` intrinsic; known as `__builtin_HEXAGON_C4_and_andn` in GCC.
        #[link_name = "llvm.hexagon.C4.and.andn"]
        pub fn C4_and_andn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.and.orn` intrinsic; known as `__builtin_HEXAGON_C4_and_orn` in GCC.
        #[link_name = "llvm.hexagon.C4.and.orn"]
        pub fn C4_and_orn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.or.andn` intrinsic; known as `__builtin_HEXAGON_C4_or_andn` in GCC.
        #[link_name = "llvm.hexagon.C4.or.andn"]
        pub fn C4_or_andn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C4.or.orn` intrinsic; known as `__builtin_HEXAGON_C4_or_orn` in GCC.
        #[link_name = "llvm.hexagon.C4.or.orn"]
        pub fn C4_or_orn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C2.pxfer.map` intrinsic; known as `__builtin_HEXAGON_C2_pxfer_map` in GCC.
        #[link_name = "llvm.hexagon.C2.pxfer.map"]
        pub fn C2_pxfer_map(a: i32) -> i32;
        /// The `llvm.hexagon.C2.any8` intrinsic; known as `__builtin_HEXAGON_C2_any8` in GCC.
        #[link_name = "llvm.hexagon.C2.any8"]
        pub fn C2_any8(a: i32) -> i32;
        /// The `llvm.hexagon.C2.all8` intrinsic; known as `__builtin_HEXAGON_C2_all8` in GCC.
        #[link_name = "llvm.hexagon.C2.all8"]
        pub fn C2_all8(a: i32) -> i32;
        /// The `llvm.hexagon.C2.vitpack` intrinsic; known as `__builtin_HEXAGON_C2_vitpack` in GCC.
        #[link_name = "llvm.hexagon.C2.vitpack"]
        pub fn C2_vitpack(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C2.mux` intrinsic; known as `__builtin_HEXAGON_C2_mux` in GCC.
        #[link_name = "llvm.hexagon.C2.mux"]
        pub fn C2_mux(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C2.muxii` intrinsic; known as `__builtin_HEXAGON_C2_muxii` in GCC.
        #[link_name = "llvm.hexagon.C2.muxii"]
        pub fn C2_muxii(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C2.muxir` intrinsic; known as `__builtin_HEXAGON_C2_muxir` in GCC.
        #[link_name = "llvm.hexagon.C2.muxir"]
        pub fn C2_muxir(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C2.muxri` intrinsic; known as `__builtin_HEXAGON_C2_muxri` in GCC.
        #[link_name = "llvm.hexagon.C2.muxri"]
        pub fn C2_muxri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.C2.vmux` intrinsic; known as `__builtin_HEXAGON_C2_vmux` in GCC.
        #[link_name = "llvm.hexagon.C2.vmux"]
        pub fn C2_vmux(a: i32, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.C2.mask` intrinsic; known as `__builtin_HEXAGON_C2_mask` in GCC.
        #[link_name = "llvm.hexagon.C2.mask"]
        pub fn C2_mask(a: i32) -> i64;
        /// The `llvm.hexagon.A2.vcmpbeq` intrinsic; known as `__builtin_HEXAGON_A2_vcmpbeq` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpbeq"]
        pub fn A2_vcmpbeq(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.vcmpbeqi` intrinsic; known as `__builtin_HEXAGON_A4_vcmpbeqi` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpbeqi"]
        pub fn A4_vcmpbeqi(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmpbeq.any` intrinsic; known as `__builtin_HEXAGON_A4_vcmpbeq_any` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpbeq.any"]
        pub fn A4_vcmpbeq_any(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vcmpbgtu` intrinsic; known as `__builtin_HEXAGON_A2_vcmpbgtu` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpbgtu"]
        pub fn A2_vcmpbgtu(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.vcmpbgtui` intrinsic; known as `__builtin_HEXAGON_A4_vcmpbgtui` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpbgtui"]
        pub fn A4_vcmpbgtui(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmpbgt` intrinsic; known as `__builtin_HEXAGON_A4_vcmpbgt` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpbgt"]
        pub fn A4_vcmpbgt(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.vcmpbgti` intrinsic; known as `__builtin_HEXAGON_A4_vcmpbgti` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpbgti"]
        pub fn A4_vcmpbgti(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbeq` intrinsic; known as `__builtin_HEXAGON_A4_cmpbeq` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbeq"]
        pub fn A4_cmpbeq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbeqi` intrinsic; known as `__builtin_HEXAGON_A4_cmpbeqi` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbeqi"]
        pub fn A4_cmpbeqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbgtu` intrinsic; known as `__builtin_HEXAGON_A4_cmpbgtu` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbgtu"]
        pub fn A4_cmpbgtu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbgtui` intrinsic; known as `__builtin_HEXAGON_A4_cmpbgtui` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbgtui"]
        pub fn A4_cmpbgtui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbgt` intrinsic; known as `__builtin_HEXAGON_A4_cmpbgt` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbgt"]
        pub fn A4_cmpbgt(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpbgti` intrinsic; known as `__builtin_HEXAGON_A4_cmpbgti` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpbgti"]
        pub fn A4_cmpbgti(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.vcmpheq` intrinsic; known as `__builtin_HEXAGON_A2_vcmpheq` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpheq"]
        pub fn A2_vcmpheq(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vcmphgt` intrinsic; known as `__builtin_HEXAGON_A2_vcmphgt` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmphgt"]
        pub fn A2_vcmphgt(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vcmphgtu` intrinsic; known as `__builtin_HEXAGON_A2_vcmphgtu` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmphgtu"]
        pub fn A2_vcmphgtu(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.vcmpheqi` intrinsic; known as `__builtin_HEXAGON_A4_vcmpheqi` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpheqi"]
        pub fn A4_vcmpheqi(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmphgti` intrinsic; known as `__builtin_HEXAGON_A4_vcmphgti` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmphgti"]
        pub fn A4_vcmphgti(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmphgtui` intrinsic; known as `__builtin_HEXAGON_A4_vcmphgtui` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmphgtui"]
        pub fn A4_vcmphgtui(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpheq` intrinsic; known as `__builtin_HEXAGON_A4_cmpheq` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpheq"]
        pub fn A4_cmpheq(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmphgt` intrinsic; known as `__builtin_HEXAGON_A4_cmphgt` in GCC.
        #[link_name = "llvm.hexagon.A4.cmphgt"]
        pub fn A4_cmphgt(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmphgtu` intrinsic; known as `__builtin_HEXAGON_A4_cmphgtu` in GCC.
        #[link_name = "llvm.hexagon.A4.cmphgtu"]
        pub fn A4_cmphgtu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmpheqi` intrinsic; known as `__builtin_HEXAGON_A4_cmpheqi` in GCC.
        #[link_name = "llvm.hexagon.A4.cmpheqi"]
        pub fn A4_cmpheqi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmphgti` intrinsic; known as `__builtin_HEXAGON_A4_cmphgti` in GCC.
        #[link_name = "llvm.hexagon.A4.cmphgti"]
        pub fn A4_cmphgti(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cmphgtui` intrinsic; known as `__builtin_HEXAGON_A4_cmphgtui` in GCC.
        #[link_name = "llvm.hexagon.A4.cmphgtui"]
        pub fn A4_cmphgtui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.vcmpweq` intrinsic; known as `__builtin_HEXAGON_A2_vcmpweq` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpweq"]
        pub fn A2_vcmpweq(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vcmpwgt` intrinsic; known as `__builtin_HEXAGON_A2_vcmpwgt` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpwgt"]
        pub fn A2_vcmpwgt(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vcmpwgtu` intrinsic; known as `__builtin_HEXAGON_A2_vcmpwgtu` in GCC.
        #[link_name = "llvm.hexagon.A2.vcmpwgtu"]
        pub fn A2_vcmpwgtu(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A4.vcmpweqi` intrinsic; known as `__builtin_HEXAGON_A4_vcmpweqi` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpweqi"]
        pub fn A4_vcmpweqi(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmpwgti` intrinsic; known as `__builtin_HEXAGON_A4_vcmpwgti` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpwgti"]
        pub fn A4_vcmpwgti(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vcmpwgtui` intrinsic; known as `__builtin_HEXAGON_A4_vcmpwgtui` in GCC.
        #[link_name = "llvm.hexagon.A4.vcmpwgtui"]
        pub fn A4_vcmpwgtui(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.A4.boundscheck` intrinsic; known as `__builtin_HEXAGON_A4_boundscheck` in GCC.
        #[link_name = "llvm.hexagon.A4.boundscheck"]
        pub fn A4_boundscheck(a: i32, b: i64) -> i32;
        /// The `llvm.hexagon.A4.tlbmatch` intrinsic; known as `__builtin_HEXAGON_A4_tlbmatch` in GCC.
        #[link_name = "llvm.hexagon.A4.tlbmatch"]
        pub fn A4_tlbmatch(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.C2.tfrpr` intrinsic; known as `__builtin_HEXAGON_C2_tfrpr` in GCC.
        #[link_name = "llvm.hexagon.C2.tfrpr"]
        pub fn C2_tfrpr(a: i32) -> i32;
        /// The `llvm.hexagon.C2.tfrrp` intrinsic; known as `__builtin_HEXAGON_C2_tfrrp` in GCC.
        #[link_name = "llvm.hexagon.C2.tfrrp"]
        pub fn C2_tfrrp(a: i32) -> i32;
        /// The `llvm.hexagon.C4.fastcorner9` intrinsic; known as `__builtin_HEXAGON_C4_fastcorner9` in GCC.
        #[link_name = "llvm.hexagon.C4.fastcorner9"]
        pub fn C4_fastcorner9(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.C4.fastcorner9.not` intrinsic; known as `__builtin_HEXAGON_C4_fastcorner9_not` in GCC.
        #[link_name = "llvm.hexagon.C4.fastcorner9.not"]
        pub fn C4_fastcorner9_not(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.hh.s0"]
        pub fn M2_mpy_acc_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.hh.s1"]
        pub fn M2_mpy_acc_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.hl.s0"]
        pub fn M2_mpy_acc_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.hl.s1"]
        pub fn M2_mpy_acc_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.lh.s0"]
        pub fn M2_mpy_acc_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.lh.s1"]
        pub fn M2_mpy_acc_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.ll.s0"]
        pub fn M2_mpy_acc_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.ll.s1"]
        pub fn M2_mpy_acc_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.hh.s0"]
        pub fn M2_mpy_nac_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.hh.s1"]
        pub fn M2_mpy_nac_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.hl.s0"]
        pub fn M2_mpy_nac_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.hl.s1"]
        pub fn M2_mpy_nac_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.lh.s0"]
        pub fn M2_mpy_nac_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.lh.s1"]
        pub fn M2_mpy_nac_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.ll.s0"]
        pub fn M2_mpy_nac_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.ll.s1"]
        pub fn M2_mpy_nac_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.hh.s0"]
        pub fn M2_mpy_acc_sat_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.hh.s1"]
        pub fn M2_mpy_acc_sat_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.hl.s0"]
        pub fn M2_mpy_acc_sat_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.hl.s1"]
        pub fn M2_mpy_acc_sat_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.lh.s0"]
        pub fn M2_mpy_acc_sat_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.lh.s1"]
        pub fn M2_mpy_acc_sat_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.ll.s0"]
        pub fn M2_mpy_acc_sat_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.acc.sat.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_acc_sat_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.acc.sat.ll.s1"]
        pub fn M2_mpy_acc_sat_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.hh.s0"]
        pub fn M2_mpy_nac_sat_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.hh.s1"]
        pub fn M2_mpy_nac_sat_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.hl.s0"]
        pub fn M2_mpy_nac_sat_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.hl.s1"]
        pub fn M2_mpy_nac_sat_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.lh.s0"]
        pub fn M2_mpy_nac_sat_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.lh.s1"]
        pub fn M2_mpy_nac_sat_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.ll.s0"]
        pub fn M2_mpy_nac_sat_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.nac.sat.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_nac_sat_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.nac.sat.ll.s1"]
        pub fn M2_mpy_nac_sat_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.hh.s0"]
        pub fn M2_mpy_hh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.hh.s1"]
        pub fn M2_mpy_hh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.hl.s0"]
        pub fn M2_mpy_hl_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.hl.s1"]
        pub fn M2_mpy_hl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.lh.s0"]
        pub fn M2_mpy_lh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.lh.s1"]
        pub fn M2_mpy_lh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.ll.s0"]
        pub fn M2_mpy_ll_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.ll.s1"]
        pub fn M2_mpy_ll_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.hh.s0"]
        pub fn M2_mpy_sat_hh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.hh.s1"]
        pub fn M2_mpy_sat_hh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.hl.s0"]
        pub fn M2_mpy_sat_hl_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.hl.s1"]
        pub fn M2_mpy_sat_hl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.lh.s0"]
        pub fn M2_mpy_sat_lh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.lh.s1"]
        pub fn M2_mpy_sat_lh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.ll.s0"]
        pub fn M2_mpy_sat_ll_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.ll.s1"]
        pub fn M2_mpy_sat_ll_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.hh.s0"]
        pub fn M2_mpy_rnd_hh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.hh.s1"]
        pub fn M2_mpy_rnd_hh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.hl.s0"]
        pub fn M2_mpy_rnd_hl_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.hl.s1"]
        pub fn M2_mpy_rnd_hl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.lh.s0"]
        pub fn M2_mpy_rnd_lh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.lh.s1"]
        pub fn M2_mpy_rnd_lh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.ll.s0"]
        pub fn M2_mpy_rnd_ll_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.rnd.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_rnd_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.rnd.ll.s1"]
        pub fn M2_mpy_rnd_ll_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.hh.s0"]
        pub fn M2_mpy_sat_rnd_hh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.hh.s1"]
        pub fn M2_mpy_sat_rnd_hh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.hl.s0"]
        pub fn M2_mpy_sat_rnd_hl_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.hl.s1"]
        pub fn M2_mpy_sat_rnd_hl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.lh.s0"]
        pub fn M2_mpy_sat_rnd_lh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.lh.s1"]
        pub fn M2_mpy_sat_rnd_lh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.ll.s0"]
        pub fn M2_mpy_sat_rnd_ll_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.sat.rnd.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.sat.rnd.ll.s1"]
        pub fn M2_mpy_sat_rnd_ll_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyd.acc.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.hh.s0"]
        pub fn M2_mpyd_acc_hh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.hh.s1"]
        pub fn M2_mpyd_acc_hh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.hl.s0"]
        pub fn M2_mpyd_acc_hl_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.hl.s1"]
        pub fn M2_mpyd_acc_hl_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.lh.s0"]
        pub fn M2_mpyd_acc_lh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.lh.s1"]
        pub fn M2_mpyd_acc_lh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.ll.s0"]
        pub fn M2_mpyd_acc_ll_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.acc.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_acc_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.acc.ll.s1"]
        pub fn M2_mpyd_acc_ll_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.hh.s0"]
        pub fn M2_mpyd_nac_hh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.hh.s1"]
        pub fn M2_mpyd_nac_hh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.hl.s0"]
        pub fn M2_mpyd_nac_hl_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.hl.s1"]
        pub fn M2_mpyd_nac_hl_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.lh.s0"]
        pub fn M2_mpyd_nac_lh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.lh.s1"]
        pub fn M2_mpyd_nac_lh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.ll.s0"]
        pub fn M2_mpyd_nac_ll_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.nac.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_nac_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.nac.ll.s1"]
        pub fn M2_mpyd_nac_ll_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.hh.s0"]
        pub fn M2_mpyd_hh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.hh.s1"]
        pub fn M2_mpyd_hh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.hl.s0"]
        pub fn M2_mpyd_hl_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.hl.s1"]
        pub fn M2_mpyd_hl_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.lh.s0"]
        pub fn M2_mpyd_lh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.lh.s1"]
        pub fn M2_mpyd_lh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.ll.s0"]
        pub fn M2_mpyd_ll_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.ll.s1"]
        pub fn M2_mpyd_ll_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.hh.s0"]
        pub fn M2_mpyd_rnd_hh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.hh.s1"]
        pub fn M2_mpyd_rnd_hh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.hl.s0"]
        pub fn M2_mpyd_rnd_hl_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.hl.s1"]
        pub fn M2_mpyd_rnd_hl_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.lh.s0"]
        pub fn M2_mpyd_rnd_lh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.lh.s1"]
        pub fn M2_mpyd_rnd_lh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.ll.s0"]
        pub fn M2_mpyd_rnd_ll_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyd.rnd.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyd_rnd_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyd.rnd.ll.s1"]
        pub fn M2_mpyd_rnd_ll_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyu.acc.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.hh.s0"]
        pub fn M2_mpyu_acc_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.hh.s1"]
        pub fn M2_mpyu_acc_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.hl.s0"]
        pub fn M2_mpyu_acc_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.hl.s1"]
        pub fn M2_mpyu_acc_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.lh.s0"]
        pub fn M2_mpyu_acc_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.lh.s1"]
        pub fn M2_mpyu_acc_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.ll.s0"]
        pub fn M2_mpyu_acc_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.acc.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_acc_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.acc.ll.s1"]
        pub fn M2_mpyu_acc_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.hh.s0"]
        pub fn M2_mpyu_nac_hh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.hh.s1"]
        pub fn M2_mpyu_nac_hh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.hl.s0"]
        pub fn M2_mpyu_nac_hl_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.hl.s1"]
        pub fn M2_mpyu_nac_hl_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.lh.s0"]
        pub fn M2_mpyu_nac_lh_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.lh.s1"]
        pub fn M2_mpyu_nac_lh_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.ll.s0"]
        pub fn M2_mpyu_nac_ll_s0(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.nac.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_nac_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.nac.ll.s1"]
        pub fn M2_mpyu_nac_ll_s1(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.hh.s0"]
        pub fn M2_mpyu_hh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.hh.s1"]
        pub fn M2_mpyu_hh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.hl.s0"]
        pub fn M2_mpyu_hl_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.hl.s1"]
        pub fn M2_mpyu_hl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.lh.s0"]
        pub fn M2_mpyu_lh_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.lh.s1"]
        pub fn M2_mpyu_lh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.ll.s0"]
        pub fn M2_mpyu_ll_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.ll.s1"]
        pub fn M2_mpyu_ll_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyud.acc.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.hh.s0"]
        pub fn M2_mpyud_acc_hh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.hh.s1"]
        pub fn M2_mpyud_acc_hh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.hl.s0"]
        pub fn M2_mpyud_acc_hl_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.hl.s1"]
        pub fn M2_mpyud_acc_hl_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.lh.s0"]
        pub fn M2_mpyud_acc_lh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.lh.s1"]
        pub fn M2_mpyud_acc_lh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.ll.s0"]
        pub fn M2_mpyud_acc_ll_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.acc.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_acc_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.acc.ll.s1"]
        pub fn M2_mpyud_acc_ll_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.hh.s0"]
        pub fn M2_mpyud_nac_hh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.hh.s1"]
        pub fn M2_mpyud_nac_hh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.hl.s0"]
        pub fn M2_mpyud_nac_hl_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.hl.s1"]
        pub fn M2_mpyud_nac_hl_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.lh.s0"]
        pub fn M2_mpyud_nac_lh_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.lh.s1"]
        pub fn M2_mpyud_nac_lh_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.ll.s0"]
        pub fn M2_mpyud_nac_ll_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.nac.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_nac_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.nac.ll.s1"]
        pub fn M2_mpyud_nac_ll_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.hh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_hh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.hh.s0"]
        pub fn M2_mpyud_hh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.hh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_hh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.hh.s1"]
        pub fn M2_mpyud_hh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.hl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_hl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.hl.s0"]
        pub fn M2_mpyud_hl_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.hl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_hl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.hl.s1"]
        pub fn M2_mpyud_hl_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.lh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_lh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.lh.s0"]
        pub fn M2_mpyud_lh_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.lh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_lh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.lh.s1"]
        pub fn M2_mpyud_lh_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.ll.s0` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_ll_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.ll.s0"]
        pub fn M2_mpyud_ll_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpyud.ll.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpyud_ll_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyud.ll.s1"]
        pub fn M2_mpyud_ll_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.mpysmi` intrinsic; known as `__builtin_HEXAGON_M2_mpysmi` in GCC.
        #[link_name = "llvm.hexagon.M2.mpysmi"]
        pub fn M2_mpysmi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.macsip` intrinsic; known as `__builtin_HEXAGON_M2_macsip` in GCC.
        #[link_name = "llvm.hexagon.M2.macsip"]
        pub fn M2_macsip(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.macsin` intrinsic; known as `__builtin_HEXAGON_M2_macsin` in GCC.
        #[link_name = "llvm.hexagon.M2.macsin"]
        pub fn M2_macsin(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.dpmpyss.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyss_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyss.s0"]
        pub fn M2_dpmpyss_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.dpmpyss.acc.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyss_acc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyss.acc.s0"]
        pub fn M2_dpmpyss_acc_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.dpmpyss.nac.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyss_nac_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyss.nac.s0"]
        pub fn M2_dpmpyss_nac_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.dpmpyuu.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyuu_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyuu.s0"]
        pub fn M2_dpmpyuu_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.dpmpyuu.acc.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyuu_acc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyuu.acc.s0"]
        pub fn M2_dpmpyuu_acc_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.dpmpyuu.nac.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyuu_nac_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyuu.nac.s0"]
        pub fn M2_dpmpyuu_nac_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.mpy.up` intrinsic; known as `__builtin_HEXAGON_M2_mpy_up` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.up"]
        pub fn M2_mpy_up(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.up.s1` intrinsic; known as `__builtin_HEXAGON_M2_mpy_up_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.up.s1"]
        pub fn M2_mpy_up_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpy.up.s1.sat` intrinsic; known as `__builtin_HEXAGON_M2_mpy_up_s1_sat` in GCC.
        #[link_name = "llvm.hexagon.M2.mpy.up.s1.sat"]
        pub fn M2_mpy_up_s1_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyu.up` intrinsic; known as `__builtin_HEXAGON_M2_mpyu_up` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyu.up"]
        pub fn M2_mpyu_up(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpysu.up` intrinsic; known as `__builtin_HEXAGON_M2_mpysu_up` in GCC.
        #[link_name = "llvm.hexagon.M2.mpysu.up"]
        pub fn M2_mpysu_up(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.dpmpyss.rnd.s0` intrinsic; known as `__builtin_HEXAGON_M2_dpmpyss_rnd_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.dpmpyss.rnd.s0"]
        pub fn M2_dpmpyss_rnd_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M4.mac.up.s1.sat` intrinsic; known as `__builtin_HEXAGON_M4_mac_up_s1_sat` in GCC.
        #[link_name = "llvm.hexagon.M4.mac.up.s1.sat"]
        pub fn M4_mac_up_s1_sat(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.nac.up.s1.sat` intrinsic; known as `__builtin_HEXAGON_M4_nac_up_s1_sat` in GCC.
        #[link_name = "llvm.hexagon.M4.nac.up.s1.sat"]
        pub fn M4_nac_up_s1_sat(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyi` intrinsic; known as `__builtin_HEXAGON_M2_mpyi` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyi"]
        pub fn M2_mpyi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mpyui` intrinsic; known as `__builtin_HEXAGON_M2_mpyui` in GCC.
        #[link_name = "llvm.hexagon.M2.mpyui"]
        pub fn M2_mpyui(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.maci` intrinsic; known as `__builtin_HEXAGON_M2_maci` in GCC.
        #[link_name = "llvm.hexagon.M2.maci"]
        pub fn M2_maci(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.acci` intrinsic; known as `__builtin_HEXAGON_M2_acci` in GCC.
        #[link_name = "llvm.hexagon.M2.acci"]
        pub fn M2_acci(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.accii` intrinsic; known as `__builtin_HEXAGON_M2_accii` in GCC.
        #[link_name = "llvm.hexagon.M2.accii"]
        pub fn M2_accii(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.nacci` intrinsic; known as `__builtin_HEXAGON_M2_nacci` in GCC.
        #[link_name = "llvm.hexagon.M2.nacci"]
        pub fn M2_nacci(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.naccii` intrinsic; known as `__builtin_HEXAGON_M2_naccii` in GCC.
        #[link_name = "llvm.hexagon.M2.naccii"]
        pub fn M2_naccii(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.subacc` intrinsic; known as `__builtin_HEXAGON_M2_subacc` in GCC.
        #[link_name = "llvm.hexagon.M2.subacc"]
        pub fn M2_subacc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.mpyrr.addr` intrinsic; known as `__builtin_HEXAGON_M4_mpyrr_addr` in GCC.
        #[link_name = "llvm.hexagon.M4.mpyrr.addr"]
        pub fn M4_mpyrr_addr(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.mpyri.addr.u2` intrinsic; known as `__builtin_HEXAGON_M4_mpyri_addr_u2` in GCC.
        #[link_name = "llvm.hexagon.M4.mpyri.addr.u2"]
        pub fn M4_mpyri_addr_u2(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.mpyri.addr` intrinsic; known as `__builtin_HEXAGON_M4_mpyri_addr` in GCC.
        #[link_name = "llvm.hexagon.M4.mpyri.addr"]
        pub fn M4_mpyri_addr(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.mpyri.addi` intrinsic; known as `__builtin_HEXAGON_M4_mpyri_addi` in GCC.
        #[link_name = "llvm.hexagon.M4.mpyri.addi"]
        pub fn M4_mpyri_addi(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.mpyrr.addi` intrinsic; known as `__builtin_HEXAGON_M4_mpyrr_addi` in GCC.
        #[link_name = "llvm.hexagon.M4.mpyrr.addi"]
        pub fn M4_mpyrr_addi(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M2.vmpy2s.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2s_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2s.s0"]
        pub fn M2_vmpy2s_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.vmpy2s.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2s_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2s.s1"]
        pub fn M2_vmpy2s_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.vmac2s.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmac2s_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2s.s0"]
        pub fn M2_vmac2s_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vmac2s.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmac2s_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2s.s1"]
        pub fn M2_vmac2s_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vmpy2su.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2su_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2su.s0"]
        pub fn M2_vmpy2su_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.vmpy2su.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2su_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2su.s1"]
        pub fn M2_vmpy2su_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.vmac2su.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmac2su_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2su.s0"]
        pub fn M2_vmac2su_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vmac2su.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmac2su_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2su.s1"]
        pub fn M2_vmac2su_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vmpy2s.s0pack` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2s_s0pack` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2s.s0pack"]
        pub fn M2_vmpy2s_s0pack(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.vmpy2s.s1pack` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2s_s1pack` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2s.s1pack"]
        pub fn M2_vmpy2s_s1pack(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.vmac2` intrinsic; known as `__builtin_HEXAGON_M2_vmac2` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2"]
        pub fn M2_vmac2(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vmpy2es.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2es_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2es.s0"]
        pub fn M2_vmpy2es_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vmpy2es.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmpy2es_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmpy2es.s1"]
        pub fn M2_vmpy2es_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vmac2es.s0` intrinsic; known as `__builtin_HEXAGON_M2_vmac2es_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2es.s0"]
        pub fn M2_vmac2es_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vmac2es.s1` intrinsic; known as `__builtin_HEXAGON_M2_vmac2es_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2es.s1"]
        pub fn M2_vmac2es_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vmac2es` intrinsic; known as `__builtin_HEXAGON_M2_vmac2es` in GCC.
        #[link_name = "llvm.hexagon.M2.vmac2es"]
        pub fn M2_vmac2es(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vrmac.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrmac_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrmac.s0"]
        pub fn M2_vrmac_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vrmpy.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrmpy_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrmpy.s0"]
        pub fn M2_vrmpy_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vdmpyrs.s0` intrinsic; known as `__builtin_HEXAGON_M2_vdmpyrs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmpyrs.s0"]
        pub fn M2_vdmpyrs_s0(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.M2.vdmpyrs.s1` intrinsic; known as `__builtin_HEXAGON_M2_vdmpyrs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmpyrs.s1"]
        pub fn M2_vdmpyrs_s1(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.M5.vrmpybuu` intrinsic; known as `__builtin_HEXAGON_M5_vrmpybuu` in GCC.
        #[link_name = "llvm.hexagon.M5.vrmpybuu"]
        pub fn M5_vrmpybuu(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M5.vrmacbuu` intrinsic; known as `__builtin_HEXAGON_M5_vrmacbuu` in GCC.
        #[link_name = "llvm.hexagon.M5.vrmacbuu"]
        pub fn M5_vrmacbuu(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M5.vrmpybsu` intrinsic; known as `__builtin_HEXAGON_M5_vrmpybsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vrmpybsu"]
        pub fn M5_vrmpybsu(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M5.vrmacbsu` intrinsic; known as `__builtin_HEXAGON_M5_vrmacbsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vrmacbsu"]
        pub fn M5_vrmacbsu(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M5.vmpybuu` intrinsic; known as `__builtin_HEXAGON_M5_vmpybuu` in GCC.
        #[link_name = "llvm.hexagon.M5.vmpybuu"]
        pub fn M5_vmpybuu(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M5.vmpybsu` intrinsic; known as `__builtin_HEXAGON_M5_vmpybsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vmpybsu"]
        pub fn M5_vmpybsu(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M5.vmacbuu` intrinsic; known as `__builtin_HEXAGON_M5_vmacbuu` in GCC.
        #[link_name = "llvm.hexagon.M5.vmacbuu"]
        pub fn M5_vmacbuu(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M5.vmacbsu` intrinsic; known as `__builtin_HEXAGON_M5_vmacbsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vmacbsu"]
        pub fn M5_vmacbsu(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M5.vdmpybsu` intrinsic; known as `__builtin_HEXAGON_M5_vdmpybsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vdmpybsu"]
        pub fn M5_vdmpybsu(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M5.vdmacbsu` intrinsic; known as `__builtin_HEXAGON_M5_vdmacbsu` in GCC.
        #[link_name = "llvm.hexagon.M5.vdmacbsu"]
        pub fn M5_vdmacbsu(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vdmacs.s0` intrinsic; known as `__builtin_HEXAGON_M2_vdmacs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmacs.s0"]
        pub fn M2_vdmacs_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vdmacs.s1` intrinsic; known as `__builtin_HEXAGON_M2_vdmacs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmacs.s1"]
        pub fn M2_vdmacs_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vdmpys.s0` intrinsic; known as `__builtin_HEXAGON_M2_vdmpys_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmpys.s0"]
        pub fn M2_vdmpys_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vdmpys.s1` intrinsic; known as `__builtin_HEXAGON_M2_vdmpys_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vdmpys.s1"]
        pub fn M2_vdmpys_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.cmpyrs.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpyrs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyrs.s0"]
        pub fn M2_cmpyrs_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.cmpyrs.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmpyrs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyrs.s1"]
        pub fn M2_cmpyrs_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.cmpyrsc.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpyrsc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyrsc.s0"]
        pub fn M2_cmpyrsc_s0(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.cmpyrsc.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmpyrsc_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyrsc.s1"]
        pub fn M2_cmpyrsc_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.cmacs.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmacs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmacs.s0"]
        pub fn M2_cmacs_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cmacs.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmacs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmacs.s1"]
        pub fn M2_cmacs_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cmacsc.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmacsc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmacsc.s0"]
        pub fn M2_cmacsc_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cmacsc.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmacsc_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmacsc.s1"]
        pub fn M2_cmacsc_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cmpys.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpys_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpys.s0"]
        pub fn M2_cmpys_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.cmpys.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmpys_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpys.s1"]
        pub fn M2_cmpys_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.cmpysc.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpysc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpysc.s0"]
        pub fn M2_cmpysc_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.cmpysc.s1` intrinsic; known as `__builtin_HEXAGON_M2_cmpysc_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpysc.s1"]
        pub fn M2_cmpysc_s1(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.cnacs.s0` intrinsic; known as `__builtin_HEXAGON_M2_cnacs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cnacs.s0"]
        pub fn M2_cnacs_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cnacs.s1` intrinsic; known as `__builtin_HEXAGON_M2_cnacs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cnacs.s1"]
        pub fn M2_cnacs_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cnacsc.s0` intrinsic; known as `__builtin_HEXAGON_M2_cnacsc_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cnacsc.s0"]
        pub fn M2_cnacsc_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cnacsc.s1` intrinsic; known as `__builtin_HEXAGON_M2_cnacsc_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.cnacsc.s1"]
        pub fn M2_cnacsc_s1(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vrcmpys.s1` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpys_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpys.s1"]
        pub fn M2_vrcmpys_s1(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.M2.vrcmpys.acc.s1` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpys_acc_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpys.acc.s1"]
        pub fn M2_vrcmpys_acc_s1(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vrcmpys.s1rp` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpys_s1rp` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpys.s1rp"]
        pub fn M2_vrcmpys_s1rp(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mmacls.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmacls_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacls.s0"]
        pub fn M2_mmacls_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacls.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmacls_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacls.s1"]
        pub fn M2_mmacls_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmachs.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmachs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmachs.s0"]
        pub fn M2_mmachs_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmachs.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmachs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmachs.s1"]
        pub fn M2_mmachs_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyl.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyl_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyl.s0"]
        pub fn M2_mmpyl_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyl.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyl.s1"]
        pub fn M2_mmpyl_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyh.s0"]
        pub fn M2_mmpyh_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyh.s1"]
        pub fn M2_mmpyh_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacls.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmacls_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacls.rs0"]
        pub fn M2_mmacls_rs0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacls.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmacls_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacls.rs1"]
        pub fn M2_mmacls_rs1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmachs.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmachs_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmachs.rs0"]
        pub fn M2_mmachs_rs0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmachs.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmachs_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmachs.rs1"]
        pub fn M2_mmachs_rs1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyl.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyl_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyl.rs0"]
        pub fn M2_mmpyl_rs0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyl.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyl_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyl.rs1"]
        pub fn M2_mmpyl_rs1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyh.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyh_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyh.rs0"]
        pub fn M2_mmpyh_rs0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyh.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyh_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyh.rs1"]
        pub fn M2_mmpyh_rs1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyeh.s0` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyeh_s0` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyeh.s0"]
        pub fn M4_vrmpyeh_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyeh.s1` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyeh_s1` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyeh.s1"]
        pub fn M4_vrmpyeh_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyeh.acc.s0` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyeh_acc_s0` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyeh.acc.s0"]
        pub fn M4_vrmpyeh_acc_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyeh.acc.s1` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyeh_acc_s1` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyeh.acc.s1"]
        pub fn M4_vrmpyeh_acc_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyoh.s0` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyoh_s0` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyoh.s0"]
        pub fn M4_vrmpyoh_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyoh.s1` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyoh_s1` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyoh.s1"]
        pub fn M4_vrmpyoh_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyoh.acc.s0` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyoh_acc_s0` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyoh.acc.s0"]
        pub fn M4_vrmpyoh_acc_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M4.vrmpyoh.acc.s1` intrinsic; known as `__builtin_HEXAGON_M4_vrmpyoh_acc_s1` in GCC.
        #[link_name = "llvm.hexagon.M4.vrmpyoh.acc.s1"]
        pub fn M4_vrmpyoh_acc_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.hmmpyl.rs1` intrinsic; known as `__builtin_HEXAGON_M2_hmmpyl_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.hmmpyl.rs1"]
        pub fn M2_hmmpyl_rs1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.hmmpyh.rs1` intrinsic; known as `__builtin_HEXAGON_M2_hmmpyh_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.hmmpyh.rs1"]
        pub fn M2_hmmpyh_rs1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.hmmpyl.s1` intrinsic; known as `__builtin_HEXAGON_M2_hmmpyl_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.hmmpyl.s1"]
        pub fn M2_hmmpyl_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.hmmpyh.s1` intrinsic; known as `__builtin_HEXAGON_M2_hmmpyh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.hmmpyh.s1"]
        pub fn M2_hmmpyh_s1(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.M2.mmaculs.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmaculs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmaculs.s0"]
        pub fn M2_mmaculs_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmaculs.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmaculs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmaculs.s1"]
        pub fn M2_mmaculs_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacuhs.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmacuhs_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacuhs.s0"]
        pub fn M2_mmacuhs_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacuhs.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmacuhs_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacuhs.s1"]
        pub fn M2_mmacuhs_s1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyul.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyul_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyul.s0"]
        pub fn M2_mmpyul_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyul.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyul_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyul.s1"]
        pub fn M2_mmpyul_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyuh.s0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyuh_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyuh.s0"]
        pub fn M2_mmpyuh_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyuh.s1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyuh_s1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyuh.s1"]
        pub fn M2_mmpyuh_s1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmaculs.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmaculs_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmaculs.rs0"]
        pub fn M2_mmaculs_rs0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmaculs.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmaculs_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmaculs.rs1"]
        pub fn M2_mmaculs_rs1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacuhs.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmacuhs_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacuhs.rs0"]
        pub fn M2_mmacuhs_rs0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmacuhs.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmacuhs_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmacuhs.rs1"]
        pub fn M2_mmacuhs_rs1(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyul.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyul_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyul.rs0"]
        pub fn M2_mmpyul_rs0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyul.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyul_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyul.rs1"]
        pub fn M2_mmpyul_rs1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyuh.rs0` intrinsic; known as `__builtin_HEXAGON_M2_mmpyuh_rs0` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyuh.rs0"]
        pub fn M2_mmpyuh_rs0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.mmpyuh.rs1` intrinsic; known as `__builtin_HEXAGON_M2_mmpyuh_rs1` in GCC.
        #[link_name = "llvm.hexagon.M2.mmpyuh.rs1"]
        pub fn M2_mmpyuh_rs1(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmaci.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrcmaci_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmaci.s0"]
        pub fn M2_vrcmaci_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmacr.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrcmacr_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmacr.s0"]
        pub fn M2_vrcmacr_s0(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmaci.s0c` intrinsic; known as `__builtin_HEXAGON_M2_vrcmaci_s0c` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmaci.s0c"]
        pub fn M2_vrcmaci_s0c(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmacr.s0c` intrinsic; known as `__builtin_HEXAGON_M2_vrcmacr_s0c` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmacr.s0c"]
        pub fn M2_vrcmacr_s0c(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.cmaci.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmaci_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmaci.s0"]
        pub fn M2_cmaci_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.cmacr.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmacr_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmacr.s0"]
        pub fn M2_cmacr_s0(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M2.vrcmpyi.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpyi_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpyi.s0"]
        pub fn M2_vrcmpyi_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmpyr.s0` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpyr_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpyr.s0"]
        pub fn M2_vrcmpyr_s0(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmpyi.s0c` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpyi_s0c` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpyi.s0c"]
        pub fn M2_vrcmpyi_s0c(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vrcmpyr.s0c` intrinsic; known as `__builtin_HEXAGON_M2_vrcmpyr_s0c` in GCC.
        #[link_name = "llvm.hexagon.M2.vrcmpyr.s0c"]
        pub fn M2_vrcmpyr_s0c(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.cmpyi.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpyi_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyi.s0"]
        pub fn M2_cmpyi_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M2.cmpyr.s0` intrinsic; known as `__builtin_HEXAGON_M2_cmpyr_s0` in GCC.
        #[link_name = "llvm.hexagon.M2.cmpyr.s0"]
        pub fn M2_cmpyr_s0(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M4.cmpyi.wh` intrinsic; known as `__builtin_HEXAGON_M4_cmpyi_wh` in GCC.
        #[link_name = "llvm.hexagon.M4.cmpyi.wh"]
        pub fn M4_cmpyi_wh(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.M4.cmpyr.wh` intrinsic; known as `__builtin_HEXAGON_M4_cmpyr_wh` in GCC.
        #[link_name = "llvm.hexagon.M4.cmpyr.wh"]
        pub fn M4_cmpyr_wh(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.M4.cmpyi.whc` intrinsic; known as `__builtin_HEXAGON_M4_cmpyi_whc` in GCC.
        #[link_name = "llvm.hexagon.M4.cmpyi.whc"]
        pub fn M4_cmpyi_whc(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.M4.cmpyr.whc` intrinsic; known as `__builtin_HEXAGON_M4_cmpyr_whc` in GCC.
        #[link_name = "llvm.hexagon.M4.cmpyr.whc"]
        pub fn M4_cmpyr_whc(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.M2.vcmpy.s0.sat.i` intrinsic; known as `__builtin_HEXAGON_M2_vcmpy_s0_sat_i` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmpy.s0.sat.i"]
        pub fn M2_vcmpy_s0_sat_i(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vcmpy.s0.sat.r` intrinsic; known as `__builtin_HEXAGON_M2_vcmpy_s0_sat_r` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmpy.s0.sat.r"]
        pub fn M2_vcmpy_s0_sat_r(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vcmpy.s1.sat.i` intrinsic; known as `__builtin_HEXAGON_M2_vcmpy_s1_sat_i` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmpy.s1.sat.i"]
        pub fn M2_vcmpy_s1_sat_i(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vcmpy.s1.sat.r` intrinsic; known as `__builtin_HEXAGON_M2_vcmpy_s1_sat_r` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmpy.s1.sat.r"]
        pub fn M2_vcmpy_s1_sat_r(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vcmac.s0.sat.i` intrinsic; known as `__builtin_HEXAGON_M2_vcmac_s0_sat_i` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmac.s0.sat.i"]
        pub fn M2_vcmac_s0_sat_i(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vcmac.s0.sat.r` intrinsic; known as `__builtin_HEXAGON_M2_vcmac_s0_sat_r` in GCC.
        #[link_name = "llvm.hexagon.M2.vcmac.s0.sat.r"]
        pub fn M2_vcmac_s0_sat_r(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.S2.vcrotate` intrinsic; known as `__builtin_HEXAGON_S2_vcrotate` in GCC.
        #[link_name = "llvm.hexagon.S2.vcrotate"]
        pub fn S2_vcrotate(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S4.vrcrotate.acc` intrinsic; known as `__builtin_HEXAGON_S4_vrcrotate_acc` in GCC.
        #[link_name = "llvm.hexagon.S4.vrcrotate.acc"]
        pub fn S4_vrcrotate_acc(a: i64, b: i64, c: i32, d: i32) -> i64;
        /// The `llvm.hexagon.S4.vrcrotate` intrinsic; known as `__builtin_HEXAGON_S4_vrcrotate` in GCC.
        #[link_name = "llvm.hexagon.S4.vrcrotate"]
        pub fn S4_vrcrotate(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.S2.vcnegh` intrinsic; known as `__builtin_HEXAGON_S2_vcnegh` in GCC.
        #[link_name = "llvm.hexagon.S2.vcnegh"]
        pub fn S2_vcnegh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.vrcnegh` intrinsic; known as `__builtin_HEXAGON_S2_vrcnegh` in GCC.
        #[link_name = "llvm.hexagon.S2.vrcnegh"]
        pub fn S2_vrcnegh(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.M4.pmpyw` intrinsic; known as `__builtin_HEXAGON_M4_pmpyw` in GCC.
        #[link_name = "llvm.hexagon.M4.pmpyw"]
        pub fn M4_pmpyw(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M4.vpmpyh` intrinsic; known as `__builtin_HEXAGON_M4_vpmpyh` in GCC.
        #[link_name = "llvm.hexagon.M4.vpmpyh"]
        pub fn M4_vpmpyh(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.M4.pmpyw.acc` intrinsic; known as `__builtin_HEXAGON_M4_pmpyw_acc` in GCC.
        #[link_name = "llvm.hexagon.M4.pmpyw.acc"]
        pub fn M4_pmpyw_acc(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.M4.vpmpyh.acc` intrinsic; known as `__builtin_HEXAGON_M4_vpmpyh_acc` in GCC.
        #[link_name = "llvm.hexagon.M4.vpmpyh.acc"]
        pub fn M4_vpmpyh_acc(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.A2.add` intrinsic; known as `__builtin_HEXAGON_A2_add` in GCC.
        #[link_name = "llvm.hexagon.A2.add"]
        pub fn A2_add(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.sub` intrinsic; known as `__builtin_HEXAGON_A2_sub` in GCC.
        #[link_name = "llvm.hexagon.A2.sub"]
        pub fn A2_sub(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addsat` intrinsic; known as `__builtin_HEXAGON_A2_addsat` in GCC.
        #[link_name = "llvm.hexagon.A2.addsat"]
        pub fn A2_addsat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subsat` intrinsic; known as `__builtin_HEXAGON_A2_subsat` in GCC.
        #[link_name = "llvm.hexagon.A2.subsat"]
        pub fn A2_subsat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addi` intrinsic; known as `__builtin_HEXAGON_A2_addi` in GCC.
        #[link_name = "llvm.hexagon.A2.addi"]
        pub fn A2_addi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.l16.ll` intrinsic; known as `__builtin_HEXAGON_A2_addh_l16_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.l16.ll"]
        pub fn A2_addh_l16_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.l16.hl` intrinsic; known as `__builtin_HEXAGON_A2_addh_l16_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.l16.hl"]
        pub fn A2_addh_l16_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.l16.sat.ll` intrinsic; known as `__builtin_HEXAGON_A2_addh_l16_sat_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.l16.sat.ll"]
        pub fn A2_addh_l16_sat_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.l16.sat.hl` intrinsic; known as `__builtin_HEXAGON_A2_addh_l16_sat_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.l16.sat.hl"]
        pub fn A2_addh_l16_sat_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.l16.ll` intrinsic; known as `__builtin_HEXAGON_A2_subh_l16_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.l16.ll"]
        pub fn A2_subh_l16_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.l16.hl` intrinsic; known as `__builtin_HEXAGON_A2_subh_l16_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.l16.hl"]
        pub fn A2_subh_l16_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.l16.sat.ll` intrinsic; known as `__builtin_HEXAGON_A2_subh_l16_sat_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.l16.sat.ll"]
        pub fn A2_subh_l16_sat_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.l16.sat.hl` intrinsic; known as `__builtin_HEXAGON_A2_subh_l16_sat_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.l16.sat.hl"]
        pub fn A2_subh_l16_sat_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.ll` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.ll"]
        pub fn A2_addh_h16_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.lh` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_lh` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.lh"]
        pub fn A2_addh_h16_lh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.hl` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.hl"]
        pub fn A2_addh_h16_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.hh` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_hh` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.hh"]
        pub fn A2_addh_h16_hh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.sat.ll` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_sat_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.sat.ll"]
        pub fn A2_addh_h16_sat_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.sat.lh` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_sat_lh` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.sat.lh"]
        pub fn A2_addh_h16_sat_lh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.sat.hl` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_sat_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.sat.hl"]
        pub fn A2_addh_h16_sat_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.addh.h16.sat.hh` intrinsic; known as `__builtin_HEXAGON_A2_addh_h16_sat_hh` in GCC.
        #[link_name = "llvm.hexagon.A2.addh.h16.sat.hh"]
        pub fn A2_addh_h16_sat_hh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.ll` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.ll"]
        pub fn A2_subh_h16_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.lh` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_lh` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.lh"]
        pub fn A2_subh_h16_lh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.hl` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.hl"]
        pub fn A2_subh_h16_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.hh` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_hh` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.hh"]
        pub fn A2_subh_h16_hh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.sat.ll` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_sat_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.sat.ll"]
        pub fn A2_subh_h16_sat_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.sat.lh` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_sat_lh` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.sat.lh"]
        pub fn A2_subh_h16_sat_lh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.sat.hl` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_sat_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.sat.hl"]
        pub fn A2_subh_h16_sat_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.subh.h16.sat.hh` intrinsic; known as `__builtin_HEXAGON_A2_subh_h16_sat_hh` in GCC.
        #[link_name = "llvm.hexagon.A2.subh.h16.sat.hh"]
        pub fn A2_subh_h16_sat_hh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.aslh` intrinsic; known as `__builtin_HEXAGON_A2_aslh` in GCC.
        #[link_name = "llvm.hexagon.A2.aslh"]
        pub fn A2_aslh(a: i32) -> i32;
        /// The `llvm.hexagon.A2.asrh` intrinsic; known as `__builtin_HEXAGON_A2_asrh` in GCC.
        #[link_name = "llvm.hexagon.A2.asrh"]
        pub fn A2_asrh(a: i32) -> i32;
        /// The `llvm.hexagon.A2.addp` intrinsic; known as `__builtin_HEXAGON_A2_addp` in GCC.
        #[link_name = "llvm.hexagon.A2.addp"]
        pub fn A2_addp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.addpsat` intrinsic; known as `__builtin_HEXAGON_A2_addpsat` in GCC.
        #[link_name = "llvm.hexagon.A2.addpsat"]
        pub fn A2_addpsat(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.addsp` intrinsic; known as `__builtin_HEXAGON_A2_addsp` in GCC.
        #[link_name = "llvm.hexagon.A2.addsp"]
        pub fn A2_addsp(a: i32, b: i64) -> i64;
        /// The `llvm.hexagon.A2.subp` intrinsic; known as `__builtin_HEXAGON_A2_subp` in GCC.
        #[link_name = "llvm.hexagon.A2.subp"]
        pub fn A2_subp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.neg` intrinsic; known as `__builtin_HEXAGON_A2_neg` in GCC.
        #[link_name = "llvm.hexagon.A2.neg"]
        pub fn A2_neg(a: i32) -> i32;
        /// The `llvm.hexagon.A2.negsat` intrinsic; known as `__builtin_HEXAGON_A2_negsat` in GCC.
        #[link_name = "llvm.hexagon.A2.negsat"]
        pub fn A2_negsat(a: i32) -> i32;
        /// The `llvm.hexagon.A2.abs` intrinsic; known as `__builtin_HEXAGON_A2_abs` in GCC.
        #[link_name = "llvm.hexagon.A2.abs"]
        pub fn A2_abs(a: i32) -> i32;
        /// The `llvm.hexagon.A2.abssat` intrinsic; known as `__builtin_HEXAGON_A2_abssat` in GCC.
        #[link_name = "llvm.hexagon.A2.abssat"]
        pub fn A2_abssat(a: i32) -> i32;
        /// The `llvm.hexagon.A2.vconj` intrinsic; known as `__builtin_HEXAGON_A2_vconj` in GCC.
        #[link_name = "llvm.hexagon.A2.vconj"]
        pub fn A2_vconj(a: i64) -> i64;
        /// The `llvm.hexagon.A2.negp` intrinsic; known as `__builtin_HEXAGON_A2_negp` in GCC.
        #[link_name = "llvm.hexagon.A2.negp"]
        pub fn A2_negp(a: i64) -> i64;
        /// The `llvm.hexagon.A2.absp` intrinsic; known as `__builtin_HEXAGON_A2_absp` in GCC.
        #[link_name = "llvm.hexagon.A2.absp"]
        pub fn A2_absp(a: i64) -> i64;
        /// The `llvm.hexagon.A2.max` intrinsic; known as `__builtin_HEXAGON_A2_max` in GCC.
        #[link_name = "llvm.hexagon.A2.max"]
        pub fn A2_max(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.maxu` intrinsic; known as `__builtin_HEXAGON_A2_maxu` in GCC.
        #[link_name = "llvm.hexagon.A2.maxu"]
        pub fn A2_maxu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.min` intrinsic; known as `__builtin_HEXAGON_A2_min` in GCC.
        #[link_name = "llvm.hexagon.A2.min"]
        pub fn A2_min(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.minu` intrinsic; known as `__builtin_HEXAGON_A2_minu` in GCC.
        #[link_name = "llvm.hexagon.A2.minu"]
        pub fn A2_minu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.maxp` intrinsic; known as `__builtin_HEXAGON_A2_maxp` in GCC.
        #[link_name = "llvm.hexagon.A2.maxp"]
        pub fn A2_maxp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.maxup` intrinsic; known as `__builtin_HEXAGON_A2_maxup` in GCC.
        #[link_name = "llvm.hexagon.A2.maxup"]
        pub fn A2_maxup(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.minp` intrinsic; known as `__builtin_HEXAGON_A2_minp` in GCC.
        #[link_name = "llvm.hexagon.A2.minp"]
        pub fn A2_minp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.minup` intrinsic; known as `__builtin_HEXAGON_A2_minup` in GCC.
        #[link_name = "llvm.hexagon.A2.minup"]
        pub fn A2_minup(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.tfr` intrinsic; known as `__builtin_HEXAGON_A2_tfr` in GCC.
        #[link_name = "llvm.hexagon.A2.tfr"]
        pub fn A2_tfr(a: i32) -> i32;
        /// The `llvm.hexagon.A2.tfrsi` intrinsic; known as `__builtin_HEXAGON_A2_tfrsi` in GCC.
        #[link_name = "llvm.hexagon.A2.tfrsi"]
        pub fn A2_tfrsi(a: i32) -> i32;
        /// The `llvm.hexagon.A2.tfrp` intrinsic; known as `__builtin_HEXAGON_A2_tfrp` in GCC.
        #[link_name = "llvm.hexagon.A2.tfrp"]
        pub fn A2_tfrp(a: i64) -> i64;
        /// The `llvm.hexagon.A2.tfrpi` intrinsic; known as `__builtin_HEXAGON_A2_tfrpi` in GCC.
        #[link_name = "llvm.hexagon.A2.tfrpi"]
        pub fn A2_tfrpi(a: i32) -> i64;
        /// The `llvm.hexagon.A2.zxtb` intrinsic; known as `__builtin_HEXAGON_A2_zxtb` in GCC.
        #[link_name = "llvm.hexagon.A2.zxtb"]
        pub fn A2_zxtb(a: i32) -> i32;
        /// The `llvm.hexagon.A2.sxtb` intrinsic; known as `__builtin_HEXAGON_A2_sxtb` in GCC.
        #[link_name = "llvm.hexagon.A2.sxtb"]
        pub fn A2_sxtb(a: i32) -> i32;
        /// The `llvm.hexagon.A2.zxth` intrinsic; known as `__builtin_HEXAGON_A2_zxth` in GCC.
        #[link_name = "llvm.hexagon.A2.zxth"]
        pub fn A2_zxth(a: i32) -> i32;
        /// The `llvm.hexagon.A2.sxth` intrinsic; known as `__builtin_HEXAGON_A2_sxth` in GCC.
        #[link_name = "llvm.hexagon.A2.sxth"]
        pub fn A2_sxth(a: i32) -> i32;
        /// The `llvm.hexagon.A2.combinew` intrinsic; known as `__builtin_HEXAGON_A2_combinew` in GCC.
        #[link_name = "llvm.hexagon.A2.combinew"]
        pub fn A2_combinew(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A4.combineri` intrinsic; known as `__builtin_HEXAGON_A4_combineri` in GCC.
        #[link_name = "llvm.hexagon.A4.combineri"]
        pub fn A4_combineri(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A4.combineir` intrinsic; known as `__builtin_HEXAGON_A4_combineir` in GCC.
        #[link_name = "llvm.hexagon.A4.combineir"]
        pub fn A4_combineir(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A2.combineii` intrinsic; known as `__builtin_HEXAGON_A2_combineii` in GCC.
        #[link_name = "llvm.hexagon.A2.combineii"]
        pub fn A2_combineii(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A2.combine.hh` intrinsic; known as `__builtin_HEXAGON_A2_combine_hh` in GCC.
        #[link_name = "llvm.hexagon.A2.combine.hh"]
        pub fn A2_combine_hh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.combine.hl` intrinsic; known as `__builtin_HEXAGON_A2_combine_hl` in GCC.
        #[link_name = "llvm.hexagon.A2.combine.hl"]
        pub fn A2_combine_hl(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.combine.lh` intrinsic; known as `__builtin_HEXAGON_A2_combine_lh` in GCC.
        #[link_name = "llvm.hexagon.A2.combine.lh"]
        pub fn A2_combine_lh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.combine.ll` intrinsic; known as `__builtin_HEXAGON_A2_combine_ll` in GCC.
        #[link_name = "llvm.hexagon.A2.combine.ll"]
        pub fn A2_combine_ll(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.tfril` intrinsic; known as `__builtin_HEXAGON_A2_tfril` in GCC.
        #[link_name = "llvm.hexagon.A2.tfril"]
        pub fn A2_tfril(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.tfrih` intrinsic; known as `__builtin_HEXAGON_A2_tfrih` in GCC.
        #[link_name = "llvm.hexagon.A2.tfrih"]
        pub fn A2_tfrih(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.and` intrinsic; known as `__builtin_HEXAGON_A2_and` in GCC.
        #[link_name = "llvm.hexagon.A2.and"]
        pub fn A2_and(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.or` intrinsic; known as `__builtin_HEXAGON_A2_or` in GCC.
        #[link_name = "llvm.hexagon.A2.or"]
        pub fn A2_or(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.xor` intrinsic; known as `__builtin_HEXAGON_A2_xor` in GCC.
        #[link_name = "llvm.hexagon.A2.xor"]
        pub fn A2_xor(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.not` intrinsic; known as `__builtin_HEXAGON_A2_not` in GCC.
        #[link_name = "llvm.hexagon.A2.not"]
        pub fn A2_not(a: i32) -> i32;
        /// The `llvm.hexagon.M2.xor.xacc` intrinsic; known as `__builtin_HEXAGON_M2_xor_xacc` in GCC.
        #[link_name = "llvm.hexagon.M2.xor.xacc"]
        pub fn M2_xor_xacc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.xor.xacc` intrinsic; known as `__builtin_HEXAGON_M4_xor_xacc` in GCC.
        #[link_name = "llvm.hexagon.M4.xor.xacc"]
        pub fn M4_xor_xacc(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.A4.andn` intrinsic; known as `__builtin_HEXAGON_A4_andn` in GCC.
        #[link_name = "llvm.hexagon.A4.andn"]
        pub fn A4_andn(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.orn` intrinsic; known as `__builtin_HEXAGON_A4_orn` in GCC.
        #[link_name = "llvm.hexagon.A4.orn"]
        pub fn A4_orn(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.andnp` intrinsic; known as `__builtin_HEXAGON_A4_andnp` in GCC.
        #[link_name = "llvm.hexagon.A4.andnp"]
        pub fn A4_andnp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A4.ornp` intrinsic; known as `__builtin_HEXAGON_A4_ornp` in GCC.
        #[link_name = "llvm.hexagon.A4.ornp"]
        pub fn A4_ornp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.addaddi` intrinsic; known as `__builtin_HEXAGON_S4_addaddi` in GCC.
        #[link_name = "llvm.hexagon.S4.addaddi"]
        pub fn S4_addaddi(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.subaddi` intrinsic; known as `__builtin_HEXAGON_S4_subaddi` in GCC.
        #[link_name = "llvm.hexagon.S4.subaddi"]
        pub fn S4_subaddi(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.and.and` intrinsic; known as `__builtin_HEXAGON_M4_and_and` in GCC.
        #[link_name = "llvm.hexagon.M4.and.and"]
        pub fn M4_and_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.and.andn` intrinsic; known as `__builtin_HEXAGON_M4_and_andn` in GCC.
        #[link_name = "llvm.hexagon.M4.and.andn"]
        pub fn M4_and_andn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.and.or` intrinsic; known as `__builtin_HEXAGON_M4_and_or` in GCC.
        #[link_name = "llvm.hexagon.M4.and.or"]
        pub fn M4_and_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.and.xor` intrinsic; known as `__builtin_HEXAGON_M4_and_xor` in GCC.
        #[link_name = "llvm.hexagon.M4.and.xor"]
        pub fn M4_and_xor(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.or.and` intrinsic; known as `__builtin_HEXAGON_M4_or_and` in GCC.
        #[link_name = "llvm.hexagon.M4.or.and"]
        pub fn M4_or_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.or.andn` intrinsic; known as `__builtin_HEXAGON_M4_or_andn` in GCC.
        #[link_name = "llvm.hexagon.M4.or.andn"]
        pub fn M4_or_andn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.or.or` intrinsic; known as `__builtin_HEXAGON_M4_or_or` in GCC.
        #[link_name = "llvm.hexagon.M4.or.or"]
        pub fn M4_or_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.or.xor` intrinsic; known as `__builtin_HEXAGON_M4_or_xor` in GCC.
        #[link_name = "llvm.hexagon.M4.or.xor"]
        pub fn M4_or_xor(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.or.andix` intrinsic; known as `__builtin_HEXAGON_S4_or_andix` in GCC.
        #[link_name = "llvm.hexagon.S4.or.andix"]
        pub fn S4_or_andix(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.or.andi` intrinsic; known as `__builtin_HEXAGON_S4_or_andi` in GCC.
        #[link_name = "llvm.hexagon.S4.or.andi"]
        pub fn S4_or_andi(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.or.ori` intrinsic; known as `__builtin_HEXAGON_S4_or_ori` in GCC.
        #[link_name = "llvm.hexagon.S4.or.ori"]
        pub fn S4_or_ori(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.xor.and` intrinsic; known as `__builtin_HEXAGON_M4_xor_and` in GCC.
        #[link_name = "llvm.hexagon.M4.xor.and"]
        pub fn M4_xor_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.xor.or` intrinsic; known as `__builtin_HEXAGON_M4_xor_or` in GCC.
        #[link_name = "llvm.hexagon.M4.xor.or"]
        pub fn M4_xor_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.M4.xor.andn` intrinsic; known as `__builtin_HEXAGON_M4_xor_andn` in GCC.
        #[link_name = "llvm.hexagon.M4.xor.andn"]
        pub fn M4_xor_andn(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.A2.subri` intrinsic; known as `__builtin_HEXAGON_A2_subri` in GCC.
        #[link_name = "llvm.hexagon.A2.subri"]
        pub fn A2_subri(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.andir` intrinsic; known as `__builtin_HEXAGON_A2_andir` in GCC.
        #[link_name = "llvm.hexagon.A2.andir"]
        pub fn A2_andir(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.orir` intrinsic; known as `__builtin_HEXAGON_A2_orir` in GCC.
        #[link_name = "llvm.hexagon.A2.orir"]
        pub fn A2_orir(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.andp` intrinsic; known as `__builtin_HEXAGON_A2_andp` in GCC.
        #[link_name = "llvm.hexagon.A2.andp"]
        pub fn A2_andp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.orp` intrinsic; known as `__builtin_HEXAGON_A2_orp` in GCC.
        #[link_name = "llvm.hexagon.A2.orp"]
        pub fn A2_orp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.xorp` intrinsic; known as `__builtin_HEXAGON_A2_xorp` in GCC.
        #[link_name = "llvm.hexagon.A2.xorp"]
        pub fn A2_xorp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.notp` intrinsic; known as `__builtin_HEXAGON_A2_notp` in GCC.
        #[link_name = "llvm.hexagon.A2.notp"]
        pub fn A2_notp(a: i64) -> i64;
        /// The `llvm.hexagon.A2.sxtw` intrinsic; known as `__builtin_HEXAGON_A2_sxtw` in GCC.
        #[link_name = "llvm.hexagon.A2.sxtw"]
        pub fn A2_sxtw(a: i32) -> i64;
        /// The `llvm.hexagon.A2.sat` intrinsic; known as `__builtin_HEXAGON_A2_sat` in GCC.
        #[link_name = "llvm.hexagon.A2.sat"]
        pub fn A2_sat(a: i64) -> i32;
        /// The `llvm.hexagon.A2.roundsat` intrinsic; known as `__builtin_HEXAGON_A2_roundsat` in GCC.
        #[link_name = "llvm.hexagon.A2.roundsat"]
        pub fn A2_roundsat(a: i64) -> i32;
        /// The `llvm.hexagon.A2.sath` intrinsic; known as `__builtin_HEXAGON_A2_sath` in GCC.
        #[link_name = "llvm.hexagon.A2.sath"]
        pub fn A2_sath(a: i32) -> i32;
        /// The `llvm.hexagon.A2.satuh` intrinsic; known as `__builtin_HEXAGON_A2_satuh` in GCC.
        #[link_name = "llvm.hexagon.A2.satuh"]
        pub fn A2_satuh(a: i32) -> i32;
        /// The `llvm.hexagon.A2.satub` intrinsic; known as `__builtin_HEXAGON_A2_satub` in GCC.
        #[link_name = "llvm.hexagon.A2.satub"]
        pub fn A2_satub(a: i32) -> i32;
        /// The `llvm.hexagon.A2.satb` intrinsic; known as `__builtin_HEXAGON_A2_satb` in GCC.
        #[link_name = "llvm.hexagon.A2.satb"]
        pub fn A2_satb(a: i32) -> i32;
        /// The `llvm.hexagon.A2.vaddub` intrinsic; known as `__builtin_HEXAGON_A2_vaddub` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddub"]
        pub fn A2_vaddub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vaddb.map` intrinsic; known as `__builtin_HEXAGON_A2_vaddb_map` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddb.map"]
        pub fn A2_vaddb_map(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vaddubs` intrinsic; known as `__builtin_HEXAGON_A2_vaddubs` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddubs"]
        pub fn A2_vaddubs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vaddh` intrinsic; known as `__builtin_HEXAGON_A2_vaddh` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddh"]
        pub fn A2_vaddh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vaddhs` intrinsic; known as `__builtin_HEXAGON_A2_vaddhs` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddhs"]
        pub fn A2_vaddhs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vadduhs` intrinsic; known as `__builtin_HEXAGON_A2_vadduhs` in GCC.
        #[link_name = "llvm.hexagon.A2.vadduhs"]
        pub fn A2_vadduhs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A5.vaddhubs` intrinsic; known as `__builtin_HEXAGON_A5_vaddhubs` in GCC.
        #[link_name = "llvm.hexagon.A5.vaddhubs"]
        pub fn A5_vaddhubs(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vaddw` intrinsic; known as `__builtin_HEXAGON_A2_vaddw` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddw"]
        pub fn A2_vaddw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vaddws` intrinsic; known as `__builtin_HEXAGON_A2_vaddws` in GCC.
        #[link_name = "llvm.hexagon.A2.vaddws"]
        pub fn A2_vaddws(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxaddsubw` intrinsic; known as `__builtin_HEXAGON_S4_vxaddsubw` in GCC.
        #[link_name = "llvm.hexagon.S4.vxaddsubw"]
        pub fn S4_vxaddsubw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxsubaddw` intrinsic; known as `__builtin_HEXAGON_S4_vxsubaddw` in GCC.
        #[link_name = "llvm.hexagon.S4.vxsubaddw"]
        pub fn S4_vxsubaddw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxaddsubh` intrinsic; known as `__builtin_HEXAGON_S4_vxaddsubh` in GCC.
        #[link_name = "llvm.hexagon.S4.vxaddsubh"]
        pub fn S4_vxaddsubh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxsubaddh` intrinsic; known as `__builtin_HEXAGON_S4_vxsubaddh` in GCC.
        #[link_name = "llvm.hexagon.S4.vxsubaddh"]
        pub fn S4_vxsubaddh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxaddsubhr` intrinsic; known as `__builtin_HEXAGON_S4_vxaddsubhr` in GCC.
        #[link_name = "llvm.hexagon.S4.vxaddsubhr"]
        pub fn S4_vxaddsubhr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S4.vxsubaddhr` intrinsic; known as `__builtin_HEXAGON_S4_vxsubaddhr` in GCC.
        #[link_name = "llvm.hexagon.S4.vxsubaddhr"]
        pub fn S4_vxsubaddhr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.svavgh` intrinsic; known as `__builtin_HEXAGON_A2_svavgh` in GCC.
        #[link_name = "llvm.hexagon.A2.svavgh"]
        pub fn A2_svavgh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svavghs` intrinsic; known as `__builtin_HEXAGON_A2_svavghs` in GCC.
        #[link_name = "llvm.hexagon.A2.svavghs"]
        pub fn A2_svavghs(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svnavgh` intrinsic; known as `__builtin_HEXAGON_A2_svnavgh` in GCC.
        #[link_name = "llvm.hexagon.A2.svnavgh"]
        pub fn A2_svnavgh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svaddh` intrinsic; known as `__builtin_HEXAGON_A2_svaddh` in GCC.
        #[link_name = "llvm.hexagon.A2.svaddh"]
        pub fn A2_svaddh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svaddhs` intrinsic; known as `__builtin_HEXAGON_A2_svaddhs` in GCC.
        #[link_name = "llvm.hexagon.A2.svaddhs"]
        pub fn A2_svaddhs(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svadduhs` intrinsic; known as `__builtin_HEXAGON_A2_svadduhs` in GCC.
        #[link_name = "llvm.hexagon.A2.svadduhs"]
        pub fn A2_svadduhs(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svsubh` intrinsic; known as `__builtin_HEXAGON_A2_svsubh` in GCC.
        #[link_name = "llvm.hexagon.A2.svsubh"]
        pub fn A2_svsubh(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svsubhs` intrinsic; known as `__builtin_HEXAGON_A2_svsubhs` in GCC.
        #[link_name = "llvm.hexagon.A2.svsubhs"]
        pub fn A2_svsubhs(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.svsubuhs` intrinsic; known as `__builtin_HEXAGON_A2_svsubuhs` in GCC.
        #[link_name = "llvm.hexagon.A2.svsubuhs"]
        pub fn A2_svsubuhs(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A2.vraddub` intrinsic; known as `__builtin_HEXAGON_A2_vraddub` in GCC.
        #[link_name = "llvm.hexagon.A2.vraddub"]
        pub fn A2_vraddub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vraddub.acc` intrinsic; known as `__builtin_HEXAGON_A2_vraddub_acc` in GCC.
        #[link_name = "llvm.hexagon.A2.vraddub.acc"]
        pub fn A2_vraddub_acc(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.M2.vraddh` intrinsic; known as `__builtin_HEXAGON_M2_vraddh` in GCC.
        #[link_name = "llvm.hexagon.M2.vraddh"]
        pub fn M2_vraddh(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.M2.vradduh` intrinsic; known as `__builtin_HEXAGON_M2_vradduh` in GCC.
        #[link_name = "llvm.hexagon.M2.vradduh"]
        pub fn M2_vradduh(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.A2.vsubub` intrinsic; known as `__builtin_HEXAGON_A2_vsubub` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubub"]
        pub fn A2_vsubub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubb.map` intrinsic; known as `__builtin_HEXAGON_A2_vsubb_map` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubb.map"]
        pub fn A2_vsubb_map(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsububs` intrinsic; known as `__builtin_HEXAGON_A2_vsububs` in GCC.
        #[link_name = "llvm.hexagon.A2.vsububs"]
        pub fn A2_vsububs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubh` intrinsic; known as `__builtin_HEXAGON_A2_vsubh` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubh"]
        pub fn A2_vsubh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubhs` intrinsic; known as `__builtin_HEXAGON_A2_vsubhs` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubhs"]
        pub fn A2_vsubhs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubuhs` intrinsic; known as `__builtin_HEXAGON_A2_vsubuhs` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubuhs"]
        pub fn A2_vsubuhs(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubw` intrinsic; known as `__builtin_HEXAGON_A2_vsubw` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubw"]
        pub fn A2_vsubw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vsubws` intrinsic; known as `__builtin_HEXAGON_A2_vsubws` in GCC.
        #[link_name = "llvm.hexagon.A2.vsubws"]
        pub fn A2_vsubws(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vabsh` intrinsic; known as `__builtin_HEXAGON_A2_vabsh` in GCC.
        #[link_name = "llvm.hexagon.A2.vabsh"]
        pub fn A2_vabsh(a: i64) -> i64;
        /// The `llvm.hexagon.A2.vabshsat` intrinsic; known as `__builtin_HEXAGON_A2_vabshsat` in GCC.
        #[link_name = "llvm.hexagon.A2.vabshsat"]
        pub fn A2_vabshsat(a: i64) -> i64;
        /// The `llvm.hexagon.A2.vabsw` intrinsic; known as `__builtin_HEXAGON_A2_vabsw` in GCC.
        #[link_name = "llvm.hexagon.A2.vabsw"]
        pub fn A2_vabsw(a: i64) -> i64;
        /// The `llvm.hexagon.A2.vabswsat` intrinsic; known as `__builtin_HEXAGON_A2_vabswsat` in GCC.
        #[link_name = "llvm.hexagon.A2.vabswsat"]
        pub fn A2_vabswsat(a: i64) -> i64;
        /// The `llvm.hexagon.M2.vabsdiffw` intrinsic; known as `__builtin_HEXAGON_M2_vabsdiffw` in GCC.
        #[link_name = "llvm.hexagon.M2.vabsdiffw"]
        pub fn M2_vabsdiffw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M2.vabsdiffh` intrinsic; known as `__builtin_HEXAGON_M2_vabsdiffh` in GCC.
        #[link_name = "llvm.hexagon.M2.vabsdiffh"]
        pub fn M2_vabsdiffh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vrsadub` intrinsic; known as `__builtin_HEXAGON_A2_vrsadub` in GCC.
        #[link_name = "llvm.hexagon.A2.vrsadub"]
        pub fn A2_vrsadub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vrsadub.acc` intrinsic; known as `__builtin_HEXAGON_A2_vrsadub_acc` in GCC.
        #[link_name = "llvm.hexagon.A2.vrsadub.acc"]
        pub fn A2_vrsadub_acc(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgub` intrinsic; known as `__builtin_HEXAGON_A2_vavgub` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgub"]
        pub fn A2_vavgub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavguh` intrinsic; known as `__builtin_HEXAGON_A2_vavguh` in GCC.
        #[link_name = "llvm.hexagon.A2.vavguh"]
        pub fn A2_vavguh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgh` intrinsic; known as `__builtin_HEXAGON_A2_vavgh` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgh"]
        pub fn A2_vavgh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavgh` intrinsic; known as `__builtin_HEXAGON_A2_vnavgh` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavgh"]
        pub fn A2_vnavgh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgw` intrinsic; known as `__builtin_HEXAGON_A2_vavgw` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgw"]
        pub fn A2_vavgw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavgw` intrinsic; known as `__builtin_HEXAGON_A2_vnavgw` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavgw"]
        pub fn A2_vnavgw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgwr` intrinsic; known as `__builtin_HEXAGON_A2_vavgwr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgwr"]
        pub fn A2_vavgwr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavgwr` intrinsic; known as `__builtin_HEXAGON_A2_vnavgwr` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavgwr"]
        pub fn A2_vnavgwr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgwcr` intrinsic; known as `__builtin_HEXAGON_A2_vavgwcr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgwcr"]
        pub fn A2_vavgwcr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavgwcr` intrinsic; known as `__builtin_HEXAGON_A2_vnavgwcr` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavgwcr"]
        pub fn A2_vnavgwcr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavghcr` intrinsic; known as `__builtin_HEXAGON_A2_vavghcr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavghcr"]
        pub fn A2_vavghcr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavghcr` intrinsic; known as `__builtin_HEXAGON_A2_vnavghcr` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavghcr"]
        pub fn A2_vnavghcr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavguw` intrinsic; known as `__builtin_HEXAGON_A2_vavguw` in GCC.
        #[link_name = "llvm.hexagon.A2.vavguw"]
        pub fn A2_vavguw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavguwr` intrinsic; known as `__builtin_HEXAGON_A2_vavguwr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavguwr"]
        pub fn A2_vavguwr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavgubr` intrinsic; known as `__builtin_HEXAGON_A2_vavgubr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavgubr"]
        pub fn A2_vavgubr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavguhr` intrinsic; known as `__builtin_HEXAGON_A2_vavguhr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavguhr"]
        pub fn A2_vavguhr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vavghr` intrinsic; known as `__builtin_HEXAGON_A2_vavghr` in GCC.
        #[link_name = "llvm.hexagon.A2.vavghr"]
        pub fn A2_vavghr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vnavghr` intrinsic; known as `__builtin_HEXAGON_A2_vnavghr` in GCC.
        #[link_name = "llvm.hexagon.A2.vnavghr"]
        pub fn A2_vnavghr(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A4.round.ri` intrinsic; known as `__builtin_HEXAGON_A4_round_ri` in GCC.
        #[link_name = "llvm.hexagon.A4.round.ri"]
        pub fn A4_round_ri(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.round.rr` intrinsic; known as `__builtin_HEXAGON_A4_round_rr` in GCC.
        #[link_name = "llvm.hexagon.A4.round.rr"]
        pub fn A4_round_rr(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.round.ri.sat` intrinsic; known as `__builtin_HEXAGON_A4_round_ri_sat` in GCC.
        #[link_name = "llvm.hexagon.A4.round.ri.sat"]
        pub fn A4_round_ri_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.round.rr.sat` intrinsic; known as `__builtin_HEXAGON_A4_round_rr_sat` in GCC.
        #[link_name = "llvm.hexagon.A4.round.rr.sat"]
        pub fn A4_round_rr_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cround.ri` intrinsic; known as `__builtin_HEXAGON_A4_cround_ri` in GCC.
        #[link_name = "llvm.hexagon.A4.cround.ri"]
        pub fn A4_cround_ri(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.cround.rr` intrinsic; known as `__builtin_HEXAGON_A4_cround_rr` in GCC.
        #[link_name = "llvm.hexagon.A4.cround.rr"]
        pub fn A4_cround_rr(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.A4.vrminh` intrinsic; known as `__builtin_HEXAGON_A4_vrminh` in GCC.
        #[link_name = "llvm.hexagon.A4.vrminh"]
        pub fn A4_vrminh(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrmaxh` intrinsic; known as `__builtin_HEXAGON_A4_vrmaxh` in GCC.
        #[link_name = "llvm.hexagon.A4.vrmaxh"]
        pub fn A4_vrmaxh(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrminuh` intrinsic; known as `__builtin_HEXAGON_A4_vrminuh` in GCC.
        #[link_name = "llvm.hexagon.A4.vrminuh"]
        pub fn A4_vrminuh(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrmaxuh` intrinsic; known as `__builtin_HEXAGON_A4_vrmaxuh` in GCC.
        #[link_name = "llvm.hexagon.A4.vrmaxuh"]
        pub fn A4_vrmaxuh(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrminw` intrinsic; known as `__builtin_HEXAGON_A4_vrminw` in GCC.
        #[link_name = "llvm.hexagon.A4.vrminw"]
        pub fn A4_vrminw(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrmaxw` intrinsic; known as `__builtin_HEXAGON_A4_vrmaxw` in GCC.
        #[link_name = "llvm.hexagon.A4.vrmaxw"]
        pub fn A4_vrmaxw(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrminuw` intrinsic; known as `__builtin_HEXAGON_A4_vrminuw` in GCC.
        #[link_name = "llvm.hexagon.A4.vrminuw"]
        pub fn A4_vrminuw(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A4.vrmaxuw` intrinsic; known as `__builtin_HEXAGON_A4_vrmaxuw` in GCC.
        #[link_name = "llvm.hexagon.A4.vrmaxuw"]
        pub fn A4_vrmaxuw(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.A2.vminb` intrinsic; known as `__builtin_HEXAGON_A2_vminb` in GCC.
        #[link_name = "llvm.hexagon.A2.vminb"]
        pub fn A2_vminb(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxb` intrinsic; known as `__builtin_HEXAGON_A2_vmaxb` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxb"]
        pub fn A2_vmaxb(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vminub` intrinsic; known as `__builtin_HEXAGON_A2_vminub` in GCC.
        #[link_name = "llvm.hexagon.A2.vminub"]
        pub fn A2_vminub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxub` intrinsic; known as `__builtin_HEXAGON_A2_vmaxub` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxub"]
        pub fn A2_vmaxub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vminh` intrinsic; known as `__builtin_HEXAGON_A2_vminh` in GCC.
        #[link_name = "llvm.hexagon.A2.vminh"]
        pub fn A2_vminh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxh` intrinsic; known as `__builtin_HEXAGON_A2_vmaxh` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxh"]
        pub fn A2_vmaxh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vminuh` intrinsic; known as `__builtin_HEXAGON_A2_vminuh` in GCC.
        #[link_name = "llvm.hexagon.A2.vminuh"]
        pub fn A2_vminuh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxuh` intrinsic; known as `__builtin_HEXAGON_A2_vmaxuh` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxuh"]
        pub fn A2_vmaxuh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vminw` intrinsic; known as `__builtin_HEXAGON_A2_vminw` in GCC.
        #[link_name = "llvm.hexagon.A2.vminw"]
        pub fn A2_vminw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxw` intrinsic; known as `__builtin_HEXAGON_A2_vmaxw` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxw"]
        pub fn A2_vmaxw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vminuw` intrinsic; known as `__builtin_HEXAGON_A2_vminuw` in GCC.
        #[link_name = "llvm.hexagon.A2.vminuw"]
        pub fn A2_vminuw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A2.vmaxuw` intrinsic; known as `__builtin_HEXAGON_A2_vmaxuw` in GCC.
        #[link_name = "llvm.hexagon.A2.vmaxuw"]
        pub fn A2_vmaxuw(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.A4.modwrapu` intrinsic; known as `__builtin_HEXAGON_A4_modwrapu` in GCC.
        #[link_name = "llvm.hexagon.A4.modwrapu"]
        pub fn A4_modwrapu(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.F2.sfadd` intrinsic; known as `__builtin_HEXAGON_F2_sfadd` in GCC.
        #[link_name = "llvm.hexagon.F2.sfadd"]
        pub fn F2_sfadd(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sfsub` intrinsic; known as `__builtin_HEXAGON_F2_sfsub` in GCC.
        #[link_name = "llvm.hexagon.F2.sfsub"]
        pub fn F2_sfsub(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sfmpy` intrinsic; known as `__builtin_HEXAGON_F2_sfmpy` in GCC.
        #[link_name = "llvm.hexagon.F2.sfmpy"]
        pub fn F2_sfmpy(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sffma` intrinsic; known as `__builtin_HEXAGON_F2_sffma` in GCC.
        #[link_name = "llvm.hexagon.F2.sffma"]
        pub fn F2_sffma(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.hexagon.F2.sffma.sc` intrinsic; known as `__builtin_HEXAGON_F2_sffma_sc` in GCC.
        #[link_name = "llvm.hexagon.F2.sffma.sc"]
        pub fn F2_sffma_sc(a: f32, b: f32, c: f32, d: i32) -> f32;
        /// The `llvm.hexagon.F2.sffms` intrinsic; known as `__builtin_HEXAGON_F2_sffms` in GCC.
        #[link_name = "llvm.hexagon.F2.sffms"]
        pub fn F2_sffms(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.hexagon.F2.sffma.lib` intrinsic; known as `__builtin_HEXAGON_F2_sffma_lib` in GCC.
        #[link_name = "llvm.hexagon.F2.sffma.lib"]
        pub fn F2_sffma_lib(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.hexagon.F2.sffms.lib` intrinsic; known as `__builtin_HEXAGON_F2_sffms_lib` in GCC.
        #[link_name = "llvm.hexagon.F2.sffms.lib"]
        pub fn F2_sffms_lib(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.hexagon.F2.sfcmpeq` intrinsic; known as `__builtin_HEXAGON_F2_sfcmpeq` in GCC.
        #[link_name = "llvm.hexagon.F2.sfcmpeq"]
        pub fn F2_sfcmpeq(a: f32, b: f32) -> i32;
        /// The `llvm.hexagon.F2.sfcmpgt` intrinsic; known as `__builtin_HEXAGON_F2_sfcmpgt` in GCC.
        #[link_name = "llvm.hexagon.F2.sfcmpgt"]
        pub fn F2_sfcmpgt(a: f32, b: f32) -> i32;
        /// The `llvm.hexagon.F2.sfcmpge` intrinsic; known as `__builtin_HEXAGON_F2_sfcmpge` in GCC.
        #[link_name = "llvm.hexagon.F2.sfcmpge"]
        pub fn F2_sfcmpge(a: f32, b: f32) -> i32;
        /// The `llvm.hexagon.F2.sfcmpuo` intrinsic; known as `__builtin_HEXAGON_F2_sfcmpuo` in GCC.
        #[link_name = "llvm.hexagon.F2.sfcmpuo"]
        pub fn F2_sfcmpuo(a: f32, b: f32) -> i32;
        /// The `llvm.hexagon.F2.sfmax` intrinsic; known as `__builtin_HEXAGON_F2_sfmax` in GCC.
        #[link_name = "llvm.hexagon.F2.sfmax"]
        pub fn F2_sfmax(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sfmin` intrinsic; known as `__builtin_HEXAGON_F2_sfmin` in GCC.
        #[link_name = "llvm.hexagon.F2.sfmin"]
        pub fn F2_sfmin(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sfclass` intrinsic; known as `__builtin_HEXAGON_F2_sfclass` in GCC.
        #[link_name = "llvm.hexagon.F2.sfclass"]
        pub fn F2_sfclass(a: f32, b: i32) -> i32;
        /// The `llvm.hexagon.F2.sfimm.p` intrinsic; known as `__builtin_HEXAGON_F2_sfimm_p` in GCC.
        #[link_name = "llvm.hexagon.F2.sfimm.p"]
        pub fn F2_sfimm_p(a: i32) -> f32;
        /// The `llvm.hexagon.F2.sfimm.n` intrinsic; known as `__builtin_HEXAGON_F2_sfimm_n` in GCC.
        #[link_name = "llvm.hexagon.F2.sfimm.n"]
        pub fn F2_sfimm_n(a: i32) -> f32;
        /// The `llvm.hexagon.F2.sffixupn` intrinsic; known as `__builtin_HEXAGON_F2_sffixupn` in GCC.
        #[link_name = "llvm.hexagon.F2.sffixupn"]
        pub fn F2_sffixupn(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sffixupd` intrinsic; known as `__builtin_HEXAGON_F2_sffixupd` in GCC.
        #[link_name = "llvm.hexagon.F2.sffixupd"]
        pub fn F2_sffixupd(a: f32, b: f32) -> f32;
        /// The `llvm.hexagon.F2.sffixupr` intrinsic; known as `__builtin_HEXAGON_F2_sffixupr` in GCC.
        #[link_name = "llvm.hexagon.F2.sffixupr"]
        pub fn F2_sffixupr(a: f32) -> f32;
        /// The `llvm.hexagon.F2.dfcmpeq` intrinsic; known as `__builtin_HEXAGON_F2_dfcmpeq` in GCC.
        #[link_name = "llvm.hexagon.F2.dfcmpeq"]
        pub fn F2_dfcmpeq(a: f64, b: f64) -> i32;
        /// The `llvm.hexagon.F2.dfcmpgt` intrinsic; known as `__builtin_HEXAGON_F2_dfcmpgt` in GCC.
        #[link_name = "llvm.hexagon.F2.dfcmpgt"]
        pub fn F2_dfcmpgt(a: f64, b: f64) -> i32;
        /// The `llvm.hexagon.F2.dfcmpge` intrinsic; known as `__builtin_HEXAGON_F2_dfcmpge` in GCC.
        #[link_name = "llvm.hexagon.F2.dfcmpge"]
        pub fn F2_dfcmpge(a: f64, b: f64) -> i32;
        /// The `llvm.hexagon.F2.dfcmpuo` intrinsic; known as `__builtin_HEXAGON_F2_dfcmpuo` in GCC.
        #[link_name = "llvm.hexagon.F2.dfcmpuo"]
        pub fn F2_dfcmpuo(a: f64, b: f64) -> i32;
        /// The `llvm.hexagon.F2.dfclass` intrinsic; known as `__builtin_HEXAGON_F2_dfclass` in GCC.
        #[link_name = "llvm.hexagon.F2.dfclass"]
        pub fn F2_dfclass(a: f64, b: i32) -> i32;
        /// The `llvm.hexagon.F2.dfimm.p` intrinsic; known as `__builtin_HEXAGON_F2_dfimm_p` in GCC.
        #[link_name = "llvm.hexagon.F2.dfimm.p"]
        pub fn F2_dfimm_p(a: i32) -> f64;
        /// The `llvm.hexagon.F2.dfimm.n` intrinsic; known as `__builtin_HEXAGON_F2_dfimm_n` in GCC.
        #[link_name = "llvm.hexagon.F2.dfimm.n"]
        pub fn F2_dfimm_n(a: i32) -> f64;
        /// The `llvm.hexagon.F2.conv.sf2df` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2df` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2df"]
        pub fn F2_conv_sf2df(a: f32) -> f64;
        /// The `llvm.hexagon.F2.conv.df2sf` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2sf` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2sf"]
        pub fn F2_conv_df2sf(a: f64) -> f32;
        /// The `llvm.hexagon.F2.conv.uw2sf` intrinsic; known as `__builtin_HEXAGON_F2_conv_uw2sf` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.uw2sf"]
        pub fn F2_conv_uw2sf(a: i32) -> f32;
        /// The `llvm.hexagon.F2.conv.uw2df` intrinsic; known as `__builtin_HEXAGON_F2_conv_uw2df` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.uw2df"]
        pub fn F2_conv_uw2df(a: i32) -> f64;
        /// The `llvm.hexagon.F2.conv.w2sf` intrinsic; known as `__builtin_HEXAGON_F2_conv_w2sf` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.w2sf"]
        pub fn F2_conv_w2sf(a: i32) -> f32;
        /// The `llvm.hexagon.F2.conv.w2df` intrinsic; known as `__builtin_HEXAGON_F2_conv_w2df` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.w2df"]
        pub fn F2_conv_w2df(a: i32) -> f64;
        /// The `llvm.hexagon.F2.conv.ud2sf` intrinsic; known as `__builtin_HEXAGON_F2_conv_ud2sf` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.ud2sf"]
        pub fn F2_conv_ud2sf(a: i64) -> f32;
        /// The `llvm.hexagon.F2.conv.ud2df` intrinsic; known as `__builtin_HEXAGON_F2_conv_ud2df` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.ud2df"]
        pub fn F2_conv_ud2df(a: i64) -> f64;
        /// The `llvm.hexagon.F2.conv.d2sf` intrinsic; known as `__builtin_HEXAGON_F2_conv_d2sf` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.d2sf"]
        pub fn F2_conv_d2sf(a: i64) -> f32;
        /// The `llvm.hexagon.F2.conv.d2df` intrinsic; known as `__builtin_HEXAGON_F2_conv_d2df` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.d2df"]
        pub fn F2_conv_d2df(a: i64) -> f64;
        /// The `llvm.hexagon.F2.conv.sf2uw` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2uw` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2uw"]
        pub fn F2_conv_sf2uw(a: f32) -> i32;
        /// The `llvm.hexagon.F2.conv.sf2w` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2w` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2w"]
        pub fn F2_conv_sf2w(a: f32) -> i32;
        /// The `llvm.hexagon.F2.conv.sf2ud` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2ud` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2ud"]
        pub fn F2_conv_sf2ud(a: f32) -> i64;
        /// The `llvm.hexagon.F2.conv.sf2d` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2d` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2d"]
        pub fn F2_conv_sf2d(a: f32) -> i64;
        /// The `llvm.hexagon.F2.conv.df2uw` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2uw` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2uw"]
        pub fn F2_conv_df2uw(a: f64) -> i32;
        /// The `llvm.hexagon.F2.conv.df2w` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2w` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2w"]
        pub fn F2_conv_df2w(a: f64) -> i32;
        /// The `llvm.hexagon.F2.conv.df2ud` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2ud` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2ud"]
        pub fn F2_conv_df2ud(a: f64) -> i64;
        /// The `llvm.hexagon.F2.conv.df2d` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2d` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2d"]
        pub fn F2_conv_df2d(a: f64) -> i64;
        /// The `llvm.hexagon.F2.conv.sf2uw.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2uw_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2uw.chop"]
        pub fn F2_conv_sf2uw_chop(a: f32) -> i32;
        /// The `llvm.hexagon.F2.conv.sf2w.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2w_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2w.chop"]
        pub fn F2_conv_sf2w_chop(a: f32) -> i32;
        /// The `llvm.hexagon.F2.conv.sf2ud.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2ud_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2ud.chop"]
        pub fn F2_conv_sf2ud_chop(a: f32) -> i64;
        /// The `llvm.hexagon.F2.conv.sf2d.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_sf2d_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.sf2d.chop"]
        pub fn F2_conv_sf2d_chop(a: f32) -> i64;
        /// The `llvm.hexagon.F2.conv.df2uw.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2uw_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2uw.chop"]
        pub fn F2_conv_df2uw_chop(a: f64) -> i32;
        /// The `llvm.hexagon.F2.conv.df2w.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2w_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2w.chop"]
        pub fn F2_conv_df2w_chop(a: f64) -> i32;
        /// The `llvm.hexagon.F2.conv.df2ud.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2ud_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2ud.chop"]
        pub fn F2_conv_df2ud_chop(a: f64) -> i64;
        /// The `llvm.hexagon.F2.conv.df2d.chop` intrinsic; known as `__builtin_HEXAGON_F2_conv_df2d_chop` in GCC.
        #[link_name = "llvm.hexagon.F2.conv.df2d.chop"]
        pub fn F2_conv_df2d_chop(a: f64) -> i64;
        /// The `llvm.hexagon.S2.asr.r.r` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r"]
        pub fn S2_asr_r_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r"]
        pub fn S2_asl_r_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.r.r` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_r` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.r"]
        pub fn S2_lsr_r_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.lsl.r.r` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_r` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.r"]
        pub fn S2_lsl_r_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.p` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p"]
        pub fn S2_asr_r_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p"]
        pub fn S2_asl_r_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p"]
        pub fn S2_lsr_r_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p"]
        pub fn S2_lsl_r_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r.acc"]
        pub fn S2_asr_r_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r.acc"]
        pub fn S2_asl_r_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.r.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.r.acc"]
        pub fn S2_lsr_r_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsl.r.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.r.acc"]
        pub fn S2_lsl_r_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p.acc"]
        pub fn S2_asr_r_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p.acc"]
        pub fn S2_asl_r_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p.acc"]
        pub fn S2_lsr_r_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p.acc"]
        pub fn S2_lsl_r_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r.nac"]
        pub fn S2_asr_r_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r.nac"]
        pub fn S2_asl_r_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.r.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.r.nac"]
        pub fn S2_lsr_r_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsl.r.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.r.nac"]
        pub fn S2_lsl_r_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p.nac"]
        pub fn S2_asr_r_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p.nac"]
        pub fn S2_asl_r_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p.nac"]
        pub fn S2_lsr_r_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p.nac"]
        pub fn S2_lsl_r_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.r.and` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r.and"]
        pub fn S2_asr_r_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r.and` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r.and"]
        pub fn S2_asl_r_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.r.r.and` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.r.and"]
        pub fn S2_lsr_r_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsl.r.r.and` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.r.and"]
        pub fn S2_lsl_r_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.r.or` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r.or"]
        pub fn S2_asr_r_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r.or` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r.or"]
        pub fn S2_asl_r_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.r.r.or` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.r.or"]
        pub fn S2_lsr_r_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsl.r.r.or` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.r.or"]
        pub fn S2_lsl_r_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.p.and` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p.and"]
        pub fn S2_asr_r_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p.and` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p.and"]
        pub fn S2_asl_r_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p.and` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p.and"]
        pub fn S2_lsr_r_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p.and` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p.and"]
        pub fn S2_lsl_r_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.p.or` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p.or"]
        pub fn S2_asr_r_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p.or` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p.or"]
        pub fn S2_asl_r_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p.or` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p.or"]
        pub fn S2_lsr_r_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p.or` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p.or"]
        pub fn S2_lsl_r_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.p.xor` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_p_xor` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.p.xor"]
        pub fn S2_asr_r_p_xor(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.p.xor` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_p_xor` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.p.xor"]
        pub fn S2_asl_r_p_xor(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.p.xor` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_p_xor` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.p.xor"]
        pub fn S2_lsr_r_p_xor(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.p.xor` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_p_xor` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.p.xor"]
        pub fn S2_lsl_r_p_xor(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.r.sat` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_r_sat` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.r.sat"]
        pub fn S2_asr_r_r_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.r.r.sat` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_r_sat` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.r.sat"]
        pub fn S2_asl_r_r_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.r` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r"]
        pub fn S2_asr_i_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.r` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r"]
        pub fn S2_lsr_i_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r"]
        pub fn S2_asl_i_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.p` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p"]
        pub fn S2_asr_i_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.p` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p"]
        pub fn S2_lsr_i_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p"]
        pub fn S2_asl_i_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.acc"]
        pub fn S2_asr_i_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r.acc"]
        pub fn S2_lsr_i_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r.acc` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.acc"]
        pub fn S2_asl_i_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.acc"]
        pub fn S2_asr_i_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p.acc"]
        pub fn S2_lsr_i_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p.acc` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p.acc"]
        pub fn S2_asl_i_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.nac"]
        pub fn S2_asr_i_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r.nac"]
        pub fn S2_lsr_i_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r.nac` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.nac"]
        pub fn S2_asl_i_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.nac"]
        pub fn S2_asr_i_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p.nac"]
        pub fn S2_lsr_i_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p.nac` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p.nac"]
        pub fn S2_asl_i_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.r.xacc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r_xacc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r.xacc"]
        pub fn S2_lsr_i_r_xacc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r.xacc` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_xacc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.xacc"]
        pub fn S2_asl_i_r_xacc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.p.xacc` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p_xacc` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p.xacc"]
        pub fn S2_lsr_i_p_xacc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p.xacc` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p_xacc` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p.xacc"]
        pub fn S2_asl_i_p_xacc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.r.and` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.and"]
        pub fn S2_asr_i_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.r.and` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r.and"]
        pub fn S2_lsr_i_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r.and` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.and"]
        pub fn S2_asl_i_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.r.or` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.or"]
        pub fn S2_asr_i_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.r.or` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.r.or"]
        pub fn S2_lsr_i_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asl.i.r.or` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.or"]
        pub fn S2_asl_i_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.p.and` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.and"]
        pub fn S2_asr_i_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.p.and` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p.and"]
        pub fn S2_lsr_i_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p.and` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p_and` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p.and"]
        pub fn S2_asl_i_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.p.or` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.or"]
        pub fn S2_asr_i_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.p.or` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.p.or"]
        pub fn S2_lsr_i_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.p.or` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_p_or` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.p.or"]
        pub fn S2_asl_i_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.r.sat` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_r_sat` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.r.sat"]
        pub fn S2_asl_i_r_sat(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.r.rnd` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_rnd` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.rnd"]
        pub fn S2_asr_i_r_rnd(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.r.rnd.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_r_rnd_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.r.rnd.goodsyntax"]
        pub fn S2_asr_i_r_rnd_goodsyntax(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.p.rnd` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_rnd` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.rnd"]
        pub fn S2_asr_i_p_rnd(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.p.rnd.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_p_rnd_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.p.rnd.goodsyntax"]
        pub fn S2_asr_i_p_rnd_goodsyntax(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S4.lsli` intrinsic; known as `__builtin_HEXAGON_S4_lsli` in GCC.
        #[link_name = "llvm.hexagon.S4.lsli"]
        pub fn S4_lsli(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.addasl.rrri` intrinsic; known as `__builtin_HEXAGON_S2_addasl_rrri` in GCC.
        #[link_name = "llvm.hexagon.S2.addasl.rrri"]
        pub fn S2_addasl_rrri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.andi.asl.ri` intrinsic; known as `__builtin_HEXAGON_S4_andi_asl_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.andi.asl.ri"]
        pub fn S4_andi_asl_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.ori.asl.ri` intrinsic; known as `__builtin_HEXAGON_S4_ori_asl_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.ori.asl.ri"]
        pub fn S4_ori_asl_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.addi.asl.ri` intrinsic; known as `__builtin_HEXAGON_S4_addi_asl_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.addi.asl.ri"]
        pub fn S4_addi_asl_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.subi.asl.ri` intrinsic; known as `__builtin_HEXAGON_S4_subi_asl_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.subi.asl.ri"]
        pub fn S4_subi_asl_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.andi.lsr.ri` intrinsic; known as `__builtin_HEXAGON_S4_andi_lsr_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.andi.lsr.ri"]
        pub fn S4_andi_lsr_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.ori.lsr.ri` intrinsic; known as `__builtin_HEXAGON_S4_ori_lsr_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.ori.lsr.ri"]
        pub fn S4_ori_lsr_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.addi.lsr.ri` intrinsic; known as `__builtin_HEXAGON_S4_addi_lsr_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.addi.lsr.ri"]
        pub fn S4_addi_lsr_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S4.subi.lsr.ri` intrinsic; known as `__builtin_HEXAGON_S4_subi_lsr_ri` in GCC.
        #[link_name = "llvm.hexagon.S4.subi.lsr.ri"]
        pub fn S4_subi_lsr_ri(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.valignib` intrinsic; known as `__builtin_HEXAGON_S2_valignib` in GCC.
        #[link_name = "llvm.hexagon.S2.valignib"]
        pub fn S2_valignib(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.valignrb` intrinsic; known as `__builtin_HEXAGON_S2_valignrb` in GCC.
        #[link_name = "llvm.hexagon.S2.valignrb"]
        pub fn S2_valignrb(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.vspliceib` intrinsic; known as `__builtin_HEXAGON_S2_vspliceib` in GCC.
        #[link_name = "llvm.hexagon.S2.vspliceib"]
        pub fn S2_vspliceib(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.vsplicerb` intrinsic; known as `__builtin_HEXAGON_S2_vsplicerb` in GCC.
        #[link_name = "llvm.hexagon.S2.vsplicerb"]
        pub fn S2_vsplicerb(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.vsplatrh` intrinsic; known as `__builtin_HEXAGON_S2_vsplatrh` in GCC.
        #[link_name = "llvm.hexagon.S2.vsplatrh"]
        pub fn S2_vsplatrh(a: i32) -> i64;
        /// The `llvm.hexagon.S2.vsplatrb` intrinsic; known as `__builtin_HEXAGON_S2_vsplatrb` in GCC.
        #[link_name = "llvm.hexagon.S2.vsplatrb"]
        pub fn S2_vsplatrb(a: i32) -> i32;
        /// The `llvm.hexagon.S2.insert` intrinsic; known as `__builtin_HEXAGON_S2_insert` in GCC.
        #[link_name = "llvm.hexagon.S2.insert"]
        pub fn S2_insert(a: i32, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.hexagon.S2.tableidxb.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_tableidxb_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.tableidxb.goodsyntax"]
        pub fn S2_tableidxb_goodsyntax(a: i32, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.hexagon.S2.tableidxh.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_tableidxh_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.tableidxh.goodsyntax"]
        pub fn S2_tableidxh_goodsyntax(a: i32, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.hexagon.S2.tableidxw.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_tableidxw_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.tableidxw.goodsyntax"]
        pub fn S2_tableidxw_goodsyntax(a: i32, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.hexagon.S2.tableidxd.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S2_tableidxd_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S2.tableidxd.goodsyntax"]
        pub fn S2_tableidxd_goodsyntax(a: i32, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.hexagon.A4.bitspliti` intrinsic; known as `__builtin_HEXAGON_A4_bitspliti` in GCC.
        #[link_name = "llvm.hexagon.A4.bitspliti"]
        pub fn A4_bitspliti(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A4.bitsplit` intrinsic; known as `__builtin_HEXAGON_A4_bitsplit` in GCC.
        #[link_name = "llvm.hexagon.A4.bitsplit"]
        pub fn A4_bitsplit(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.S4.extract` intrinsic; known as `__builtin_HEXAGON_S4_extract` in GCC.
        #[link_name = "llvm.hexagon.S4.extract"]
        pub fn S4_extract(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.extractu` intrinsic; known as `__builtin_HEXAGON_S2_extractu` in GCC.
        #[link_name = "llvm.hexagon.S2.extractu"]
        pub fn S2_extractu(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S2.insertp` intrinsic; known as `__builtin_HEXAGON_S2_insertp` in GCC.
        #[link_name = "llvm.hexagon.S2.insertp"]
        pub fn S2_insertp(a: i64, b: i64, c: i32, d: i32) -> i64;
        /// The `llvm.hexagon.S4.extractp` intrinsic; known as `__builtin_HEXAGON_S4_extractp` in GCC.
        #[link_name = "llvm.hexagon.S4.extractp"]
        pub fn S4_extractp(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.S2.extractup` intrinsic; known as `__builtin_HEXAGON_S2_extractup` in GCC.
        #[link_name = "llvm.hexagon.S2.extractup"]
        pub fn S2_extractup(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.hexagon.S2.insert.rp` intrinsic; known as `__builtin_HEXAGON_S2_insert_rp` in GCC.
        #[link_name = "llvm.hexagon.S2.insert.rp"]
        pub fn S2_insert_rp(a: i32, b: i32, c: i64) -> i32;
        /// The `llvm.hexagon.S4.extract.rp` intrinsic; known as `__builtin_HEXAGON_S4_extract_rp` in GCC.
        #[link_name = "llvm.hexagon.S4.extract.rp"]
        pub fn S4_extract_rp(a: i32, b: i64) -> i32;
        /// The `llvm.hexagon.S2.extractu.rp` intrinsic; known as `__builtin_HEXAGON_S2_extractu_rp` in GCC.
        #[link_name = "llvm.hexagon.S2.extractu.rp"]
        pub fn S2_extractu_rp(a: i32, b: i64) -> i32;
        /// The `llvm.hexagon.S2.insertp.rp` intrinsic; known as `__builtin_HEXAGON_S2_insertp_rp` in GCC.
        #[link_name = "llvm.hexagon.S2.insertp.rp"]
        pub fn S2_insertp_rp(a: i64, b: i64, c: i64) -> i64;
        /// The `llvm.hexagon.S4.extractp.rp` intrinsic; known as `__builtin_HEXAGON_S4_extractp_rp` in GCC.
        #[link_name = "llvm.hexagon.S4.extractp.rp"]
        pub fn S4_extractp_rp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.extractup.rp` intrinsic; known as `__builtin_HEXAGON_S2_extractup_rp` in GCC.
        #[link_name = "llvm.hexagon.S2.extractup.rp"]
        pub fn S2_extractup_rp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.tstbit.i` intrinsic; known as `__builtin_HEXAGON_S2_tstbit_i` in GCC.
        #[link_name = "llvm.hexagon.S2.tstbit.i"]
        pub fn S2_tstbit_i(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S4.ntstbit.i` intrinsic; known as `__builtin_HEXAGON_S4_ntstbit_i` in GCC.
        #[link_name = "llvm.hexagon.S4.ntstbit.i"]
        pub fn S4_ntstbit_i(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.setbit.i` intrinsic; known as `__builtin_HEXAGON_S2_setbit_i` in GCC.
        #[link_name = "llvm.hexagon.S2.setbit.i"]
        pub fn S2_setbit_i(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.togglebit.i` intrinsic; known as `__builtin_HEXAGON_S2_togglebit_i` in GCC.
        #[link_name = "llvm.hexagon.S2.togglebit.i"]
        pub fn S2_togglebit_i(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.clrbit.i` intrinsic; known as `__builtin_HEXAGON_S2_clrbit_i` in GCC.
        #[link_name = "llvm.hexagon.S2.clrbit.i"]
        pub fn S2_clrbit_i(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.tstbit.r` intrinsic; known as `__builtin_HEXAGON_S2_tstbit_r` in GCC.
        #[link_name = "llvm.hexagon.S2.tstbit.r"]
        pub fn S2_tstbit_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S4.ntstbit.r` intrinsic; known as `__builtin_HEXAGON_S4_ntstbit_r` in GCC.
        #[link_name = "llvm.hexagon.S4.ntstbit.r"]
        pub fn S4_ntstbit_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.setbit.r` intrinsic; known as `__builtin_HEXAGON_S2_setbit_r` in GCC.
        #[link_name = "llvm.hexagon.S2.setbit.r"]
        pub fn S2_setbit_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.togglebit.r` intrinsic; known as `__builtin_HEXAGON_S2_togglebit_r` in GCC.
        #[link_name = "llvm.hexagon.S2.togglebit.r"]
        pub fn S2_togglebit_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.clrbit.r` intrinsic; known as `__builtin_HEXAGON_S2_clrbit_r` in GCC.
        #[link_name = "llvm.hexagon.S2.clrbit.r"]
        pub fn S2_clrbit_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.i.vh` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.vh"]
        pub fn S2_asr_i_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.i.vh` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.vh"]
        pub fn S2_lsr_i_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.vh` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.vh"]
        pub fn S2_asl_i_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.vh` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.vh"]
        pub fn S2_asr_r_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S5.asrhub.rnd.sat.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S5_asrhub_rnd_sat_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S5.asrhub.rnd.sat.goodsyntax"]
        pub fn S5_asrhub_rnd_sat_goodsyntax(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.S5.asrhub.sat` intrinsic; known as `__builtin_HEXAGON_S5_asrhub_sat` in GCC.
        #[link_name = "llvm.hexagon.S5.asrhub.sat"]
        pub fn S5_asrhub_sat(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.S5.vasrhrnd.goodsyntax` intrinsic; known as `__builtin_HEXAGON_S5_vasrhrnd_goodsyntax` in GCC.
        #[link_name = "llvm.hexagon.S5.vasrhrnd.goodsyntax"]
        pub fn S5_vasrhrnd_goodsyntax(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.vh` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.vh"]
        pub fn S2_asl_r_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.vh` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.vh"]
        pub fn S2_lsr_r_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.vh` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_vh` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.vh"]
        pub fn S2_lsl_r_vh(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.vw` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.vw"]
        pub fn S2_asr_i_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.i.svw.trun` intrinsic; known as `__builtin_HEXAGON_S2_asr_i_svw_trun` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.i.svw.trun"]
        pub fn S2_asr_i_svw_trun(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.S2.asr.r.svw.trun` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_svw_trun` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.svw.trun"]
        pub fn S2_asr_r_svw_trun(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.S2.lsr.i.vw` intrinsic; known as `__builtin_HEXAGON_S2_lsr_i_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.i.vw"]
        pub fn S2_lsr_i_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.i.vw` intrinsic; known as `__builtin_HEXAGON_S2_asl_i_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.i.vw"]
        pub fn S2_asl_i_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asr.r.vw` intrinsic; known as `__builtin_HEXAGON_S2_asr_r_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.asr.r.vw"]
        pub fn S2_asr_r_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.asl.r.vw` intrinsic; known as `__builtin_HEXAGON_S2_asl_r_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.asl.r.vw"]
        pub fn S2_asl_r_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsr.r.vw` intrinsic; known as `__builtin_HEXAGON_S2_lsr_r_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.lsr.r.vw"]
        pub fn S2_lsr_r_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.lsl.r.vw` intrinsic; known as `__builtin_HEXAGON_S2_lsl_r_vw` in GCC.
        #[link_name = "llvm.hexagon.S2.lsl.r.vw"]
        pub fn S2_lsl_r_vw(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S2.vrndpackwh` intrinsic; known as `__builtin_HEXAGON_S2_vrndpackwh` in GCC.
        #[link_name = "llvm.hexagon.S2.vrndpackwh"]
        pub fn S2_vrndpackwh(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vrndpackwhs` intrinsic; known as `__builtin_HEXAGON_S2_vrndpackwhs` in GCC.
        #[link_name = "llvm.hexagon.S2.vrndpackwhs"]
        pub fn S2_vrndpackwhs(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vsxtbh` intrinsic; known as `__builtin_HEXAGON_S2_vsxtbh` in GCC.
        #[link_name = "llvm.hexagon.S2.vsxtbh"]
        pub fn S2_vsxtbh(a: i32) -> i64;
        /// The `llvm.hexagon.S2.vzxtbh` intrinsic; known as `__builtin_HEXAGON_S2_vzxtbh` in GCC.
        #[link_name = "llvm.hexagon.S2.vzxtbh"]
        pub fn S2_vzxtbh(a: i32) -> i64;
        /// The `llvm.hexagon.S2.vsathub` intrinsic; known as `__builtin_HEXAGON_S2_vsathub` in GCC.
        #[link_name = "llvm.hexagon.S2.vsathub"]
        pub fn S2_vsathub(a: i64) -> i32;
        /// The `llvm.hexagon.S2.svsathub` intrinsic; known as `__builtin_HEXAGON_S2_svsathub` in GCC.
        #[link_name = "llvm.hexagon.S2.svsathub"]
        pub fn S2_svsathub(a: i32) -> i32;
        /// The `llvm.hexagon.S2.svsathb` intrinsic; known as `__builtin_HEXAGON_S2_svsathb` in GCC.
        #[link_name = "llvm.hexagon.S2.svsathb"]
        pub fn S2_svsathb(a: i32) -> i32;
        /// The `llvm.hexagon.S2.vsathb` intrinsic; known as `__builtin_HEXAGON_S2_vsathb` in GCC.
        #[link_name = "llvm.hexagon.S2.vsathb"]
        pub fn S2_vsathb(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vtrunohb` intrinsic; known as `__builtin_HEXAGON_S2_vtrunohb` in GCC.
        #[link_name = "llvm.hexagon.S2.vtrunohb"]
        pub fn S2_vtrunohb(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vtrunewh` intrinsic; known as `__builtin_HEXAGON_S2_vtrunewh` in GCC.
        #[link_name = "llvm.hexagon.S2.vtrunewh"]
        pub fn S2_vtrunewh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.vtrunowh` intrinsic; known as `__builtin_HEXAGON_S2_vtrunowh` in GCC.
        #[link_name = "llvm.hexagon.S2.vtrunowh"]
        pub fn S2_vtrunowh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.vtrunehb` intrinsic; known as `__builtin_HEXAGON_S2_vtrunehb` in GCC.
        #[link_name = "llvm.hexagon.S2.vtrunehb"]
        pub fn S2_vtrunehb(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vsxthw` intrinsic; known as `__builtin_HEXAGON_S2_vsxthw` in GCC.
        #[link_name = "llvm.hexagon.S2.vsxthw"]
        pub fn S2_vsxthw(a: i32) -> i64;
        /// The `llvm.hexagon.S2.vzxthw` intrinsic; known as `__builtin_HEXAGON_S2_vzxthw` in GCC.
        #[link_name = "llvm.hexagon.S2.vzxthw"]
        pub fn S2_vzxthw(a: i32) -> i64;
        /// The `llvm.hexagon.S2.vsatwh` intrinsic; known as `__builtin_HEXAGON_S2_vsatwh` in GCC.
        #[link_name = "llvm.hexagon.S2.vsatwh"]
        pub fn S2_vsatwh(a: i64) -> i32;
        /// The `llvm.hexagon.S2.vsatwuh` intrinsic; known as `__builtin_HEXAGON_S2_vsatwuh` in GCC.
        #[link_name = "llvm.hexagon.S2.vsatwuh"]
        pub fn S2_vsatwuh(a: i64) -> i32;
        /// The `llvm.hexagon.S2.packhl` intrinsic; known as `__builtin_HEXAGON_S2_packhl` in GCC.
        #[link_name = "llvm.hexagon.S2.packhl"]
        pub fn S2_packhl(a: i32, b: i32) -> i64;
        /// The `llvm.hexagon.A2.swiz` intrinsic; known as `__builtin_HEXAGON_A2_swiz` in GCC.
        #[link_name = "llvm.hexagon.A2.swiz"]
        pub fn A2_swiz(a: i32) -> i32;
        /// The `llvm.hexagon.S2.vsathub.nopack` intrinsic; known as `__builtin_HEXAGON_S2_vsathub_nopack` in GCC.
        #[link_name = "llvm.hexagon.S2.vsathub.nopack"]
        pub fn S2_vsathub_nopack(a: i64) -> i64;
        /// The `llvm.hexagon.S2.vsathb.nopack` intrinsic; known as `__builtin_HEXAGON_S2_vsathb_nopack` in GCC.
        #[link_name = "llvm.hexagon.S2.vsathb.nopack"]
        pub fn S2_vsathb_nopack(a: i64) -> i64;
        /// The `llvm.hexagon.S2.vsatwh.nopack` intrinsic; known as `__builtin_HEXAGON_S2_vsatwh_nopack` in GCC.
        #[link_name = "llvm.hexagon.S2.vsatwh.nopack"]
        pub fn S2_vsatwh_nopack(a: i64) -> i64;
        /// The `llvm.hexagon.S2.vsatwuh.nopack` intrinsic; known as `__builtin_HEXAGON_S2_vsatwuh_nopack` in GCC.
        #[link_name = "llvm.hexagon.S2.vsatwuh.nopack"]
        pub fn S2_vsatwuh_nopack(a: i64) -> i64;
        /// The `llvm.hexagon.S2.shuffob` intrinsic; known as `__builtin_HEXAGON_S2_shuffob` in GCC.
        #[link_name = "llvm.hexagon.S2.shuffob"]
        pub fn S2_shuffob(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.shuffeb` intrinsic; known as `__builtin_HEXAGON_S2_shuffeb` in GCC.
        #[link_name = "llvm.hexagon.S2.shuffeb"]
        pub fn S2_shuffeb(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.shuffoh` intrinsic; known as `__builtin_HEXAGON_S2_shuffoh` in GCC.
        #[link_name = "llvm.hexagon.S2.shuffoh"]
        pub fn S2_shuffoh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.shuffeh` intrinsic; known as `__builtin_HEXAGON_S2_shuffeh` in GCC.
        #[link_name = "llvm.hexagon.S2.shuffeh"]
        pub fn S2_shuffeh(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S5.popcountp` intrinsic; known as `__builtin_HEXAGON_S5_popcountp` in GCC.
        #[link_name = "llvm.hexagon.S5.popcountp"]
        pub fn S5_popcountp(a: i64) -> i32;
        /// The `llvm.hexagon.S4.parity` intrinsic; known as `__builtin_HEXAGON_S4_parity` in GCC.
        #[link_name = "llvm.hexagon.S4.parity"]
        pub fn S4_parity(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S2.parityp` intrinsic; known as `__builtin_HEXAGON_S2_parityp` in GCC.
        #[link_name = "llvm.hexagon.S2.parityp"]
        pub fn S2_parityp(a: i64, b: i64) -> i32;
        /// The `llvm.hexagon.S2.lfsp` intrinsic; known as `__builtin_HEXAGON_S2_lfsp` in GCC.
        #[link_name = "llvm.hexagon.S2.lfsp"]
        pub fn S2_lfsp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S2.clbnorm` intrinsic; known as `__builtin_HEXAGON_S2_clbnorm` in GCC.
        #[link_name = "llvm.hexagon.S2.clbnorm"]
        pub fn S2_clbnorm(a: i32) -> i32;
        /// The `llvm.hexagon.S4.clbaddi` intrinsic; known as `__builtin_HEXAGON_S4_clbaddi` in GCC.
        #[link_name = "llvm.hexagon.S4.clbaddi"]
        pub fn S4_clbaddi(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S4.clbpnorm` intrinsic; known as `__builtin_HEXAGON_S4_clbpnorm` in GCC.
        #[link_name = "llvm.hexagon.S4.clbpnorm"]
        pub fn S4_clbpnorm(a: i64) -> i32;
        /// The `llvm.hexagon.S4.clbpaddi` intrinsic; known as `__builtin_HEXAGON_S4_clbpaddi` in GCC.
        #[link_name = "llvm.hexagon.S4.clbpaddi"]
        pub fn S4_clbpaddi(a: i64, b: i32) -> i32;
        /// The `llvm.hexagon.S2.clb` intrinsic; known as `__builtin_HEXAGON_S2_clb` in GCC.
        #[link_name = "llvm.hexagon.S2.clb"]
        pub fn S2_clb(a: i32) -> i32;
        /// The `llvm.hexagon.S2.cl0` intrinsic; known as `__builtin_HEXAGON_S2_cl0` in GCC.
        #[link_name = "llvm.hexagon.S2.cl0"]
        pub fn S2_cl0(a: i32) -> i32;
        /// The `llvm.hexagon.S2.cl1` intrinsic; known as `__builtin_HEXAGON_S2_cl1` in GCC.
        #[link_name = "llvm.hexagon.S2.cl1"]
        pub fn S2_cl1(a: i32) -> i32;
        /// The `llvm.hexagon.S2.clbp` intrinsic; known as `__builtin_HEXAGON_S2_clbp` in GCC.
        #[link_name = "llvm.hexagon.S2.clbp"]
        pub fn S2_clbp(a: i64) -> i32;
        /// The `llvm.hexagon.S2.cl0p` intrinsic; known as `__builtin_HEXAGON_S2_cl0p` in GCC.
        #[link_name = "llvm.hexagon.S2.cl0p"]
        pub fn S2_cl0p(a: i64) -> i32;
        /// The `llvm.hexagon.S2.cl1p` intrinsic; known as `__builtin_HEXAGON_S2_cl1p` in GCC.
        #[link_name = "llvm.hexagon.S2.cl1p"]
        pub fn S2_cl1p(a: i64) -> i32;
        /// The `llvm.hexagon.S2.brev` intrinsic; known as `__builtin_HEXAGON_S2_brev` in GCC.
        #[link_name = "llvm.hexagon.S2.brev"]
        pub fn S2_brev(a: i32) -> i32;
        /// The `llvm.hexagon.S2.brevp` intrinsic; known as `__builtin_HEXAGON_S2_brevp` in GCC.
        #[link_name = "llvm.hexagon.S2.brevp"]
        pub fn S2_brevp(a: i64) -> i64;
        /// The `llvm.hexagon.S2.ct0` intrinsic; known as `__builtin_HEXAGON_S2_ct0` in GCC.
        #[link_name = "llvm.hexagon.S2.ct0"]
        pub fn S2_ct0(a: i32) -> i32;
        /// The `llvm.hexagon.S2.ct1` intrinsic; known as `__builtin_HEXAGON_S2_ct1` in GCC.
        #[link_name = "llvm.hexagon.S2.ct1"]
        pub fn S2_ct1(a: i32) -> i32;
        /// The `llvm.hexagon.S2.ct0p` intrinsic; known as `__builtin_HEXAGON_S2_ct0p` in GCC.
        #[link_name = "llvm.hexagon.S2.ct0p"]
        pub fn S2_ct0p(a: i64) -> i32;
        /// The `llvm.hexagon.S2.ct1p` intrinsic; known as `__builtin_HEXAGON_S2_ct1p` in GCC.
        #[link_name = "llvm.hexagon.S2.ct1p"]
        pub fn S2_ct1p(a: i64) -> i32;
        /// The `llvm.hexagon.S2.interleave` intrinsic; known as `__builtin_HEXAGON_S2_interleave` in GCC.
        #[link_name = "llvm.hexagon.S2.interleave"]
        pub fn S2_interleave(a: i64) -> i64;
        /// The `llvm.hexagon.S2.deinterleave` intrinsic; known as `__builtin_HEXAGON_S2_deinterleave` in GCC.
        #[link_name = "llvm.hexagon.S2.deinterleave"]
        pub fn S2_deinterleave(a: i64) -> i64;
        /// The `llvm.hexagon.prefetch` intrinsic; known as `__builtin_HEXAGON_prefetch` in GCC.
        #[link_name = "llvm.hexagon.prefetch"]
        pub fn prefetch(a: *mut i8) -> ();
        /// The `llvm.hexagon.V6.hi` intrinsic; known as `__builtin_HEXAGON_V6_hi` in GCC.
        #[link_name = "llvm.hexagon.V6.hi"]
        pub fn V6_hi(a: ::simdty::i32x32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.lo` intrinsic; known as `__builtin_HEXAGON_V6_lo` in GCC.
        #[link_name = "llvm.hexagon.V6.lo"]
        pub fn V6_lo(a: ::simdty::i32x32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.hi.128B` intrinsic; known as `__builtin_HEXAGON_V6_hi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.hi.128B"]
        pub fn V6_hi_128B(a: ::simdty::i32x64) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.lo.128B` intrinsic; known as `__builtin_HEXAGON_V6_lo_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.lo.128B"]
        pub fn V6_lo_128B(a: ::simdty::i32x64) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vassignp` intrinsic; known as `__builtin_HEXAGON_V6_vassignp` in GCC.
        #[link_name = "llvm.hexagon.V6.vassignp"]
        pub fn V6_vassignp(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vassignp.128B` intrinsic; known as `__builtin_HEXAGON_V6_vassignp_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vassignp.128B"]
        pub fn V6_vassignp_128B(a: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.S6.rol.i.r` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r"]
        pub fn S6_rol_i_r(a: i32, b: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.p` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p"]
        pub fn S6_rol_i_p(a: i64, b: i32) -> i64;
        /// The `llvm.hexagon.S6.rol.i.r.acc` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r_acc` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r.acc"]
        pub fn S6_rol_i_r_acc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.p.acc` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p_acc` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p.acc"]
        pub fn S6_rol_i_p_acc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S6.rol.i.r.nac` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r_nac` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r.nac"]
        pub fn S6_rol_i_r_nac(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.p.nac` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p_nac` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p.nac"]
        pub fn S6_rol_i_p_nac(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S6.rol.i.r.xacc` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r_xacc` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r.xacc"]
        pub fn S6_rol_i_r_xacc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.p.xacc` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p_xacc` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p.xacc"]
        pub fn S6_rol_i_p_xacc(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S6.rol.i.r.and` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r_and` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r.and"]
        pub fn S6_rol_i_r_and(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.r.or` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_r_or` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.r.or"]
        pub fn S6_rol_i_r_or(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.hexagon.S6.rol.i.p.and` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p_and` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p.and"]
        pub fn S6_rol_i_p_and(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S6.rol.i.p.or` intrinsic; known as `__builtin_HEXAGON_S6_rol_i_p_or` in GCC.
        #[link_name = "llvm.hexagon.S6.rol.i.p.or"]
        pub fn S6_rol_i_p_or(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.S2.cabacencbin` intrinsic; known as `__builtin_HEXAGON_S2_cabacencbin` in GCC.
        #[link_name = "llvm.hexagon.S2.cabacencbin"]
        pub fn S2_cabacencbin(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.hexagon.V6.valignb` intrinsic; known as `__builtin_HEXAGON_V6_valignb` in GCC.
        #[link_name = "llvm.hexagon.V6.valignb"]
        pub fn V6_valignb(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.valignb.128B` intrinsic; known as `__builtin_HEXAGON_V6_valignb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.valignb.128B"]
        pub fn V6_valignb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlalignb` intrinsic; known as `__builtin_HEXAGON_V6_vlalignb` in GCC.
        #[link_name = "llvm.hexagon.V6.vlalignb"]
        pub fn V6_vlalignb(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlalignb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlalignb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlalignb.128B"]
        pub fn V6_vlalignb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.valignbi` intrinsic; known as `__builtin_HEXAGON_V6_valignbi` in GCC.
        #[link_name = "llvm.hexagon.V6.valignbi"]
        pub fn V6_valignbi(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.valignbi.128B` intrinsic; known as `__builtin_HEXAGON_V6_valignbi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.valignbi.128B"]
        pub fn V6_valignbi_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlalignbi` intrinsic; known as `__builtin_HEXAGON_V6_vlalignbi` in GCC.
        #[link_name = "llvm.hexagon.V6.vlalignbi"]
        pub fn V6_vlalignbi(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlalignbi.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlalignbi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlalignbi.128B"]
        pub fn V6_vlalignbi_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vror` intrinsic; known as `__builtin_HEXAGON_V6_vror` in GCC.
        #[link_name = "llvm.hexagon.V6.vror"]
        pub fn V6_vror(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vror.128B` intrinsic; known as `__builtin_HEXAGON_V6_vror_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vror.128B"]
        pub fn V6_vror_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackub` intrinsic; known as `__builtin_HEXAGON_V6_vunpackub` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackub"]
        pub fn V6_vunpackub(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackub.128B"]
        pub fn V6_vunpackub_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vunpackb` intrinsic; known as `__builtin_HEXAGON_V6_vunpackb` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackb"]
        pub fn V6_vunpackb(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackb.128B"]
        pub fn V6_vunpackb_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vunpackuh` intrinsic; known as `__builtin_HEXAGON_V6_vunpackuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackuh"]
        pub fn V6_vunpackuh(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackuh.128B"]
        pub fn V6_vunpackuh_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vunpackh` intrinsic; known as `__builtin_HEXAGON_V6_vunpackh` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackh"]
        pub fn V6_vunpackh(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackh.128B"]
        pub fn V6_vunpackh_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vunpackob` intrinsic; known as `__builtin_HEXAGON_V6_vunpackob` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackob"]
        pub fn V6_vunpackob(a: ::simdty::i32x32, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackob.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackob_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackob.128B"]
        pub fn V6_vunpackob_128B(a: ::simdty::i32x64, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vunpackoh` intrinsic; known as `__builtin_HEXAGON_V6_vunpackoh` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackoh"]
        pub fn V6_vunpackoh(a: ::simdty::i32x32, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vunpackoh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vunpackoh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vunpackoh.128B"]
        pub fn V6_vunpackoh_128B(a: ::simdty::i32x64, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vpackeb` intrinsic; known as `__builtin_HEXAGON_V6_vpackeb` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackeb"]
        pub fn V6_vpackeb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackeb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackeb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackeb.128B"]
        pub fn V6_vpackeb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackeh` intrinsic; known as `__builtin_HEXAGON_V6_vpackeh` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackeh"]
        pub fn V6_vpackeh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackeh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackeh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackeh.128B"]
        pub fn V6_vpackeh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackob` intrinsic; known as `__builtin_HEXAGON_V6_vpackob` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackob"]
        pub fn V6_vpackob(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackob.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackob_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackob.128B"]
        pub fn V6_vpackob_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackoh` intrinsic; known as `__builtin_HEXAGON_V6_vpackoh` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackoh"]
        pub fn V6_vpackoh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackoh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackoh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackoh.128B"]
        pub fn V6_vpackoh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackhub.sat` intrinsic; known as `__builtin_HEXAGON_V6_vpackhub_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackhub.sat"]
        pub fn V6_vpackhub_sat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackhub.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackhub_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackhub.sat.128B"]
        pub fn V6_vpackhub_sat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackhb.sat` intrinsic; known as `__builtin_HEXAGON_V6_vpackhb_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackhb.sat"]
        pub fn V6_vpackhb_sat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackhb.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackhb_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackhb.sat.128B"]
        pub fn V6_vpackhb_sat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackwuh.sat` intrinsic; known as `__builtin_HEXAGON_V6_vpackwuh_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackwuh.sat"]
        pub fn V6_vpackwuh_sat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackwuh.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackwuh_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackwuh.sat.128B"]
        pub fn V6_vpackwuh_sat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpackwh.sat` intrinsic; known as `__builtin_HEXAGON_V6_vpackwh_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackwh.sat"]
        pub fn V6_vpackwh_sat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpackwh.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpackwh_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpackwh.sat.128B"]
        pub fn V6_vpackwh_sat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vzb` intrinsic; known as `__builtin_HEXAGON_V6_vzb` in GCC.
        #[link_name = "llvm.hexagon.V6.vzb"]
        pub fn V6_vzb(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vzb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vzb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vzb.128B"]
        pub fn V6_vzb_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsb` intrinsic; known as `__builtin_HEXAGON_V6_vsb` in GCC.
        #[link_name = "llvm.hexagon.V6.vsb"]
        pub fn V6_vsb(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsb.128B"]
        pub fn V6_vsb_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vzh` intrinsic; known as `__builtin_HEXAGON_V6_vzh` in GCC.
        #[link_name = "llvm.hexagon.V6.vzh"]
        pub fn V6_vzh(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vzh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vzh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vzh.128B"]
        pub fn V6_vzh_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsh` intrinsic; known as `__builtin_HEXAGON_V6_vsh` in GCC.
        #[link_name = "llvm.hexagon.V6.vsh"]
        pub fn V6_vsh(a: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsh.128B"]
        pub fn V6_vsh_128B(a: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdmpybus` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus"]
        pub fn V6_vdmpybus(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpybus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.128B"]
        pub fn V6_vdmpybus_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpybus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.acc"]
        pub fn V6_vdmpybus_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpybus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.acc.128B"]
        pub fn V6_vdmpybus_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpybus.dv` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.dv"]
        pub fn V6_vdmpybus_dv(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpybus.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.dv.128B"]
        pub fn V6_vdmpybus_dv_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdmpybus.dv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_dv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.dv.acc"]
        pub fn V6_vdmpybus_dv_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpybus.dv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpybus_dv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpybus.dv.acc.128B"]
        pub fn V6_vdmpybus_dv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdmpyhb` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb"]
        pub fn V6_vdmpyhb(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.128B"]
        pub fn V6_vdmpyhb_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.acc"]
        pub fn V6_vdmpyhb_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.acc.128B"]
        pub fn V6_vdmpyhb_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhb.dv` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.dv"]
        pub fn V6_vdmpyhb_dv(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhb.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.dv.128B"]
        pub fn V6_vdmpyhb_dv_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdmpyhb.dv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_dv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.dv.acc"]
        pub fn V6_vdmpyhb_dv_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhb.dv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhb_dv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhb.dv.acc.128B"]
        pub fn V6_vdmpyhb_dv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdmpyhvsat` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhvsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhvsat"]
        pub fn V6_vdmpyhvsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhvsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhvsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhvsat.128B"]
        pub fn V6_vdmpyhvsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhvsat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhvsat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhvsat.acc"]
        pub fn V6_vdmpyhvsat_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhvsat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhvsat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhvsat.acc.128B"]
        pub fn V6_vdmpyhvsat_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsat` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsat"]
        pub fn V6_vdmpyhsat(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsat.128B"]
        pub fn V6_vdmpyhsat_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsat.acc"]
        pub fn V6_vdmpyhsat_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsat.acc.128B"]
        pub fn V6_vdmpyhsat_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhisat` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhisat` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhisat"]
        pub fn V6_vdmpyhisat(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhisat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhisat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhisat.128B"]
        pub fn V6_vdmpyhisat_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhisat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhisat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhisat.acc"]
        pub fn V6_vdmpyhisat_acc(a: ::simdty::i32x16, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhisat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhisat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhisat.acc.128B"]
        pub fn V6_vdmpyhisat_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsusat` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsusat` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsusat"]
        pub fn V6_vdmpyhsusat(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsusat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsusat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsusat.128B"]
        pub fn V6_vdmpyhsusat_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsusat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsusat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsusat.acc"]
        pub fn V6_vdmpyhsusat_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsusat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsusat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsusat.acc.128B"]
        pub fn V6_vdmpyhsusat_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsuisat` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsuisat` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsuisat"]
        pub fn V6_vdmpyhsuisat(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsuisat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsuisat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsuisat.128B"]
        pub fn V6_vdmpyhsuisat_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdmpyhsuisat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsuisat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsuisat.acc"]
        pub fn V6_vdmpyhsuisat_acc(a: ::simdty::i32x16, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdmpyhsuisat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdmpyhsuisat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdmpyhsuisat.acc.128B"]
        pub fn V6_vdmpyhsuisat_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpyb` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyb` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyb"]
        pub fn V6_vtmpyb(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpyb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyb.128B"]
        pub fn V6_vtmpyb_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vtmpyb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyb.acc"]
        pub fn V6_vtmpyb_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpyb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyb.acc.128B"]
        pub fn V6_vtmpyb_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vtmpybus` intrinsic; known as `__builtin_HEXAGON_V6_vtmpybus` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpybus"]
        pub fn V6_vtmpybus(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpybus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpybus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpybus.128B"]
        pub fn V6_vtmpybus_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vtmpybus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vtmpybus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpybus.acc"]
        pub fn V6_vtmpybus_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpybus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpybus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpybus.acc.128B"]
        pub fn V6_vtmpybus_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vtmpyhb` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyhb` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyhb"]
        pub fn V6_vtmpyhb(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpyhb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyhb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyhb.128B"]
        pub fn V6_vtmpyhb_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vtmpyhb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyhb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyhb.acc"]
        pub fn V6_vtmpyhb_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vtmpyhb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vtmpyhb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vtmpyhb.acc.128B"]
        pub fn V6_vtmpyhb_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrmpyub` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyub` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyub"]
        pub fn V6_vrmpyub(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpyub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyub.128B"]
        pub fn V6_vrmpyub_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyub.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyub_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyub.acc"]
        pub fn V6_vrmpyub_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpyub.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyub_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyub.acc.128B"]
        pub fn V6_vrmpyub_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyubv` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubv` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubv"]
        pub fn V6_vrmpyubv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpyubv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubv.128B"]
        pub fn V6_vrmpyubv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyubv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubv.acc"]
        pub fn V6_vrmpyubv_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpyubv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubv.acc.128B"]
        pub fn V6_vrmpyubv_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybv` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybv` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybv"]
        pub fn V6_vrmpybv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybv.128B"]
        pub fn V6_vrmpybv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybv.acc"]
        pub fn V6_vrmpybv_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybv.acc.128B"]
        pub fn V6_vrmpybv_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyubi` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubi` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubi"]
        pub fn V6_vrmpyubi(a: ::simdty::i32x32, b: i32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyubi.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubi.128B"]
        pub fn V6_vrmpyubi_128B(a: ::simdty::i32x64, b: i32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrmpyubi.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubi_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubi.acc"]
        pub fn V6_vrmpyubi_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpyubi.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpyubi_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpyubi.acc.128B"]
        pub fn V6_vrmpyubi_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32, d: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrmpybus` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybus` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybus"]
        pub fn V6_vrmpybus(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybus.128B"]
        pub fn V6_vrmpybus_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybus.acc"]
        pub fn V6_vrmpybus_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybus.acc.128B"]
        pub fn V6_vrmpybus_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybusi` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusi` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusi"]
        pub fn V6_vrmpybusi(a: ::simdty::i32x32, b: i32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybusi.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusi.128B"]
        pub fn V6_vrmpybusi_128B(a: ::simdty::i32x64, b: i32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrmpybusi.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusi_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusi.acc"]
        pub fn V6_vrmpybusi_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybusi.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusi_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusi.acc.128B"]
        pub fn V6_vrmpybusi_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32, d: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrmpybusv` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusv` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusv"]
        pub fn V6_vrmpybusv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybusv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusv.128B"]
        pub fn V6_vrmpybusv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrmpybusv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusv.acc"]
        pub fn V6_vrmpybusv_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrmpybusv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrmpybusv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrmpybusv.acc.128B"]
        pub fn V6_vrmpybusv_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdsaduh` intrinsic; known as `__builtin_HEXAGON_V6_vdsaduh` in GCC.
        #[link_name = "llvm.hexagon.V6.vdsaduh"]
        pub fn V6_vdsaduh(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdsaduh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdsaduh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdsaduh.128B"]
        pub fn V6_vdsaduh_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdsaduh.acc` intrinsic; known as `__builtin_HEXAGON_V6_vdsaduh_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vdsaduh.acc"]
        pub fn V6_vdsaduh_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdsaduh.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdsaduh_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdsaduh.acc.128B"]
        pub fn V6_vdsaduh_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrsadubi` intrinsic; known as `__builtin_HEXAGON_V6_vrsadubi` in GCC.
        #[link_name = "llvm.hexagon.V6.vrsadubi"]
        pub fn V6_vrsadubi(a: ::simdty::i32x32, b: i32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrsadubi.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrsadubi_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrsadubi.128B"]
        pub fn V6_vrsadubi_128B(a: ::simdty::i32x64, b: i32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vrsadubi.acc` intrinsic; known as `__builtin_HEXAGON_V6_vrsadubi_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vrsadubi.acc"]
        pub fn V6_vrsadubi_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrsadubi.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrsadubi_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrsadubi.acc.128B"]
        pub fn V6_vrsadubi_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32, d: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vasrw` intrinsic; known as `__builtin_HEXAGON_V6_vasrw` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrw"]
        pub fn V6_vasrw(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrw.128B"]
        pub fn V6_vasrw_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaslw` intrinsic; known as `__builtin_HEXAGON_V6_vaslw` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslw"]
        pub fn V6_vaslw(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaslw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaslw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslw.128B"]
        pub fn V6_vaslw_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlsrw` intrinsic; known as `__builtin_HEXAGON_V6_vlsrw` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrw"]
        pub fn V6_vlsrw(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlsrw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlsrw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrw.128B"]
        pub fn V6_vlsrw_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrwv` intrinsic; known as `__builtin_HEXAGON_V6_vasrwv` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwv"]
        pub fn V6_vasrwv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrwv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrwv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwv.128B"]
        pub fn V6_vasrwv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaslwv` intrinsic; known as `__builtin_HEXAGON_V6_vaslwv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslwv"]
        pub fn V6_vaslwv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaslwv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaslwv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslwv.128B"]
        pub fn V6_vaslwv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlsrwv` intrinsic; known as `__builtin_HEXAGON_V6_vlsrwv` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrwv"]
        pub fn V6_vlsrwv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlsrwv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlsrwv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrwv.128B"]
        pub fn V6_vlsrwv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrh` intrinsic; known as `__builtin_HEXAGON_V6_vasrh` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrh"]
        pub fn V6_vasrh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrh.128B"]
        pub fn V6_vasrh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaslh` intrinsic; known as `__builtin_HEXAGON_V6_vaslh` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslh"]
        pub fn V6_vaslh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaslh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaslh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslh.128B"]
        pub fn V6_vaslh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlsrh` intrinsic; known as `__builtin_HEXAGON_V6_vlsrh` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrh"]
        pub fn V6_vlsrh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlsrh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlsrh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrh.128B"]
        pub fn V6_vlsrh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrhv` intrinsic; known as `__builtin_HEXAGON_V6_vasrhv` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhv"]
        pub fn V6_vasrhv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrhv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrhv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhv.128B"]
        pub fn V6_vasrhv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaslhv` intrinsic; known as `__builtin_HEXAGON_V6_vaslhv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslhv"]
        pub fn V6_vaslhv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaslhv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaslhv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslhv.128B"]
        pub fn V6_vaslhv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlsrhv` intrinsic; known as `__builtin_HEXAGON_V6_vlsrhv` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrhv"]
        pub fn V6_vlsrhv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlsrhv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlsrhv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlsrhv.128B"]
        pub fn V6_vlsrhv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrwh` intrinsic; known as `__builtin_HEXAGON_V6_vasrwh` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwh"]
        pub fn V6_vasrwh(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrwh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrwh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwh.128B"]
        pub fn V6_vasrwh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrwhsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrwhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwhsat"]
        pub fn V6_vasrwhsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrwhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrwhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwhsat.128B"]
        pub fn V6_vasrwhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrwhrndsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrwhrndsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwhrndsat"]
        pub fn V6_vasrwhrndsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrwhrndsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrwhrndsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwhrndsat.128B"]
        pub fn V6_vasrwhrndsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrwuhsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrwuhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwuhsat"]
        pub fn V6_vasrwuhsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrwuhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrwuhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrwuhsat.128B"]
        pub fn V6_vasrwuhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vroundwh` intrinsic; known as `__builtin_HEXAGON_V6_vroundwh` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundwh"]
        pub fn V6_vroundwh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vroundwh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vroundwh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundwh.128B"]
        pub fn V6_vroundwh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vroundwuh` intrinsic; known as `__builtin_HEXAGON_V6_vroundwuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundwuh"]
        pub fn V6_vroundwuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vroundwuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vroundwuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundwuh.128B"]
        pub fn V6_vroundwuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrhubsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrhubsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhubsat"]
        pub fn V6_vasrhubsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrhubsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrhubsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhubsat.128B"]
        pub fn V6_vasrhubsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrhubrndsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrhubrndsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhubrndsat"]
        pub fn V6_vasrhubrndsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrhubrndsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrhubrndsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhubrndsat.128B"]
        pub fn V6_vasrhubrndsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrhbrndsat` intrinsic; known as `__builtin_HEXAGON_V6_vasrhbrndsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhbrndsat"]
        pub fn V6_vasrhbrndsat(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrhbrndsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrhbrndsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrhbrndsat.128B"]
        pub fn V6_vasrhbrndsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vroundhb` intrinsic; known as `__builtin_HEXAGON_V6_vroundhb` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundhb"]
        pub fn V6_vroundhb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vroundhb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vroundhb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundhb.128B"]
        pub fn V6_vroundhb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vroundhub` intrinsic; known as `__builtin_HEXAGON_V6_vroundhub` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundhub"]
        pub fn V6_vroundhub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vroundhub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vroundhub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vroundhub.128B"]
        pub fn V6_vroundhub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaslw.acc` intrinsic; known as `__builtin_HEXAGON_V6_vaslw_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslw.acc"]
        pub fn V6_vaslw_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaslw.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaslw_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaslw.acc.128B"]
        pub fn V6_vaslw_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vasrw.acc` intrinsic; known as `__builtin_HEXAGON_V6_vasrw_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrw.acc"]
        pub fn V6_vasrw_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vasrw.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vasrw_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vasrw.acc.128B"]
        pub fn V6_vasrw_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddb` intrinsic; known as `__builtin_HEXAGON_V6_vaddb` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddb"]
        pub fn V6_vaddb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddb.128B"]
        pub fn V6_vaddb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubb` intrinsic; known as `__builtin_HEXAGON_V6_vsubb` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubb"]
        pub fn V6_vsubb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubb.128B"]
        pub fn V6_vsubb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddb.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddb_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddb.dv"]
        pub fn V6_vaddb_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddb.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddb_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddb.dv.128B"]
        pub fn V6_vaddb_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubb.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubb_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubb.dv"]
        pub fn V6_vsubb_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubb.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubb_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubb.dv.128B"]
        pub fn V6_vsubb_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddh` intrinsic; known as `__builtin_HEXAGON_V6_vaddh` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddh"]
        pub fn V6_vaddh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddh.128B"]
        pub fn V6_vaddh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubh` intrinsic; known as `__builtin_HEXAGON_V6_vsubh` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubh"]
        pub fn V6_vsubh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubh.128B"]
        pub fn V6_vsubh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddh.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddh_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddh.dv"]
        pub fn V6_vaddh_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddh.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddh_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddh.dv.128B"]
        pub fn V6_vaddh_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubh.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubh_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubh.dv"]
        pub fn V6_vsubh_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubh.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubh_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubh.dv.128B"]
        pub fn V6_vsubh_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddw` intrinsic; known as `__builtin_HEXAGON_V6_vaddw` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddw"]
        pub fn V6_vaddw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddw.128B"]
        pub fn V6_vaddw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubw` intrinsic; known as `__builtin_HEXAGON_V6_vsubw` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubw"]
        pub fn V6_vsubw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubw.128B"]
        pub fn V6_vsubw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddw.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddw_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddw.dv"]
        pub fn V6_vaddw_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddw.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddw_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddw.dv.128B"]
        pub fn V6_vaddw_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubw.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubw_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubw.dv"]
        pub fn V6_vsubw_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubw.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubw_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubw.dv.128B"]
        pub fn V6_vsubw_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddubsat` intrinsic; known as `__builtin_HEXAGON_V6_vaddubsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubsat"]
        pub fn V6_vaddubsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddubsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddubsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubsat.128B"]
        pub fn V6_vaddubsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddubsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddubsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubsat.dv"]
        pub fn V6_vaddubsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddubsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddubsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubsat.dv.128B"]
        pub fn V6_vaddubsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsububsat` intrinsic; known as `__builtin_HEXAGON_V6_vsububsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububsat"]
        pub fn V6_vsububsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsububsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsububsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububsat.128B"]
        pub fn V6_vsububsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsububsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsububsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububsat.dv"]
        pub fn V6_vsububsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsububsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsububsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububsat.dv.128B"]
        pub fn V6_vsububsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vadduhsat` intrinsic; known as `__builtin_HEXAGON_V6_vadduhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhsat"]
        pub fn V6_vadduhsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vadduhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vadduhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhsat.128B"]
        pub fn V6_vadduhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vadduhsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vadduhsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhsat.dv"]
        pub fn V6_vadduhsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vadduhsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vadduhsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhsat.dv.128B"]
        pub fn V6_vadduhsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubuhsat` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhsat"]
        pub fn V6_vsubuhsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubuhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhsat.128B"]
        pub fn V6_vsubuhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubuhsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhsat.dv"]
        pub fn V6_vsubuhsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubuhsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhsat.dv.128B"]
        pub fn V6_vsubuhsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddhsat` intrinsic; known as `__builtin_HEXAGON_V6_vaddhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhsat"]
        pub fn V6_vaddhsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhsat.128B"]
        pub fn V6_vaddhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddhsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddhsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhsat.dv"]
        pub fn V6_vaddhsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddhsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddhsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhsat.dv.128B"]
        pub fn V6_vaddhsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubhsat` intrinsic; known as `__builtin_HEXAGON_V6_vsubhsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhsat"]
        pub fn V6_vsubhsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubhsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubhsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhsat.128B"]
        pub fn V6_vsubhsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubhsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubhsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhsat.dv"]
        pub fn V6_vsubhsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubhsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubhsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhsat.dv.128B"]
        pub fn V6_vsubhsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddwsat` intrinsic; known as `__builtin_HEXAGON_V6_vaddwsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddwsat"]
        pub fn V6_vaddwsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vaddwsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddwsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddwsat.128B"]
        pub fn V6_vaddwsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddwsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vaddwsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddwsat.dv"]
        pub fn V6_vaddwsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddwsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddwsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddwsat.dv.128B"]
        pub fn V6_vaddwsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubwsat` intrinsic; known as `__builtin_HEXAGON_V6_vsubwsat` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubwsat"]
        pub fn V6_vsubwsat(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsubwsat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubwsat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubwsat.128B"]
        pub fn V6_vsubwsat_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubwsat.dv` intrinsic; known as `__builtin_HEXAGON_V6_vsubwsat_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubwsat.dv"]
        pub fn V6_vsubwsat_dv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubwsat.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubwsat_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubwsat.dv.128B"]
        pub fn V6_vsubwsat_dv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vavgub` intrinsic; known as `__builtin_HEXAGON_V6_vavgub` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgub"]
        pub fn V6_vavgub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavgub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavgub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgub.128B"]
        pub fn V6_vavgub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavgubrnd` intrinsic; known as `__builtin_HEXAGON_V6_vavgubrnd` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgubrnd"]
        pub fn V6_vavgubrnd(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavgubrnd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavgubrnd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgubrnd.128B"]
        pub fn V6_vavgubrnd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavguh` intrinsic; known as `__builtin_HEXAGON_V6_vavguh` in GCC.
        #[link_name = "llvm.hexagon.V6.vavguh"]
        pub fn V6_vavguh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavguh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavguh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavguh.128B"]
        pub fn V6_vavguh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavguhrnd` intrinsic; known as `__builtin_HEXAGON_V6_vavguhrnd` in GCC.
        #[link_name = "llvm.hexagon.V6.vavguhrnd"]
        pub fn V6_vavguhrnd(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavguhrnd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavguhrnd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavguhrnd.128B"]
        pub fn V6_vavguhrnd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavgh` intrinsic; known as `__builtin_HEXAGON_V6_vavgh` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgh"]
        pub fn V6_vavgh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavgh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavgh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgh.128B"]
        pub fn V6_vavgh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavghrnd` intrinsic; known as `__builtin_HEXAGON_V6_vavghrnd` in GCC.
        #[link_name = "llvm.hexagon.V6.vavghrnd"]
        pub fn V6_vavghrnd(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavghrnd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavghrnd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavghrnd.128B"]
        pub fn V6_vavghrnd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnavgh` intrinsic; known as `__builtin_HEXAGON_V6_vnavgh` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgh"]
        pub fn V6_vnavgh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnavgh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnavgh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgh.128B"]
        pub fn V6_vnavgh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavgw` intrinsic; known as `__builtin_HEXAGON_V6_vavgw` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgw"]
        pub fn V6_vavgw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavgw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavgw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgw.128B"]
        pub fn V6_vavgw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vavgwrnd` intrinsic; known as `__builtin_HEXAGON_V6_vavgwrnd` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgwrnd"]
        pub fn V6_vavgwrnd(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vavgwrnd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vavgwrnd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vavgwrnd.128B"]
        pub fn V6_vavgwrnd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnavgw` intrinsic; known as `__builtin_HEXAGON_V6_vnavgw` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgw"]
        pub fn V6_vnavgw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnavgw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnavgw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgw.128B"]
        pub fn V6_vnavgw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsdiffub` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffub` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffub"]
        pub fn V6_vabsdiffub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsdiffub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffub.128B"]
        pub fn V6_vabsdiffub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsdiffuh` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffuh"]
        pub fn V6_vabsdiffuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsdiffuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffuh.128B"]
        pub fn V6_vabsdiffuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsdiffh` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffh` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffh"]
        pub fn V6_vabsdiffh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsdiffh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffh.128B"]
        pub fn V6_vabsdiffh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsdiffw` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffw` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffw"]
        pub fn V6_vabsdiffw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsdiffw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsdiffw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsdiffw.128B"]
        pub fn V6_vabsdiffw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnavgub` intrinsic; known as `__builtin_HEXAGON_V6_vnavgub` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgub"]
        pub fn V6_vnavgub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnavgub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnavgub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnavgub.128B"]
        pub fn V6_vnavgub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddubh` intrinsic; known as `__builtin_HEXAGON_V6_vaddubh` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubh"]
        pub fn V6_vaddubh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddubh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddubh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddubh.128B"]
        pub fn V6_vaddubh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsububh` intrinsic; known as `__builtin_HEXAGON_V6_vsububh` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububh"]
        pub fn V6_vsububh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsububh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsububh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsububh.128B"]
        pub fn V6_vsububh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vaddhw` intrinsic; known as `__builtin_HEXAGON_V6_vaddhw` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhw"]
        pub fn V6_vaddhw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vaddhw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vaddhw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vaddhw.128B"]
        pub fn V6_vaddhw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubhw` intrinsic; known as `__builtin_HEXAGON_V6_vsubhw` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhw"]
        pub fn V6_vsubhw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubhw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubhw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubhw.128B"]
        pub fn V6_vsubhw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vadduhw` intrinsic; known as `__builtin_HEXAGON_V6_vadduhw` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhw"]
        pub fn V6_vadduhw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vadduhw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vadduhw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vadduhw.128B"]
        pub fn V6_vadduhw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vsubuhw` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhw` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhw"]
        pub fn V6_vsubuhw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsubuhw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsubuhw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsubuhw.128B"]
        pub fn V6_vsubuhw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vd0` intrinsic; known as `__builtin_HEXAGON_V6_vd0` in GCC.
        #[link_name = "llvm.hexagon.V6.vd0"]
        pub fn V6_vd0() -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vd0.128B` intrinsic; known as `__builtin_HEXAGON_V6_vd0_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vd0.128B"]
        pub fn V6_vd0_128B() -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsh` intrinsic; known as `__builtin_HEXAGON_V6_vabsh` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsh"]
        pub fn V6_vabsh(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsh.128B"]
        pub fn V6_vabsh_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsh.sat` intrinsic; known as `__builtin_HEXAGON_V6_vabsh_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsh.sat"]
        pub fn V6_vabsh_sat(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsh.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsh_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsh.sat.128B"]
        pub fn V6_vabsh_sat_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsw` intrinsic; known as `__builtin_HEXAGON_V6_vabsw` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsw"]
        pub fn V6_vabsw(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsw.128B"]
        pub fn V6_vabsw_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vabsw.sat` intrinsic; known as `__builtin_HEXAGON_V6_vabsw_sat` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsw.sat"]
        pub fn V6_vabsw_sat(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vabsw.sat.128B` intrinsic; known as `__builtin_HEXAGON_V6_vabsw_sat_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vabsw.sat.128B"]
        pub fn V6_vabsw_sat_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybv` intrinsic; known as `__builtin_HEXAGON_V6_vmpybv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybv"]
        pub fn V6_vmpybv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybv.128B"]
        pub fn V6_vmpybv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpybv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpybv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybv.acc"]
        pub fn V6_vmpybv_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybv.acc.128B"]
        pub fn V6_vmpybv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyubv` intrinsic; known as `__builtin_HEXAGON_V6_vmpyubv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyubv"]
        pub fn V6_vmpyubv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyubv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyubv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyubv.128B"]
        pub fn V6_vmpyubv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyubv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyubv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyubv.acc"]
        pub fn V6_vmpyubv_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyubv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyubv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyubv.acc.128B"]
        pub fn V6_vmpyubv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpybusv` intrinsic; known as `__builtin_HEXAGON_V6_vmpybusv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybusv"]
        pub fn V6_vmpybusv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybusv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybusv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybusv.128B"]
        pub fn V6_vmpybusv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpybusv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpybusv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybusv.acc"]
        pub fn V6_vmpybusv_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybusv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybusv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybusv.acc.128B"]
        pub fn V6_vmpybusv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpabusv` intrinsic; known as `__builtin_HEXAGON_V6_vmpabusv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabusv"]
        pub fn V6_vmpabusv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpabusv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpabusv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabusv.128B"]
        pub fn V6_vmpabusv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpabuuv` intrinsic; known as `__builtin_HEXAGON_V6_vmpabuuv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabuuv"]
        pub fn V6_vmpabuuv(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpabuuv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpabuuv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabuuv.128B"]
        pub fn V6_vmpabuuv_128B(a: ::simdty::i32x64, b: ::simdty::i32x64) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhv` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhv"]
        pub fn V6_vmpyhv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhv.128B"]
        pub fn V6_vmpyhv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhv.acc"]
        pub fn V6_vmpyhv_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhv.acc.128B"]
        pub fn V6_vmpyhv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyuhv` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuhv` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuhv"]
        pub fn V6_vmpyuhv(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyuhv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuhv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuhv.128B"]
        pub fn V6_vmpyuhv_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyuhv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuhv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuhv.acc"]
        pub fn V6_vmpyuhv_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyuhv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuhv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuhv.acc.128B"]
        pub fn V6_vmpyuhv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhvsrs` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhvsrs` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhvsrs"]
        pub fn V6_vmpyhvsrs(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyhvsrs.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhvsrs_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhvsrs.128B"]
        pub fn V6_vmpyhvsrs_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhus` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhus` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhus"]
        pub fn V6_vmpyhus(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhus.128B"]
        pub fn V6_vmpyhus_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhus.acc"]
        pub fn V6_vmpyhus_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhus.acc.128B"]
        pub fn V6_vmpyhus_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyih` intrinsic; known as `__builtin_HEXAGON_V6_vmpyih` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyih"]
        pub fn V6_vmpyih(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyih.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyih_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyih.128B"]
        pub fn V6_vmpyih_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyih.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyih_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyih.acc"]
        pub fn V6_vmpyih_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyih.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyih_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyih.acc.128B"]
        pub fn V6_vmpyih_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyewuh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyewuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyewuh"]
        pub fn V6_vmpyewuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyewuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyewuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyewuh.128B"]
        pub fn V6_vmpyewuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyowh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh"]
        pub fn V6_vmpyowh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyowh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.128B"]
        pub fn V6_vmpyowh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyowh.rnd` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_rnd` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.rnd"]
        pub fn V6_vmpyowh_rnd(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyowh.rnd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_rnd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.rnd.128B"]
        pub fn V6_vmpyowh_rnd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyowh.sacc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_sacc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.sacc"]
        pub fn V6_vmpyowh_sacc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyowh.sacc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_sacc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.sacc.128B"]
        pub fn V6_vmpyowh_sacc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyowh.rnd.sacc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_rnd_sacc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.rnd.sacc"]
        pub fn V6_vmpyowh_rnd_sacc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyowh.rnd.sacc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyowh_rnd_sacc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyowh.rnd.sacc.128B"]
        pub fn V6_vmpyowh_rnd_sacc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyieoh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyieoh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyieoh"]
        pub fn V6_vmpyieoh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyieoh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyieoh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyieoh.128B"]
        pub fn V6_vmpyieoh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiewuh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewuh"]
        pub fn V6_vmpyiewuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiewuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewuh.128B"]
        pub fn V6_vmpyiewuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiowh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiowh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiowh"]
        pub fn V6_vmpyiowh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiowh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiowh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiowh.128B"]
        pub fn V6_vmpyiowh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiewh.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewh_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewh.acc"]
        pub fn V6_vmpyiewh_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiewh.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewh_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewh.acc.128B"]
        pub fn V6_vmpyiewh_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiewuh.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewuh_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewuh.acc"]
        pub fn V6_vmpyiewuh_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiewuh.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiewuh_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiewuh.acc.128B"]
        pub fn V6_vmpyiewuh_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyub` intrinsic; known as `__builtin_HEXAGON_V6_vmpyub` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyub"]
        pub fn V6_vmpyub(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyub.128B"]
        pub fn V6_vmpyub_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyub.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyub_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyub.acc"]
        pub fn V6_vmpyub_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyub.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyub_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyub.acc.128B"]
        pub fn V6_vmpyub_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpybus` intrinsic; known as `__builtin_HEXAGON_V6_vmpybus` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybus"]
        pub fn V6_vmpybus(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybus.128B"]
        pub fn V6_vmpybus_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpybus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpybus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybus.acc"]
        pub fn V6_vmpybus_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpybus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpybus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpybus.acc.128B"]
        pub fn V6_vmpybus_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpabus` intrinsic; known as `__builtin_HEXAGON_V6_vmpabus` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabus"]
        pub fn V6_vmpabus(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpabus.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpabus_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabus.128B"]
        pub fn V6_vmpabus_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpabus.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpabus_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabus.acc"]
        pub fn V6_vmpabus_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpabus.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpabus_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpabus.acc.128B"]
        pub fn V6_vmpabus_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpahb` intrinsic; known as `__builtin_HEXAGON_V6_vmpahb` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpahb"]
        pub fn V6_vmpahb(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpahb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpahb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpahb.128B"]
        pub fn V6_vmpahb_128B(a: ::simdty::i32x64, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpahb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpahb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpahb.acc"]
        pub fn V6_vmpahb_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpahb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpahb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpahb.acc.128B"]
        pub fn V6_vmpahb_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyh"]
        pub fn V6_vmpyh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyh.128B"]
        pub fn V6_vmpyh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhsat.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhsat_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhsat.acc"]
        pub fn V6_vmpyhsat_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhsat.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhsat_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhsat.acc.128B"]
        pub fn V6_vmpyhsat_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyhss` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhss` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhss"]
        pub fn V6_vmpyhss(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyhss.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhss_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhss.128B"]
        pub fn V6_vmpyhss_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyhsrs` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhsrs` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhsrs"]
        pub fn V6_vmpyhsrs(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyhsrs.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyhsrs_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyhsrs.128B"]
        pub fn V6_vmpyhsrs_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyuh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuh"]
        pub fn V6_vmpyuh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuh.128B"]
        pub fn V6_vmpyuh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyuh.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuh_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuh.acc"]
        pub fn V6_vmpyuh_acc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyuh.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyuh_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyuh.acc.128B"]
        pub fn V6_vmpyuh_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vmpyihb` intrinsic; known as `__builtin_HEXAGON_V6_vmpyihb` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyihb"]
        pub fn V6_vmpyihb(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyihb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyihb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyihb.128B"]
        pub fn V6_vmpyihb_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyihb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyihb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyihb.acc"]
        pub fn V6_vmpyihb_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyihb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyihb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyihb.acc.128B"]
        pub fn V6_vmpyihb_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiwb` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwb` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwb"]
        pub fn V6_vmpyiwb(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiwb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwb.128B"]
        pub fn V6_vmpyiwb_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiwb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwb.acc"]
        pub fn V6_vmpyiwb_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiwb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwb.acc.128B"]
        pub fn V6_vmpyiwb_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiwh` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwh"]
        pub fn V6_vmpyiwh(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiwh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwh.128B"]
        pub fn V6_vmpyiwh_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmpyiwh.acc` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwh_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwh.acc"]
        pub fn V6_vmpyiwh_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmpyiwh.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmpyiwh_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmpyiwh.acc.128B"]
        pub fn V6_vmpyiwh_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vand` intrinsic; known as `__builtin_HEXAGON_V6_vand` in GCC.
        #[link_name = "llvm.hexagon.V6.vand"]
        pub fn V6_vand(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vand.128B` intrinsic; known as `__builtin_HEXAGON_V6_vand_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vand.128B"]
        pub fn V6_vand_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vor` intrinsic; known as `__builtin_HEXAGON_V6_vor` in GCC.
        #[link_name = "llvm.hexagon.V6.vor"]
        pub fn V6_vor(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vor.128B` intrinsic; known as `__builtin_HEXAGON_V6_vor_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vor.128B"]
        pub fn V6_vor_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vxor` intrinsic; known as `__builtin_HEXAGON_V6_vxor` in GCC.
        #[link_name = "llvm.hexagon.V6.vxor"]
        pub fn V6_vxor(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vxor.128B` intrinsic; known as `__builtin_HEXAGON_V6_vxor_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vxor.128B"]
        pub fn V6_vxor_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnot` intrinsic; known as `__builtin_HEXAGON_V6_vnot` in GCC.
        #[link_name = "llvm.hexagon.V6.vnot"]
        pub fn V6_vnot(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnot.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnot_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnot.128B"]
        pub fn V6_vnot_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmaxub` intrinsic; known as `__builtin_HEXAGON_V6_vmaxub` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxub"]
        pub fn V6_vmaxub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmaxub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmaxub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxub.128B"]
        pub fn V6_vmaxub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vminub` intrinsic; known as `__builtin_HEXAGON_V6_vminub` in GCC.
        #[link_name = "llvm.hexagon.V6.vminub"]
        pub fn V6_vminub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vminub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vminub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vminub.128B"]
        pub fn V6_vminub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmaxuh` intrinsic; known as `__builtin_HEXAGON_V6_vmaxuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxuh"]
        pub fn V6_vmaxuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmaxuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmaxuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxuh.128B"]
        pub fn V6_vmaxuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vminuh` intrinsic; known as `__builtin_HEXAGON_V6_vminuh` in GCC.
        #[link_name = "llvm.hexagon.V6.vminuh"]
        pub fn V6_vminuh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vminuh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vminuh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vminuh.128B"]
        pub fn V6_vminuh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmaxh` intrinsic; known as `__builtin_HEXAGON_V6_vmaxh` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxh"]
        pub fn V6_vmaxh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmaxh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmaxh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxh.128B"]
        pub fn V6_vmaxh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vminh` intrinsic; known as `__builtin_HEXAGON_V6_vminh` in GCC.
        #[link_name = "llvm.hexagon.V6.vminh"]
        pub fn V6_vminh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vminh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vminh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vminh.128B"]
        pub fn V6_vminh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vmaxw` intrinsic; known as `__builtin_HEXAGON_V6_vmaxw` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxw"]
        pub fn V6_vmaxw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vmaxw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vmaxw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vmaxw.128B"]
        pub fn V6_vmaxw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vminw` intrinsic; known as `__builtin_HEXAGON_V6_vminw` in GCC.
        #[link_name = "llvm.hexagon.V6.vminw"]
        pub fn V6_vminw(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vminw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vminw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vminw.128B"]
        pub fn V6_vminw_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsathub` intrinsic; known as `__builtin_HEXAGON_V6_vsathub` in GCC.
        #[link_name = "llvm.hexagon.V6.vsathub"]
        pub fn V6_vsathub(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsathub.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsathub_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsathub.128B"]
        pub fn V6_vsathub_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vsatwh` intrinsic; known as `__builtin_HEXAGON_V6_vsatwh` in GCC.
        #[link_name = "llvm.hexagon.V6.vsatwh"]
        pub fn V6_vsatwh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vsatwh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vsatwh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vsatwh.128B"]
        pub fn V6_vsatwh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffeb` intrinsic; known as `__builtin_HEXAGON_V6_vshuffeb` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffeb"]
        pub fn V6_vshuffeb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshuffeb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshuffeb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffeb.128B"]
        pub fn V6_vshuffeb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffob` intrinsic; known as `__builtin_HEXAGON_V6_vshuffob` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffob"]
        pub fn V6_vshuffob(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshuffob.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshuffob_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffob.128B"]
        pub fn V6_vshuffob_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshufeh` intrinsic; known as `__builtin_HEXAGON_V6_vshufeh` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufeh"]
        pub fn V6_vshufeh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshufeh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshufeh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufeh.128B"]
        pub fn V6_vshufeh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshufoh` intrinsic; known as `__builtin_HEXAGON_V6_vshufoh` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoh"]
        pub fn V6_vshufoh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshufoh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshufoh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoh.128B"]
        pub fn V6_vshufoh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffvdd` intrinsic; known as `__builtin_HEXAGON_V6_vshuffvdd` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffvdd"]
        pub fn V6_vshuffvdd(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffvdd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshuffvdd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffvdd.128B"]
        pub fn V6_vshuffvdd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdealvdd` intrinsic; known as `__builtin_HEXAGON_V6_vdealvdd` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealvdd"]
        pub fn V6_vdealvdd(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdealvdd.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdealvdd_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealvdd.128B"]
        pub fn V6_vdealvdd_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vshufoeh` intrinsic; known as `__builtin_HEXAGON_V6_vshufoeh` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoeh"]
        pub fn V6_vshufoeh(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshufoeh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshufoeh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoeh.128B"]
        pub fn V6_vshufoeh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vshufoeb` intrinsic; known as `__builtin_HEXAGON_V6_vshufoeb` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoeb"]
        pub fn V6_vshufoeb(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshufoeb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshufoeb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshufoeb.128B"]
        pub fn V6_vshufoeb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdealh` intrinsic; known as `__builtin_HEXAGON_V6_vdealh` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealh"]
        pub fn V6_vdealh(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdealh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdealh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealh.128B"]
        pub fn V6_vdealh_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdealb` intrinsic; known as `__builtin_HEXAGON_V6_vdealb` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealb"]
        pub fn V6_vdealb(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdealb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdealb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealb.128B"]
        pub fn V6_vdealb_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vdealb4w` intrinsic; known as `__builtin_HEXAGON_V6_vdealb4w` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealb4w"]
        pub fn V6_vdealb4w(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdealb4w.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdealb4w_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdealb4w.128B"]
        pub fn V6_vdealb4w_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffh` intrinsic; known as `__builtin_HEXAGON_V6_vshuffh` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffh"]
        pub fn V6_vshuffh(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshuffh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshuffh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffh.128B"]
        pub fn V6_vshuffh_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vshuffb` intrinsic; known as `__builtin_HEXAGON_V6_vshuffb` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffb"]
        pub fn V6_vshuffb(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vshuffb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vshuffb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vshuffb.128B"]
        pub fn V6_vshuffb_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.extractw` intrinsic; known as `__builtin_HEXAGON_V6_extractw` in GCC.
        #[link_name = "llvm.hexagon.V6.extractw"]
        pub fn V6_extractw(a: ::simdty::i32x16, b: i32) -> i32;
        /// The `llvm.hexagon.V6.extractw.128B` intrinsic; known as `__builtin_HEXAGON_V6_extractw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.extractw.128B"]
        pub fn V6_extractw_128B(a: ::simdty::i32x32, b: i32) -> i32;
        /// The `llvm.hexagon.V6.vinsertwr` intrinsic; known as `__builtin_HEXAGON_V6_vinsertwr` in GCC.
        #[link_name = "llvm.hexagon.V6.vinsertwr"]
        pub fn V6_vinsertwr(a: ::simdty::i32x16, b: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vinsertwr.128B` intrinsic; known as `__builtin_HEXAGON_V6_vinsertwr_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vinsertwr.128B"]
        pub fn V6_vinsertwr_128B(a: ::simdty::i32x32, b: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.lvsplatw` intrinsic; known as `__builtin_HEXAGON_V6_lvsplatw` in GCC.
        #[link_name = "llvm.hexagon.V6.lvsplatw"]
        pub fn V6_lvsplatw(a: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.lvsplatw.128B` intrinsic; known as `__builtin_HEXAGON_V6_lvsplatw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.lvsplatw.128B"]
        pub fn V6_lvsplatw_128B(a: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vassign` intrinsic; known as `__builtin_HEXAGON_V6_vassign` in GCC.
        #[link_name = "llvm.hexagon.V6.vassign"]
        pub fn V6_vassign(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vassign.128B` intrinsic; known as `__builtin_HEXAGON_V6_vassign_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vassign.128B"]
        pub fn V6_vassign_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vcombine` intrinsic; known as `__builtin_HEXAGON_V6_vcombine` in GCC.
        #[link_name = "llvm.hexagon.V6.vcombine"]
        pub fn V6_vcombine(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vcombine.128B` intrinsic; known as `__builtin_HEXAGON_V6_vcombine_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vcombine.128B"]
        pub fn V6_vcombine_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vlutb` intrinsic; known as `__builtin_HEXAGON_V6_vlutb` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb"]
        pub fn V6_vlutb(a: ::simdty::i32x16, b: i64, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlutb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.128B"]
        pub fn V6_vlutb_128B(a: ::simdty::i32x32, b: i64, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutb.acc` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.acc"]
        pub fn V6_vlutb_acc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i64, d: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlutb.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.acc.128B"]
        pub fn V6_vlutb_acc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i64, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutb.dv` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_dv` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.dv"]
        pub fn V6_vlutb_dv(a: ::simdty::i32x32, b: i64, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutb.dv.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_dv_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.dv.128B"]
        pub fn V6_vlutb_dv_128B(a: ::simdty::i32x64, b: i64, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vlutb.dv.acc` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_dv_acc` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.dv.acc"]
        pub fn V6_vlutb_dv_acc(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i64, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutb.dv.acc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutb_dv_acc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutb.dv.acc.128B"]
        pub fn V6_vlutb_dv_acc_128B(a: ::simdty::i32x64, b: ::simdty::i32x64, c: i64, d: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vdelta` intrinsic; known as `__builtin_HEXAGON_V6_vdelta` in GCC.
        #[link_name = "llvm.hexagon.V6.vdelta"]
        pub fn V6_vdelta(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vdelta.128B` intrinsic; known as `__builtin_HEXAGON_V6_vdelta_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vdelta.128B"]
        pub fn V6_vdelta_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vrdelta` intrinsic; known as `__builtin_HEXAGON_V6_vrdelta` in GCC.
        #[link_name = "llvm.hexagon.V6.vrdelta"]
        pub fn V6_vrdelta(a: ::simdty::i32x16, b: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vrdelta.128B` intrinsic; known as `__builtin_HEXAGON_V6_vrdelta_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vrdelta.128B"]
        pub fn V6_vrdelta_128B(a: ::simdty::i32x32, b: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vcl0w` intrinsic; known as `__builtin_HEXAGON_V6_vcl0w` in GCC.
        #[link_name = "llvm.hexagon.V6.vcl0w"]
        pub fn V6_vcl0w(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vcl0w.128B` intrinsic; known as `__builtin_HEXAGON_V6_vcl0w_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vcl0w.128B"]
        pub fn V6_vcl0w_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vcl0h` intrinsic; known as `__builtin_HEXAGON_V6_vcl0h` in GCC.
        #[link_name = "llvm.hexagon.V6.vcl0h"]
        pub fn V6_vcl0h(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vcl0h.128B` intrinsic; known as `__builtin_HEXAGON_V6_vcl0h_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vcl0h.128B"]
        pub fn V6_vcl0h_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnormamtw` intrinsic; known as `__builtin_HEXAGON_V6_vnormamtw` in GCC.
        #[link_name = "llvm.hexagon.V6.vnormamtw"]
        pub fn V6_vnormamtw(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnormamtw.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnormamtw_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnormamtw.128B"]
        pub fn V6_vnormamtw_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vnormamth` intrinsic; known as `__builtin_HEXAGON_V6_vnormamth` in GCC.
        #[link_name = "llvm.hexagon.V6.vnormamth"]
        pub fn V6_vnormamth(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vnormamth.128B` intrinsic; known as `__builtin_HEXAGON_V6_vnormamth_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vnormamth.128B"]
        pub fn V6_vnormamth_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vpopcounth` intrinsic; known as `__builtin_HEXAGON_V6_vpopcounth` in GCC.
        #[link_name = "llvm.hexagon.V6.vpopcounth"]
        pub fn V6_vpopcounth(a: ::simdty::i32x16) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vpopcounth.128B` intrinsic; known as `__builtin_HEXAGON_V6_vpopcounth_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vpopcounth.128B"]
        pub fn V6_vpopcounth_128B(a: ::simdty::i32x32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutvvb` intrinsic; known as `__builtin_HEXAGON_V6_vlutvvb` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvvb"]
        pub fn V6_vlutvvb(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlutvvb.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutvvb_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvvb.128B"]
        pub fn V6_vlutvvb_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutvvb.oracc` intrinsic; known as `__builtin_HEXAGON_V6_vlutvvb_oracc` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvvb.oracc"]
        pub fn V6_vlutvvb_oracc(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i32) -> ::simdty::i32x16;
        /// The `llvm.hexagon.V6.vlutvvb.oracc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutvvb_oracc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvvb.oracc.128B"]
        pub fn V6_vlutvvb_oracc_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: ::simdty::i32x32, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutvwh` intrinsic; known as `__builtin_HEXAGON_V6_vlutvwh` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvwh"]
        pub fn V6_vlutvwh(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutvwh.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutvwh_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvwh.128B"]
        pub fn V6_vlutvwh_128B(a: ::simdty::i32x32, b: ::simdty::i32x32, c: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.V6.vlutvwh.oracc` intrinsic; known as `__builtin_HEXAGON_V6_vlutvwh_oracc` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvwh.oracc"]
        pub fn V6_vlutvwh_oracc(a: ::simdty::i32x32, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i32) -> ::simdty::i32x32;
        /// The `llvm.hexagon.V6.vlutvwh.oracc.128B` intrinsic; known as `__builtin_HEXAGON_V6_vlutvwh_oracc_128B` in GCC.
        #[link_name = "llvm.hexagon.V6.vlutvwh.oracc.128B"]
        pub fn V6_vlutvwh_oracc_128B(a: ::simdty::i32x64, b: ::simdty::i32x32, c: ::simdty::i32x32, d: i32) -> ::simdty::i32x64;
        /// The `llvm.hexagon.M6.vabsdiffb` intrinsic; known as `__builtin_HEXAGON_M6_vabsdiffb` in GCC.
        #[link_name = "llvm.hexagon.M6.vabsdiffb"]
        pub fn M6_vabsdiffb(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.M6.vabsdiffub` intrinsic; known as `__builtin_HEXAGON_M6_vabsdiffub` in GCC.
        #[link_name = "llvm.hexagon.M6.vabsdiffub"]
        pub fn M6_vabsdiffub(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S6.vsplatrbp` intrinsic; known as `__builtin_HEXAGON_S6_vsplatrbp` in GCC.
        #[link_name = "llvm.hexagon.S6.vsplatrbp"]
        pub fn S6_vsplatrbp(a: i32) -> i64;
        /// The `llvm.hexagon.S6.vtrunehb.ppp` intrinsic; known as `__builtin_HEXAGON_S6_vtrunehb_ppp` in GCC.
        #[link_name = "llvm.hexagon.S6.vtrunehb.ppp"]
        pub fn S6_vtrunehb_ppp(a: i64, b: i64) -> i64;
        /// The `llvm.hexagon.S6.vtrunohb.ppp` intrinsic; known as `__builtin_HEXAGON_S6_vtrunohb_ppp` in GCC.
        #[link_name = "llvm.hexagon.S6.vtrunohb.ppp"]
        pub fn S6_vtrunohb_ppp(a: i64, b: i64) -> i64;
    }
}
/// LLVM intrinsics for the mips architecture.
pub mod mips {
    extern {
        /// The `llvm.mips.addu.qb` intrinsic; known as `__builtin_mips_addu_qb` in GCC.
        #[link_name = "llvm.mips.addu.qb"]
        pub fn addu_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.addu.s.qb` intrinsic; known as `__builtin_mips_addu_s_qb` in GCC.
        #[link_name = "llvm.mips.addu.s.qb"]
        pub fn addu_s_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.subu.qb` intrinsic; known as `__builtin_mips_subu_qb` in GCC.
        #[link_name = "llvm.mips.subu.qb"]
        pub fn subu_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.subu.s.qb` intrinsic; known as `__builtin_mips_subu_s_qb` in GCC.
        #[link_name = "llvm.mips.subu.s.qb"]
        pub fn subu_s_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.madd` intrinsic; known as `__builtin_mips_madd` in GCC.
        #[link_name = "llvm.mips.madd"]
        pub fn madd(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.mips.maddu` intrinsic; known as `__builtin_mips_maddu` in GCC.
        #[link_name = "llvm.mips.maddu"]
        pub fn maddu(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.mips.msub` intrinsic; known as `__builtin_mips_msub` in GCC.
        #[link_name = "llvm.mips.msub"]
        pub fn msub(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.mips.msubu` intrinsic; known as `__builtin_mips_msubu` in GCC.
        #[link_name = "llvm.mips.msubu"]
        pub fn msubu(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.mips.addsc` intrinsic; known as `__builtin_mips_addsc` in GCC.
        #[link_name = "llvm.mips.addsc"]
        pub fn addsc(a: i32, b: i32) -> i32;
        /// The `llvm.mips.addwc` intrinsic; known as `__builtin_mips_addwc` in GCC.
        #[link_name = "llvm.mips.addwc"]
        pub fn addwc(a: i32, b: i32) -> i32;
        /// The `llvm.mips.modsub` intrinsic; known as `__builtin_mips_modsub` in GCC.
        #[link_name = "llvm.mips.modsub"]
        pub fn modsub(a: i32, b: i32) -> i32;
        /// The `llvm.mips.raddu.w.qb` intrinsic; known as `__builtin_mips_raddu_w_qb` in GCC.
        #[link_name = "llvm.mips.raddu.w.qb"]
        pub fn raddu_w_qb(a: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.shll.qb` intrinsic; known as `__builtin_mips_shll_qb` in GCC.
        #[link_name = "llvm.mips.shll.qb"]
        pub fn shll_qb(a: ::simdty::i8x4, b: i32) -> ::simdty::i8x4;
        /// The `llvm.mips.shrl.qb` intrinsic; known as `__builtin_mips_shrl_qb` in GCC.
        #[link_name = "llvm.mips.shrl.qb"]
        pub fn shrl_qb(a: ::simdty::i8x4, b: i32) -> ::simdty::i8x4;
        /// The `llvm.mips.shilo` intrinsic; known as `__builtin_mips_shilo` in GCC.
        #[link_name = "llvm.mips.shilo"]
        pub fn shilo(a: i64, b: i32) -> i64;
        /// The `llvm.mips.mult` intrinsic; known as `__builtin_mips_mult` in GCC.
        #[link_name = "llvm.mips.mult"]
        pub fn mult(a: i32, b: i32) -> i64;
        /// The `llvm.mips.multu` intrinsic; known as `__builtin_mips_multu` in GCC.
        #[link_name = "llvm.mips.multu"]
        pub fn multu(a: i32, b: i32) -> i64;
        /// The `llvm.mips.dpau.h.qbl` intrinsic; known as `__builtin_mips_dpau_h_qbl` in GCC.
        #[link_name = "llvm.mips.dpau.h.qbl"]
        pub fn dpau_h_qbl(a: i64, b: ::simdty::i8x4, c: ::simdty::i8x4) -> i64;
        /// The `llvm.mips.dpau.h.qbr` intrinsic; known as `__builtin_mips_dpau_h_qbr` in GCC.
        #[link_name = "llvm.mips.dpau.h.qbr"]
        pub fn dpau_h_qbr(a: i64, b: ::simdty::i8x4, c: ::simdty::i8x4) -> i64;
        /// The `llvm.mips.dpsu.h.qbl` intrinsic; known as `__builtin_mips_dpsu_h_qbl` in GCC.
        #[link_name = "llvm.mips.dpsu.h.qbl"]
        pub fn dpsu_h_qbl(a: i64, b: ::simdty::i8x4, c: ::simdty::i8x4) -> i64;
        /// The `llvm.mips.dpsu.h.qbr` intrinsic; known as `__builtin_mips_dpsu_h_qbr` in GCC.
        #[link_name = "llvm.mips.dpsu.h.qbr"]
        pub fn dpsu_h_qbr(a: i64, b: ::simdty::i8x4, c: ::simdty::i8x4) -> i64;
        /// The `llvm.mips.cmpu.eq.qb` intrinsic; known as `__builtin_mips_cmpu_eq_qb` in GCC.
        #[link_name = "llvm.mips.cmpu.eq.qb"]
        pub fn cmpu_eq_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ();
        /// The `llvm.mips.cmpu.lt.qb` intrinsic; known as `__builtin_mips_cmpu_lt_qb` in GCC.
        #[link_name = "llvm.mips.cmpu.lt.qb"]
        pub fn cmpu_lt_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ();
        /// The `llvm.mips.cmpu.le.qb` intrinsic; known as `__builtin_mips_cmpu_le_qb` in GCC.
        #[link_name = "llvm.mips.cmpu.le.qb"]
        pub fn cmpu_le_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ();
        /// The `llvm.mips.cmpgu.eq.qb` intrinsic; known as `__builtin_mips_cmpgu_eq_qb` in GCC.
        #[link_name = "llvm.mips.cmpgu.eq.qb"]
        pub fn cmpgu_eq_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.cmpgu.lt.qb` intrinsic; known as `__builtin_mips_cmpgu_lt_qb` in GCC.
        #[link_name = "llvm.mips.cmpgu.lt.qb"]
        pub fn cmpgu_lt_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.cmpgu.le.qb` intrinsic; known as `__builtin_mips_cmpgu_le_qb` in GCC.
        #[link_name = "llvm.mips.cmpgu.le.qb"]
        pub fn cmpgu_le_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.extr.s.h` intrinsic; known as `__builtin_mips_extr_s_h` in GCC.
        #[link_name = "llvm.mips.extr.s.h"]
        pub fn extr_s_h(a: i64, b: i32) -> i32;
        /// The `llvm.mips.extr.w` intrinsic; known as `__builtin_mips_extr_w` in GCC.
        #[link_name = "llvm.mips.extr.w"]
        pub fn extr_w(a: i64, b: i32) -> i32;
        /// The `llvm.mips.extr.rs.w` intrinsic; known as `__builtin_mips_extr_rs_w` in GCC.
        #[link_name = "llvm.mips.extr.rs.w"]
        pub fn extr_rs_w(a: i64, b: i32) -> i32;
        /// The `llvm.mips.extr.r.w` intrinsic; known as `__builtin_mips_extr_r_w` in GCC.
        #[link_name = "llvm.mips.extr.r.w"]
        pub fn extr_r_w(a: i64, b: i32) -> i32;
        /// The `llvm.mips.extp` intrinsic; known as `__builtin_mips_extp` in GCC.
        #[link_name = "llvm.mips.extp"]
        pub fn extp(a: i64, b: i32) -> i32;
        /// The `llvm.mips.extpdp` intrinsic; known as `__builtin_mips_extpdp` in GCC.
        #[link_name = "llvm.mips.extpdp"]
        pub fn extpdp(a: i64, b: i32) -> i32;
        /// The `llvm.mips.wrdsp` intrinsic; known as `__builtin_mips_wrdsp` in GCC.
        #[link_name = "llvm.mips.wrdsp"]
        pub fn wrdsp(a: i32, b: i32) -> ();
        /// The `llvm.mips.rddsp` intrinsic; known as `__builtin_mips_rddsp` in GCC.
        #[link_name = "llvm.mips.rddsp"]
        pub fn rddsp(a: i32) -> i32;
        /// The `llvm.mips.insv` intrinsic; known as `__builtin_mips_insv` in GCC.
        #[link_name = "llvm.mips.insv"]
        pub fn insv(a: i32, b: i32) -> i32;
        /// The `llvm.mips.bitrev` intrinsic; known as `__builtin_mips_bitrev` in GCC.
        #[link_name = "llvm.mips.bitrev"]
        pub fn bitrev(a: i32) -> i32;
        /// The `llvm.mips.repl.qb` intrinsic; known as `__builtin_mips_repl_qb` in GCC.
        #[link_name = "llvm.mips.repl.qb"]
        pub fn repl_qb(a: i32) -> ::simdty::i8x4;
        /// The `llvm.mips.pick.qb` intrinsic; known as `__builtin_mips_pick_qb` in GCC.
        #[link_name = "llvm.mips.pick.qb"]
        pub fn pick_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.mthlip` intrinsic; known as `__builtin_mips_mthlip` in GCC.
        #[link_name = "llvm.mips.mthlip"]
        pub fn mthlip(a: i64, b: i32) -> i64;
        /// The `llvm.mips.bposge32` intrinsic; known as `__builtin_mips_bposge32` in GCC.
        #[link_name = "llvm.mips.bposge32"]
        pub fn bposge32() -> i32;
        /// The `llvm.mips.lbux` intrinsic; known as `__builtin_mips_lbux` in GCC.
        #[link_name = "llvm.mips.lbux"]
        pub fn lbux(a: *mut i8, b: i32) -> i32;
        /// The `llvm.mips.lhx` intrinsic; known as `__builtin_mips_lhx` in GCC.
        #[link_name = "llvm.mips.lhx"]
        pub fn lhx(a: *mut i8, b: i32) -> i32;
        /// The `llvm.mips.lwx` intrinsic; known as `__builtin_mips_lwx` in GCC.
        #[link_name = "llvm.mips.lwx"]
        pub fn lwx(a: *mut i8, b: i32) -> i32;
        /// The `llvm.mips.addu.ph` intrinsic; known as `__builtin_mips_addu_ph` in GCC.
        #[link_name = "llvm.mips.addu.ph"]
        pub fn addu_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.addu.s.ph` intrinsic; known as `__builtin_mips_addu_s_ph` in GCC.
        #[link_name = "llvm.mips.addu.s.ph"]
        pub fn addu_s_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.adduh.qb` intrinsic; known as `__builtin_mips_adduh_qb` in GCC.
        #[link_name = "llvm.mips.adduh.qb"]
        pub fn adduh_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.adduh.r.qb` intrinsic; known as `__builtin_mips_adduh_r_qb` in GCC.
        #[link_name = "llvm.mips.adduh.r.qb"]
        pub fn adduh_r_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.append` intrinsic; known as `__builtin_mips_append` in GCC.
        #[link_name = "llvm.mips.append"]
        pub fn append(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.mips.balign` intrinsic; known as `__builtin_mips_balign` in GCC.
        #[link_name = "llvm.mips.balign"]
        pub fn balign(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.mips.cmpgdu.eq.qb` intrinsic; known as `__builtin_mips_cmpgdu_eq_qb` in GCC.
        #[link_name = "llvm.mips.cmpgdu.eq.qb"]
        pub fn cmpgdu_eq_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.cmpgdu.lt.qb` intrinsic; known as `__builtin_mips_cmpgdu_lt_qb` in GCC.
        #[link_name = "llvm.mips.cmpgdu.lt.qb"]
        pub fn cmpgdu_lt_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.cmpgdu.le.qb` intrinsic; known as `__builtin_mips_cmpgdu_le_qb` in GCC.
        #[link_name = "llvm.mips.cmpgdu.le.qb"]
        pub fn cmpgdu_le_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> i32;
        /// The `llvm.mips.dpa.w.ph` intrinsic; known as `__builtin_mips_dpa_w_ph` in GCC.
        #[link_name = "llvm.mips.dpa.w.ph"]
        pub fn dpa_w_ph(a: i64, b: ::simdty::i16x2, c: ::simdty::i16x2) -> i64;
        /// The `llvm.mips.dps.w.ph` intrinsic; known as `__builtin_mips_dps_w_ph` in GCC.
        #[link_name = "llvm.mips.dps.w.ph"]
        pub fn dps_w_ph(a: i64, b: ::simdty::i16x2, c: ::simdty::i16x2) -> i64;
        /// The `llvm.mips.dpax.w.ph` intrinsic; known as `__builtin_mips_dpax_w_ph` in GCC.
        #[link_name = "llvm.mips.dpax.w.ph"]
        pub fn dpax_w_ph(a: i64, b: ::simdty::i16x2, c: ::simdty::i16x2) -> i64;
        /// The `llvm.mips.dpsx.w.ph` intrinsic; known as `__builtin_mips_dpsx_w_ph` in GCC.
        #[link_name = "llvm.mips.dpsx.w.ph"]
        pub fn dpsx_w_ph(a: i64, b: ::simdty::i16x2, c: ::simdty::i16x2) -> i64;
        /// The `llvm.mips.mul.ph` intrinsic; known as `__builtin_mips_mul_ph` in GCC.
        #[link_name = "llvm.mips.mul.ph"]
        pub fn mul_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.mul.s.ph` intrinsic; known as `__builtin_mips_mul_s_ph` in GCC.
        #[link_name = "llvm.mips.mul.s.ph"]
        pub fn mul_s_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.mulsa.w.ph` intrinsic; known as `__builtin_mips_mulsa_w_ph` in GCC.
        #[link_name = "llvm.mips.mulsa.w.ph"]
        pub fn mulsa_w_ph(a: i64, b: ::simdty::i16x2, c: ::simdty::i16x2) -> i64;
        /// The `llvm.mips.precr.qb.ph` intrinsic; known as `__builtin_mips_precr_qb_ph` in GCC.
        #[link_name = "llvm.mips.precr.qb.ph"]
        pub fn precr_qb_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i8x4;
        /// The `llvm.mips.precr.sra.ph.w` intrinsic; known as `__builtin_mips_precr_sra_ph_w` in GCC.
        #[link_name = "llvm.mips.precr.sra.ph.w"]
        pub fn precr_sra_ph_w(a: i32, b: i32, c: i32) -> ::simdty::i16x2;
        /// The `llvm.mips.precr.sra.r.ph.w` intrinsic; known as `__builtin_mips_precr_sra_r_ph_w` in GCC.
        #[link_name = "llvm.mips.precr.sra.r.ph.w"]
        pub fn precr_sra_r_ph_w(a: i32, b: i32, c: i32) -> ::simdty::i16x2;
        /// The `llvm.mips.prepend` intrinsic; known as `__builtin_mips_prepend` in GCC.
        #[link_name = "llvm.mips.prepend"]
        pub fn prepend(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.mips.shra.qb` intrinsic; known as `__builtin_mips_shra_qb` in GCC.
        #[link_name = "llvm.mips.shra.qb"]
        pub fn shra_qb(a: ::simdty::i8x4, b: i32) -> ::simdty::i8x4;
        /// The `llvm.mips.shra.r.qb` intrinsic; known as `__builtin_mips_shra_r_qb` in GCC.
        #[link_name = "llvm.mips.shra.r.qb"]
        pub fn shra_r_qb(a: ::simdty::i8x4, b: i32) -> ::simdty::i8x4;
        /// The `llvm.mips.shrl.ph` intrinsic; known as `__builtin_mips_shrl_ph` in GCC.
        #[link_name = "llvm.mips.shrl.ph"]
        pub fn shrl_ph(a: ::simdty::i16x2, b: i32) -> ::simdty::i16x2;
        /// The `llvm.mips.subu.ph` intrinsic; known as `__builtin_mips_subu_ph` in GCC.
        #[link_name = "llvm.mips.subu.ph"]
        pub fn subu_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.subu.s.ph` intrinsic; known as `__builtin_mips_subu_s_ph` in GCC.
        #[link_name = "llvm.mips.subu.s.ph"]
        pub fn subu_s_ph(a: ::simdty::i16x2, b: ::simdty::i16x2) -> ::simdty::i16x2;
        /// The `llvm.mips.subuh.qb` intrinsic; known as `__builtin_mips_subuh_qb` in GCC.
        #[link_name = "llvm.mips.subuh.qb"]
        pub fn subuh_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.subuh.r.qb` intrinsic; known as `__builtin_mips_subuh_r_qb` in GCC.
        #[link_name = "llvm.mips.subuh.r.qb"]
        pub fn subuh_r_qb(a: ::simdty::i8x4, b: ::simdty::i8x4) -> ::simdty::i8x4;
        /// The `llvm.mips.add.a.b` intrinsic; known as `__builtin_msa_add_a_b` in GCC.
        #[link_name = "llvm.mips.add.a.b"]
        pub fn add_a_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.add.a.h` intrinsic; known as `__builtin_msa_add_a_h` in GCC.
        #[link_name = "llvm.mips.add.a.h"]
        pub fn add_a_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.add.a.w` intrinsic; known as `__builtin_msa_add_a_w` in GCC.
        #[link_name = "llvm.mips.add.a.w"]
        pub fn add_a_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.add.a.d` intrinsic; known as `__builtin_msa_add_a_d` in GCC.
        #[link_name = "llvm.mips.add.a.d"]
        pub fn add_a_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.adds.a.b` intrinsic; known as `__builtin_msa_adds_a_b` in GCC.
        #[link_name = "llvm.mips.adds.a.b"]
        pub fn adds_a_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.adds.a.h` intrinsic; known as `__builtin_msa_adds_a_h` in GCC.
        #[link_name = "llvm.mips.adds.a.h"]
        pub fn adds_a_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.adds.a.w` intrinsic; known as `__builtin_msa_adds_a_w` in GCC.
        #[link_name = "llvm.mips.adds.a.w"]
        pub fn adds_a_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.adds.a.d` intrinsic; known as `__builtin_msa_adds_a_d` in GCC.
        #[link_name = "llvm.mips.adds.a.d"]
        pub fn adds_a_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.adds.s.b` intrinsic; known as `__builtin_msa_adds_s_b` in GCC.
        #[link_name = "llvm.mips.adds.s.b"]
        pub fn adds_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.adds.s.h` intrinsic; known as `__builtin_msa_adds_s_h` in GCC.
        #[link_name = "llvm.mips.adds.s.h"]
        pub fn adds_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.adds.s.w` intrinsic; known as `__builtin_msa_adds_s_w` in GCC.
        #[link_name = "llvm.mips.adds.s.w"]
        pub fn adds_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.adds.s.d` intrinsic; known as `__builtin_msa_adds_s_d` in GCC.
        #[link_name = "llvm.mips.adds.s.d"]
        pub fn adds_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.adds.u.b` intrinsic; known as `__builtin_msa_adds_u_b` in GCC.
        #[link_name = "llvm.mips.adds.u.b"]
        pub fn adds_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.adds.u.h` intrinsic; known as `__builtin_msa_adds_u_h` in GCC.
        #[link_name = "llvm.mips.adds.u.h"]
        pub fn adds_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.adds.u.w` intrinsic; known as `__builtin_msa_adds_u_w` in GCC.
        #[link_name = "llvm.mips.adds.u.w"]
        pub fn adds_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.adds.u.d` intrinsic; known as `__builtin_msa_adds_u_d` in GCC.
        #[link_name = "llvm.mips.adds.u.d"]
        pub fn adds_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.addv.b` intrinsic; known as `__builtin_msa_addv_b` in GCC.
        #[link_name = "llvm.mips.addv.b"]
        pub fn addv_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.addv.h` intrinsic; known as `__builtin_msa_addv_h` in GCC.
        #[link_name = "llvm.mips.addv.h"]
        pub fn addv_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.addv.w` intrinsic; known as `__builtin_msa_addv_w` in GCC.
        #[link_name = "llvm.mips.addv.w"]
        pub fn addv_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.addv.d` intrinsic; known as `__builtin_msa_addv_d` in GCC.
        #[link_name = "llvm.mips.addv.d"]
        pub fn addv_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.addvi.b` intrinsic; known as `__builtin_msa_addvi_b` in GCC.
        #[link_name = "llvm.mips.addvi.b"]
        pub fn addvi_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.addvi.h` intrinsic; known as `__builtin_msa_addvi_h` in GCC.
        #[link_name = "llvm.mips.addvi.h"]
        pub fn addvi_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.addvi.w` intrinsic; known as `__builtin_msa_addvi_w` in GCC.
        #[link_name = "llvm.mips.addvi.w"]
        pub fn addvi_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.addvi.d` intrinsic; known as `__builtin_msa_addvi_d` in GCC.
        #[link_name = "llvm.mips.addvi.d"]
        pub fn addvi_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.and.v` intrinsic; known as `__builtin_msa_and_v` in GCC.
        #[link_name = "llvm.mips.and.v"]
        pub fn and_v(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.andi.b` intrinsic; known as `__builtin_msa_andi_b` in GCC.
        #[link_name = "llvm.mips.andi.b"]
        pub fn andi_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.asub.s.b` intrinsic; known as `__builtin_msa_asub_s_b` in GCC.
        #[link_name = "llvm.mips.asub.s.b"]
        pub fn asub_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.asub.s.h` intrinsic; known as `__builtin_msa_asub_s_h` in GCC.
        #[link_name = "llvm.mips.asub.s.h"]
        pub fn asub_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.asub.s.w` intrinsic; known as `__builtin_msa_asub_s_w` in GCC.
        #[link_name = "llvm.mips.asub.s.w"]
        pub fn asub_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.asub.s.d` intrinsic; known as `__builtin_msa_asub_s_d` in GCC.
        #[link_name = "llvm.mips.asub.s.d"]
        pub fn asub_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.asub.u.b` intrinsic; known as `__builtin_msa_asub_u_b` in GCC.
        #[link_name = "llvm.mips.asub.u.b"]
        pub fn asub_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.asub.u.h` intrinsic; known as `__builtin_msa_asub_u_h` in GCC.
        #[link_name = "llvm.mips.asub.u.h"]
        pub fn asub_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.asub.u.w` intrinsic; known as `__builtin_msa_asub_u_w` in GCC.
        #[link_name = "llvm.mips.asub.u.w"]
        pub fn asub_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.asub.u.d` intrinsic; known as `__builtin_msa_asub_u_d` in GCC.
        #[link_name = "llvm.mips.asub.u.d"]
        pub fn asub_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ave.s.b` intrinsic; known as `__builtin_msa_ave_s_b` in GCC.
        #[link_name = "llvm.mips.ave.s.b"]
        pub fn ave_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ave.s.h` intrinsic; known as `__builtin_msa_ave_s_h` in GCC.
        #[link_name = "llvm.mips.ave.s.h"]
        pub fn ave_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ave.s.w` intrinsic; known as `__builtin_msa_ave_s_w` in GCC.
        #[link_name = "llvm.mips.ave.s.w"]
        pub fn ave_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ave.s.d` intrinsic; known as `__builtin_msa_ave_s_d` in GCC.
        #[link_name = "llvm.mips.ave.s.d"]
        pub fn ave_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ave.u.b` intrinsic; known as `__builtin_msa_ave_u_b` in GCC.
        #[link_name = "llvm.mips.ave.u.b"]
        pub fn ave_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ave.u.h` intrinsic; known as `__builtin_msa_ave_u_h` in GCC.
        #[link_name = "llvm.mips.ave.u.h"]
        pub fn ave_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ave.u.w` intrinsic; known as `__builtin_msa_ave_u_w` in GCC.
        #[link_name = "llvm.mips.ave.u.w"]
        pub fn ave_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ave.u.d` intrinsic; known as `__builtin_msa_ave_u_d` in GCC.
        #[link_name = "llvm.mips.ave.u.d"]
        pub fn ave_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.aver.s.b` intrinsic; known as `__builtin_msa_aver_s_b` in GCC.
        #[link_name = "llvm.mips.aver.s.b"]
        pub fn aver_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.aver.s.h` intrinsic; known as `__builtin_msa_aver_s_h` in GCC.
        #[link_name = "llvm.mips.aver.s.h"]
        pub fn aver_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.aver.s.w` intrinsic; known as `__builtin_msa_aver_s_w` in GCC.
        #[link_name = "llvm.mips.aver.s.w"]
        pub fn aver_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.aver.s.d` intrinsic; known as `__builtin_msa_aver_s_d` in GCC.
        #[link_name = "llvm.mips.aver.s.d"]
        pub fn aver_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.aver.u.b` intrinsic; known as `__builtin_msa_aver_u_b` in GCC.
        #[link_name = "llvm.mips.aver.u.b"]
        pub fn aver_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.aver.u.h` intrinsic; known as `__builtin_msa_aver_u_h` in GCC.
        #[link_name = "llvm.mips.aver.u.h"]
        pub fn aver_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.aver.u.w` intrinsic; known as `__builtin_msa_aver_u_w` in GCC.
        #[link_name = "llvm.mips.aver.u.w"]
        pub fn aver_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.aver.u.d` intrinsic; known as `__builtin_msa_aver_u_d` in GCC.
        #[link_name = "llvm.mips.aver.u.d"]
        pub fn aver_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.bclr.b` intrinsic; known as `__builtin_msa_bclr_b` in GCC.
        #[link_name = "llvm.mips.bclr.b"]
        pub fn bclr_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bclr.h` intrinsic; known as `__builtin_msa_bclr_h` in GCC.
        #[link_name = "llvm.mips.bclr.h"]
        pub fn bclr_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.bclr.w` intrinsic; known as `__builtin_msa_bclr_w` in GCC.
        #[link_name = "llvm.mips.bclr.w"]
        pub fn bclr_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.bclr.d` intrinsic; known as `__builtin_msa_bclr_d` in GCC.
        #[link_name = "llvm.mips.bclr.d"]
        pub fn bclr_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.bclri.b` intrinsic; known as `__builtin_msa_bclri_b` in GCC.
        #[link_name = "llvm.mips.bclri.b"]
        pub fn bclri_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bclri.h` intrinsic; known as `__builtin_msa_bclri_h` in GCC.
        #[link_name = "llvm.mips.bclri.h"]
        pub fn bclri_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.bclri.w` intrinsic; known as `__builtin_msa_bclri_w` in GCC.
        #[link_name = "llvm.mips.bclri.w"]
        pub fn bclri_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.bclri.d` intrinsic; known as `__builtin_msa_bclri_d` in GCC.
        #[link_name = "llvm.mips.bclri.d"]
        pub fn bclri_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.binsl.b` intrinsic; known as `__builtin_msa_binsl_b` in GCC.
        #[link_name = "llvm.mips.binsl.b"]
        pub fn binsl_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.binsl.h` intrinsic; known as `__builtin_msa_binsl_h` in GCC.
        #[link_name = "llvm.mips.binsl.h"]
        pub fn binsl_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.binsl.w` intrinsic; known as `__builtin_msa_binsl_w` in GCC.
        #[link_name = "llvm.mips.binsl.w"]
        pub fn binsl_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.binsl.d` intrinsic; known as `__builtin_msa_binsl_d` in GCC.
        #[link_name = "llvm.mips.binsl.d"]
        pub fn binsl_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.binsli.b` intrinsic; known as `__builtin_msa_binsli_b` in GCC.
        #[link_name = "llvm.mips.binsli.b"]
        pub fn binsli_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.binsli.h` intrinsic; known as `__builtin_msa_binsli_h` in GCC.
        #[link_name = "llvm.mips.binsli.h"]
        pub fn binsli_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.binsli.w` intrinsic; known as `__builtin_msa_binsli_w` in GCC.
        #[link_name = "llvm.mips.binsli.w"]
        pub fn binsli_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.binsli.d` intrinsic; known as `__builtin_msa_binsli_d` in GCC.
        #[link_name = "llvm.mips.binsli.d"]
        pub fn binsli_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.binsr.b` intrinsic; known as `__builtin_msa_binsr_b` in GCC.
        #[link_name = "llvm.mips.binsr.b"]
        pub fn binsr_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.binsr.h` intrinsic; known as `__builtin_msa_binsr_h` in GCC.
        #[link_name = "llvm.mips.binsr.h"]
        pub fn binsr_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.binsr.w` intrinsic; known as `__builtin_msa_binsr_w` in GCC.
        #[link_name = "llvm.mips.binsr.w"]
        pub fn binsr_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.binsr.d` intrinsic; known as `__builtin_msa_binsr_d` in GCC.
        #[link_name = "llvm.mips.binsr.d"]
        pub fn binsr_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.binsri.b` intrinsic; known as `__builtin_msa_binsri_b` in GCC.
        #[link_name = "llvm.mips.binsri.b"]
        pub fn binsri_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.binsri.h` intrinsic; known as `__builtin_msa_binsri_h` in GCC.
        #[link_name = "llvm.mips.binsri.h"]
        pub fn binsri_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.binsri.w` intrinsic; known as `__builtin_msa_binsri_w` in GCC.
        #[link_name = "llvm.mips.binsri.w"]
        pub fn binsri_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.binsri.d` intrinsic; known as `__builtin_msa_binsri_d` in GCC.
        #[link_name = "llvm.mips.binsri.d"]
        pub fn binsri_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.bmnz.v` intrinsic; known as `__builtin_msa_bmnz_v` in GCC.
        #[link_name = "llvm.mips.bmnz.v"]
        pub fn bmnz_v(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bmnzi.b` intrinsic; known as `__builtin_msa_bmnzi_b` in GCC.
        #[link_name = "llvm.mips.bmnzi.b"]
        pub fn bmnzi_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bmz.v` intrinsic; known as `__builtin_msa_bmz_v` in GCC.
        #[link_name = "llvm.mips.bmz.v"]
        pub fn bmz_v(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bmzi.b` intrinsic; known as `__builtin_msa_bmzi_b` in GCC.
        #[link_name = "llvm.mips.bmzi.b"]
        pub fn bmzi_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bneg.b` intrinsic; known as `__builtin_msa_bneg_b` in GCC.
        #[link_name = "llvm.mips.bneg.b"]
        pub fn bneg_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bneg.h` intrinsic; known as `__builtin_msa_bneg_h` in GCC.
        #[link_name = "llvm.mips.bneg.h"]
        pub fn bneg_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.bneg.w` intrinsic; known as `__builtin_msa_bneg_w` in GCC.
        #[link_name = "llvm.mips.bneg.w"]
        pub fn bneg_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.bneg.d` intrinsic; known as `__builtin_msa_bneg_d` in GCC.
        #[link_name = "llvm.mips.bneg.d"]
        pub fn bneg_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.bnegi.b` intrinsic; known as `__builtin_msa_bnegi_b` in GCC.
        #[link_name = "llvm.mips.bnegi.b"]
        pub fn bnegi_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bnegi.h` intrinsic; known as `__builtin_msa_bnegi_h` in GCC.
        #[link_name = "llvm.mips.bnegi.h"]
        pub fn bnegi_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.bnegi.w` intrinsic; known as `__builtin_msa_bnegi_w` in GCC.
        #[link_name = "llvm.mips.bnegi.w"]
        pub fn bnegi_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.bnegi.d` intrinsic; known as `__builtin_msa_bnegi_d` in GCC.
        #[link_name = "llvm.mips.bnegi.d"]
        pub fn bnegi_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.bnz.b` intrinsic; known as `__builtin_msa_bnz_b` in GCC.
        #[link_name = "llvm.mips.bnz.b"]
        pub fn bnz_b(a: ::simdty::i8x16) -> i32;
        /// The `llvm.mips.bnz.h` intrinsic; known as `__builtin_msa_bnz_h` in GCC.
        #[link_name = "llvm.mips.bnz.h"]
        pub fn bnz_h(a: ::simdty::i16x8) -> i32;
        /// The `llvm.mips.bnz.w` intrinsic; known as `__builtin_msa_bnz_w` in GCC.
        #[link_name = "llvm.mips.bnz.w"]
        pub fn bnz_w(a: ::simdty::i32x4) -> i32;
        /// The `llvm.mips.bnz.d` intrinsic; known as `__builtin_msa_bnz_d` in GCC.
        #[link_name = "llvm.mips.bnz.d"]
        pub fn bnz_d(a: ::simdty::i64x2) -> i32;
        /// The `llvm.mips.bnz.v` intrinsic; known as `__builtin_msa_bnz_v` in GCC.
        #[link_name = "llvm.mips.bnz.v"]
        pub fn bnz_v(a: ::simdty::i8x16) -> i32;
        /// The `llvm.mips.bsel.v` intrinsic; known as `__builtin_msa_bsel_v` in GCC.
        #[link_name = "llvm.mips.bsel.v"]
        pub fn bsel_v(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bseli.b` intrinsic; known as `__builtin_msa_bseli_b` in GCC.
        #[link_name = "llvm.mips.bseli.b"]
        pub fn bseli_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bset.b` intrinsic; known as `__builtin_msa_bset_b` in GCC.
        #[link_name = "llvm.mips.bset.b"]
        pub fn bset_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.bset.h` intrinsic; known as `__builtin_msa_bset_h` in GCC.
        #[link_name = "llvm.mips.bset.h"]
        pub fn bset_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.bset.w` intrinsic; known as `__builtin_msa_bset_w` in GCC.
        #[link_name = "llvm.mips.bset.w"]
        pub fn bset_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.bset.d` intrinsic; known as `__builtin_msa_bset_d` in GCC.
        #[link_name = "llvm.mips.bset.d"]
        pub fn bset_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.bseti.b` intrinsic; known as `__builtin_msa_bseti_b` in GCC.
        #[link_name = "llvm.mips.bseti.b"]
        pub fn bseti_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.bseti.h` intrinsic; known as `__builtin_msa_bseti_h` in GCC.
        #[link_name = "llvm.mips.bseti.h"]
        pub fn bseti_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.bseti.w` intrinsic; known as `__builtin_msa_bseti_w` in GCC.
        #[link_name = "llvm.mips.bseti.w"]
        pub fn bseti_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.bseti.d` intrinsic; known as `__builtin_msa_bseti_d` in GCC.
        #[link_name = "llvm.mips.bseti.d"]
        pub fn bseti_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.bz.b` intrinsic; known as `__builtin_msa_bz_b` in GCC.
        #[link_name = "llvm.mips.bz.b"]
        pub fn bz_b(a: ::simdty::i8x16) -> i32;
        /// The `llvm.mips.bz.h` intrinsic; known as `__builtin_msa_bz_h` in GCC.
        #[link_name = "llvm.mips.bz.h"]
        pub fn bz_h(a: ::simdty::i16x8) -> i32;
        /// The `llvm.mips.bz.w` intrinsic; known as `__builtin_msa_bz_w` in GCC.
        #[link_name = "llvm.mips.bz.w"]
        pub fn bz_w(a: ::simdty::i32x4) -> i32;
        /// The `llvm.mips.bz.d` intrinsic; known as `__builtin_msa_bz_d` in GCC.
        #[link_name = "llvm.mips.bz.d"]
        pub fn bz_d(a: ::simdty::i64x2) -> i32;
        /// The `llvm.mips.bz.v` intrinsic; known as `__builtin_msa_bz_v` in GCC.
        #[link_name = "llvm.mips.bz.v"]
        pub fn bz_v(a: ::simdty::i8x16) -> i32;
        /// The `llvm.mips.ceq.b` intrinsic; known as `__builtin_msa_ceq_b` in GCC.
        #[link_name = "llvm.mips.ceq.b"]
        pub fn ceq_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ceq.h` intrinsic; known as `__builtin_msa_ceq_h` in GCC.
        #[link_name = "llvm.mips.ceq.h"]
        pub fn ceq_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ceq.w` intrinsic; known as `__builtin_msa_ceq_w` in GCC.
        #[link_name = "llvm.mips.ceq.w"]
        pub fn ceq_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ceq.d` intrinsic; known as `__builtin_msa_ceq_d` in GCC.
        #[link_name = "llvm.mips.ceq.d"]
        pub fn ceq_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ceqi.b` intrinsic; known as `__builtin_msa_ceqi_b` in GCC.
        #[link_name = "llvm.mips.ceqi.b"]
        pub fn ceqi_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.ceqi.h` intrinsic; known as `__builtin_msa_ceqi_h` in GCC.
        #[link_name = "llvm.mips.ceqi.h"]
        pub fn ceqi_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.ceqi.w` intrinsic; known as `__builtin_msa_ceqi_w` in GCC.
        #[link_name = "llvm.mips.ceqi.w"]
        pub fn ceqi_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.ceqi.d` intrinsic; known as `__builtin_msa_ceqi_d` in GCC.
        #[link_name = "llvm.mips.ceqi.d"]
        pub fn ceqi_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.cfcmsa` intrinsic; known as `__builtin_msa_cfcmsa` in GCC.
        #[link_name = "llvm.mips.cfcmsa"]
        pub fn cfcmsa(a: i32) -> i32;
        /// The `llvm.mips.cle.s.b` intrinsic; known as `__builtin_msa_cle_s_b` in GCC.
        #[link_name = "llvm.mips.cle.s.b"]
        pub fn cle_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.cle.s.h` intrinsic; known as `__builtin_msa_cle_s_h` in GCC.
        #[link_name = "llvm.mips.cle.s.h"]
        pub fn cle_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.cle.s.w` intrinsic; known as `__builtin_msa_cle_s_w` in GCC.
        #[link_name = "llvm.mips.cle.s.w"]
        pub fn cle_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.cle.s.d` intrinsic; known as `__builtin_msa_cle_s_d` in GCC.
        #[link_name = "llvm.mips.cle.s.d"]
        pub fn cle_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.cle.u.b` intrinsic; known as `__builtin_msa_cle_u_b` in GCC.
        #[link_name = "llvm.mips.cle.u.b"]
        pub fn cle_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.cle.u.h` intrinsic; known as `__builtin_msa_cle_u_h` in GCC.
        #[link_name = "llvm.mips.cle.u.h"]
        pub fn cle_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.cle.u.w` intrinsic; known as `__builtin_msa_cle_u_w` in GCC.
        #[link_name = "llvm.mips.cle.u.w"]
        pub fn cle_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.cle.u.d` intrinsic; known as `__builtin_msa_cle_u_d` in GCC.
        #[link_name = "llvm.mips.cle.u.d"]
        pub fn cle_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.clei.s.b` intrinsic; known as `__builtin_msa_clei_s_b` in GCC.
        #[link_name = "llvm.mips.clei.s.b"]
        pub fn clei_s_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.clei.s.h` intrinsic; known as `__builtin_msa_clei_s_h` in GCC.
        #[link_name = "llvm.mips.clei.s.h"]
        pub fn clei_s_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.clei.s.w` intrinsic; known as `__builtin_msa_clei_s_w` in GCC.
        #[link_name = "llvm.mips.clei.s.w"]
        pub fn clei_s_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.clei.s.d` intrinsic; known as `__builtin_msa_clei_s_d` in GCC.
        #[link_name = "llvm.mips.clei.s.d"]
        pub fn clei_s_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.clei.u.b` intrinsic; known as `__builtin_msa_clei_u_b` in GCC.
        #[link_name = "llvm.mips.clei.u.b"]
        pub fn clei_u_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.clei.u.h` intrinsic; known as `__builtin_msa_clei_u_h` in GCC.
        #[link_name = "llvm.mips.clei.u.h"]
        pub fn clei_u_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.clei.u.w` intrinsic; known as `__builtin_msa_clei_u_w` in GCC.
        #[link_name = "llvm.mips.clei.u.w"]
        pub fn clei_u_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.clei.u.d` intrinsic; known as `__builtin_msa_clei_u_d` in GCC.
        #[link_name = "llvm.mips.clei.u.d"]
        pub fn clei_u_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.clt.s.b` intrinsic; known as `__builtin_msa_clt_s_b` in GCC.
        #[link_name = "llvm.mips.clt.s.b"]
        pub fn clt_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.clt.s.h` intrinsic; known as `__builtin_msa_clt_s_h` in GCC.
        #[link_name = "llvm.mips.clt.s.h"]
        pub fn clt_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.clt.s.w` intrinsic; known as `__builtin_msa_clt_s_w` in GCC.
        #[link_name = "llvm.mips.clt.s.w"]
        pub fn clt_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.clt.s.d` intrinsic; known as `__builtin_msa_clt_s_d` in GCC.
        #[link_name = "llvm.mips.clt.s.d"]
        pub fn clt_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.clt.u.b` intrinsic; known as `__builtin_msa_clt_u_b` in GCC.
        #[link_name = "llvm.mips.clt.u.b"]
        pub fn clt_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.clt.u.h` intrinsic; known as `__builtin_msa_clt_u_h` in GCC.
        #[link_name = "llvm.mips.clt.u.h"]
        pub fn clt_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.clt.u.w` intrinsic; known as `__builtin_msa_clt_u_w` in GCC.
        #[link_name = "llvm.mips.clt.u.w"]
        pub fn clt_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.clt.u.d` intrinsic; known as `__builtin_msa_clt_u_d` in GCC.
        #[link_name = "llvm.mips.clt.u.d"]
        pub fn clt_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.clti.s.b` intrinsic; known as `__builtin_msa_clti_s_b` in GCC.
        #[link_name = "llvm.mips.clti.s.b"]
        pub fn clti_s_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.clti.s.h` intrinsic; known as `__builtin_msa_clti_s_h` in GCC.
        #[link_name = "llvm.mips.clti.s.h"]
        pub fn clti_s_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.clti.s.w` intrinsic; known as `__builtin_msa_clti_s_w` in GCC.
        #[link_name = "llvm.mips.clti.s.w"]
        pub fn clti_s_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.clti.s.d` intrinsic; known as `__builtin_msa_clti_s_d` in GCC.
        #[link_name = "llvm.mips.clti.s.d"]
        pub fn clti_s_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.clti.u.b` intrinsic; known as `__builtin_msa_clti_u_b` in GCC.
        #[link_name = "llvm.mips.clti.u.b"]
        pub fn clti_u_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.clti.u.h` intrinsic; known as `__builtin_msa_clti_u_h` in GCC.
        #[link_name = "llvm.mips.clti.u.h"]
        pub fn clti_u_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.clti.u.w` intrinsic; known as `__builtin_msa_clti_u_w` in GCC.
        #[link_name = "llvm.mips.clti.u.w"]
        pub fn clti_u_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.clti.u.d` intrinsic; known as `__builtin_msa_clti_u_d` in GCC.
        #[link_name = "llvm.mips.clti.u.d"]
        pub fn clti_u_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.copy.s.b` intrinsic; known as `__builtin_msa_copy_s_b` in GCC.
        #[link_name = "llvm.mips.copy.s.b"]
        pub fn copy_s_b(a: ::simdty::i8x16, b: i32) -> i32;
        /// The `llvm.mips.copy.s.h` intrinsic; known as `__builtin_msa_copy_s_h` in GCC.
        #[link_name = "llvm.mips.copy.s.h"]
        pub fn copy_s_h(a: ::simdty::i16x8, b: i32) -> i32;
        /// The `llvm.mips.copy.s.w` intrinsic; known as `__builtin_msa_copy_s_w` in GCC.
        #[link_name = "llvm.mips.copy.s.w"]
        pub fn copy_s_w(a: ::simdty::i32x4, b: i32) -> i32;
        /// The `llvm.mips.copy.s.d` intrinsic; known as `__builtin_msa_copy_s_d` in GCC.
        #[link_name = "llvm.mips.copy.s.d"]
        pub fn copy_s_d(a: ::simdty::i64x2, b: i32) -> i64;
        /// The `llvm.mips.copy.u.b` intrinsic; known as `__builtin_msa_copy_u_b` in GCC.
        #[link_name = "llvm.mips.copy.u.b"]
        pub fn copy_u_b(a: ::simdty::i8x16, b: i32) -> i32;
        /// The `llvm.mips.copy.u.h` intrinsic; known as `__builtin_msa_copy_u_h` in GCC.
        #[link_name = "llvm.mips.copy.u.h"]
        pub fn copy_u_h(a: ::simdty::i16x8, b: i32) -> i32;
        /// The `llvm.mips.copy.u.w` intrinsic; known as `__builtin_msa_copy_u_w` in GCC.
        #[link_name = "llvm.mips.copy.u.w"]
        pub fn copy_u_w(a: ::simdty::i32x4, b: i32) -> i32;
        /// The `llvm.mips.copy.u.d` intrinsic; known as `__builtin_msa_copy_u_d` in GCC.
        #[link_name = "llvm.mips.copy.u.d"]
        pub fn copy_u_d(a: ::simdty::i64x2, b: i32) -> i64;
        /// The `llvm.mips.ctcmsa` intrinsic; known as `__builtin_msa_ctcmsa` in GCC.
        #[link_name = "llvm.mips.ctcmsa"]
        pub fn ctcmsa(a: i32, b: i32) -> ();
        /// The `llvm.mips.div.s.b` intrinsic; known as `__builtin_msa_div_s_b` in GCC.
        #[link_name = "llvm.mips.div.s.b"]
        pub fn div_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.div.s.h` intrinsic; known as `__builtin_msa_div_s_h` in GCC.
        #[link_name = "llvm.mips.div.s.h"]
        pub fn div_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.div.s.w` intrinsic; known as `__builtin_msa_div_s_w` in GCC.
        #[link_name = "llvm.mips.div.s.w"]
        pub fn div_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.div.s.d` intrinsic; known as `__builtin_msa_div_s_d` in GCC.
        #[link_name = "llvm.mips.div.s.d"]
        pub fn div_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.div.u.b` intrinsic; known as `__builtin_msa_div_u_b` in GCC.
        #[link_name = "llvm.mips.div.u.b"]
        pub fn div_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.div.u.h` intrinsic; known as `__builtin_msa_div_u_h` in GCC.
        #[link_name = "llvm.mips.div.u.h"]
        pub fn div_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.div.u.w` intrinsic; known as `__builtin_msa_div_u_w` in GCC.
        #[link_name = "llvm.mips.div.u.w"]
        pub fn div_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.div.u.d` intrinsic; known as `__builtin_msa_div_u_d` in GCC.
        #[link_name = "llvm.mips.div.u.d"]
        pub fn div_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.dlsa` intrinsic; known as `__builtin_mips_dlsa` in GCC.
        #[link_name = "llvm.mips.dlsa"]
        pub fn dlsa(a: i64, b: i64, c: i32) -> i64;
        /// The `llvm.mips.dotp.s.h` intrinsic; known as `__builtin_msa_dotp_s_h` in GCC.
        #[link_name = "llvm.mips.dotp.s.h"]
        pub fn dotp_s_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dotp.s.w` intrinsic; known as `__builtin_msa_dotp_s_w` in GCC.
        #[link_name = "llvm.mips.dotp.s.w"]
        pub fn dotp_s_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dotp.s.d` intrinsic; known as `__builtin_msa_dotp_s_d` in GCC.
        #[link_name = "llvm.mips.dotp.s.d"]
        pub fn dotp_s_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.dotp.u.h` intrinsic; known as `__builtin_msa_dotp_u_h` in GCC.
        #[link_name = "llvm.mips.dotp.u.h"]
        pub fn dotp_u_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dotp.u.w` intrinsic; known as `__builtin_msa_dotp_u_w` in GCC.
        #[link_name = "llvm.mips.dotp.u.w"]
        pub fn dotp_u_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dotp.u.d` intrinsic; known as `__builtin_msa_dotp_u_d` in GCC.
        #[link_name = "llvm.mips.dotp.u.d"]
        pub fn dotp_u_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.dpadd.s.h` intrinsic; known as `__builtin_msa_dpadd_s_h` in GCC.
        #[link_name = "llvm.mips.dpadd.s.h"]
        pub fn dpadd_s_h(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dpadd.s.w` intrinsic; known as `__builtin_msa_dpadd_s_w` in GCC.
        #[link_name = "llvm.mips.dpadd.s.w"]
        pub fn dpadd_s_w(a: ::simdty::i32x4, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dpadd.s.d` intrinsic; known as `__builtin_msa_dpadd_s_d` in GCC.
        #[link_name = "llvm.mips.dpadd.s.d"]
        pub fn dpadd_s_d(a: ::simdty::i64x2, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.dpadd.u.h` intrinsic; known as `__builtin_msa_dpadd_u_h` in GCC.
        #[link_name = "llvm.mips.dpadd.u.h"]
        pub fn dpadd_u_h(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dpadd.u.w` intrinsic; known as `__builtin_msa_dpadd_u_w` in GCC.
        #[link_name = "llvm.mips.dpadd.u.w"]
        pub fn dpadd_u_w(a: ::simdty::i32x4, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dpadd.u.d` intrinsic; known as `__builtin_msa_dpadd_u_d` in GCC.
        #[link_name = "llvm.mips.dpadd.u.d"]
        pub fn dpadd_u_d(a: ::simdty::i64x2, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.dpsub.s.h` intrinsic; known as `__builtin_msa_dpsub_s_h` in GCC.
        #[link_name = "llvm.mips.dpsub.s.h"]
        pub fn dpsub_s_h(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dpsub.s.w` intrinsic; known as `__builtin_msa_dpsub_s_w` in GCC.
        #[link_name = "llvm.mips.dpsub.s.w"]
        pub fn dpsub_s_w(a: ::simdty::i32x4, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dpsub.s.d` intrinsic; known as `__builtin_msa_dpsub_s_d` in GCC.
        #[link_name = "llvm.mips.dpsub.s.d"]
        pub fn dpsub_s_d(a: ::simdty::i64x2, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.dpsub.u.h` intrinsic; known as `__builtin_msa_dpsub_u_h` in GCC.
        #[link_name = "llvm.mips.dpsub.u.h"]
        pub fn dpsub_u_h(a: ::simdty::i16x8, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.dpsub.u.w` intrinsic; known as `__builtin_msa_dpsub_u_w` in GCC.
        #[link_name = "llvm.mips.dpsub.u.w"]
        pub fn dpsub_u_w(a: ::simdty::i32x4, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.dpsub.u.d` intrinsic; known as `__builtin_msa_dpsub_u_d` in GCC.
        #[link_name = "llvm.mips.dpsub.u.d"]
        pub fn dpsub_u_d(a: ::simdty::i64x2, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.fadd.w` intrinsic; known as `__builtin_msa_fadd_w` in GCC.
        #[link_name = "llvm.mips.fadd.w"]
        pub fn fadd_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fadd.d` intrinsic; known as `__builtin_msa_fadd_d` in GCC.
        #[link_name = "llvm.mips.fadd.d"]
        pub fn fadd_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fcaf.w` intrinsic; known as `__builtin_msa_fcaf_w` in GCC.
        #[link_name = "llvm.mips.fcaf.w"]
        pub fn fcaf_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcaf.d` intrinsic; known as `__builtin_msa_fcaf_d` in GCC.
        #[link_name = "llvm.mips.fcaf.d"]
        pub fn fcaf_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fceq.w` intrinsic; known as `__builtin_msa_fceq_w` in GCC.
        #[link_name = "llvm.mips.fceq.w"]
        pub fn fceq_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fceq.d` intrinsic; known as `__builtin_msa_fceq_d` in GCC.
        #[link_name = "llvm.mips.fceq.d"]
        pub fn fceq_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcle.w` intrinsic; known as `__builtin_msa_fcle_w` in GCC.
        #[link_name = "llvm.mips.fcle.w"]
        pub fn fcle_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcle.d` intrinsic; known as `__builtin_msa_fcle_d` in GCC.
        #[link_name = "llvm.mips.fcle.d"]
        pub fn fcle_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fclt.w` intrinsic; known as `__builtin_msa_fclt_w` in GCC.
        #[link_name = "llvm.mips.fclt.w"]
        pub fn fclt_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fclt.d` intrinsic; known as `__builtin_msa_fclt_d` in GCC.
        #[link_name = "llvm.mips.fclt.d"]
        pub fn fclt_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fclass.w` intrinsic; known as `__builtin_msa_fclass_w` in GCC.
        #[link_name = "llvm.mips.fclass.w"]
        pub fn fclass_w(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fclass.d` intrinsic; known as `__builtin_msa_fclass_d` in GCC.
        #[link_name = "llvm.mips.fclass.d"]
        pub fn fclass_d(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcne.w` intrinsic; known as `__builtin_msa_fcne_w` in GCC.
        #[link_name = "llvm.mips.fcne.w"]
        pub fn fcne_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcne.d` intrinsic; known as `__builtin_msa_fcne_d` in GCC.
        #[link_name = "llvm.mips.fcne.d"]
        pub fn fcne_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcor.w` intrinsic; known as `__builtin_msa_fcor_w` in GCC.
        #[link_name = "llvm.mips.fcor.w"]
        pub fn fcor_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcor.d` intrinsic; known as `__builtin_msa_fcor_d` in GCC.
        #[link_name = "llvm.mips.fcor.d"]
        pub fn fcor_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcueq.w` intrinsic; known as `__builtin_msa_fcueq_w` in GCC.
        #[link_name = "llvm.mips.fcueq.w"]
        pub fn fcueq_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcueq.d` intrinsic; known as `__builtin_msa_fcueq_d` in GCC.
        #[link_name = "llvm.mips.fcueq.d"]
        pub fn fcueq_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcule.w` intrinsic; known as `__builtin_msa_fcule_w` in GCC.
        #[link_name = "llvm.mips.fcule.w"]
        pub fn fcule_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcule.d` intrinsic; known as `__builtin_msa_fcule_d` in GCC.
        #[link_name = "llvm.mips.fcule.d"]
        pub fn fcule_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcult.w` intrinsic; known as `__builtin_msa_fcult_w` in GCC.
        #[link_name = "llvm.mips.fcult.w"]
        pub fn fcult_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcult.d` intrinsic; known as `__builtin_msa_fcult_d` in GCC.
        #[link_name = "llvm.mips.fcult.d"]
        pub fn fcult_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcun.w` intrinsic; known as `__builtin_msa_fcun_w` in GCC.
        #[link_name = "llvm.mips.fcun.w"]
        pub fn fcun_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcun.d` intrinsic; known as `__builtin_msa_fcun_d` in GCC.
        #[link_name = "llvm.mips.fcun.d"]
        pub fn fcun_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fcune.w` intrinsic; known as `__builtin_msa_fcune_w` in GCC.
        #[link_name = "llvm.mips.fcune.w"]
        pub fn fcune_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fcune.d` intrinsic; known as `__builtin_msa_fcune_d` in GCC.
        #[link_name = "llvm.mips.fcune.d"]
        pub fn fcune_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fdiv.w` intrinsic; known as `__builtin_msa_fdiv_w` in GCC.
        #[link_name = "llvm.mips.fdiv.w"]
        pub fn fdiv_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fdiv.d` intrinsic; known as `__builtin_msa_fdiv_d` in GCC.
        #[link_name = "llvm.mips.fdiv.d"]
        pub fn fdiv_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fexdo.w` intrinsic; known as `__builtin_msa_fexdo_w` in GCC.
        #[link_name = "llvm.mips.fexdo.w"]
        pub fn fexdo_w(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.mips.fexp2.w` intrinsic; known as `__builtin_msa_fexp2_w` in GCC.
        #[link_name = "llvm.mips.fexp2.w"]
        pub fn fexp2_w(a: ::simdty::f32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fexp2.d` intrinsic; known as `__builtin_msa_fexp2_d` in GCC.
        #[link_name = "llvm.mips.fexp2.d"]
        pub fn fexp2_d(a: ::simdty::f64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fexupl.d` intrinsic; known as `__builtin_msa_fexupl_d` in GCC.
        #[link_name = "llvm.mips.fexupl.d"]
        pub fn fexupl_d(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.mips.fexupr.d` intrinsic; known as `__builtin_msa_fexupr_d` in GCC.
        #[link_name = "llvm.mips.fexupr.d"]
        pub fn fexupr_d(a: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.mips.ffint.s.w` intrinsic; known as `__builtin_msa_ffint_s_w` in GCC.
        #[link_name = "llvm.mips.ffint.s.w"]
        pub fn ffint_s_w(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.ffint.s.d` intrinsic; known as `__builtin_msa_ffint_s_d` in GCC.
        #[link_name = "llvm.mips.ffint.s.d"]
        pub fn ffint_s_d(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.ffint.u.w` intrinsic; known as `__builtin_msa_ffint_u_w` in GCC.
        #[link_name = "llvm.mips.ffint.u.w"]
        pub fn ffint_u_w(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.ffint.u.d` intrinsic; known as `__builtin_msa_ffint_u_d` in GCC.
        #[link_name = "llvm.mips.ffint.u.d"]
        pub fn ffint_u_d(a: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.ffql.w` intrinsic; known as `__builtin_msa_ffql_w` in GCC.
        #[link_name = "llvm.mips.ffql.w"]
        pub fn ffql_w(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.mips.ffql.d` intrinsic; known as `__builtin_msa_ffql_d` in GCC.
        #[link_name = "llvm.mips.ffql.d"]
        pub fn ffql_d(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.mips.ffqr.w` intrinsic; known as `__builtin_msa_ffqr_w` in GCC.
        #[link_name = "llvm.mips.ffqr.w"]
        pub fn ffqr_w(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.mips.ffqr.d` intrinsic; known as `__builtin_msa_ffqr_d` in GCC.
        #[link_name = "llvm.mips.ffqr.d"]
        pub fn ffqr_d(a: ::simdty::i32x4) -> ::simdty::f64x2;
        /// The `llvm.mips.fill.b` intrinsic; known as `__builtin_msa_fill_b` in GCC.
        #[link_name = "llvm.mips.fill.b"]
        pub fn fill_b(a: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.fill.h` intrinsic; known as `__builtin_msa_fill_h` in GCC.
        #[link_name = "llvm.mips.fill.h"]
        pub fn fill_h(a: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.fill.w` intrinsic; known as `__builtin_msa_fill_w` in GCC.
        #[link_name = "llvm.mips.fill.w"]
        pub fn fill_w(a: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.fill.d` intrinsic; known as `__builtin_msa_fill_d` in GCC.
        #[link_name = "llvm.mips.fill.d"]
        pub fn fill_d(a: i64) -> ::simdty::i64x2;
        /// The `llvm.mips.flog2.w` intrinsic; known as `__builtin_msa_flog2_w` in GCC.
        #[link_name = "llvm.mips.flog2.w"]
        pub fn flog2_w(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.flog2.d` intrinsic; known as `__builtin_msa_flog2_d` in GCC.
        #[link_name = "llvm.mips.flog2.d"]
        pub fn flog2_d(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmadd.w` intrinsic; known as `__builtin_msa_fmadd_w` in GCC.
        #[link_name = "llvm.mips.fmadd.w"]
        pub fn fmadd_w(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmadd.d` intrinsic; known as `__builtin_msa_fmadd_d` in GCC.
        #[link_name = "llvm.mips.fmadd.d"]
        pub fn fmadd_d(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmax.w` intrinsic; known as `__builtin_msa_fmax_w` in GCC.
        #[link_name = "llvm.mips.fmax.w"]
        pub fn fmax_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmax.d` intrinsic; known as `__builtin_msa_fmax_d` in GCC.
        #[link_name = "llvm.mips.fmax.d"]
        pub fn fmax_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmax.a.w` intrinsic; known as `__builtin_msa_fmax_a_w` in GCC.
        #[link_name = "llvm.mips.fmax.a.w"]
        pub fn fmax_a_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmax.a.d` intrinsic; known as `__builtin_msa_fmax_a_d` in GCC.
        #[link_name = "llvm.mips.fmax.a.d"]
        pub fn fmax_a_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmin.w` intrinsic; known as `__builtin_msa_fmin_w` in GCC.
        #[link_name = "llvm.mips.fmin.w"]
        pub fn fmin_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmin.d` intrinsic; known as `__builtin_msa_fmin_d` in GCC.
        #[link_name = "llvm.mips.fmin.d"]
        pub fn fmin_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmin.a.w` intrinsic; known as `__builtin_msa_fmin_a_w` in GCC.
        #[link_name = "llvm.mips.fmin.a.w"]
        pub fn fmin_a_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmin.a.d` intrinsic; known as `__builtin_msa_fmin_a_d` in GCC.
        #[link_name = "llvm.mips.fmin.a.d"]
        pub fn fmin_a_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmsub.w` intrinsic; known as `__builtin_msa_fmsub_w` in GCC.
        #[link_name = "llvm.mips.fmsub.w"]
        pub fn fmsub_w(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmsub.d` intrinsic; known as `__builtin_msa_fmsub_d` in GCC.
        #[link_name = "llvm.mips.fmsub.d"]
        pub fn fmsub_d(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fmul.w` intrinsic; known as `__builtin_msa_fmul_w` in GCC.
        #[link_name = "llvm.mips.fmul.w"]
        pub fn fmul_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fmul.d` intrinsic; known as `__builtin_msa_fmul_d` in GCC.
        #[link_name = "llvm.mips.fmul.d"]
        pub fn fmul_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.frint.w` intrinsic; known as `__builtin_msa_frint_w` in GCC.
        #[link_name = "llvm.mips.frint.w"]
        pub fn frint_w(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.frint.d` intrinsic; known as `__builtin_msa_frint_d` in GCC.
        #[link_name = "llvm.mips.frint.d"]
        pub fn frint_d(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.frcp.w` intrinsic; known as `__builtin_msa_frcp_w` in GCC.
        #[link_name = "llvm.mips.frcp.w"]
        pub fn frcp_w(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.frcp.d` intrinsic; known as `__builtin_msa_frcp_d` in GCC.
        #[link_name = "llvm.mips.frcp.d"]
        pub fn frcp_d(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.frsqrt.w` intrinsic; known as `__builtin_msa_frsqrt_w` in GCC.
        #[link_name = "llvm.mips.frsqrt.w"]
        pub fn frsqrt_w(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.frsqrt.d` intrinsic; known as `__builtin_msa_frsqrt_d` in GCC.
        #[link_name = "llvm.mips.frsqrt.d"]
        pub fn frsqrt_d(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fsaf.w` intrinsic; known as `__builtin_msa_fsaf_w` in GCC.
        #[link_name = "llvm.mips.fsaf.w"]
        pub fn fsaf_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsaf.d` intrinsic; known as `__builtin_msa_fsaf_d` in GCC.
        #[link_name = "llvm.mips.fsaf.d"]
        pub fn fsaf_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fseq.w` intrinsic; known as `__builtin_msa_fseq_w` in GCC.
        #[link_name = "llvm.mips.fseq.w"]
        pub fn fseq_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fseq.d` intrinsic; known as `__builtin_msa_fseq_d` in GCC.
        #[link_name = "llvm.mips.fseq.d"]
        pub fn fseq_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsle.w` intrinsic; known as `__builtin_msa_fsle_w` in GCC.
        #[link_name = "llvm.mips.fsle.w"]
        pub fn fsle_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsle.d` intrinsic; known as `__builtin_msa_fsle_d` in GCC.
        #[link_name = "llvm.mips.fsle.d"]
        pub fn fsle_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fslt.w` intrinsic; known as `__builtin_msa_fslt_w` in GCC.
        #[link_name = "llvm.mips.fslt.w"]
        pub fn fslt_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fslt.d` intrinsic; known as `__builtin_msa_fslt_d` in GCC.
        #[link_name = "llvm.mips.fslt.d"]
        pub fn fslt_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsne.w` intrinsic; known as `__builtin_msa_fsne_w` in GCC.
        #[link_name = "llvm.mips.fsne.w"]
        pub fn fsne_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsne.d` intrinsic; known as `__builtin_msa_fsne_d` in GCC.
        #[link_name = "llvm.mips.fsne.d"]
        pub fn fsne_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsor.w` intrinsic; known as `__builtin_msa_fsor_w` in GCC.
        #[link_name = "llvm.mips.fsor.w"]
        pub fn fsor_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsor.d` intrinsic; known as `__builtin_msa_fsor_d` in GCC.
        #[link_name = "llvm.mips.fsor.d"]
        pub fn fsor_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsqrt.w` intrinsic; known as `__builtin_msa_fsqrt_w` in GCC.
        #[link_name = "llvm.mips.fsqrt.w"]
        pub fn fsqrt_w(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fsqrt.d` intrinsic; known as `__builtin_msa_fsqrt_d` in GCC.
        #[link_name = "llvm.mips.fsqrt.d"]
        pub fn fsqrt_d(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fsub.w` intrinsic; known as `__builtin_msa_fsub_w` in GCC.
        #[link_name = "llvm.mips.fsub.w"]
        pub fn fsub_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.mips.fsub.d` intrinsic; known as `__builtin_msa_fsub_d` in GCC.
        #[link_name = "llvm.mips.fsub.d"]
        pub fn fsub_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.mips.fsueq.w` intrinsic; known as `__builtin_msa_fsueq_w` in GCC.
        #[link_name = "llvm.mips.fsueq.w"]
        pub fn fsueq_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsueq.d` intrinsic; known as `__builtin_msa_fsueq_d` in GCC.
        #[link_name = "llvm.mips.fsueq.d"]
        pub fn fsueq_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsule.w` intrinsic; known as `__builtin_msa_fsule_w` in GCC.
        #[link_name = "llvm.mips.fsule.w"]
        pub fn fsule_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsule.d` intrinsic; known as `__builtin_msa_fsule_d` in GCC.
        #[link_name = "llvm.mips.fsule.d"]
        pub fn fsule_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsult.w` intrinsic; known as `__builtin_msa_fsult_w` in GCC.
        #[link_name = "llvm.mips.fsult.w"]
        pub fn fsult_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsult.d` intrinsic; known as `__builtin_msa_fsult_d` in GCC.
        #[link_name = "llvm.mips.fsult.d"]
        pub fn fsult_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsun.w` intrinsic; known as `__builtin_msa_fsun_w` in GCC.
        #[link_name = "llvm.mips.fsun.w"]
        pub fn fsun_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsun.d` intrinsic; known as `__builtin_msa_fsun_d` in GCC.
        #[link_name = "llvm.mips.fsun.d"]
        pub fn fsun_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.fsune.w` intrinsic; known as `__builtin_msa_fsune_w` in GCC.
        #[link_name = "llvm.mips.fsune.w"]
        pub fn fsune_w(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.fsune.d` intrinsic; known as `__builtin_msa_fsune_d` in GCC.
        #[link_name = "llvm.mips.fsune.d"]
        pub fn fsune_d(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ftint.s.w` intrinsic; known as `__builtin_msa_ftint_s_w` in GCC.
        #[link_name = "llvm.mips.ftint.s.w"]
        pub fn ftint_s_w(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ftint.s.d` intrinsic; known as `__builtin_msa_ftint_s_d` in GCC.
        #[link_name = "llvm.mips.ftint.s.d"]
        pub fn ftint_s_d(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ftint.u.w` intrinsic; known as `__builtin_msa_ftint_u_w` in GCC.
        #[link_name = "llvm.mips.ftint.u.w"]
        pub fn ftint_u_w(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ftint.u.d` intrinsic; known as `__builtin_msa_ftint_u_d` in GCC.
        #[link_name = "llvm.mips.ftint.u.d"]
        pub fn ftint_u_d(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ftq.h` intrinsic; known as `__builtin_msa_ftq_h` in GCC.
        #[link_name = "llvm.mips.ftq.h"]
        pub fn ftq_h(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i16x8;
        /// The `llvm.mips.ftq.w` intrinsic; known as `__builtin_msa_ftq_w` in GCC.
        #[link_name = "llvm.mips.ftq.w"]
        pub fn ftq_w(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.mips.ftrunc.s.w` intrinsic; known as `__builtin_msa_ftrunc_s_w` in GCC.
        #[link_name = "llvm.mips.ftrunc.s.w"]
        pub fn ftrunc_s_w(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ftrunc.s.d` intrinsic; known as `__builtin_msa_ftrunc_s_d` in GCC.
        #[link_name = "llvm.mips.ftrunc.s.d"]
        pub fn ftrunc_s_d(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ftrunc.u.w` intrinsic; known as `__builtin_msa_ftrunc_u_w` in GCC.
        #[link_name = "llvm.mips.ftrunc.u.w"]
        pub fn ftrunc_u_w(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ftrunc.u.d` intrinsic; known as `__builtin_msa_ftrunc_u_d` in GCC.
        #[link_name = "llvm.mips.ftrunc.u.d"]
        pub fn ftrunc_u_d(a: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.hadd.s.h` intrinsic; known as `__builtin_msa_hadd_s_h` in GCC.
        #[link_name = "llvm.mips.hadd.s.h"]
        pub fn hadd_s_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.hadd.s.w` intrinsic; known as `__builtin_msa_hadd_s_w` in GCC.
        #[link_name = "llvm.mips.hadd.s.w"]
        pub fn hadd_s_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.hadd.s.d` intrinsic; known as `__builtin_msa_hadd_s_d` in GCC.
        #[link_name = "llvm.mips.hadd.s.d"]
        pub fn hadd_s_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.hadd.u.h` intrinsic; known as `__builtin_msa_hadd_u_h` in GCC.
        #[link_name = "llvm.mips.hadd.u.h"]
        pub fn hadd_u_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.hadd.u.w` intrinsic; known as `__builtin_msa_hadd_u_w` in GCC.
        #[link_name = "llvm.mips.hadd.u.w"]
        pub fn hadd_u_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.hadd.u.d` intrinsic; known as `__builtin_msa_hadd_u_d` in GCC.
        #[link_name = "llvm.mips.hadd.u.d"]
        pub fn hadd_u_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.hsub.s.h` intrinsic; known as `__builtin_msa_hsub_s_h` in GCC.
        #[link_name = "llvm.mips.hsub.s.h"]
        pub fn hsub_s_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.hsub.s.w` intrinsic; known as `__builtin_msa_hsub_s_w` in GCC.
        #[link_name = "llvm.mips.hsub.s.w"]
        pub fn hsub_s_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.hsub.s.d` intrinsic; known as `__builtin_msa_hsub_s_d` in GCC.
        #[link_name = "llvm.mips.hsub.s.d"]
        pub fn hsub_s_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.hsub.u.h` intrinsic; known as `__builtin_msa_hsub_u_h` in GCC.
        #[link_name = "llvm.mips.hsub.u.h"]
        pub fn hsub_u_h(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.mips.hsub.u.w` intrinsic; known as `__builtin_msa_hsub_u_w` in GCC.
        #[link_name = "llvm.mips.hsub.u.w"]
        pub fn hsub_u_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.mips.hsub.u.d` intrinsic; known as `__builtin_msa_hsub_u_d` in GCC.
        #[link_name = "llvm.mips.hsub.u.d"]
        pub fn hsub_u_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.mips.ilvev.b` intrinsic; known as `__builtin_msa_ilvev_b` in GCC.
        #[link_name = "llvm.mips.ilvev.b"]
        pub fn ilvev_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ilvev.h` intrinsic; known as `__builtin_msa_ilvev_h` in GCC.
        #[link_name = "llvm.mips.ilvev.h"]
        pub fn ilvev_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ilvev.w` intrinsic; known as `__builtin_msa_ilvev_w` in GCC.
        #[link_name = "llvm.mips.ilvev.w"]
        pub fn ilvev_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ilvev.d` intrinsic; known as `__builtin_msa_ilvev_d` in GCC.
        #[link_name = "llvm.mips.ilvev.d"]
        pub fn ilvev_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ilvl.b` intrinsic; known as `__builtin_msa_ilvl_b` in GCC.
        #[link_name = "llvm.mips.ilvl.b"]
        pub fn ilvl_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ilvl.h` intrinsic; known as `__builtin_msa_ilvl_h` in GCC.
        #[link_name = "llvm.mips.ilvl.h"]
        pub fn ilvl_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ilvl.w` intrinsic; known as `__builtin_msa_ilvl_w` in GCC.
        #[link_name = "llvm.mips.ilvl.w"]
        pub fn ilvl_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ilvl.d` intrinsic; known as `__builtin_msa_ilvl_d` in GCC.
        #[link_name = "llvm.mips.ilvl.d"]
        pub fn ilvl_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ilvod.b` intrinsic; known as `__builtin_msa_ilvod_b` in GCC.
        #[link_name = "llvm.mips.ilvod.b"]
        pub fn ilvod_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ilvod.h` intrinsic; known as `__builtin_msa_ilvod_h` in GCC.
        #[link_name = "llvm.mips.ilvod.h"]
        pub fn ilvod_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ilvod.w` intrinsic; known as `__builtin_msa_ilvod_w` in GCC.
        #[link_name = "llvm.mips.ilvod.w"]
        pub fn ilvod_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ilvod.d` intrinsic; known as `__builtin_msa_ilvod_d` in GCC.
        #[link_name = "llvm.mips.ilvod.d"]
        pub fn ilvod_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ilvr.b` intrinsic; known as `__builtin_msa_ilvr_b` in GCC.
        #[link_name = "llvm.mips.ilvr.b"]
        pub fn ilvr_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ilvr.h` intrinsic; known as `__builtin_msa_ilvr_h` in GCC.
        #[link_name = "llvm.mips.ilvr.h"]
        pub fn ilvr_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.ilvr.w` intrinsic; known as `__builtin_msa_ilvr_w` in GCC.
        #[link_name = "llvm.mips.ilvr.w"]
        pub fn ilvr_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.ilvr.d` intrinsic; known as `__builtin_msa_ilvr_d` in GCC.
        #[link_name = "llvm.mips.ilvr.d"]
        pub fn ilvr_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.insert.b` intrinsic; known as `__builtin_msa_insert_b` in GCC.
        #[link_name = "llvm.mips.insert.b"]
        pub fn insert_b(a: ::simdty::i8x16, b: i32, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.insert.h` intrinsic; known as `__builtin_msa_insert_h` in GCC.
        #[link_name = "llvm.mips.insert.h"]
        pub fn insert_h(a: ::simdty::i16x8, b: i32, c: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.insert.w` intrinsic; known as `__builtin_msa_insert_w` in GCC.
        #[link_name = "llvm.mips.insert.w"]
        pub fn insert_w(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.insert.d` intrinsic; known as `__builtin_msa_insert_d` in GCC.
        #[link_name = "llvm.mips.insert.d"]
        pub fn insert_d(a: ::simdty::i64x2, b: i32, c: i64) -> ::simdty::i64x2;
        /// The `llvm.mips.insve.b` intrinsic; known as `__builtin_msa_insve_b` in GCC.
        #[link_name = "llvm.mips.insve.b"]
        pub fn insve_b(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.insve.h` intrinsic; known as `__builtin_msa_insve_h` in GCC.
        #[link_name = "llvm.mips.insve.h"]
        pub fn insve_h(a: ::simdty::i16x8, b: i32, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.insve.w` intrinsic; known as `__builtin_msa_insve_w` in GCC.
        #[link_name = "llvm.mips.insve.w"]
        pub fn insve_w(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.insve.d` intrinsic; known as `__builtin_msa_insve_d` in GCC.
        #[link_name = "llvm.mips.insve.d"]
        pub fn insve_d(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.ld.b` intrinsic; known as `__builtin_msa_ld_b` in GCC.
        #[link_name = "llvm.mips.ld.b"]
        pub fn ld_b(a: *mut i8, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.ld.h` intrinsic; known as `__builtin_msa_ld_h` in GCC.
        #[link_name = "llvm.mips.ld.h"]
        pub fn ld_h(a: *mut i8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.ld.w` intrinsic; known as `__builtin_msa_ld_w` in GCC.
        #[link_name = "llvm.mips.ld.w"]
        pub fn ld_w(a: *mut i8, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.ld.d` intrinsic; known as `__builtin_msa_ld_d` in GCC.
        #[link_name = "llvm.mips.ld.d"]
        pub fn ld_d(a: *mut i8, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.ldi.b` intrinsic; known as `__builtin_msa_ldi_b` in GCC.
        #[link_name = "llvm.mips.ldi.b"]
        pub fn ldi_b(a: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.ldi.h` intrinsic; known as `__builtin_msa_ldi_h` in GCC.
        #[link_name = "llvm.mips.ldi.h"]
        pub fn ldi_h(a: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.ldi.w` intrinsic; known as `__builtin_msa_ldi_w` in GCC.
        #[link_name = "llvm.mips.ldi.w"]
        pub fn ldi_w(a: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.ldi.d` intrinsic; known as `__builtin_msa_ldi_d` in GCC.
        #[link_name = "llvm.mips.ldi.d"]
        pub fn ldi_d(a: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.lsa` intrinsic; known as `__builtin_mips_lsa` in GCC.
        #[link_name = "llvm.mips.lsa"]
        pub fn lsa(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.mips.madd.q.h` intrinsic; known as `__builtin_msa_madd_q_h` in GCC.
        #[link_name = "llvm.mips.madd.q.h"]
        pub fn madd_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.madd.q.w` intrinsic; known as `__builtin_msa_madd_q_w` in GCC.
        #[link_name = "llvm.mips.madd.q.w"]
        pub fn madd_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.maddr.q.h` intrinsic; known as `__builtin_msa_maddr_q_h` in GCC.
        #[link_name = "llvm.mips.maddr.q.h"]
        pub fn maddr_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.maddr.q.w` intrinsic; known as `__builtin_msa_maddr_q_w` in GCC.
        #[link_name = "llvm.mips.maddr.q.w"]
        pub fn maddr_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.maddv.b` intrinsic; known as `__builtin_msa_maddv_b` in GCC.
        #[link_name = "llvm.mips.maddv.b"]
        pub fn maddv_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.maddv.h` intrinsic; known as `__builtin_msa_maddv_h` in GCC.
        #[link_name = "llvm.mips.maddv.h"]
        pub fn maddv_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.maddv.w` intrinsic; known as `__builtin_msa_maddv_w` in GCC.
        #[link_name = "llvm.mips.maddv.w"]
        pub fn maddv_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.maddv.d` intrinsic; known as `__builtin_msa_maddv_d` in GCC.
        #[link_name = "llvm.mips.maddv.d"]
        pub fn maddv_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.max.a.b` intrinsic; known as `__builtin_msa_max_a_b` in GCC.
        #[link_name = "llvm.mips.max.a.b"]
        pub fn max_a_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.max.a.h` intrinsic; known as `__builtin_msa_max_a_h` in GCC.
        #[link_name = "llvm.mips.max.a.h"]
        pub fn max_a_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.max.a.w` intrinsic; known as `__builtin_msa_max_a_w` in GCC.
        #[link_name = "llvm.mips.max.a.w"]
        pub fn max_a_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.max.a.d` intrinsic; known as `__builtin_msa_max_a_d` in GCC.
        #[link_name = "llvm.mips.max.a.d"]
        pub fn max_a_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.max.s.b` intrinsic; known as `__builtin_msa_max_s_b` in GCC.
        #[link_name = "llvm.mips.max.s.b"]
        pub fn max_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.max.s.h` intrinsic; known as `__builtin_msa_max_s_h` in GCC.
        #[link_name = "llvm.mips.max.s.h"]
        pub fn max_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.max.s.w` intrinsic; known as `__builtin_msa_max_s_w` in GCC.
        #[link_name = "llvm.mips.max.s.w"]
        pub fn max_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.max.s.d` intrinsic; known as `__builtin_msa_max_s_d` in GCC.
        #[link_name = "llvm.mips.max.s.d"]
        pub fn max_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.max.u.b` intrinsic; known as `__builtin_msa_max_u_b` in GCC.
        #[link_name = "llvm.mips.max.u.b"]
        pub fn max_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.max.u.h` intrinsic; known as `__builtin_msa_max_u_h` in GCC.
        #[link_name = "llvm.mips.max.u.h"]
        pub fn max_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.max.u.w` intrinsic; known as `__builtin_msa_max_u_w` in GCC.
        #[link_name = "llvm.mips.max.u.w"]
        pub fn max_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.max.u.d` intrinsic; known as `__builtin_msa_max_u_d` in GCC.
        #[link_name = "llvm.mips.max.u.d"]
        pub fn max_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.maxi.s.b` intrinsic; known as `__builtin_msa_maxi_s_b` in GCC.
        #[link_name = "llvm.mips.maxi.s.b"]
        pub fn maxi_s_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.maxi.s.h` intrinsic; known as `__builtin_msa_maxi_s_h` in GCC.
        #[link_name = "llvm.mips.maxi.s.h"]
        pub fn maxi_s_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.maxi.s.w` intrinsic; known as `__builtin_msa_maxi_s_w` in GCC.
        #[link_name = "llvm.mips.maxi.s.w"]
        pub fn maxi_s_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.maxi.s.d` intrinsic; known as `__builtin_msa_maxi_s_d` in GCC.
        #[link_name = "llvm.mips.maxi.s.d"]
        pub fn maxi_s_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.maxi.u.b` intrinsic; known as `__builtin_msa_maxi_u_b` in GCC.
        #[link_name = "llvm.mips.maxi.u.b"]
        pub fn maxi_u_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.maxi.u.h` intrinsic; known as `__builtin_msa_maxi_u_h` in GCC.
        #[link_name = "llvm.mips.maxi.u.h"]
        pub fn maxi_u_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.maxi.u.w` intrinsic; known as `__builtin_msa_maxi_u_w` in GCC.
        #[link_name = "llvm.mips.maxi.u.w"]
        pub fn maxi_u_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.maxi.u.d` intrinsic; known as `__builtin_msa_maxi_u_d` in GCC.
        #[link_name = "llvm.mips.maxi.u.d"]
        pub fn maxi_u_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.min.a.b` intrinsic; known as `__builtin_msa_min_a_b` in GCC.
        #[link_name = "llvm.mips.min.a.b"]
        pub fn min_a_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.min.a.h` intrinsic; known as `__builtin_msa_min_a_h` in GCC.
        #[link_name = "llvm.mips.min.a.h"]
        pub fn min_a_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.min.a.w` intrinsic; known as `__builtin_msa_min_a_w` in GCC.
        #[link_name = "llvm.mips.min.a.w"]
        pub fn min_a_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.min.a.d` intrinsic; known as `__builtin_msa_min_a_d` in GCC.
        #[link_name = "llvm.mips.min.a.d"]
        pub fn min_a_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.min.s.b` intrinsic; known as `__builtin_msa_min_s_b` in GCC.
        #[link_name = "llvm.mips.min.s.b"]
        pub fn min_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.min.s.h` intrinsic; known as `__builtin_msa_min_s_h` in GCC.
        #[link_name = "llvm.mips.min.s.h"]
        pub fn min_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.min.s.w` intrinsic; known as `__builtin_msa_min_s_w` in GCC.
        #[link_name = "llvm.mips.min.s.w"]
        pub fn min_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.min.s.d` intrinsic; known as `__builtin_msa_min_s_d` in GCC.
        #[link_name = "llvm.mips.min.s.d"]
        pub fn min_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.min.u.b` intrinsic; known as `__builtin_msa_min_u_b` in GCC.
        #[link_name = "llvm.mips.min.u.b"]
        pub fn min_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.min.u.h` intrinsic; known as `__builtin_msa_min_u_h` in GCC.
        #[link_name = "llvm.mips.min.u.h"]
        pub fn min_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.min.u.w` intrinsic; known as `__builtin_msa_min_u_w` in GCC.
        #[link_name = "llvm.mips.min.u.w"]
        pub fn min_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.min.u.d` intrinsic; known as `__builtin_msa_min_u_d` in GCC.
        #[link_name = "llvm.mips.min.u.d"]
        pub fn min_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.mini.s.b` intrinsic; known as `__builtin_msa_mini_s_b` in GCC.
        #[link_name = "llvm.mips.mini.s.b"]
        pub fn mini_s_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.mini.s.h` intrinsic; known as `__builtin_msa_mini_s_h` in GCC.
        #[link_name = "llvm.mips.mini.s.h"]
        pub fn mini_s_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.mini.s.w` intrinsic; known as `__builtin_msa_mini_s_w` in GCC.
        #[link_name = "llvm.mips.mini.s.w"]
        pub fn mini_s_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.mini.s.d` intrinsic; known as `__builtin_msa_mini_s_d` in GCC.
        #[link_name = "llvm.mips.mini.s.d"]
        pub fn mini_s_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.mini.u.b` intrinsic; known as `__builtin_msa_mini_u_b` in GCC.
        #[link_name = "llvm.mips.mini.u.b"]
        pub fn mini_u_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.mini.u.h` intrinsic; known as `__builtin_msa_mini_u_h` in GCC.
        #[link_name = "llvm.mips.mini.u.h"]
        pub fn mini_u_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.mini.u.w` intrinsic; known as `__builtin_msa_mini_u_w` in GCC.
        #[link_name = "llvm.mips.mini.u.w"]
        pub fn mini_u_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.mini.u.d` intrinsic; known as `__builtin_msa_mini_u_d` in GCC.
        #[link_name = "llvm.mips.mini.u.d"]
        pub fn mini_u_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.mod.s.b` intrinsic; known as `__builtin_msa_mod_s_b` in GCC.
        #[link_name = "llvm.mips.mod.s.b"]
        pub fn mod_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.mod.s.h` intrinsic; known as `__builtin_msa_mod_s_h` in GCC.
        #[link_name = "llvm.mips.mod.s.h"]
        pub fn mod_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.mod.s.w` intrinsic; known as `__builtin_msa_mod_s_w` in GCC.
        #[link_name = "llvm.mips.mod.s.w"]
        pub fn mod_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.mod.s.d` intrinsic; known as `__builtin_msa_mod_s_d` in GCC.
        #[link_name = "llvm.mips.mod.s.d"]
        pub fn mod_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.mod.u.b` intrinsic; known as `__builtin_msa_mod_u_b` in GCC.
        #[link_name = "llvm.mips.mod.u.b"]
        pub fn mod_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.mod.u.h` intrinsic; known as `__builtin_msa_mod_u_h` in GCC.
        #[link_name = "llvm.mips.mod.u.h"]
        pub fn mod_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.mod.u.w` intrinsic; known as `__builtin_msa_mod_u_w` in GCC.
        #[link_name = "llvm.mips.mod.u.w"]
        pub fn mod_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.mod.u.d` intrinsic; known as `__builtin_msa_mod_u_d` in GCC.
        #[link_name = "llvm.mips.mod.u.d"]
        pub fn mod_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.move.v` intrinsic; known as `__builtin_msa_move_v` in GCC.
        #[link_name = "llvm.mips.move.v"]
        pub fn move_v(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.msub.q.h` intrinsic; known as `__builtin_msa_msub_q_h` in GCC.
        #[link_name = "llvm.mips.msub.q.h"]
        pub fn msub_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.msub.q.w` intrinsic; known as `__builtin_msa_msub_q_w` in GCC.
        #[link_name = "llvm.mips.msub.q.w"]
        pub fn msub_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.msubr.q.h` intrinsic; known as `__builtin_msa_msubr_q_h` in GCC.
        #[link_name = "llvm.mips.msubr.q.h"]
        pub fn msubr_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.msubr.q.w` intrinsic; known as `__builtin_msa_msubr_q_w` in GCC.
        #[link_name = "llvm.mips.msubr.q.w"]
        pub fn msubr_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.msubv.b` intrinsic; known as `__builtin_msa_msubv_b` in GCC.
        #[link_name = "llvm.mips.msubv.b"]
        pub fn msubv_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.msubv.h` intrinsic; known as `__builtin_msa_msubv_h` in GCC.
        #[link_name = "llvm.mips.msubv.h"]
        pub fn msubv_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.msubv.w` intrinsic; known as `__builtin_msa_msubv_w` in GCC.
        #[link_name = "llvm.mips.msubv.w"]
        pub fn msubv_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.msubv.d` intrinsic; known as `__builtin_msa_msubv_d` in GCC.
        #[link_name = "llvm.mips.msubv.d"]
        pub fn msubv_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.mul.q.h` intrinsic; known as `__builtin_msa_mul_q_h` in GCC.
        #[link_name = "llvm.mips.mul.q.h"]
        pub fn mul_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.mul.q.w` intrinsic; known as `__builtin_msa_mul_q_w` in GCC.
        #[link_name = "llvm.mips.mul.q.w"]
        pub fn mul_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.mulr.q.h` intrinsic; known as `__builtin_msa_mulr_q_h` in GCC.
        #[link_name = "llvm.mips.mulr.q.h"]
        pub fn mulr_q_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.mulr.q.w` intrinsic; known as `__builtin_msa_mulr_q_w` in GCC.
        #[link_name = "llvm.mips.mulr.q.w"]
        pub fn mulr_q_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.mulv.b` intrinsic; known as `__builtin_msa_mulv_b` in GCC.
        #[link_name = "llvm.mips.mulv.b"]
        pub fn mulv_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.mulv.h` intrinsic; known as `__builtin_msa_mulv_h` in GCC.
        #[link_name = "llvm.mips.mulv.h"]
        pub fn mulv_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.mulv.w` intrinsic; known as `__builtin_msa_mulv_w` in GCC.
        #[link_name = "llvm.mips.mulv.w"]
        pub fn mulv_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.mulv.d` intrinsic; known as `__builtin_msa_mulv_d` in GCC.
        #[link_name = "llvm.mips.mulv.d"]
        pub fn mulv_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.nloc.b` intrinsic; known as `__builtin_msa_nloc_b` in GCC.
        #[link_name = "llvm.mips.nloc.b"]
        pub fn nloc_b(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.nloc.h` intrinsic; known as `__builtin_msa_nloc_h` in GCC.
        #[link_name = "llvm.mips.nloc.h"]
        pub fn nloc_h(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.nloc.w` intrinsic; known as `__builtin_msa_nloc_w` in GCC.
        #[link_name = "llvm.mips.nloc.w"]
        pub fn nloc_w(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.nloc.d` intrinsic; known as `__builtin_msa_nloc_d` in GCC.
        #[link_name = "llvm.mips.nloc.d"]
        pub fn nloc_d(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.nlzc.b` intrinsic; known as `__builtin_msa_nlzc_b` in GCC.
        #[link_name = "llvm.mips.nlzc.b"]
        pub fn nlzc_b(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.nlzc.h` intrinsic; known as `__builtin_msa_nlzc_h` in GCC.
        #[link_name = "llvm.mips.nlzc.h"]
        pub fn nlzc_h(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.nlzc.w` intrinsic; known as `__builtin_msa_nlzc_w` in GCC.
        #[link_name = "llvm.mips.nlzc.w"]
        pub fn nlzc_w(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.nlzc.d` intrinsic; known as `__builtin_msa_nlzc_d` in GCC.
        #[link_name = "llvm.mips.nlzc.d"]
        pub fn nlzc_d(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.nor.v` intrinsic; known as `__builtin_msa_nor_v` in GCC.
        #[link_name = "llvm.mips.nor.v"]
        pub fn nor_v(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.nori.b` intrinsic; known as `__builtin_msa_nori_b` in GCC.
        #[link_name = "llvm.mips.nori.b"]
        pub fn nori_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.or.v` intrinsic; known as `__builtin_msa_or_v` in GCC.
        #[link_name = "llvm.mips.or.v"]
        pub fn or_v(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.ori.b` intrinsic; known as `__builtin_msa_ori_b` in GCC.
        #[link_name = "llvm.mips.ori.b"]
        pub fn ori_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.pckev.b` intrinsic; known as `__builtin_msa_pckev_b` in GCC.
        #[link_name = "llvm.mips.pckev.b"]
        pub fn pckev_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.pckev.h` intrinsic; known as `__builtin_msa_pckev_h` in GCC.
        #[link_name = "llvm.mips.pckev.h"]
        pub fn pckev_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.pckev.w` intrinsic; known as `__builtin_msa_pckev_w` in GCC.
        #[link_name = "llvm.mips.pckev.w"]
        pub fn pckev_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.pckev.d` intrinsic; known as `__builtin_msa_pckev_d` in GCC.
        #[link_name = "llvm.mips.pckev.d"]
        pub fn pckev_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.pckod.b` intrinsic; known as `__builtin_msa_pckod_b` in GCC.
        #[link_name = "llvm.mips.pckod.b"]
        pub fn pckod_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.pckod.h` intrinsic; known as `__builtin_msa_pckod_h` in GCC.
        #[link_name = "llvm.mips.pckod.h"]
        pub fn pckod_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.pckod.w` intrinsic; known as `__builtin_msa_pckod_w` in GCC.
        #[link_name = "llvm.mips.pckod.w"]
        pub fn pckod_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.pckod.d` intrinsic; known as `__builtin_msa_pckod_d` in GCC.
        #[link_name = "llvm.mips.pckod.d"]
        pub fn pckod_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.pcnt.b` intrinsic; known as `__builtin_msa_pcnt_b` in GCC.
        #[link_name = "llvm.mips.pcnt.b"]
        pub fn pcnt_b(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.pcnt.h` intrinsic; known as `__builtin_msa_pcnt_h` in GCC.
        #[link_name = "llvm.mips.pcnt.h"]
        pub fn pcnt_h(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.pcnt.w` intrinsic; known as `__builtin_msa_pcnt_w` in GCC.
        #[link_name = "llvm.mips.pcnt.w"]
        pub fn pcnt_w(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.pcnt.d` intrinsic; known as `__builtin_msa_pcnt_d` in GCC.
        #[link_name = "llvm.mips.pcnt.d"]
        pub fn pcnt_d(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.sat.s.b` intrinsic; known as `__builtin_msa_sat_s_b` in GCC.
        #[link_name = "llvm.mips.sat.s.b"]
        pub fn sat_s_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.sat.s.h` intrinsic; known as `__builtin_msa_sat_s_h` in GCC.
        #[link_name = "llvm.mips.sat.s.h"]
        pub fn sat_s_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.sat.s.w` intrinsic; known as `__builtin_msa_sat_s_w` in GCC.
        #[link_name = "llvm.mips.sat.s.w"]
        pub fn sat_s_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.sat.s.d` intrinsic; known as `__builtin_msa_sat_s_d` in GCC.
        #[link_name = "llvm.mips.sat.s.d"]
        pub fn sat_s_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.sat.u.b` intrinsic; known as `__builtin_msa_sat_u_b` in GCC.
        #[link_name = "llvm.mips.sat.u.b"]
        pub fn sat_u_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.sat.u.h` intrinsic; known as `__builtin_msa_sat_u_h` in GCC.
        #[link_name = "llvm.mips.sat.u.h"]
        pub fn sat_u_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.sat.u.w` intrinsic; known as `__builtin_msa_sat_u_w` in GCC.
        #[link_name = "llvm.mips.sat.u.w"]
        pub fn sat_u_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.sat.u.d` intrinsic; known as `__builtin_msa_sat_u_d` in GCC.
        #[link_name = "llvm.mips.sat.u.d"]
        pub fn sat_u_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.shf.b` intrinsic; known as `__builtin_msa_shf_b` in GCC.
        #[link_name = "llvm.mips.shf.b"]
        pub fn shf_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.shf.h` intrinsic; known as `__builtin_msa_shf_h` in GCC.
        #[link_name = "llvm.mips.shf.h"]
        pub fn shf_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.shf.w` intrinsic; known as `__builtin_msa_shf_w` in GCC.
        #[link_name = "llvm.mips.shf.w"]
        pub fn shf_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.sld.b` intrinsic; known as `__builtin_msa_sld_b` in GCC.
        #[link_name = "llvm.mips.sld.b"]
        pub fn sld_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.sld.h` intrinsic; known as `__builtin_msa_sld_h` in GCC.
        #[link_name = "llvm.mips.sld.h"]
        pub fn sld_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.sld.w` intrinsic; known as `__builtin_msa_sld_w` in GCC.
        #[link_name = "llvm.mips.sld.w"]
        pub fn sld_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.sld.d` intrinsic; known as `__builtin_msa_sld_d` in GCC.
        #[link_name = "llvm.mips.sld.d"]
        pub fn sld_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.sldi.b` intrinsic; known as `__builtin_msa_sldi_b` in GCC.
        #[link_name = "llvm.mips.sldi.b"]
        pub fn sldi_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.sldi.h` intrinsic; known as `__builtin_msa_sldi_h` in GCC.
        #[link_name = "llvm.mips.sldi.h"]
        pub fn sldi_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.sldi.w` intrinsic; known as `__builtin_msa_sldi_w` in GCC.
        #[link_name = "llvm.mips.sldi.w"]
        pub fn sldi_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.sldi.d` intrinsic; known as `__builtin_msa_sldi_d` in GCC.
        #[link_name = "llvm.mips.sldi.d"]
        pub fn sldi_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.sll.b` intrinsic; known as `__builtin_msa_sll_b` in GCC.
        #[link_name = "llvm.mips.sll.b"]
        pub fn sll_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.sll.h` intrinsic; known as `__builtin_msa_sll_h` in GCC.
        #[link_name = "llvm.mips.sll.h"]
        pub fn sll_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.sll.w` intrinsic; known as `__builtin_msa_sll_w` in GCC.
        #[link_name = "llvm.mips.sll.w"]
        pub fn sll_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.sll.d` intrinsic; known as `__builtin_msa_sll_d` in GCC.
        #[link_name = "llvm.mips.sll.d"]
        pub fn sll_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.slli.b` intrinsic; known as `__builtin_msa_slli_b` in GCC.
        #[link_name = "llvm.mips.slli.b"]
        pub fn slli_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.slli.h` intrinsic; known as `__builtin_msa_slli_h` in GCC.
        #[link_name = "llvm.mips.slli.h"]
        pub fn slli_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.slli.w` intrinsic; known as `__builtin_msa_slli_w` in GCC.
        #[link_name = "llvm.mips.slli.w"]
        pub fn slli_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.slli.d` intrinsic; known as `__builtin_msa_slli_d` in GCC.
        #[link_name = "llvm.mips.slli.d"]
        pub fn slli_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.splat.b` intrinsic; known as `__builtin_msa_splat_b` in GCC.
        #[link_name = "llvm.mips.splat.b"]
        pub fn splat_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.splat.h` intrinsic; known as `__builtin_msa_splat_h` in GCC.
        #[link_name = "llvm.mips.splat.h"]
        pub fn splat_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.splat.w` intrinsic; known as `__builtin_msa_splat_w` in GCC.
        #[link_name = "llvm.mips.splat.w"]
        pub fn splat_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.splat.d` intrinsic; known as `__builtin_msa_splat_d` in GCC.
        #[link_name = "llvm.mips.splat.d"]
        pub fn splat_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.splati.b` intrinsic; known as `__builtin_msa_splati_b` in GCC.
        #[link_name = "llvm.mips.splati.b"]
        pub fn splati_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.splati.h` intrinsic; known as `__builtin_msa_splati_h` in GCC.
        #[link_name = "llvm.mips.splati.h"]
        pub fn splati_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.splati.w` intrinsic; known as `__builtin_msa_splati_w` in GCC.
        #[link_name = "llvm.mips.splati.w"]
        pub fn splati_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.splati.d` intrinsic; known as `__builtin_msa_splati_d` in GCC.
        #[link_name = "llvm.mips.splati.d"]
        pub fn splati_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.sra.b` intrinsic; known as `__builtin_msa_sra_b` in GCC.
        #[link_name = "llvm.mips.sra.b"]
        pub fn sra_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.sra.h` intrinsic; known as `__builtin_msa_sra_h` in GCC.
        #[link_name = "llvm.mips.sra.h"]
        pub fn sra_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.sra.w` intrinsic; known as `__builtin_msa_sra_w` in GCC.
        #[link_name = "llvm.mips.sra.w"]
        pub fn sra_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.sra.d` intrinsic; known as `__builtin_msa_sra_d` in GCC.
        #[link_name = "llvm.mips.sra.d"]
        pub fn sra_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.srai.b` intrinsic; known as `__builtin_msa_srai_b` in GCC.
        #[link_name = "llvm.mips.srai.b"]
        pub fn srai_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.srai.h` intrinsic; known as `__builtin_msa_srai_h` in GCC.
        #[link_name = "llvm.mips.srai.h"]
        pub fn srai_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.srai.w` intrinsic; known as `__builtin_msa_srai_w` in GCC.
        #[link_name = "llvm.mips.srai.w"]
        pub fn srai_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.srai.d` intrinsic; known as `__builtin_msa_srai_d` in GCC.
        #[link_name = "llvm.mips.srai.d"]
        pub fn srai_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.srar.b` intrinsic; known as `__builtin_msa_srar_b` in GCC.
        #[link_name = "llvm.mips.srar.b"]
        pub fn srar_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.srar.h` intrinsic; known as `__builtin_msa_srar_h` in GCC.
        #[link_name = "llvm.mips.srar.h"]
        pub fn srar_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.srar.w` intrinsic; known as `__builtin_msa_srar_w` in GCC.
        #[link_name = "llvm.mips.srar.w"]
        pub fn srar_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.srar.d` intrinsic; known as `__builtin_msa_srar_d` in GCC.
        #[link_name = "llvm.mips.srar.d"]
        pub fn srar_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.srari.b` intrinsic; known as `__builtin_msa_srari_b` in GCC.
        #[link_name = "llvm.mips.srari.b"]
        pub fn srari_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.srari.h` intrinsic; known as `__builtin_msa_srari_h` in GCC.
        #[link_name = "llvm.mips.srari.h"]
        pub fn srari_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.srari.w` intrinsic; known as `__builtin_msa_srari_w` in GCC.
        #[link_name = "llvm.mips.srari.w"]
        pub fn srari_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.srari.d` intrinsic; known as `__builtin_msa_srari_d` in GCC.
        #[link_name = "llvm.mips.srari.d"]
        pub fn srari_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.srl.b` intrinsic; known as `__builtin_msa_srl_b` in GCC.
        #[link_name = "llvm.mips.srl.b"]
        pub fn srl_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.srl.h` intrinsic; known as `__builtin_msa_srl_h` in GCC.
        #[link_name = "llvm.mips.srl.h"]
        pub fn srl_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.srl.w` intrinsic; known as `__builtin_msa_srl_w` in GCC.
        #[link_name = "llvm.mips.srl.w"]
        pub fn srl_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.srl.d` intrinsic; known as `__builtin_msa_srl_d` in GCC.
        #[link_name = "llvm.mips.srl.d"]
        pub fn srl_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.srli.b` intrinsic; known as `__builtin_msa_srli_b` in GCC.
        #[link_name = "llvm.mips.srli.b"]
        pub fn srli_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.srli.h` intrinsic; known as `__builtin_msa_srli_h` in GCC.
        #[link_name = "llvm.mips.srli.h"]
        pub fn srli_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.srli.w` intrinsic; known as `__builtin_msa_srli_w` in GCC.
        #[link_name = "llvm.mips.srli.w"]
        pub fn srli_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.srli.d` intrinsic; known as `__builtin_msa_srli_d` in GCC.
        #[link_name = "llvm.mips.srli.d"]
        pub fn srli_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.srlr.b` intrinsic; known as `__builtin_msa_srlr_b` in GCC.
        #[link_name = "llvm.mips.srlr.b"]
        pub fn srlr_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.srlr.h` intrinsic; known as `__builtin_msa_srlr_h` in GCC.
        #[link_name = "llvm.mips.srlr.h"]
        pub fn srlr_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.srlr.w` intrinsic; known as `__builtin_msa_srlr_w` in GCC.
        #[link_name = "llvm.mips.srlr.w"]
        pub fn srlr_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.srlr.d` intrinsic; known as `__builtin_msa_srlr_d` in GCC.
        #[link_name = "llvm.mips.srlr.d"]
        pub fn srlr_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.srlri.b` intrinsic; known as `__builtin_msa_srlri_b` in GCC.
        #[link_name = "llvm.mips.srlri.b"]
        pub fn srlri_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.srlri.h` intrinsic; known as `__builtin_msa_srlri_h` in GCC.
        #[link_name = "llvm.mips.srlri.h"]
        pub fn srlri_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.srlri.w` intrinsic; known as `__builtin_msa_srlri_w` in GCC.
        #[link_name = "llvm.mips.srlri.w"]
        pub fn srlri_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.srlri.d` intrinsic; known as `__builtin_msa_srlri_d` in GCC.
        #[link_name = "llvm.mips.srlri.d"]
        pub fn srlri_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.st.b` intrinsic; known as `__builtin_msa_st_b` in GCC.
        #[link_name = "llvm.mips.st.b"]
        pub fn st_b(a: ::simdty::i8x16, b: *mut i8, c: i32) -> ();
        /// The `llvm.mips.st.h` intrinsic; known as `__builtin_msa_st_h` in GCC.
        #[link_name = "llvm.mips.st.h"]
        pub fn st_h(a: ::simdty::i16x8, b: *mut i8, c: i32) -> ();
        /// The `llvm.mips.st.w` intrinsic; known as `__builtin_msa_st_w` in GCC.
        #[link_name = "llvm.mips.st.w"]
        pub fn st_w(a: ::simdty::i32x4, b: *mut i8, c: i32) -> ();
        /// The `llvm.mips.st.d` intrinsic; known as `__builtin_msa_st_d` in GCC.
        #[link_name = "llvm.mips.st.d"]
        pub fn st_d(a: ::simdty::i64x2, b: *mut i8, c: i32) -> ();
        /// The `llvm.mips.subs.s.b` intrinsic; known as `__builtin_msa_subs_s_b` in GCC.
        #[link_name = "llvm.mips.subs.s.b"]
        pub fn subs_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.subs.s.h` intrinsic; known as `__builtin_msa_subs_s_h` in GCC.
        #[link_name = "llvm.mips.subs.s.h"]
        pub fn subs_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.subs.s.w` intrinsic; known as `__builtin_msa_subs_s_w` in GCC.
        #[link_name = "llvm.mips.subs.s.w"]
        pub fn subs_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.subs.s.d` intrinsic; known as `__builtin_msa_subs_s_d` in GCC.
        #[link_name = "llvm.mips.subs.s.d"]
        pub fn subs_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.subs.u.b` intrinsic; known as `__builtin_msa_subs_u_b` in GCC.
        #[link_name = "llvm.mips.subs.u.b"]
        pub fn subs_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.subs.u.h` intrinsic; known as `__builtin_msa_subs_u_h` in GCC.
        #[link_name = "llvm.mips.subs.u.h"]
        pub fn subs_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.subs.u.w` intrinsic; known as `__builtin_msa_subs_u_w` in GCC.
        #[link_name = "llvm.mips.subs.u.w"]
        pub fn subs_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.subs.u.d` intrinsic; known as `__builtin_msa_subs_u_d` in GCC.
        #[link_name = "llvm.mips.subs.u.d"]
        pub fn subs_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.subsus.u.b` intrinsic; known as `__builtin_msa_subsus_u_b` in GCC.
        #[link_name = "llvm.mips.subsus.u.b"]
        pub fn subsus_u_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.subsus.u.h` intrinsic; known as `__builtin_msa_subsus_u_h` in GCC.
        #[link_name = "llvm.mips.subsus.u.h"]
        pub fn subsus_u_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.subsus.u.w` intrinsic; known as `__builtin_msa_subsus_u_w` in GCC.
        #[link_name = "llvm.mips.subsus.u.w"]
        pub fn subsus_u_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.subsus.u.d` intrinsic; known as `__builtin_msa_subsus_u_d` in GCC.
        #[link_name = "llvm.mips.subsus.u.d"]
        pub fn subsus_u_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.subsuu.s.b` intrinsic; known as `__builtin_msa_subsuu_s_b` in GCC.
        #[link_name = "llvm.mips.subsuu.s.b"]
        pub fn subsuu_s_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.subsuu.s.h` intrinsic; known as `__builtin_msa_subsuu_s_h` in GCC.
        #[link_name = "llvm.mips.subsuu.s.h"]
        pub fn subsuu_s_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.subsuu.s.w` intrinsic; known as `__builtin_msa_subsuu_s_w` in GCC.
        #[link_name = "llvm.mips.subsuu.s.w"]
        pub fn subsuu_s_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.subsuu.s.d` intrinsic; known as `__builtin_msa_subsuu_s_d` in GCC.
        #[link_name = "llvm.mips.subsuu.s.d"]
        pub fn subsuu_s_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.subv.b` intrinsic; known as `__builtin_msa_subv_b` in GCC.
        #[link_name = "llvm.mips.subv.b"]
        pub fn subv_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.subv.h` intrinsic; known as `__builtin_msa_subv_h` in GCC.
        #[link_name = "llvm.mips.subv.h"]
        pub fn subv_h(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.subv.w` intrinsic; known as `__builtin_msa_subv_w` in GCC.
        #[link_name = "llvm.mips.subv.w"]
        pub fn subv_w(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.subv.d` intrinsic; known as `__builtin_msa_subv_d` in GCC.
        #[link_name = "llvm.mips.subv.d"]
        pub fn subv_d(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.subvi.b` intrinsic; known as `__builtin_msa_subvi_b` in GCC.
        #[link_name = "llvm.mips.subvi.b"]
        pub fn subvi_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.mips.subvi.h` intrinsic; known as `__builtin_msa_subvi_h` in GCC.
        #[link_name = "llvm.mips.subvi.h"]
        pub fn subvi_h(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.mips.subvi.w` intrinsic; known as `__builtin_msa_subvi_w` in GCC.
        #[link_name = "llvm.mips.subvi.w"]
        pub fn subvi_w(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.mips.subvi.d` intrinsic; known as `__builtin_msa_subvi_d` in GCC.
        #[link_name = "llvm.mips.subvi.d"]
        pub fn subvi_d(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.mips.vshf.b` intrinsic; known as `__builtin_msa_vshf_b` in GCC.
        #[link_name = "llvm.mips.vshf.b"]
        pub fn vshf_b(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.vshf.h` intrinsic; known as `__builtin_msa_vshf_h` in GCC.
        #[link_name = "llvm.mips.vshf.h"]
        pub fn vshf_h(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.mips.vshf.w` intrinsic; known as `__builtin_msa_vshf_w` in GCC.
        #[link_name = "llvm.mips.vshf.w"]
        pub fn vshf_w(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.mips.vshf.d` intrinsic; known as `__builtin_msa_vshf_d` in GCC.
        #[link_name = "llvm.mips.vshf.d"]
        pub fn vshf_d(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.mips.xor.v` intrinsic; known as `__builtin_msa_xor_v` in GCC.
        #[link_name = "llvm.mips.xor.v"]
        pub fn xor_v(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.mips.xori.b` intrinsic; known as `__builtin_msa_xori_b` in GCC.
        #[link_name = "llvm.mips.xori.b"]
        pub fn xori_b(a: ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
    }
}
/// LLVM intrinsics for the nvvm architecture.
pub mod nvvm {
    extern {
        /// The `llvm.nvvm.clz.i` intrinsic; known as `__nvvm_clz_i` in GCC.
        #[link_name = "llvm.nvvm.clz.i"]
        pub fn clz_i(a: i32) -> i32;
        /// The `llvm.nvvm.clz.ll` intrinsic; known as `__nvvm_clz_ll` in GCC.
        #[link_name = "llvm.nvvm.clz.ll"]
        pub fn clz_ll(a: i64) -> i32;
        /// The `llvm.nvvm.popc.i` intrinsic; known as `__nvvm_popc_i` in GCC.
        #[link_name = "llvm.nvvm.popc.i"]
        pub fn popc_i(a: i32) -> i32;
        /// The `llvm.nvvm.popc.ll` intrinsic; known as `__nvvm_popc_ll` in GCC.
        #[link_name = "llvm.nvvm.popc.ll"]
        pub fn popc_ll(a: i64) -> i32;
        /// The `llvm.nvvm.prmt` intrinsic; known as `__nvvm_prmt` in GCC.
        #[link_name = "llvm.nvvm.prmt"]
        pub fn prmt(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.min.i` intrinsic; known as `__nvvm_min_i` in GCC.
        #[link_name = "llvm.nvvm.min.i"]
        pub fn min_i(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.min.ui` intrinsic; known as `__nvvm_min_ui` in GCC.
        #[link_name = "llvm.nvvm.min.ui"]
        pub fn min_ui(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.min.ll` intrinsic; known as `__nvvm_min_ll` in GCC.
        #[link_name = "llvm.nvvm.min.ll"]
        pub fn min_ll(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.min.ull` intrinsic; known as `__nvvm_min_ull` in GCC.
        #[link_name = "llvm.nvvm.min.ull"]
        pub fn min_ull(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.max.i` intrinsic; known as `__nvvm_max_i` in GCC.
        #[link_name = "llvm.nvvm.max.i"]
        pub fn max_i(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.max.ui` intrinsic; known as `__nvvm_max_ui` in GCC.
        #[link_name = "llvm.nvvm.max.ui"]
        pub fn max_ui(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.max.ll` intrinsic; known as `__nvvm_max_ll` in GCC.
        #[link_name = "llvm.nvvm.max.ll"]
        pub fn max_ll(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.max.ull` intrinsic; known as `__nvvm_max_ull` in GCC.
        #[link_name = "llvm.nvvm.max.ull"]
        pub fn max_ull(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.fmin.f` intrinsic; known as `__nvvm_fmin_f` in GCC.
        #[link_name = "llvm.nvvm.fmin.f"]
        pub fn fmin_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.fmin.ftz.f` intrinsic; known as `__nvvm_fmin_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fmin.ftz.f"]
        pub fn fmin_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.fmax.f` intrinsic; known as `__nvvm_fmax_f` in GCC.
        #[link_name = "llvm.nvvm.fmax.f"]
        pub fn fmax_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.fmax.ftz.f` intrinsic; known as `__nvvm_fmax_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fmax.ftz.f"]
        pub fn fmax_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.fmin.d` intrinsic; known as `__nvvm_fmin_d` in GCC.
        #[link_name = "llvm.nvvm.fmin.d"]
        pub fn fmin_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.fmax.d` intrinsic; known as `__nvvm_fmax_d` in GCC.
        #[link_name = "llvm.nvvm.fmax.d"]
        pub fn fmax_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.mulhi.i` intrinsic; known as `__nvvm_mulhi_i` in GCC.
        #[link_name = "llvm.nvvm.mulhi.i"]
        pub fn mulhi_i(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.mulhi.ui` intrinsic; known as `__nvvm_mulhi_ui` in GCC.
        #[link_name = "llvm.nvvm.mulhi.ui"]
        pub fn mulhi_ui(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.mulhi.ll` intrinsic; known as `__nvvm_mulhi_ll` in GCC.
        #[link_name = "llvm.nvvm.mulhi.ll"]
        pub fn mulhi_ll(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.mulhi.ull` intrinsic; known as `__nvvm_mulhi_ull` in GCC.
        #[link_name = "llvm.nvvm.mulhi.ull"]
        pub fn mulhi_ull(a: i64, b: i64) -> i64;
        /// The `llvm.nvvm.mul.rn.ftz.f` intrinsic; known as `__nvvm_mul_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rn.ftz.f"]
        pub fn mul_rn_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rn.f` intrinsic; known as `__nvvm_mul_rn_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rn.f"]
        pub fn mul_rn_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rz.ftz.f` intrinsic; known as `__nvvm_mul_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rz.ftz.f"]
        pub fn mul_rz_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rz.f` intrinsic; known as `__nvvm_mul_rz_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rz.f"]
        pub fn mul_rz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rm.ftz.f` intrinsic; known as `__nvvm_mul_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rm.ftz.f"]
        pub fn mul_rm_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rm.f` intrinsic; known as `__nvvm_mul_rm_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rm.f"]
        pub fn mul_rm_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rp.ftz.f` intrinsic; known as `__nvvm_mul_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rp.ftz.f"]
        pub fn mul_rp_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rp.f` intrinsic; known as `__nvvm_mul_rp_f` in GCC.
        #[link_name = "llvm.nvvm.mul.rp.f"]
        pub fn mul_rp_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.mul.rn.d` intrinsic; known as `__nvvm_mul_rn_d` in GCC.
        #[link_name = "llvm.nvvm.mul.rn.d"]
        pub fn mul_rn_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.mul.rz.d` intrinsic; known as `__nvvm_mul_rz_d` in GCC.
        #[link_name = "llvm.nvvm.mul.rz.d"]
        pub fn mul_rz_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.mul.rm.d` intrinsic; known as `__nvvm_mul_rm_d` in GCC.
        #[link_name = "llvm.nvvm.mul.rm.d"]
        pub fn mul_rm_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.mul.rp.d` intrinsic; known as `__nvvm_mul_rp_d` in GCC.
        #[link_name = "llvm.nvvm.mul.rp.d"]
        pub fn mul_rp_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.mul24.i` intrinsic; known as `__nvvm_mul24_i` in GCC.
        #[link_name = "llvm.nvvm.mul24.i"]
        pub fn mul24_i(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.mul24.ui` intrinsic; known as `__nvvm_mul24_ui` in GCC.
        #[link_name = "llvm.nvvm.mul24.ui"]
        pub fn mul24_ui(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.div.approx.ftz.f` intrinsic; known as `__nvvm_div_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.div.approx.ftz.f"]
        pub fn div_approx_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.approx.f` intrinsic; known as `__nvvm_div_approx_f` in GCC.
        #[link_name = "llvm.nvvm.div.approx.f"]
        pub fn div_approx_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rn.ftz.f` intrinsic; known as `__nvvm_div_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.div.rn.ftz.f"]
        pub fn div_rn_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rn.f` intrinsic; known as `__nvvm_div_rn_f` in GCC.
        #[link_name = "llvm.nvvm.div.rn.f"]
        pub fn div_rn_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rz.ftz.f` intrinsic; known as `__nvvm_div_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.div.rz.ftz.f"]
        pub fn div_rz_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rz.f` intrinsic; known as `__nvvm_div_rz_f` in GCC.
        #[link_name = "llvm.nvvm.div.rz.f"]
        pub fn div_rz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rm.ftz.f` intrinsic; known as `__nvvm_div_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.div.rm.ftz.f"]
        pub fn div_rm_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rm.f` intrinsic; known as `__nvvm_div_rm_f` in GCC.
        #[link_name = "llvm.nvvm.div.rm.f"]
        pub fn div_rm_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rp.ftz.f` intrinsic; known as `__nvvm_div_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.div.rp.ftz.f"]
        pub fn div_rp_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rp.f` intrinsic; known as `__nvvm_div_rp_f` in GCC.
        #[link_name = "llvm.nvvm.div.rp.f"]
        pub fn div_rp_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.div.rn.d` intrinsic; known as `__nvvm_div_rn_d` in GCC.
        #[link_name = "llvm.nvvm.div.rn.d"]
        pub fn div_rn_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.div.rz.d` intrinsic; known as `__nvvm_div_rz_d` in GCC.
        #[link_name = "llvm.nvvm.div.rz.d"]
        pub fn div_rz_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.div.rm.d` intrinsic; known as `__nvvm_div_rm_d` in GCC.
        #[link_name = "llvm.nvvm.div.rm.d"]
        pub fn div_rm_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.div.rp.d` intrinsic; known as `__nvvm_div_rp_d` in GCC.
        #[link_name = "llvm.nvvm.div.rp.d"]
        pub fn div_rp_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.brev32` intrinsic; known as `__nvvm_brev32` in GCC.
        #[link_name = "llvm.nvvm.brev32"]
        pub fn brev32(a: i32) -> i32;
        /// The `llvm.nvvm.brev64` intrinsic; known as `__nvvm_brev64` in GCC.
        #[link_name = "llvm.nvvm.brev64"]
        pub fn brev64(a: i64) -> i64;
        /// The `llvm.nvvm.sad.i` intrinsic; known as `__nvvm_sad_i` in GCC.
        #[link_name = "llvm.nvvm.sad.i"]
        pub fn sad_i(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.sad.ui` intrinsic; known as `__nvvm_sad_ui` in GCC.
        #[link_name = "llvm.nvvm.sad.ui"]
        pub fn sad_ui(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.floor.ftz.f` intrinsic; known as `__nvvm_floor_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.floor.ftz.f"]
        pub fn floor_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.floor.f` intrinsic; known as `__nvvm_floor_f` in GCC.
        #[link_name = "llvm.nvvm.floor.f"]
        pub fn floor_f(a: f32) -> f32;
        /// The `llvm.nvvm.floor.d` intrinsic; known as `__nvvm_floor_d` in GCC.
        #[link_name = "llvm.nvvm.floor.d"]
        pub fn floor_d(a: f64) -> f64;
        /// The `llvm.nvvm.ceil.ftz.f` intrinsic; known as `__nvvm_ceil_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.ceil.ftz.f"]
        pub fn ceil_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.ceil.f` intrinsic; known as `__nvvm_ceil_f` in GCC.
        #[link_name = "llvm.nvvm.ceil.f"]
        pub fn ceil_f(a: f32) -> f32;
        /// The `llvm.nvvm.ceil.d` intrinsic; known as `__nvvm_ceil_d` in GCC.
        #[link_name = "llvm.nvvm.ceil.d"]
        pub fn ceil_d(a: f64) -> f64;
        /// The `llvm.nvvm.abs.i` intrinsic; known as `__nvvm_abs_i` in GCC.
        #[link_name = "llvm.nvvm.abs.i"]
        pub fn abs_i(a: i32) -> i32;
        /// The `llvm.nvvm.abs.ll` intrinsic; known as `__nvvm_abs_ll` in GCC.
        #[link_name = "llvm.nvvm.abs.ll"]
        pub fn abs_ll(a: i64) -> i64;
        /// The `llvm.nvvm.fabs.ftz.f` intrinsic; known as `__nvvm_fabs_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fabs.ftz.f"]
        pub fn fabs_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.fabs.f` intrinsic; known as `__nvvm_fabs_f` in GCC.
        #[link_name = "llvm.nvvm.fabs.f"]
        pub fn fabs_f(a: f32) -> f32;
        /// The `llvm.nvvm.fabs.d` intrinsic; known as `__nvvm_fabs_d` in GCC.
        #[link_name = "llvm.nvvm.fabs.d"]
        pub fn fabs_d(a: f64) -> f64;
        /// The `llvm.nvvm.round.ftz.f` intrinsic; known as `__nvvm_round_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.round.ftz.f"]
        pub fn round_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.round.f` intrinsic; known as `__nvvm_round_f` in GCC.
        #[link_name = "llvm.nvvm.round.f"]
        pub fn round_f(a: f32) -> f32;
        /// The `llvm.nvvm.round.d` intrinsic; known as `__nvvm_round_d` in GCC.
        #[link_name = "llvm.nvvm.round.d"]
        pub fn round_d(a: f64) -> f64;
        /// The `llvm.nvvm.trunc.ftz.f` intrinsic; known as `__nvvm_trunc_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.trunc.ftz.f"]
        pub fn trunc_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.trunc.f` intrinsic; known as `__nvvm_trunc_f` in GCC.
        #[link_name = "llvm.nvvm.trunc.f"]
        pub fn trunc_f(a: f32) -> f32;
        /// The `llvm.nvvm.trunc.d` intrinsic; known as `__nvvm_trunc_d` in GCC.
        #[link_name = "llvm.nvvm.trunc.d"]
        pub fn trunc_d(a: f64) -> f64;
        /// The `llvm.nvvm.saturate.ftz.f` intrinsic; known as `__nvvm_saturate_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.saturate.ftz.f"]
        pub fn saturate_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.saturate.f` intrinsic; known as `__nvvm_saturate_f` in GCC.
        #[link_name = "llvm.nvvm.saturate.f"]
        pub fn saturate_f(a: f32) -> f32;
        /// The `llvm.nvvm.saturate.d` intrinsic; known as `__nvvm_saturate_d` in GCC.
        #[link_name = "llvm.nvvm.saturate.d"]
        pub fn saturate_d(a: f64) -> f64;
        /// The `llvm.nvvm.ex2.approx.ftz.f` intrinsic; known as `__nvvm_ex2_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.ex2.approx.ftz.f"]
        pub fn ex2_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.ex2.approx.f` intrinsic; known as `__nvvm_ex2_approx_f` in GCC.
        #[link_name = "llvm.nvvm.ex2.approx.f"]
        pub fn ex2_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.ex2.approx.d` intrinsic; known as `__nvvm_ex2_approx_d` in GCC.
        #[link_name = "llvm.nvvm.ex2.approx.d"]
        pub fn ex2_approx_d(a: f64) -> f64;
        /// The `llvm.nvvm.lg2.approx.ftz.f` intrinsic; known as `__nvvm_lg2_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.lg2.approx.ftz.f"]
        pub fn lg2_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.lg2.approx.f` intrinsic; known as `__nvvm_lg2_approx_f` in GCC.
        #[link_name = "llvm.nvvm.lg2.approx.f"]
        pub fn lg2_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.lg2.approx.d` intrinsic; known as `__nvvm_lg2_approx_d` in GCC.
        #[link_name = "llvm.nvvm.lg2.approx.d"]
        pub fn lg2_approx_d(a: f64) -> f64;
        /// The `llvm.nvvm.sin.approx.ftz.f` intrinsic; known as `__nvvm_sin_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sin.approx.ftz.f"]
        pub fn sin_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sin.approx.f` intrinsic; known as `__nvvm_sin_approx_f` in GCC.
        #[link_name = "llvm.nvvm.sin.approx.f"]
        pub fn sin_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.cos.approx.ftz.f` intrinsic; known as `__nvvm_cos_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.cos.approx.ftz.f"]
        pub fn cos_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.cos.approx.f` intrinsic; known as `__nvvm_cos_approx_f` in GCC.
        #[link_name = "llvm.nvvm.cos.approx.f"]
        pub fn cos_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.fma.rn.ftz.f` intrinsic; known as `__nvvm_fma_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rn.ftz.f"]
        pub fn fma_rn_ftz_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rn.f` intrinsic; known as `__nvvm_fma_rn_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rn.f"]
        pub fn fma_rn_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rz.ftz.f` intrinsic; known as `__nvvm_fma_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rz.ftz.f"]
        pub fn fma_rz_ftz_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rz.f` intrinsic; known as `__nvvm_fma_rz_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rz.f"]
        pub fn fma_rz_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rm.ftz.f` intrinsic; known as `__nvvm_fma_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rm.ftz.f"]
        pub fn fma_rm_ftz_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rm.f` intrinsic; known as `__nvvm_fma_rm_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rm.f"]
        pub fn fma_rm_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rp.ftz.f` intrinsic; known as `__nvvm_fma_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rp.ftz.f"]
        pub fn fma_rp_ftz_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rp.f` intrinsic; known as `__nvvm_fma_rp_f` in GCC.
        #[link_name = "llvm.nvvm.fma.rp.f"]
        pub fn fma_rp_f(a: f32, b: f32, c: f32) -> f32;
        /// The `llvm.nvvm.fma.rn.d` intrinsic; known as `__nvvm_fma_rn_d` in GCC.
        #[link_name = "llvm.nvvm.fma.rn.d"]
        pub fn fma_rn_d(a: f64, b: f64, c: f64) -> f64;
        /// The `llvm.nvvm.fma.rz.d` intrinsic; known as `__nvvm_fma_rz_d` in GCC.
        #[link_name = "llvm.nvvm.fma.rz.d"]
        pub fn fma_rz_d(a: f64, b: f64, c: f64) -> f64;
        /// The `llvm.nvvm.fma.rm.d` intrinsic; known as `__nvvm_fma_rm_d` in GCC.
        #[link_name = "llvm.nvvm.fma.rm.d"]
        pub fn fma_rm_d(a: f64, b: f64, c: f64) -> f64;
        /// The `llvm.nvvm.fma.rp.d` intrinsic; known as `__nvvm_fma_rp_d` in GCC.
        #[link_name = "llvm.nvvm.fma.rp.d"]
        pub fn fma_rp_d(a: f64, b: f64, c: f64) -> f64;
        /// The `llvm.nvvm.rcp.rn.ftz.f` intrinsic; known as `__nvvm_rcp_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rn.ftz.f"]
        pub fn rcp_rn_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rn.f` intrinsic; known as `__nvvm_rcp_rn_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rn.f"]
        pub fn rcp_rn_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rz.ftz.f` intrinsic; known as `__nvvm_rcp_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rz.ftz.f"]
        pub fn rcp_rz_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rz.f` intrinsic; known as `__nvvm_rcp_rz_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rz.f"]
        pub fn rcp_rz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rm.ftz.f` intrinsic; known as `__nvvm_rcp_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rm.ftz.f"]
        pub fn rcp_rm_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rm.f` intrinsic; known as `__nvvm_rcp_rm_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rm.f"]
        pub fn rcp_rm_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rp.ftz.f` intrinsic; known as `__nvvm_rcp_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rp.ftz.f"]
        pub fn rcp_rp_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rp.f` intrinsic; known as `__nvvm_rcp_rp_f` in GCC.
        #[link_name = "llvm.nvvm.rcp.rp.f"]
        pub fn rcp_rp_f(a: f32) -> f32;
        /// The `llvm.nvvm.rcp.rn.d` intrinsic; known as `__nvvm_rcp_rn_d` in GCC.
        #[link_name = "llvm.nvvm.rcp.rn.d"]
        pub fn rcp_rn_d(a: f64) -> f64;
        /// The `llvm.nvvm.rcp.rz.d` intrinsic; known as `__nvvm_rcp_rz_d` in GCC.
        #[link_name = "llvm.nvvm.rcp.rz.d"]
        pub fn rcp_rz_d(a: f64) -> f64;
        /// The `llvm.nvvm.rcp.rm.d` intrinsic; known as `__nvvm_rcp_rm_d` in GCC.
        #[link_name = "llvm.nvvm.rcp.rm.d"]
        pub fn rcp_rm_d(a: f64) -> f64;
        /// The `llvm.nvvm.rcp.rp.d` intrinsic; known as `__nvvm_rcp_rp_d` in GCC.
        #[link_name = "llvm.nvvm.rcp.rp.d"]
        pub fn rcp_rp_d(a: f64) -> f64;
        /// The `llvm.nvvm.rcp.approx.ftz.d` intrinsic; known as `__nvvm_rcp_approx_ftz_d` in GCC.
        #[link_name = "llvm.nvvm.rcp.approx.ftz.d"]
        pub fn rcp_approx_ftz_d(a: f64) -> f64;
        /// The `llvm.nvvm.sqrt.f` intrinsic; known as `__nvvm_sqrt_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.f"]
        pub fn sqrt_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rn.ftz.f` intrinsic; known as `__nvvm_sqrt_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rn.ftz.f"]
        pub fn sqrt_rn_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rn.f` intrinsic; known as `__nvvm_sqrt_rn_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rn.f"]
        pub fn sqrt_rn_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rz.ftz.f` intrinsic; known as `__nvvm_sqrt_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rz.ftz.f"]
        pub fn sqrt_rz_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rz.f` intrinsic; known as `__nvvm_sqrt_rz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rz.f"]
        pub fn sqrt_rz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rm.ftz.f` intrinsic; known as `__nvvm_sqrt_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rm.ftz.f"]
        pub fn sqrt_rm_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rm.f` intrinsic; known as `__nvvm_sqrt_rm_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rm.f"]
        pub fn sqrt_rm_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rp.ftz.f` intrinsic; known as `__nvvm_sqrt_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rp.ftz.f"]
        pub fn sqrt_rp_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rp.f` intrinsic; known as `__nvvm_sqrt_rp_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rp.f"]
        pub fn sqrt_rp_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.approx.ftz.f` intrinsic; known as `__nvvm_sqrt_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.approx.ftz.f"]
        pub fn sqrt_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.approx.f` intrinsic; known as `__nvvm_sqrt_approx_f` in GCC.
        #[link_name = "llvm.nvvm.sqrt.approx.f"]
        pub fn sqrt_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.sqrt.rn.d` intrinsic; known as `__nvvm_sqrt_rn_d` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rn.d"]
        pub fn sqrt_rn_d(a: f64) -> f64;
        /// The `llvm.nvvm.sqrt.rz.d` intrinsic; known as `__nvvm_sqrt_rz_d` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rz.d"]
        pub fn sqrt_rz_d(a: f64) -> f64;
        /// The `llvm.nvvm.sqrt.rm.d` intrinsic; known as `__nvvm_sqrt_rm_d` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rm.d"]
        pub fn sqrt_rm_d(a: f64) -> f64;
        /// The `llvm.nvvm.sqrt.rp.d` intrinsic; known as `__nvvm_sqrt_rp_d` in GCC.
        #[link_name = "llvm.nvvm.sqrt.rp.d"]
        pub fn sqrt_rp_d(a: f64) -> f64;
        /// The `llvm.nvvm.rsqrt.approx.ftz.f` intrinsic; known as `__nvvm_rsqrt_approx_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.rsqrt.approx.ftz.f"]
        pub fn rsqrt_approx_ftz_f(a: f32) -> f32;
        /// The `llvm.nvvm.rsqrt.approx.f` intrinsic; known as `__nvvm_rsqrt_approx_f` in GCC.
        #[link_name = "llvm.nvvm.rsqrt.approx.f"]
        pub fn rsqrt_approx_f(a: f32) -> f32;
        /// The `llvm.nvvm.rsqrt.approx.d` intrinsic; known as `__nvvm_rsqrt_approx_d` in GCC.
        #[link_name = "llvm.nvvm.rsqrt.approx.d"]
        pub fn rsqrt_approx_d(a: f64) -> f64;
        /// The `llvm.nvvm.add.rn.ftz.f` intrinsic; known as `__nvvm_add_rn_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.add.rn.ftz.f"]
        pub fn add_rn_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rn.f` intrinsic; known as `__nvvm_add_rn_f` in GCC.
        #[link_name = "llvm.nvvm.add.rn.f"]
        pub fn add_rn_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rz.ftz.f` intrinsic; known as `__nvvm_add_rz_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.add.rz.ftz.f"]
        pub fn add_rz_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rz.f` intrinsic; known as `__nvvm_add_rz_f` in GCC.
        #[link_name = "llvm.nvvm.add.rz.f"]
        pub fn add_rz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rm.ftz.f` intrinsic; known as `__nvvm_add_rm_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.add.rm.ftz.f"]
        pub fn add_rm_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rm.f` intrinsic; known as `__nvvm_add_rm_f` in GCC.
        #[link_name = "llvm.nvvm.add.rm.f"]
        pub fn add_rm_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rp.ftz.f` intrinsic; known as `__nvvm_add_rp_ftz_f` in GCC.
        #[link_name = "llvm.nvvm.add.rp.ftz.f"]
        pub fn add_rp_ftz_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rp.f` intrinsic; known as `__nvvm_add_rp_f` in GCC.
        #[link_name = "llvm.nvvm.add.rp.f"]
        pub fn add_rp_f(a: f32, b: f32) -> f32;
        /// The `llvm.nvvm.add.rn.d` intrinsic; known as `__nvvm_add_rn_d` in GCC.
        #[link_name = "llvm.nvvm.add.rn.d"]
        pub fn add_rn_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.add.rz.d` intrinsic; known as `__nvvm_add_rz_d` in GCC.
        #[link_name = "llvm.nvvm.add.rz.d"]
        pub fn add_rz_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.add.rm.d` intrinsic; known as `__nvvm_add_rm_d` in GCC.
        #[link_name = "llvm.nvvm.add.rm.d"]
        pub fn add_rm_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.add.rp.d` intrinsic; known as `__nvvm_add_rp_d` in GCC.
        #[link_name = "llvm.nvvm.add.rp.d"]
        pub fn add_rp_d(a: f64, b: f64) -> f64;
        /// The `llvm.nvvm.d2f.rn.ftz` intrinsic; known as `__nvvm_d2f_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.d2f.rn.ftz"]
        pub fn d2f_rn_ftz(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rn` intrinsic; known as `__nvvm_d2f_rn` in GCC.
        #[link_name = "llvm.nvvm.d2f.rn"]
        pub fn d2f_rn(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rz.ftz` intrinsic; known as `__nvvm_d2f_rz_ftz` in GCC.
        #[link_name = "llvm.nvvm.d2f.rz.ftz"]
        pub fn d2f_rz_ftz(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rz` intrinsic; known as `__nvvm_d2f_rz` in GCC.
        #[link_name = "llvm.nvvm.d2f.rz"]
        pub fn d2f_rz(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rm.ftz` intrinsic; known as `__nvvm_d2f_rm_ftz` in GCC.
        #[link_name = "llvm.nvvm.d2f.rm.ftz"]
        pub fn d2f_rm_ftz(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rm` intrinsic; known as `__nvvm_d2f_rm` in GCC.
        #[link_name = "llvm.nvvm.d2f.rm"]
        pub fn d2f_rm(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rp.ftz` intrinsic; known as `__nvvm_d2f_rp_ftz` in GCC.
        #[link_name = "llvm.nvvm.d2f.rp.ftz"]
        pub fn d2f_rp_ftz(a: f64) -> f32;
        /// The `llvm.nvvm.d2f.rp` intrinsic; known as `__nvvm_d2f_rp` in GCC.
        #[link_name = "llvm.nvvm.d2f.rp"]
        pub fn d2f_rp(a: f64) -> f32;
        /// The `llvm.nvvm.d2i.rn` intrinsic; known as `__nvvm_d2i_rn` in GCC.
        #[link_name = "llvm.nvvm.d2i.rn"]
        pub fn d2i_rn(a: f64) -> i32;
        /// The `llvm.nvvm.d2i.rz` intrinsic; known as `__nvvm_d2i_rz` in GCC.
        #[link_name = "llvm.nvvm.d2i.rz"]
        pub fn d2i_rz(a: f64) -> i32;
        /// The `llvm.nvvm.d2i.rm` intrinsic; known as `__nvvm_d2i_rm` in GCC.
        #[link_name = "llvm.nvvm.d2i.rm"]
        pub fn d2i_rm(a: f64) -> i32;
        /// The `llvm.nvvm.d2i.rp` intrinsic; known as `__nvvm_d2i_rp` in GCC.
        #[link_name = "llvm.nvvm.d2i.rp"]
        pub fn d2i_rp(a: f64) -> i32;
        /// The `llvm.nvvm.d2ui.rn` intrinsic; known as `__nvvm_d2ui_rn` in GCC.
        #[link_name = "llvm.nvvm.d2ui.rn"]
        pub fn d2ui_rn(a: f64) -> i32;
        /// The `llvm.nvvm.d2ui.rz` intrinsic; known as `__nvvm_d2ui_rz` in GCC.
        #[link_name = "llvm.nvvm.d2ui.rz"]
        pub fn d2ui_rz(a: f64) -> i32;
        /// The `llvm.nvvm.d2ui.rm` intrinsic; known as `__nvvm_d2ui_rm` in GCC.
        #[link_name = "llvm.nvvm.d2ui.rm"]
        pub fn d2ui_rm(a: f64) -> i32;
        /// The `llvm.nvvm.d2ui.rp` intrinsic; known as `__nvvm_d2ui_rp` in GCC.
        #[link_name = "llvm.nvvm.d2ui.rp"]
        pub fn d2ui_rp(a: f64) -> i32;
        /// The `llvm.nvvm.i2d.rn` intrinsic; known as `__nvvm_i2d_rn` in GCC.
        #[link_name = "llvm.nvvm.i2d.rn"]
        pub fn i2d_rn(a: i32) -> f64;
        /// The `llvm.nvvm.i2d.rz` intrinsic; known as `__nvvm_i2d_rz` in GCC.
        #[link_name = "llvm.nvvm.i2d.rz"]
        pub fn i2d_rz(a: i32) -> f64;
        /// The `llvm.nvvm.i2d.rm` intrinsic; known as `__nvvm_i2d_rm` in GCC.
        #[link_name = "llvm.nvvm.i2d.rm"]
        pub fn i2d_rm(a: i32) -> f64;
        /// The `llvm.nvvm.i2d.rp` intrinsic; known as `__nvvm_i2d_rp` in GCC.
        #[link_name = "llvm.nvvm.i2d.rp"]
        pub fn i2d_rp(a: i32) -> f64;
        /// The `llvm.nvvm.ui2d.rn` intrinsic; known as `__nvvm_ui2d_rn` in GCC.
        #[link_name = "llvm.nvvm.ui2d.rn"]
        pub fn ui2d_rn(a: i32) -> f64;
        /// The `llvm.nvvm.ui2d.rz` intrinsic; known as `__nvvm_ui2d_rz` in GCC.
        #[link_name = "llvm.nvvm.ui2d.rz"]
        pub fn ui2d_rz(a: i32) -> f64;
        /// The `llvm.nvvm.ui2d.rm` intrinsic; known as `__nvvm_ui2d_rm` in GCC.
        #[link_name = "llvm.nvvm.ui2d.rm"]
        pub fn ui2d_rm(a: i32) -> f64;
        /// The `llvm.nvvm.ui2d.rp` intrinsic; known as `__nvvm_ui2d_rp` in GCC.
        #[link_name = "llvm.nvvm.ui2d.rp"]
        pub fn ui2d_rp(a: i32) -> f64;
        /// The `llvm.nvvm.f2i.rn.ftz` intrinsic; known as `__nvvm_f2i_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2i.rn.ftz"]
        pub fn f2i_rn_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rn` intrinsic; known as `__nvvm_f2i_rn` in GCC.
        #[link_name = "llvm.nvvm.f2i.rn"]
        pub fn f2i_rn(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rz.ftz` intrinsic; known as `__nvvm_f2i_rz_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2i.rz.ftz"]
        pub fn f2i_rz_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rz` intrinsic; known as `__nvvm_f2i_rz` in GCC.
        #[link_name = "llvm.nvvm.f2i.rz"]
        pub fn f2i_rz(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rm.ftz` intrinsic; known as `__nvvm_f2i_rm_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2i.rm.ftz"]
        pub fn f2i_rm_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rm` intrinsic; known as `__nvvm_f2i_rm` in GCC.
        #[link_name = "llvm.nvvm.f2i.rm"]
        pub fn f2i_rm(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rp.ftz` intrinsic; known as `__nvvm_f2i_rp_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2i.rp.ftz"]
        pub fn f2i_rp_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2i.rp` intrinsic; known as `__nvvm_f2i_rp` in GCC.
        #[link_name = "llvm.nvvm.f2i.rp"]
        pub fn f2i_rp(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rn.ftz` intrinsic; known as `__nvvm_f2ui_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rn.ftz"]
        pub fn f2ui_rn_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rn` intrinsic; known as `__nvvm_f2ui_rn` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rn"]
        pub fn f2ui_rn(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rz.ftz` intrinsic; known as `__nvvm_f2ui_rz_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rz.ftz"]
        pub fn f2ui_rz_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rz` intrinsic; known as `__nvvm_f2ui_rz` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rz"]
        pub fn f2ui_rz(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rm.ftz` intrinsic; known as `__nvvm_f2ui_rm_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rm.ftz"]
        pub fn f2ui_rm_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rm` intrinsic; known as `__nvvm_f2ui_rm` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rm"]
        pub fn f2ui_rm(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rp.ftz` intrinsic; known as `__nvvm_f2ui_rp_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rp.ftz"]
        pub fn f2ui_rp_ftz(a: f32) -> i32;
        /// The `llvm.nvvm.f2ui.rp` intrinsic; known as `__nvvm_f2ui_rp` in GCC.
        #[link_name = "llvm.nvvm.f2ui.rp"]
        pub fn f2ui_rp(a: f32) -> i32;
        /// The `llvm.nvvm.i2f.rn` intrinsic; known as `__nvvm_i2f_rn` in GCC.
        #[link_name = "llvm.nvvm.i2f.rn"]
        pub fn i2f_rn(a: i32) -> f32;
        /// The `llvm.nvvm.i2f.rz` intrinsic; known as `__nvvm_i2f_rz` in GCC.
        #[link_name = "llvm.nvvm.i2f.rz"]
        pub fn i2f_rz(a: i32) -> f32;
        /// The `llvm.nvvm.i2f.rm` intrinsic; known as `__nvvm_i2f_rm` in GCC.
        #[link_name = "llvm.nvvm.i2f.rm"]
        pub fn i2f_rm(a: i32) -> f32;
        /// The `llvm.nvvm.i2f.rp` intrinsic; known as `__nvvm_i2f_rp` in GCC.
        #[link_name = "llvm.nvvm.i2f.rp"]
        pub fn i2f_rp(a: i32) -> f32;
        /// The `llvm.nvvm.ui2f.rn` intrinsic; known as `__nvvm_ui2f_rn` in GCC.
        #[link_name = "llvm.nvvm.ui2f.rn"]
        pub fn ui2f_rn(a: i32) -> f32;
        /// The `llvm.nvvm.ui2f.rz` intrinsic; known as `__nvvm_ui2f_rz` in GCC.
        #[link_name = "llvm.nvvm.ui2f.rz"]
        pub fn ui2f_rz(a: i32) -> f32;
        /// The `llvm.nvvm.ui2f.rm` intrinsic; known as `__nvvm_ui2f_rm` in GCC.
        #[link_name = "llvm.nvvm.ui2f.rm"]
        pub fn ui2f_rm(a: i32) -> f32;
        /// The `llvm.nvvm.ui2f.rp` intrinsic; known as `__nvvm_ui2f_rp` in GCC.
        #[link_name = "llvm.nvvm.ui2f.rp"]
        pub fn ui2f_rp(a: i32) -> f32;
        /// The `llvm.nvvm.lohi.i2d` intrinsic; known as `__nvvm_lohi_i2d` in GCC.
        #[link_name = "llvm.nvvm.lohi.i2d"]
        pub fn lohi_i2d(a: i32, b: i32) -> f64;
        /// The `llvm.nvvm.d2i.lo` intrinsic; known as `__nvvm_d2i_lo` in GCC.
        #[link_name = "llvm.nvvm.d2i.lo"]
        pub fn d2i_lo(a: f64) -> i32;
        /// The `llvm.nvvm.d2i.hi` intrinsic; known as `__nvvm_d2i_hi` in GCC.
        #[link_name = "llvm.nvvm.d2i.hi"]
        pub fn d2i_hi(a: f64) -> i32;
        /// The `llvm.nvvm.f2ll.rn.ftz` intrinsic; known as `__nvvm_f2ll_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rn.ftz"]
        pub fn f2ll_rn_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rn` intrinsic; known as `__nvvm_f2ll_rn` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rn"]
        pub fn f2ll_rn(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rz.ftz` intrinsic; known as `__nvvm_f2ll_rz_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rz.ftz"]
        pub fn f2ll_rz_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rz` intrinsic; known as `__nvvm_f2ll_rz` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rz"]
        pub fn f2ll_rz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rm.ftz` intrinsic; known as `__nvvm_f2ll_rm_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rm.ftz"]
        pub fn f2ll_rm_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rm` intrinsic; known as `__nvvm_f2ll_rm` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rm"]
        pub fn f2ll_rm(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rp.ftz` intrinsic; known as `__nvvm_f2ll_rp_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rp.ftz"]
        pub fn f2ll_rp_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ll.rp` intrinsic; known as `__nvvm_f2ll_rp` in GCC.
        #[link_name = "llvm.nvvm.f2ll.rp"]
        pub fn f2ll_rp(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rn.ftz` intrinsic; known as `__nvvm_f2ull_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rn.ftz"]
        pub fn f2ull_rn_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rn` intrinsic; known as `__nvvm_f2ull_rn` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rn"]
        pub fn f2ull_rn(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rz.ftz` intrinsic; known as `__nvvm_f2ull_rz_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rz.ftz"]
        pub fn f2ull_rz_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rz` intrinsic; known as `__nvvm_f2ull_rz` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rz"]
        pub fn f2ull_rz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rm.ftz` intrinsic; known as `__nvvm_f2ull_rm_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rm.ftz"]
        pub fn f2ull_rm_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rm` intrinsic; known as `__nvvm_f2ull_rm` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rm"]
        pub fn f2ull_rm(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rp.ftz` intrinsic; known as `__nvvm_f2ull_rp_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rp.ftz"]
        pub fn f2ull_rp_ftz(a: f32) -> i64;
        /// The `llvm.nvvm.f2ull.rp` intrinsic; known as `__nvvm_f2ull_rp` in GCC.
        #[link_name = "llvm.nvvm.f2ull.rp"]
        pub fn f2ull_rp(a: f32) -> i64;
        /// The `llvm.nvvm.d2ll.rn` intrinsic; known as `__nvvm_d2ll_rn` in GCC.
        #[link_name = "llvm.nvvm.d2ll.rn"]
        pub fn d2ll_rn(a: f64) -> i64;
        /// The `llvm.nvvm.d2ll.rz` intrinsic; known as `__nvvm_d2ll_rz` in GCC.
        #[link_name = "llvm.nvvm.d2ll.rz"]
        pub fn d2ll_rz(a: f64) -> i64;
        /// The `llvm.nvvm.d2ll.rm` intrinsic; known as `__nvvm_d2ll_rm` in GCC.
        #[link_name = "llvm.nvvm.d2ll.rm"]
        pub fn d2ll_rm(a: f64) -> i64;
        /// The `llvm.nvvm.d2ll.rp` intrinsic; known as `__nvvm_d2ll_rp` in GCC.
        #[link_name = "llvm.nvvm.d2ll.rp"]
        pub fn d2ll_rp(a: f64) -> i64;
        /// The `llvm.nvvm.d2ull.rn` intrinsic; known as `__nvvm_d2ull_rn` in GCC.
        #[link_name = "llvm.nvvm.d2ull.rn"]
        pub fn d2ull_rn(a: f64) -> i64;
        /// The `llvm.nvvm.d2ull.rz` intrinsic; known as `__nvvm_d2ull_rz` in GCC.
        #[link_name = "llvm.nvvm.d2ull.rz"]
        pub fn d2ull_rz(a: f64) -> i64;
        /// The `llvm.nvvm.d2ull.rm` intrinsic; known as `__nvvm_d2ull_rm` in GCC.
        #[link_name = "llvm.nvvm.d2ull.rm"]
        pub fn d2ull_rm(a: f64) -> i64;
        /// The `llvm.nvvm.d2ull.rp` intrinsic; known as `__nvvm_d2ull_rp` in GCC.
        #[link_name = "llvm.nvvm.d2ull.rp"]
        pub fn d2ull_rp(a: f64) -> i64;
        /// The `llvm.nvvm.ll2f.rn` intrinsic; known as `__nvvm_ll2f_rn` in GCC.
        #[link_name = "llvm.nvvm.ll2f.rn"]
        pub fn ll2f_rn(a: i64) -> f32;
        /// The `llvm.nvvm.ll2f.rz` intrinsic; known as `__nvvm_ll2f_rz` in GCC.
        #[link_name = "llvm.nvvm.ll2f.rz"]
        pub fn ll2f_rz(a: i64) -> f32;
        /// The `llvm.nvvm.ll2f.rm` intrinsic; known as `__nvvm_ll2f_rm` in GCC.
        #[link_name = "llvm.nvvm.ll2f.rm"]
        pub fn ll2f_rm(a: i64) -> f32;
        /// The `llvm.nvvm.ll2f.rp` intrinsic; known as `__nvvm_ll2f_rp` in GCC.
        #[link_name = "llvm.nvvm.ll2f.rp"]
        pub fn ll2f_rp(a: i64) -> f32;
        /// The `llvm.nvvm.ull2f.rn` intrinsic; known as `__nvvm_ull2f_rn` in GCC.
        #[link_name = "llvm.nvvm.ull2f.rn"]
        pub fn ull2f_rn(a: i64) -> f32;
        /// The `llvm.nvvm.ull2f.rz` intrinsic; known as `__nvvm_ull2f_rz` in GCC.
        #[link_name = "llvm.nvvm.ull2f.rz"]
        pub fn ull2f_rz(a: i64) -> f32;
        /// The `llvm.nvvm.ull2f.rm` intrinsic; known as `__nvvm_ull2f_rm` in GCC.
        #[link_name = "llvm.nvvm.ull2f.rm"]
        pub fn ull2f_rm(a: i64) -> f32;
        /// The `llvm.nvvm.ull2f.rp` intrinsic; known as `__nvvm_ull2f_rp` in GCC.
        #[link_name = "llvm.nvvm.ull2f.rp"]
        pub fn ull2f_rp(a: i64) -> f32;
        /// The `llvm.nvvm.ll2d.rn` intrinsic; known as `__nvvm_ll2d_rn` in GCC.
        #[link_name = "llvm.nvvm.ll2d.rn"]
        pub fn ll2d_rn(a: i64) -> f64;
        /// The `llvm.nvvm.ll2d.rz` intrinsic; known as `__nvvm_ll2d_rz` in GCC.
        #[link_name = "llvm.nvvm.ll2d.rz"]
        pub fn ll2d_rz(a: i64) -> f64;
        /// The `llvm.nvvm.ll2d.rm` intrinsic; known as `__nvvm_ll2d_rm` in GCC.
        #[link_name = "llvm.nvvm.ll2d.rm"]
        pub fn ll2d_rm(a: i64) -> f64;
        /// The `llvm.nvvm.ll2d.rp` intrinsic; known as `__nvvm_ll2d_rp` in GCC.
        #[link_name = "llvm.nvvm.ll2d.rp"]
        pub fn ll2d_rp(a: i64) -> f64;
        /// The `llvm.nvvm.ull2d.rn` intrinsic; known as `__nvvm_ull2d_rn` in GCC.
        #[link_name = "llvm.nvvm.ull2d.rn"]
        pub fn ull2d_rn(a: i64) -> f64;
        /// The `llvm.nvvm.ull2d.rz` intrinsic; known as `__nvvm_ull2d_rz` in GCC.
        #[link_name = "llvm.nvvm.ull2d.rz"]
        pub fn ull2d_rz(a: i64) -> f64;
        /// The `llvm.nvvm.ull2d.rm` intrinsic; known as `__nvvm_ull2d_rm` in GCC.
        #[link_name = "llvm.nvvm.ull2d.rm"]
        pub fn ull2d_rm(a: i64) -> f64;
        /// The `llvm.nvvm.ull2d.rp` intrinsic; known as `__nvvm_ull2d_rp` in GCC.
        #[link_name = "llvm.nvvm.ull2d.rp"]
        pub fn ull2d_rp(a: i64) -> f64;
        /// The `llvm.nvvm.f2h.rn.ftz` intrinsic; known as `__nvvm_f2h_rn_ftz` in GCC.
        #[link_name = "llvm.nvvm.f2h.rn.ftz"]
        pub fn f2h_rn_ftz(a: f32) -> i16;
        /// The `llvm.nvvm.f2h.rn` intrinsic; known as `__nvvm_f2h_rn` in GCC.
        #[link_name = "llvm.nvvm.f2h.rn"]
        pub fn f2h_rn(a: f32) -> i16;
        /// The `llvm.nvvm.h2f` intrinsic; known as `__nvvm_h2f` in GCC.
        #[link_name = "llvm.nvvm.h2f"]
        pub fn h2f(a: i16) -> f32;
        /// The `llvm.nvvm.bitcast.f2i` intrinsic; known as `__nvvm_bitcast_f2i` in GCC.
        #[link_name = "llvm.nvvm.bitcast.f2i"]
        pub fn bitcast_f2i(a: f32) -> i32;
        /// The `llvm.nvvm.bitcast.i2f` intrinsic; known as `__nvvm_bitcast_i2f` in GCC.
        #[link_name = "llvm.nvvm.bitcast.i2f"]
        pub fn bitcast_i2f(a: i32) -> f32;
        /// The `llvm.nvvm.bitcast.ll2d` intrinsic; known as `__nvvm_bitcast_ll2d` in GCC.
        #[link_name = "llvm.nvvm.bitcast.ll2d"]
        pub fn bitcast_ll2d(a: i64) -> f64;
        /// The `llvm.nvvm.bitcast.d2ll` intrinsic; known as `__nvvm_bitcast_d2ll` in GCC.
        #[link_name = "llvm.nvvm.bitcast.d2ll"]
        pub fn bitcast_d2ll(a: f64) -> i64;
        /// The `llvm.nvvm.atomic.load.add.f32` intrinsic.
        #[link_name = "llvm.nvvm.atomic.load.add.f32"]
        pub fn atomic_load_add_f32(a: *mut f32, b: f32) -> f32;
        /// The `llvm.nvvm.atomic.load.inc.32` intrinsic.
        #[link_name = "llvm.nvvm.atomic.load.inc.32"]
        pub fn atomic_load_inc_32(a: *mut i32, b: i32) -> i32;
        /// The `llvm.nvvm.atomic.load.dec.32` intrinsic.
        #[link_name = "llvm.nvvm.atomic.load.dec.32"]
        pub fn atomic_load_dec_32(a: *mut i32, b: i32) -> i32;
        /// The `llvm.nvvm.barrier0` intrinsic; known as `__syncthreads` in GCC.
        #[link_name = "llvm.nvvm.barrier0"]
        pub fn barrier0() -> ();
        /// The `llvm.nvvm.barrier0.popc` intrinsic; known as `__nvvm_bar0_popc` in GCC.
        #[link_name = "llvm.nvvm.barrier0.popc"]
        pub fn barrier0_popc(a: i32) -> i32;
        /// The `llvm.nvvm.barrier0.and` intrinsic; known as `__nvvm_bar0_and` in GCC.
        #[link_name = "llvm.nvvm.barrier0.and"]
        pub fn barrier0_and(a: i32) -> i32;
        /// The `llvm.nvvm.barrier0.or` intrinsic; known as `__nvvm_bar0_or` in GCC.
        #[link_name = "llvm.nvvm.barrier0.or"]
        pub fn barrier0_or(a: i32) -> i32;
        /// The `llvm.nvvm.bar.sync` intrinsic; known as `__nvvm_bar_sync` in GCC.
        #[link_name = "llvm.nvvm.bar.sync"]
        pub fn bar_sync(a: i32) -> ();
        /// The `llvm.nvvm.membar.cta` intrinsic; known as `__nvvm_membar_cta` in GCC.
        #[link_name = "llvm.nvvm.membar.cta"]
        pub fn membar_cta() -> ();
        /// The `llvm.nvvm.membar.gl` intrinsic; known as `__nvvm_membar_gl` in GCC.
        #[link_name = "llvm.nvvm.membar.gl"]
        pub fn membar_gl() -> ();
        /// The `llvm.nvvm.membar.sys` intrinsic; known as `__nvvm_membar_sys` in GCC.
        #[link_name = "llvm.nvvm.membar.sys"]
        pub fn membar_sys() -> ();
        /// The `llvm.nvvm.ldu.global.i.v16i8` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.v16i8"]
        pub fn ldu_global_i_v16i8(a: *mut ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.nvvm.ldu.global.i.i8` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.i8"]
        pub fn ldu_global_i_i8(a: *mut i8, b: i32) -> i8;
        /// The `llvm.nvvm.ldu.global.i.v8i16` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.v8i16"]
        pub fn ldu_global_i_v8i16(a: *mut ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.nvvm.ldu.global.i.i16` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.i16"]
        pub fn ldu_global_i_i16(a: *mut i16, b: i32) -> i16;
        /// The `llvm.nvvm.ldu.global.i.v4i32` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.v4i32"]
        pub fn ldu_global_i_v4i32(a: *mut ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.nvvm.ldu.global.i.i32` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.i32"]
        pub fn ldu_global_i_i32(a: *mut i32, b: i32) -> i32;
        /// The `llvm.nvvm.ldu.global.i.v2i64` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.v2i64"]
        pub fn ldu_global_i_v2i64(a: *mut ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.nvvm.ldu.global.i.i64` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.i.i64"]
        pub fn ldu_global_i_i64(a: *mut i64, b: i32) -> i64;
        /// The `llvm.nvvm.ldu.global.f.v4f32` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.f.v4f32"]
        pub fn ldu_global_f_v4f32(a: *mut ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.nvvm.ldu.global.f.f32` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.f.f32"]
        pub fn ldu_global_f_f32(a: *mut f32, b: i32) -> f32;
        /// The `llvm.nvvm.ldu.global.f.v2f64` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.f.v2f64"]
        pub fn ldu_global_f_v2f64(a: *mut ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.nvvm.ldu.global.f.f64` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.f.f64"]
        pub fn ldu_global_f_f64(a: *mut f64, b: i32) -> f64;
        /// The `llvm.nvvm.ldu.global.p.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ldu.global.p.p0i8"]
        pub fn ldu_global_p_p0i8(a: *mut *mut i8, b: i32) -> *mut i8;
        /// The `llvm.nvvm.ldg.global.i.v16i8` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.v16i8"]
        pub fn ldg_global_i_v16i8(a: *mut ::simdty::i8x16, b: i32) -> ::simdty::i8x16;
        /// The `llvm.nvvm.ldg.global.i.i8` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.i8"]
        pub fn ldg_global_i_i8(a: *mut i8, b: i32) -> i8;
        /// The `llvm.nvvm.ldg.global.i.v8i16` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.v8i16"]
        pub fn ldg_global_i_v8i16(a: *mut ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.nvvm.ldg.global.i.i16` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.i16"]
        pub fn ldg_global_i_i16(a: *mut i16, b: i32) -> i16;
        /// The `llvm.nvvm.ldg.global.i.v4i32` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.v4i32"]
        pub fn ldg_global_i_v4i32(a: *mut ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.nvvm.ldg.global.i.i32` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.i32"]
        pub fn ldg_global_i_i32(a: *mut i32, b: i32) -> i32;
        /// The `llvm.nvvm.ldg.global.i.v2i64` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.v2i64"]
        pub fn ldg_global_i_v2i64(a: *mut ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.nvvm.ldg.global.i.i64` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.i.i64"]
        pub fn ldg_global_i_i64(a: *mut i64, b: i32) -> i64;
        /// The `llvm.nvvm.ldg.global.f.v4f32` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.f.v4f32"]
        pub fn ldg_global_f_v4f32(a: *mut ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.nvvm.ldg.global.f.f32` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.f.f32"]
        pub fn ldg_global_f_f32(a: *mut f32, b: i32) -> f32;
        /// The `llvm.nvvm.ldg.global.f.v2f64` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.f.v2f64"]
        pub fn ldg_global_f_v2f64(a: *mut ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.nvvm.ldg.global.f.f64` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.f.f64"]
        pub fn ldg_global_f_f64(a: *mut f64, b: i32) -> f64;
        /// The `llvm.nvvm.ldg.global.p.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ldg.global.p.p0i8"]
        pub fn ldg_global_p_p0i8(a: *mut *mut i8, b: i32) -> *mut i8;
        /// The `llvm.nvvm.ptr.local.to.gen.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.local.to.gen.p0i8.p0i8"]
        pub fn ptr_local_to_gen_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.shared.to.gen.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.shared.to.gen.p0i8.p0i8"]
        pub fn ptr_shared_to_gen_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.global.to.gen.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.global.to.gen.p0i8.p0i8"]
        pub fn ptr_global_to_gen_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.constant.to.gen.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.constant.to.gen.p0i8.p0i8"]
        pub fn ptr_constant_to_gen_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.gen.to.global.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.gen.to.global.p0i8.p0i8"]
        pub fn ptr_gen_to_global_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.gen.to.shared.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.gen.to.shared.p0i8.p0i8"]
        pub fn ptr_gen_to_shared_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.gen.to.local.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.gen.to.local.p0i8.p0i8"]
        pub fn ptr_gen_to_local_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.gen.to.constant.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.gen.to.constant.p0i8.p0i8"]
        pub fn ptr_gen_to_constant_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.ptr.gen.to.param.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.ptr.gen.to.param.p0i8.p0i8"]
        pub fn ptr_gen_to_param_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.move.i16` intrinsic.
        #[link_name = "llvm.nvvm.move.i16"]
        pub fn move_i16(a: i16) -> i16;
        /// The `llvm.nvvm.move.i32` intrinsic.
        #[link_name = "llvm.nvvm.move.i32"]
        pub fn move_i32(a: i32) -> i32;
        /// The `llvm.nvvm.move.i64` intrinsic.
        #[link_name = "llvm.nvvm.move.i64"]
        pub fn move_i64(a: i64) -> i64;
        /// The `llvm.nvvm.move.float` intrinsic.
        #[link_name = "llvm.nvvm.move.float"]
        pub fn move_float(a: f32) -> f32;
        /// The `llvm.nvvm.move.double` intrinsic.
        #[link_name = "llvm.nvvm.move.double"]
        pub fn move_double(a: f64) -> f64;
        /// The `llvm.nvvm.move.ptr.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.move.ptr.p0i8.p0i8"]
        pub fn move_ptr_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.nvvm.texsurf.handle.internal.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.texsurf.handle.internal.p0i8"]
        pub fn texsurf_handle_internal_p0i8(a: *mut i8) -> i64;
        /// The `llvm.nvvm.compiler.error.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.compiler.error.p0i8"]
        pub fn compiler_error_p0i8(a: *mut i8) -> ();
        /// The `llvm.nvvm.compiler.warn.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.compiler.warn.p0i8"]
        pub fn compiler_warn_p0i8(a: *mut i8) -> ();
        /// The `llvm.nvvm.reflect.p0i8` intrinsic.
        #[link_name = "llvm.nvvm.reflect.p0i8"]
        pub fn reflect_p0i8(a: *mut i8) -> i32;
        /// The `llvm.nvvm.isspacep.const` intrinsic; known as `__nvvm_isspacep_const` in GCC.
        #[link_name = "llvm.nvvm.isspacep.const"]
        pub fn isspacep_const(a: *mut i8) -> bool;
        /// The `llvm.nvvm.isspacep.global` intrinsic; known as `__nvvm_isspacep_global` in GCC.
        #[link_name = "llvm.nvvm.isspacep.global"]
        pub fn isspacep_global(a: *mut i8) -> bool;
        /// The `llvm.nvvm.isspacep.local` intrinsic; known as `__nvvm_isspacep_local` in GCC.
        #[link_name = "llvm.nvvm.isspacep.local"]
        pub fn isspacep_local(a: *mut i8) -> bool;
        /// The `llvm.nvvm.isspacep.shared` intrinsic; known as `__nvvm_isspacep_shared` in GCC.
        #[link_name = "llvm.nvvm.isspacep.shared"]
        pub fn isspacep_shared(a: *mut i8) -> bool;
        /// The `llvm.nvvm.read.ptx.sreg.envreg0` intrinsic; known as `__nvvm_read_ptx_sreg_envreg0` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg0"]
        pub fn read_ptx_sreg_envreg0() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg1` intrinsic; known as `__nvvm_read_ptx_sreg_envreg1` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg1"]
        pub fn read_ptx_sreg_envreg1() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg2` intrinsic; known as `__nvvm_read_ptx_sreg_envreg2` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg2"]
        pub fn read_ptx_sreg_envreg2() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg3` intrinsic; known as `__nvvm_read_ptx_sreg_envreg3` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg3"]
        pub fn read_ptx_sreg_envreg3() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg4` intrinsic; known as `__nvvm_read_ptx_sreg_envreg4` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg4"]
        pub fn read_ptx_sreg_envreg4() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg5` intrinsic; known as `__nvvm_read_ptx_sreg_envreg5` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg5"]
        pub fn read_ptx_sreg_envreg5() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg6` intrinsic; known as `__nvvm_read_ptx_sreg_envreg6` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg6"]
        pub fn read_ptx_sreg_envreg6() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg7` intrinsic; known as `__nvvm_read_ptx_sreg_envreg7` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg7"]
        pub fn read_ptx_sreg_envreg7() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg8` intrinsic; known as `__nvvm_read_ptx_sreg_envreg8` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg8"]
        pub fn read_ptx_sreg_envreg8() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg9` intrinsic; known as `__nvvm_read_ptx_sreg_envreg9` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg9"]
        pub fn read_ptx_sreg_envreg9() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg10` intrinsic; known as `__nvvm_read_ptx_sreg_envreg10` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg10"]
        pub fn read_ptx_sreg_envreg10() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg11` intrinsic; known as `__nvvm_read_ptx_sreg_envreg11` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg11"]
        pub fn read_ptx_sreg_envreg11() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg12` intrinsic; known as `__nvvm_read_ptx_sreg_envreg12` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg12"]
        pub fn read_ptx_sreg_envreg12() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg13` intrinsic; known as `__nvvm_read_ptx_sreg_envreg13` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg13"]
        pub fn read_ptx_sreg_envreg13() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg14` intrinsic; known as `__nvvm_read_ptx_sreg_envreg14` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg14"]
        pub fn read_ptx_sreg_envreg14() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg15` intrinsic; known as `__nvvm_read_ptx_sreg_envreg15` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg15"]
        pub fn read_ptx_sreg_envreg15() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg16` intrinsic; known as `__nvvm_read_ptx_sreg_envreg16` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg16"]
        pub fn read_ptx_sreg_envreg16() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg17` intrinsic; known as `__nvvm_read_ptx_sreg_envreg17` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg17"]
        pub fn read_ptx_sreg_envreg17() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg18` intrinsic; known as `__nvvm_read_ptx_sreg_envreg18` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg18"]
        pub fn read_ptx_sreg_envreg18() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg19` intrinsic; known as `__nvvm_read_ptx_sreg_envreg19` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg19"]
        pub fn read_ptx_sreg_envreg19() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg20` intrinsic; known as `__nvvm_read_ptx_sreg_envreg20` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg20"]
        pub fn read_ptx_sreg_envreg20() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg21` intrinsic; known as `__nvvm_read_ptx_sreg_envreg21` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg21"]
        pub fn read_ptx_sreg_envreg21() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg22` intrinsic; known as `__nvvm_read_ptx_sreg_envreg22` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg22"]
        pub fn read_ptx_sreg_envreg22() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg23` intrinsic; known as `__nvvm_read_ptx_sreg_envreg23` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg23"]
        pub fn read_ptx_sreg_envreg23() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg24` intrinsic; known as `__nvvm_read_ptx_sreg_envreg24` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg24"]
        pub fn read_ptx_sreg_envreg24() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg25` intrinsic; known as `__nvvm_read_ptx_sreg_envreg25` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg25"]
        pub fn read_ptx_sreg_envreg25() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg26` intrinsic; known as `__nvvm_read_ptx_sreg_envreg26` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg26"]
        pub fn read_ptx_sreg_envreg26() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg27` intrinsic; known as `__nvvm_read_ptx_sreg_envreg27` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg27"]
        pub fn read_ptx_sreg_envreg27() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg28` intrinsic; known as `__nvvm_read_ptx_sreg_envreg28` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg28"]
        pub fn read_ptx_sreg_envreg28() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg29` intrinsic; known as `__nvvm_read_ptx_sreg_envreg29` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg29"]
        pub fn read_ptx_sreg_envreg29() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg30` intrinsic; known as `__nvvm_read_ptx_sreg_envreg30` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg30"]
        pub fn read_ptx_sreg_envreg30() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.envreg31` intrinsic; known as `__nvvm_read_ptx_sreg_envreg31` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.envreg31"]
        pub fn read_ptx_sreg_envreg31() -> i32;
        /// The `llvm.nvvm.suld.1d.i8.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i8.clamp"]
        pub fn suld_1d_i8_clamp(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i16.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i16.clamp"]
        pub fn suld_1d_i16_clamp(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i32.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i32.clamp"]
        pub fn suld_1d_i32_clamp(a: i64, b: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.i64.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i64.clamp"]
        pub fn suld_1d_i64_clamp(a: i64, b: i32) -> i64;
        /// The `llvm.nvvm.suld.1d.array.i8.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i8.clamp"]
        pub fn suld_1d_array_i8_clamp(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i16.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i16.clamp"]
        pub fn suld_1d_array_i16_clamp(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i32.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i32.clamp"]
        pub fn suld_1d_array_i32_clamp(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.array.i64.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i64.clamp"]
        pub fn suld_1d_array_i64_clamp(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.i8.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i8.clamp"]
        pub fn suld_2d_i8_clamp(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i16.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i16.clamp"]
        pub fn suld_2d_i16_clamp(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i32.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i32.clamp"]
        pub fn suld_2d_i32_clamp(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.i64.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i64.clamp"]
        pub fn suld_2d_i64_clamp(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.array.i8.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i8.clamp"]
        pub fn suld_2d_array_i8_clamp(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i16.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i16.clamp"]
        pub fn suld_2d_array_i16_clamp(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i32.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i32.clamp"]
        pub fn suld_2d_array_i32_clamp(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.array.i64.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i64.clamp"]
        pub fn suld_2d_array_i64_clamp(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.suld.3d.i8.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i8.clamp"]
        pub fn suld_3d_i8_clamp(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i16.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i16.clamp"]
        pub fn suld_3d_i16_clamp(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i32.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i32.clamp"]
        pub fn suld_3d_i32_clamp(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.3d.i64.clamp` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i64.clamp"]
        pub fn suld_3d_i64_clamp(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.suld.1d.i8.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i8.trap"]
        pub fn suld_1d_i8_trap(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i16.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i16.trap"]
        pub fn suld_1d_i16_trap(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i32.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i32.trap"]
        pub fn suld_1d_i32_trap(a: i64, b: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.i64.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i64.trap"]
        pub fn suld_1d_i64_trap(a: i64, b: i32) -> i64;
        /// The `llvm.nvvm.suld.1d.array.i8.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i8.trap"]
        pub fn suld_1d_array_i8_trap(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i16.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i16.trap"]
        pub fn suld_1d_array_i16_trap(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i32.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i32.trap"]
        pub fn suld_1d_array_i32_trap(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.array.i64.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i64.trap"]
        pub fn suld_1d_array_i64_trap(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.i8.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i8.trap"]
        pub fn suld_2d_i8_trap(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i16.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i16.trap"]
        pub fn suld_2d_i16_trap(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i32.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i32.trap"]
        pub fn suld_2d_i32_trap(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.i64.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i64.trap"]
        pub fn suld_2d_i64_trap(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.array.i8.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i8.trap"]
        pub fn suld_2d_array_i8_trap(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i16.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i16.trap"]
        pub fn suld_2d_array_i16_trap(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i32.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i32.trap"]
        pub fn suld_2d_array_i32_trap(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.array.i64.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i64.trap"]
        pub fn suld_2d_array_i64_trap(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.suld.3d.i8.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i8.trap"]
        pub fn suld_3d_i8_trap(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i16.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i16.trap"]
        pub fn suld_3d_i16_trap(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i32.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i32.trap"]
        pub fn suld_3d_i32_trap(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.3d.i64.trap` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i64.trap"]
        pub fn suld_3d_i64_trap(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.suld.1d.i8.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i8.zero"]
        pub fn suld_1d_i8_zero(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i16.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i16.zero"]
        pub fn suld_1d_i16_zero(a: i64, b: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.i32.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i32.zero"]
        pub fn suld_1d_i32_zero(a: i64, b: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.i64.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.i64.zero"]
        pub fn suld_1d_i64_zero(a: i64, b: i32) -> i64;
        /// The `llvm.nvvm.suld.1d.array.i8.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i8.zero"]
        pub fn suld_1d_array_i8_zero(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i16.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i16.zero"]
        pub fn suld_1d_array_i16_zero(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.1d.array.i32.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i32.zero"]
        pub fn suld_1d_array_i32_zero(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.1d.array.i64.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.1d.array.i64.zero"]
        pub fn suld_1d_array_i64_zero(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.i8.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i8.zero"]
        pub fn suld_2d_i8_zero(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i16.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i16.zero"]
        pub fn suld_2d_i16_zero(a: i64, b: i32, c: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.i32.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i32.zero"]
        pub fn suld_2d_i32_zero(a: i64, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.i64.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.i64.zero"]
        pub fn suld_2d_i64_zero(a: i64, b: i32, c: i32) -> i64;
        /// The `llvm.nvvm.suld.2d.array.i8.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i8.zero"]
        pub fn suld_2d_array_i8_zero(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i16.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i16.zero"]
        pub fn suld_2d_array_i16_zero(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.2d.array.i32.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i32.zero"]
        pub fn suld_2d_array_i32_zero(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.2d.array.i64.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.2d.array.i64.zero"]
        pub fn suld_2d_array_i64_zero(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.suld.3d.i8.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i8.zero"]
        pub fn suld_3d_i8_zero(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i16.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i16.zero"]
        pub fn suld_3d_i16_zero(a: i64, b: i32, c: i32, d: i32) -> i16;
        /// The `llvm.nvvm.suld.3d.i32.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i32.zero"]
        pub fn suld_3d_i32_zero(a: i64, b: i32, c: i32, d: i32) -> i32;
        /// The `llvm.nvvm.suld.3d.i64.zero` intrinsic.
        #[link_name = "llvm.nvvm.suld.3d.i64.zero"]
        pub fn suld_3d_i64_zero(a: i64, b: i32, c: i32, d: i32) -> i64;
        /// The `llvm.nvvm.txq.channel.order` intrinsic; known as `__nvvm_txq_channel_order` in GCC.
        #[link_name = "llvm.nvvm.txq.channel.order"]
        pub fn txq_channel_order(a: i64) -> i32;
        /// The `llvm.nvvm.txq.channel.data.type` intrinsic; known as `__nvvm_txq_channel_data_type` in GCC.
        #[link_name = "llvm.nvvm.txq.channel.data.type"]
        pub fn txq_channel_data_type(a: i64) -> i32;
        /// The `llvm.nvvm.txq.width` intrinsic; known as `__nvvm_txq_width` in GCC.
        #[link_name = "llvm.nvvm.txq.width"]
        pub fn txq_width(a: i64) -> i32;
        /// The `llvm.nvvm.txq.height` intrinsic; known as `__nvvm_txq_height` in GCC.
        #[link_name = "llvm.nvvm.txq.height"]
        pub fn txq_height(a: i64) -> i32;
        /// The `llvm.nvvm.txq.depth` intrinsic; known as `__nvvm_txq_depth` in GCC.
        #[link_name = "llvm.nvvm.txq.depth"]
        pub fn txq_depth(a: i64) -> i32;
        /// The `llvm.nvvm.txq.array.size` intrinsic; known as `__nvvm_txq_array_size` in GCC.
        #[link_name = "llvm.nvvm.txq.array.size"]
        pub fn txq_array_size(a: i64) -> i32;
        /// The `llvm.nvvm.txq.num.samples` intrinsic; known as `__nvvm_txq_num_samples` in GCC.
        #[link_name = "llvm.nvvm.txq.num.samples"]
        pub fn txq_num_samples(a: i64) -> i32;
        /// The `llvm.nvvm.txq.num.mipmap.levels` intrinsic; known as `__nvvm_txq_num_mipmap_levels` in GCC.
        #[link_name = "llvm.nvvm.txq.num.mipmap.levels"]
        pub fn txq_num_mipmap_levels(a: i64) -> i32;
        /// The `llvm.nvvm.suq.channel.order` intrinsic; known as `__nvvm_suq_channel_order` in GCC.
        #[link_name = "llvm.nvvm.suq.channel.order"]
        pub fn suq_channel_order(a: i64) -> i32;
        /// The `llvm.nvvm.suq.channel.data.type` intrinsic; known as `__nvvm_suq_channel_data_type` in GCC.
        #[link_name = "llvm.nvvm.suq.channel.data.type"]
        pub fn suq_channel_data_type(a: i64) -> i32;
        /// The `llvm.nvvm.suq.width` intrinsic; known as `__nvvm_suq_width` in GCC.
        #[link_name = "llvm.nvvm.suq.width"]
        pub fn suq_width(a: i64) -> i32;
        /// The `llvm.nvvm.suq.height` intrinsic; known as `__nvvm_suq_height` in GCC.
        #[link_name = "llvm.nvvm.suq.height"]
        pub fn suq_height(a: i64) -> i32;
        /// The `llvm.nvvm.suq.depth` intrinsic; known as `__nvvm_suq_depth` in GCC.
        #[link_name = "llvm.nvvm.suq.depth"]
        pub fn suq_depth(a: i64) -> i32;
        /// The `llvm.nvvm.suq.array.size` intrinsic; known as `__nvvm_suq_array_size` in GCC.
        #[link_name = "llvm.nvvm.suq.array.size"]
        pub fn suq_array_size(a: i64) -> i32;
        /// The `llvm.nvvm.istypep.sampler` intrinsic; known as `__nvvm_istypep_sampler` in GCC.
        #[link_name = "llvm.nvvm.istypep.sampler"]
        pub fn istypep_sampler(a: i64) -> bool;
        /// The `llvm.nvvm.istypep.surface` intrinsic; known as `__nvvm_istypep_surface` in GCC.
        #[link_name = "llvm.nvvm.istypep.surface"]
        pub fn istypep_surface(a: i64) -> bool;
        /// The `llvm.nvvm.istypep.texture` intrinsic; known as `__nvvm_istypep_texture` in GCC.
        #[link_name = "llvm.nvvm.istypep.texture"]
        pub fn istypep_texture(a: i64) -> bool;
        /// The `llvm.nvvm.sust.b.1d.i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i8.clamp"]
        pub fn sust_b_1d_i8_clamp(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i16.clamp"]
        pub fn sust_b_1d_i16_clamp(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i32.clamp"]
        pub fn sust_b_1d_i32_clamp(a: i64, b: i32, c: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.i64.clamp` intrinsic; known as `__nvvm_sust_b_1d_i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i64.clamp"]
        pub fn sust_b_1d_i64_clamp(a: i64, b: i32, c: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_v2i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i8.clamp"]
        pub fn sust_b_1d_v2i8_clamp(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_v2i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i16.clamp"]
        pub fn sust_b_1d_v2i16_clamp(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_v2i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i32.clamp"]
        pub fn sust_b_1d_v2i32_clamp(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i64.clamp` intrinsic; known as `__nvvm_sust_b_1d_v2i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i64.clamp"]
        pub fn sust_b_1d_v2i64_clamp(a: i64, b: i32, c: i64, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_v4i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i8.clamp"]
        pub fn sust_b_1d_v4i8_clamp(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_v4i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i16.clamp"]
        pub fn sust_b_1d_v4i16_clamp(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_v4i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i32.clamp"]
        pub fn sust_b_1d_v4i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i8.clamp"]
        pub fn sust_b_1d_array_i8_clamp(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i16.clamp"]
        pub fn sust_b_1d_array_i16_clamp(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i32.clamp"]
        pub fn sust_b_1d_array_i32_clamp(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i64.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i64.clamp"]
        pub fn sust_b_1d_array_i64_clamp(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v2i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i8.clamp"]
        pub fn sust_b_1d_array_v2i8_clamp(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v2i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i16.clamp"]
        pub fn sust_b_1d_array_v2i16_clamp(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v2i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i32.clamp"]
        pub fn sust_b_1d_array_v2i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i64.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v2i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i64.clamp"]
        pub fn sust_b_1d_array_v2i64_clamp(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i8.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v4i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i8.clamp"]
        pub fn sust_b_1d_array_v4i8_clamp(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i16.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v4i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i16.clamp"]
        pub fn sust_b_1d_array_v4i16_clamp(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i32.clamp` intrinsic; known as `__nvvm_sust_b_1d_array_v4i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i32.clamp"]
        pub fn sust_b_1d_array_v4i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i8.clamp"]
        pub fn sust_b_2d_i8_clamp(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i16.clamp"]
        pub fn sust_b_2d_i16_clamp(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i32.clamp"]
        pub fn sust_b_2d_i32_clamp(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i64.clamp` intrinsic; known as `__nvvm_sust_b_2d_i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i64.clamp"]
        pub fn sust_b_2d_i64_clamp(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_v2i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i8.clamp"]
        pub fn sust_b_2d_v2i8_clamp(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_v2i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i16.clamp"]
        pub fn sust_b_2d_v2i16_clamp(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_v2i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i32.clamp"]
        pub fn sust_b_2d_v2i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i64.clamp` intrinsic; known as `__nvvm_sust_b_2d_v2i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i64.clamp"]
        pub fn sust_b_2d_v2i64_clamp(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_v4i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i8.clamp"]
        pub fn sust_b_2d_v4i8_clamp(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_v4i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i16.clamp"]
        pub fn sust_b_2d_v4i16_clamp(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_v4i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i32.clamp"]
        pub fn sust_b_2d_v4i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i8.clamp"]
        pub fn sust_b_2d_array_i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i16.clamp"]
        pub fn sust_b_2d_array_i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i32.clamp"]
        pub fn sust_b_2d_array_i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i64.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i64.clamp"]
        pub fn sust_b_2d_array_i64_clamp(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v2i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i8.clamp"]
        pub fn sust_b_2d_array_v2i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v2i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i16.clamp"]
        pub fn sust_b_2d_array_v2i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v2i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i32.clamp"]
        pub fn sust_b_2d_array_v2i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i64.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v2i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i64.clamp"]
        pub fn sust_b_2d_array_v2i64_clamp(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i8.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v4i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i8.clamp"]
        pub fn sust_b_2d_array_v4i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i16.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v4i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i16.clamp"]
        pub fn sust_b_2d_array_v4i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i32.clamp` intrinsic; known as `__nvvm_sust_b_2d_array_v4i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i32.clamp"]
        pub fn sust_b_2d_array_v4i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i8.clamp` intrinsic; known as `__nvvm_sust_b_3d_i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i8.clamp"]
        pub fn sust_b_3d_i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i16.clamp` intrinsic; known as `__nvvm_sust_b_3d_i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i16.clamp"]
        pub fn sust_b_3d_i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i32.clamp` intrinsic; known as `__nvvm_sust_b_3d_i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i32.clamp"]
        pub fn sust_b_3d_i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i64.clamp` intrinsic; known as `__nvvm_sust_b_3d_i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i64.clamp"]
        pub fn sust_b_3d_i64_clamp(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i8.clamp` intrinsic; known as `__nvvm_sust_b_3d_v2i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i8.clamp"]
        pub fn sust_b_3d_v2i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i16.clamp` intrinsic; known as `__nvvm_sust_b_3d_v2i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i16.clamp"]
        pub fn sust_b_3d_v2i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i32.clamp` intrinsic; known as `__nvvm_sust_b_3d_v2i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i32.clamp"]
        pub fn sust_b_3d_v2i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i64.clamp` intrinsic; known as `__nvvm_sust_b_3d_v2i64_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i64.clamp"]
        pub fn sust_b_3d_v2i64_clamp(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i8.clamp` intrinsic; known as `__nvvm_sust_b_3d_v4i8_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i8.clamp"]
        pub fn sust_b_3d_v4i8_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i16.clamp` intrinsic; known as `__nvvm_sust_b_3d_v4i16_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i16.clamp"]
        pub fn sust_b_3d_v4i16_clamp(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i32.clamp` intrinsic; known as `__nvvm_sust_b_3d_v4i32_clamp` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i32.clamp"]
        pub fn sust_b_3d_v4i32_clamp(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.i8.trap` intrinsic; known as `__nvvm_sust_b_1d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i8.trap"]
        pub fn sust_b_1d_i8_trap(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i16.trap` intrinsic; known as `__nvvm_sust_b_1d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i16.trap"]
        pub fn sust_b_1d_i16_trap(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i32.trap` intrinsic; known as `__nvvm_sust_b_1d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i32.trap"]
        pub fn sust_b_1d_i32_trap(a: i64, b: i32, c: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.i64.trap` intrinsic; known as `__nvvm_sust_b_1d_i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i64.trap"]
        pub fn sust_b_1d_i64_trap(a: i64, b: i32, c: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i8.trap` intrinsic; known as `__nvvm_sust_b_1d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i8.trap"]
        pub fn sust_b_1d_v2i8_trap(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i16.trap` intrinsic; known as `__nvvm_sust_b_1d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i16.trap"]
        pub fn sust_b_1d_v2i16_trap(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i32.trap` intrinsic; known as `__nvvm_sust_b_1d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i32.trap"]
        pub fn sust_b_1d_v2i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i64.trap` intrinsic; known as `__nvvm_sust_b_1d_v2i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i64.trap"]
        pub fn sust_b_1d_v2i64_trap(a: i64, b: i32, c: i64, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i8.trap` intrinsic; known as `__nvvm_sust_b_1d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i8.trap"]
        pub fn sust_b_1d_v4i8_trap(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i16.trap` intrinsic; known as `__nvvm_sust_b_1d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i16.trap"]
        pub fn sust_b_1d_v4i16_trap(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i32.trap` intrinsic; known as `__nvvm_sust_b_1d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i32.trap"]
        pub fn sust_b_1d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i8.trap` intrinsic; known as `__nvvm_sust_b_1d_array_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i8.trap"]
        pub fn sust_b_1d_array_i8_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i16.trap` intrinsic; known as `__nvvm_sust_b_1d_array_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i16.trap"]
        pub fn sust_b_1d_array_i16_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i32.trap` intrinsic; known as `__nvvm_sust_b_1d_array_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i32.trap"]
        pub fn sust_b_1d_array_i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i64.trap` intrinsic; known as `__nvvm_sust_b_1d_array_i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i64.trap"]
        pub fn sust_b_1d_array_i64_trap(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i8.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i8.trap"]
        pub fn sust_b_1d_array_v2i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i16.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i16.trap"]
        pub fn sust_b_1d_array_v2i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i32.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i32.trap"]
        pub fn sust_b_1d_array_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i64.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v2i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i64.trap"]
        pub fn sust_b_1d_array_v2i64_trap(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i8.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i8.trap"]
        pub fn sust_b_1d_array_v4i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i16.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i16.trap"]
        pub fn sust_b_1d_array_v4i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i32.trap` intrinsic; known as `__nvvm_sust_b_1d_array_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i32.trap"]
        pub fn sust_b_1d_array_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i8.trap` intrinsic; known as `__nvvm_sust_b_2d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i8.trap"]
        pub fn sust_b_2d_i8_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i16.trap` intrinsic; known as `__nvvm_sust_b_2d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i16.trap"]
        pub fn sust_b_2d_i16_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i32.trap` intrinsic; known as `__nvvm_sust_b_2d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i32.trap"]
        pub fn sust_b_2d_i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i64.trap` intrinsic; known as `__nvvm_sust_b_2d_i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i64.trap"]
        pub fn sust_b_2d_i64_trap(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i8.trap` intrinsic; known as `__nvvm_sust_b_2d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i8.trap"]
        pub fn sust_b_2d_v2i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i16.trap` intrinsic; known as `__nvvm_sust_b_2d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i16.trap"]
        pub fn sust_b_2d_v2i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i32.trap` intrinsic; known as `__nvvm_sust_b_2d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i32.trap"]
        pub fn sust_b_2d_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i64.trap` intrinsic; known as `__nvvm_sust_b_2d_v2i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i64.trap"]
        pub fn sust_b_2d_v2i64_trap(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i8.trap` intrinsic; known as `__nvvm_sust_b_2d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i8.trap"]
        pub fn sust_b_2d_v4i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i16.trap` intrinsic; known as `__nvvm_sust_b_2d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i16.trap"]
        pub fn sust_b_2d_v4i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i32.trap` intrinsic; known as `__nvvm_sust_b_2d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i32.trap"]
        pub fn sust_b_2d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i8.trap` intrinsic; known as `__nvvm_sust_b_2d_array_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i8.trap"]
        pub fn sust_b_2d_array_i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i16.trap` intrinsic; known as `__nvvm_sust_b_2d_array_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i16.trap"]
        pub fn sust_b_2d_array_i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i32.trap` intrinsic; known as `__nvvm_sust_b_2d_array_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i32.trap"]
        pub fn sust_b_2d_array_i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i64.trap` intrinsic; known as `__nvvm_sust_b_2d_array_i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i64.trap"]
        pub fn sust_b_2d_array_i64_trap(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i8.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i8.trap"]
        pub fn sust_b_2d_array_v2i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i16.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i16.trap"]
        pub fn sust_b_2d_array_v2i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i32.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i32.trap"]
        pub fn sust_b_2d_array_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i64.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v2i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i64.trap"]
        pub fn sust_b_2d_array_v2i64_trap(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i8.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i8.trap"]
        pub fn sust_b_2d_array_v4i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i16.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i16.trap"]
        pub fn sust_b_2d_array_v4i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i32.trap` intrinsic; known as `__nvvm_sust_b_2d_array_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i32.trap"]
        pub fn sust_b_2d_array_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i8.trap` intrinsic; known as `__nvvm_sust_b_3d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i8.trap"]
        pub fn sust_b_3d_i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i16.trap` intrinsic; known as `__nvvm_sust_b_3d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i16.trap"]
        pub fn sust_b_3d_i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i32.trap` intrinsic; known as `__nvvm_sust_b_3d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i32.trap"]
        pub fn sust_b_3d_i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i64.trap` intrinsic; known as `__nvvm_sust_b_3d_i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i64.trap"]
        pub fn sust_b_3d_i64_trap(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i8.trap` intrinsic; known as `__nvvm_sust_b_3d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i8.trap"]
        pub fn sust_b_3d_v2i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i16.trap` intrinsic; known as `__nvvm_sust_b_3d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i16.trap"]
        pub fn sust_b_3d_v2i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i32.trap` intrinsic; known as `__nvvm_sust_b_3d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i32.trap"]
        pub fn sust_b_3d_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i64.trap` intrinsic; known as `__nvvm_sust_b_3d_v2i64_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i64.trap"]
        pub fn sust_b_3d_v2i64_trap(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i8.trap` intrinsic; known as `__nvvm_sust_b_3d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i8.trap"]
        pub fn sust_b_3d_v4i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i16.trap` intrinsic; known as `__nvvm_sust_b_3d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i16.trap"]
        pub fn sust_b_3d_v4i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i32.trap` intrinsic; known as `__nvvm_sust_b_3d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i32.trap"]
        pub fn sust_b_3d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.i8.zero` intrinsic; known as `__nvvm_sust_b_1d_i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i8.zero"]
        pub fn sust_b_1d_i8_zero(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i16.zero` intrinsic; known as `__nvvm_sust_b_1d_i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i16.zero"]
        pub fn sust_b_1d_i16_zero(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.i32.zero` intrinsic; known as `__nvvm_sust_b_1d_i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i32.zero"]
        pub fn sust_b_1d_i32_zero(a: i64, b: i32, c: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.i64.zero` intrinsic; known as `__nvvm_sust_b_1d_i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.i64.zero"]
        pub fn sust_b_1d_i64_zero(a: i64, b: i32, c: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i8.zero` intrinsic; known as `__nvvm_sust_b_1d_v2i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i8.zero"]
        pub fn sust_b_1d_v2i8_zero(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i16.zero` intrinsic; known as `__nvvm_sust_b_1d_v2i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i16.zero"]
        pub fn sust_b_1d_v2i16_zero(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i32.zero` intrinsic; known as `__nvvm_sust_b_1d_v2i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i32.zero"]
        pub fn sust_b_1d_v2i32_zero(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.v2i64.zero` intrinsic; known as `__nvvm_sust_b_1d_v2i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v2i64.zero"]
        pub fn sust_b_1d_v2i64_zero(a: i64, b: i32, c: i64, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i8.zero` intrinsic; known as `__nvvm_sust_b_1d_v4i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i8.zero"]
        pub fn sust_b_1d_v4i8_zero(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i16.zero` intrinsic; known as `__nvvm_sust_b_1d_v4i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i16.zero"]
        pub fn sust_b_1d_v4i16_zero(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.v4i32.zero` intrinsic; known as `__nvvm_sust_b_1d_v4i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.v4i32.zero"]
        pub fn sust_b_1d_v4i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i8.zero` intrinsic; known as `__nvvm_sust_b_1d_array_i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i8.zero"]
        pub fn sust_b_1d_array_i8_zero(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i16.zero` intrinsic; known as `__nvvm_sust_b_1d_array_i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i16.zero"]
        pub fn sust_b_1d_array_i16_zero(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i32.zero` intrinsic; known as `__nvvm_sust_b_1d_array_i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i32.zero"]
        pub fn sust_b_1d_array_i32_zero(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.i64.zero` intrinsic; known as `__nvvm_sust_b_1d_array_i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.i64.zero"]
        pub fn sust_b_1d_array_i64_zero(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i8.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v2i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i8.zero"]
        pub fn sust_b_1d_array_v2i8_zero(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i16.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v2i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i16.zero"]
        pub fn sust_b_1d_array_v2i16_zero(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i32.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v2i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i32.zero"]
        pub fn sust_b_1d_array_v2i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v2i64.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v2i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v2i64.zero"]
        pub fn sust_b_1d_array_v2i64_zero(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i8.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v4i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i8.zero"]
        pub fn sust_b_1d_array_v4i8_zero(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i16.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v4i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i16.zero"]
        pub fn sust_b_1d_array_v4i16_zero(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.1d.array.v4i32.zero` intrinsic; known as `__nvvm_sust_b_1d_array_v4i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.1d.array.v4i32.zero"]
        pub fn sust_b_1d_array_v4i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i8.zero` intrinsic; known as `__nvvm_sust_b_2d_i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i8.zero"]
        pub fn sust_b_2d_i8_zero(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i16.zero` intrinsic; known as `__nvvm_sust_b_2d_i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i16.zero"]
        pub fn sust_b_2d_i16_zero(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.i32.zero` intrinsic; known as `__nvvm_sust_b_2d_i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i32.zero"]
        pub fn sust_b_2d_i32_zero(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.i64.zero` intrinsic; known as `__nvvm_sust_b_2d_i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.i64.zero"]
        pub fn sust_b_2d_i64_zero(a: i64, b: i32, c: i32, d: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i8.zero` intrinsic; known as `__nvvm_sust_b_2d_v2i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i8.zero"]
        pub fn sust_b_2d_v2i8_zero(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i16.zero` intrinsic; known as `__nvvm_sust_b_2d_v2i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i16.zero"]
        pub fn sust_b_2d_v2i16_zero(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i32.zero` intrinsic; known as `__nvvm_sust_b_2d_v2i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i32.zero"]
        pub fn sust_b_2d_v2i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.v2i64.zero` intrinsic; known as `__nvvm_sust_b_2d_v2i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v2i64.zero"]
        pub fn sust_b_2d_v2i64_zero(a: i64, b: i32, c: i32, d: i64, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i8.zero` intrinsic; known as `__nvvm_sust_b_2d_v4i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i8.zero"]
        pub fn sust_b_2d_v4i8_zero(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i16.zero` intrinsic; known as `__nvvm_sust_b_2d_v4i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i16.zero"]
        pub fn sust_b_2d_v4i16_zero(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.v4i32.zero` intrinsic; known as `__nvvm_sust_b_2d_v4i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.v4i32.zero"]
        pub fn sust_b_2d_v4i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i8.zero` intrinsic; known as `__nvvm_sust_b_2d_array_i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i8.zero"]
        pub fn sust_b_2d_array_i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i16.zero` intrinsic; known as `__nvvm_sust_b_2d_array_i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i16.zero"]
        pub fn sust_b_2d_array_i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i32.zero` intrinsic; known as `__nvvm_sust_b_2d_array_i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i32.zero"]
        pub fn sust_b_2d_array_i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.i64.zero` intrinsic; known as `__nvvm_sust_b_2d_array_i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.i64.zero"]
        pub fn sust_b_2d_array_i64_zero(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i8.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v2i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i8.zero"]
        pub fn sust_b_2d_array_v2i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i16.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v2i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i16.zero"]
        pub fn sust_b_2d_array_v2i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i32.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v2i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i32.zero"]
        pub fn sust_b_2d_array_v2i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v2i64.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v2i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v2i64.zero"]
        pub fn sust_b_2d_array_v2i64_zero(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i8.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v4i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i8.zero"]
        pub fn sust_b_2d_array_v4i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i16.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v4i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i16.zero"]
        pub fn sust_b_2d_array_v4i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.2d.array.v4i32.zero` intrinsic; known as `__nvvm_sust_b_2d_array_v4i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.2d.array.v4i32.zero"]
        pub fn sust_b_2d_array_v4i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i8.zero` intrinsic; known as `__nvvm_sust_b_3d_i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i8.zero"]
        pub fn sust_b_3d_i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i16.zero` intrinsic; known as `__nvvm_sust_b_3d_i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i16.zero"]
        pub fn sust_b_3d_i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.i32.zero` intrinsic; known as `__nvvm_sust_b_3d_i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i32.zero"]
        pub fn sust_b_3d_i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.i64.zero` intrinsic; known as `__nvvm_sust_b_3d_i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.i64.zero"]
        pub fn sust_b_3d_i64_zero(a: i64, b: i32, c: i32, d: i32, e: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i8.zero` intrinsic; known as `__nvvm_sust_b_3d_v2i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i8.zero"]
        pub fn sust_b_3d_v2i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i16.zero` intrinsic; known as `__nvvm_sust_b_3d_v2i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i16.zero"]
        pub fn sust_b_3d_v2i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i32.zero` intrinsic; known as `__nvvm_sust_b_3d_v2i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i32.zero"]
        pub fn sust_b_3d_v2i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.b.3d.v2i64.zero` intrinsic; known as `__nvvm_sust_b_3d_v2i64_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v2i64.zero"]
        pub fn sust_b_3d_v2i64_zero(a: i64, b: i32, c: i32, d: i32, e: i64, f: i64) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i8.zero` intrinsic; known as `__nvvm_sust_b_3d_v4i8_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i8.zero"]
        pub fn sust_b_3d_v4i8_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i16.zero` intrinsic; known as `__nvvm_sust_b_3d_v4i16_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i16.zero"]
        pub fn sust_b_3d_v4i16_zero(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.b.3d.v4i32.zero` intrinsic; known as `__nvvm_sust_b_3d_v4i32_zero` in GCC.
        #[link_name = "llvm.nvvm.sust.b.3d.v4i32.zero"]
        pub fn sust_b_3d_v4i32_zero(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.i8.trap` intrinsic; known as `__nvvm_sust_p_1d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.i8.trap"]
        pub fn sust_p_1d_i8_trap(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.i16.trap` intrinsic; known as `__nvvm_sust_p_1d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.i16.trap"]
        pub fn sust_p_1d_i16_trap(a: i64, b: i32, c: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.i32.trap` intrinsic; known as `__nvvm_sust_p_1d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.i32.trap"]
        pub fn sust_p_1d_i32_trap(a: i64, b: i32, c: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.v2i8.trap` intrinsic; known as `__nvvm_sust_p_1d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v2i8.trap"]
        pub fn sust_p_1d_v2i8_trap(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.v2i16.trap` intrinsic; known as `__nvvm_sust_p_1d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v2i16.trap"]
        pub fn sust_p_1d_v2i16_trap(a: i64, b: i32, c: i16, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.v2i32.trap` intrinsic; known as `__nvvm_sust_p_1d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v2i32.trap"]
        pub fn sust_p_1d_v2i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.v4i8.trap` intrinsic; known as `__nvvm_sust_p_1d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v4i8.trap"]
        pub fn sust_p_1d_v4i8_trap(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.v4i16.trap` intrinsic; known as `__nvvm_sust_p_1d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v4i16.trap"]
        pub fn sust_p_1d_v4i16_trap(a: i64, b: i32, c: i16, d: i16, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.v4i32.trap` intrinsic; known as `__nvvm_sust_p_1d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.v4i32.trap"]
        pub fn sust_p_1d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.i8.trap` intrinsic; known as `__nvvm_sust_p_1d_array_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.i8.trap"]
        pub fn sust_p_1d_array_i8_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.i16.trap` intrinsic; known as `__nvvm_sust_p_1d_array_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.i16.trap"]
        pub fn sust_p_1d_array_i16_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.i32.trap` intrinsic; known as `__nvvm_sust_p_1d_array_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.i32.trap"]
        pub fn sust_p_1d_array_i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v2i8.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v2i8.trap"]
        pub fn sust_p_1d_array_v2i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v2i16.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v2i16.trap"]
        pub fn sust_p_1d_array_v2i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v2i32.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v2i32.trap"]
        pub fn sust_p_1d_array_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v4i8.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v4i8.trap"]
        pub fn sust_p_1d_array_v4i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v4i16.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v4i16.trap"]
        pub fn sust_p_1d_array_v4i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.p.1d.array.v4i32.trap` intrinsic; known as `__nvvm_sust_p_1d_array_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.1d.array.v4i32.trap"]
        pub fn sust_p_1d_array_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.i8.trap` intrinsic; known as `__nvvm_sust_p_2d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.i8.trap"]
        pub fn sust_p_2d_i8_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.i16.trap` intrinsic; known as `__nvvm_sust_p_2d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.i16.trap"]
        pub fn sust_p_2d_i16_trap(a: i64, b: i32, c: i32, d: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.i32.trap` intrinsic; known as `__nvvm_sust_p_2d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.i32.trap"]
        pub fn sust_p_2d_i32_trap(a: i64, b: i32, c: i32, d: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.v2i8.trap` intrinsic; known as `__nvvm_sust_p_2d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v2i8.trap"]
        pub fn sust_p_2d_v2i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.v2i16.trap` intrinsic; known as `__nvvm_sust_p_2d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v2i16.trap"]
        pub fn sust_p_2d_v2i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.v2i32.trap` intrinsic; known as `__nvvm_sust_p_2d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v2i32.trap"]
        pub fn sust_p_2d_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.v4i8.trap` intrinsic; known as `__nvvm_sust_p_2d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v4i8.trap"]
        pub fn sust_p_2d_v4i8_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.v4i16.trap` intrinsic; known as `__nvvm_sust_p_2d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v4i16.trap"]
        pub fn sust_p_2d_v4i16_trap(a: i64, b: i32, c: i32, d: i16, e: i16, f: i16, g: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.v4i32.trap` intrinsic; known as `__nvvm_sust_p_2d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.v4i32.trap"]
        pub fn sust_p_2d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.i8.trap` intrinsic; known as `__nvvm_sust_p_2d_array_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.i8.trap"]
        pub fn sust_p_2d_array_i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.i16.trap` intrinsic; known as `__nvvm_sust_p_2d_array_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.i16.trap"]
        pub fn sust_p_2d_array_i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.i32.trap` intrinsic; known as `__nvvm_sust_p_2d_array_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.i32.trap"]
        pub fn sust_p_2d_array_i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v2i8.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v2i8.trap"]
        pub fn sust_p_2d_array_v2i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v2i16.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v2i16.trap"]
        pub fn sust_p_2d_array_v2i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v2i32.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v2i32.trap"]
        pub fn sust_p_2d_array_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v4i8.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v4i8.trap"]
        pub fn sust_p_2d_array_v4i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v4i16.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v4i16.trap"]
        pub fn sust_p_2d_array_v4i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.p.2d.array.v4i32.trap` intrinsic; known as `__nvvm_sust_p_2d_array_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.2d.array.v4i32.trap"]
        pub fn sust_p_2d_array_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.sust.p.3d.i8.trap` intrinsic; known as `__nvvm_sust_p_3d_i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.i8.trap"]
        pub fn sust_p_3d_i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.i16.trap` intrinsic; known as `__nvvm_sust_p_3d_i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.i16.trap"]
        pub fn sust_p_3d_i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.i32.trap` intrinsic; known as `__nvvm_sust_p_3d_i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.i32.trap"]
        pub fn sust_p_3d_i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32) -> ();
        /// The `llvm.nvvm.sust.p.3d.v2i8.trap` intrinsic; known as `__nvvm_sust_p_3d_v2i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v2i8.trap"]
        pub fn sust_p_3d_v2i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.v2i16.trap` intrinsic; known as `__nvvm_sust_p_3d_v2i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v2i16.trap"]
        pub fn sust_p_3d_v2i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.v2i32.trap` intrinsic; known as `__nvvm_sust_p_3d_v2i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v2i32.trap"]
        pub fn sust_p_3d_v2i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32) -> ();
        /// The `llvm.nvvm.sust.p.3d.v4i8.trap` intrinsic; known as `__nvvm_sust_p_3d_v4i8_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v4i8.trap"]
        pub fn sust_p_3d_v4i8_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.v4i16.trap` intrinsic; known as `__nvvm_sust_p_3d_v4i16_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v4i16.trap"]
        pub fn sust_p_3d_v4i16_trap(a: i64, b: i32, c: i32, d: i32, e: i16, f: i16, g: i16, h: i16) -> ();
        /// The `llvm.nvvm.sust.p.3d.v4i32.trap` intrinsic; known as `__nvvm_sust_p_3d_v4i32_trap` in GCC.
        #[link_name = "llvm.nvvm.sust.p.3d.v4i32.trap"]
        pub fn sust_p_3d_v4i32_trap(a: i64, b: i32, c: i32, d: i32, e: i32, f: i32, g: i32, h: i32) -> ();
        /// The `llvm.nvvm.rotate.b32` intrinsic; known as `__nvvm_rotate_b32` in GCC.
        #[link_name = "llvm.nvvm.rotate.b32"]
        pub fn rotate_b32(a: i32, b: i32) -> i32;
        /// The `llvm.nvvm.rotate.b64` intrinsic; known as `__nvvm_rotate_b64` in GCC.
        #[link_name = "llvm.nvvm.rotate.b64"]
        pub fn rotate_b64(a: i64, b: i32) -> i64;
        /// The `llvm.nvvm.rotate.right.b64` intrinsic; known as `__nvvm_rotate_right_b64` in GCC.
        #[link_name = "llvm.nvvm.rotate.right.b64"]
        pub fn rotate_right_b64(a: i64, b: i32) -> i64;
        /// The `llvm.nvvm.swap.lo.hi.b64` intrinsic; known as `__nvvm_swap_lo_hi_b64` in GCC.
        #[link_name = "llvm.nvvm.swap.lo.hi.b64"]
        pub fn swap_lo_hi_b64(a: i64) -> i64;
        /// The `llvm.nvvm.read.ptx.sreg.laneid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.laneid"]
        pub fn read_ptx_sreg_laneid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.warpid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.warpid"]
        pub fn read_ptx_sreg_warpid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.nwarpid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.nwarpid"]
        pub fn read_ptx_sreg_nwarpid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.smid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.smid"]
        pub fn read_ptx_sreg_smid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.nsmid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.nsmid"]
        pub fn read_ptx_sreg_nsmid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.gridid` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.gridid"]
        pub fn read_ptx_sreg_gridid() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.lanemask.eq` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.lanemask.eq"]
        pub fn read_ptx_sreg_lanemask_eq() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.lanemask.le` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.lanemask.le"]
        pub fn read_ptx_sreg_lanemask_le() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.lanemask.lt` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.lanemask.lt"]
        pub fn read_ptx_sreg_lanemask_lt() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.lanemask.ge` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.lanemask.ge"]
        pub fn read_ptx_sreg_lanemask_ge() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.lanemask.gt` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.lanemask.gt"]
        pub fn read_ptx_sreg_lanemask_gt() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.clock` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.clock"]
        pub fn read_ptx_sreg_clock() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.clock64` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.clock64"]
        pub fn read_ptx_sreg_clock64() -> i64;
        /// The `llvm.nvvm.read.ptx.sreg.pm0` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.pm0"]
        pub fn read_ptx_sreg_pm0() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.pm1` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.pm1"]
        pub fn read_ptx_sreg_pm1() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.pm2` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.pm2"]
        pub fn read_ptx_sreg_pm2() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.pm3` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.pm3"]
        pub fn read_ptx_sreg_pm3() -> i32;
        /// The `llvm.nvvm.read.ptx.sreg.warpsize` intrinsic; known as `__nvvm_read_ptx_sreg_` in GCC.
        #[link_name = "llvm.nvvm.read.ptx.sreg.warpsize"]
        pub fn read_ptx_sreg_warpsize() -> i32;
        /// The `llvm.nvvm.shfl.down.i32` intrinsic; known as `__nvvm_shfl_down_i32` in GCC.
        #[link_name = "llvm.nvvm.shfl.down.i32"]
        pub fn shfl_down_i32(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.shfl.down.f32` intrinsic; known as `__nvvm_shfl_down_f32` in GCC.
        #[link_name = "llvm.nvvm.shfl.down.f32"]
        pub fn shfl_down_f32(a: f32, b: i32, c: i32) -> f32;
        /// The `llvm.nvvm.shfl.up.i32` intrinsic; known as `__nvvm_shfl_up_i32` in GCC.
        #[link_name = "llvm.nvvm.shfl.up.i32"]
        pub fn shfl_up_i32(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.shfl.up.f32` intrinsic; known as `__nvvm_shfl_up_f32` in GCC.
        #[link_name = "llvm.nvvm.shfl.up.f32"]
        pub fn shfl_up_f32(a: f32, b: i32, c: i32) -> f32;
        /// The `llvm.nvvm.shfl.bfly.i32` intrinsic; known as `__nvvm_shfl_bfly_i32` in GCC.
        #[link_name = "llvm.nvvm.shfl.bfly.i32"]
        pub fn shfl_bfly_i32(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.shfl.bfly.f32` intrinsic; known as `__nvvm_shfl_bfly_f32` in GCC.
        #[link_name = "llvm.nvvm.shfl.bfly.f32"]
        pub fn shfl_bfly_f32(a: f32, b: i32, c: i32) -> f32;
        /// The `llvm.nvvm.shfl.idx.i32` intrinsic; known as `__nvvm_shfl_idx_i32` in GCC.
        #[link_name = "llvm.nvvm.shfl.idx.i32"]
        pub fn shfl_idx_i32(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.nvvm.shfl.idx.f32` intrinsic; known as `__nvvm_shfl_idx_f32` in GCC.
        #[link_name = "llvm.nvvm.shfl.idx.f32"]
        pub fn shfl_idx_f32(a: f32, b: i32, c: i32) -> f32;
    }
}
/// LLVM intrinsics for the ppc architecture.
pub mod ppc {
    extern {
        /// The `llvm.ppc.dcba` intrinsic.
        #[link_name = "llvm.ppc.dcba"]
        pub fn dcba(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbf` intrinsic.
        #[link_name = "llvm.ppc.dcbf"]
        pub fn dcbf(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbi` intrinsic.
        #[link_name = "llvm.ppc.dcbi"]
        pub fn dcbi(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbst` intrinsic.
        #[link_name = "llvm.ppc.dcbst"]
        pub fn dcbst(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbt` intrinsic.
        #[link_name = "llvm.ppc.dcbt"]
        pub fn dcbt(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbtst` intrinsic.
        #[link_name = "llvm.ppc.dcbtst"]
        pub fn dcbtst(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbz` intrinsic.
        #[link_name = "llvm.ppc.dcbz"]
        pub fn dcbz(a: *mut i8) -> ();
        /// The `llvm.ppc.dcbzl` intrinsic.
        #[link_name = "llvm.ppc.dcbzl"]
        pub fn dcbzl(a: *mut i8) -> ();
        /// The `llvm.ppc.sync` intrinsic.
        #[link_name = "llvm.ppc.sync"]
        pub fn sync() -> ();
        /// The `llvm.ppc.lwsync` intrinsic.
        #[link_name = "llvm.ppc.lwsync"]
        pub fn lwsync() -> ();
        /// The `llvm.ppc.mtctr.v16i8` intrinsic.
        #[link_name = "llvm.ppc.mtctr.v16i8"]
        pub fn mtctr_v16i8(a: ::simdty::i8x16) -> ();
        /// The `llvm.ppc.mtctr.i8` intrinsic.
        #[link_name = "llvm.ppc.mtctr.i8"]
        pub fn mtctr_i8(a: i8) -> ();
        /// The `llvm.ppc.mtctr.v8i16` intrinsic.
        #[link_name = "llvm.ppc.mtctr.v8i16"]
        pub fn mtctr_v8i16(a: ::simdty::i16x8) -> ();
        /// The `llvm.ppc.mtctr.i16` intrinsic.
        #[link_name = "llvm.ppc.mtctr.i16"]
        pub fn mtctr_i16(a: i16) -> ();
        /// The `llvm.ppc.mtctr.v4i32` intrinsic.
        #[link_name = "llvm.ppc.mtctr.v4i32"]
        pub fn mtctr_v4i32(a: ::simdty::i32x4) -> ();
        /// The `llvm.ppc.mtctr.i32` intrinsic.
        #[link_name = "llvm.ppc.mtctr.i32"]
        pub fn mtctr_i32(a: i32) -> ();
        /// The `llvm.ppc.mtctr.v2i64` intrinsic.
        #[link_name = "llvm.ppc.mtctr.v2i64"]
        pub fn mtctr_v2i64(a: ::simdty::i64x2) -> ();
        /// The `llvm.ppc.mtctr.i64` intrinsic.
        #[link_name = "llvm.ppc.mtctr.i64"]
        pub fn mtctr_i64(a: i64) -> ();
        /// The `llvm.ppc.is.decremented.ctr.nonzero` intrinsic.
        #[link_name = "llvm.ppc.is.decremented.ctr.nonzero"]
        pub fn is_decremented_ctr_nonzero() -> bool;
        /// The `llvm.ppc.divwe` intrinsic; known as `__builtin_divwe` in GCC.
        #[link_name = "llvm.ppc.divwe"]
        pub fn divwe(a: i32, b: i32) -> i32;
        /// The `llvm.ppc.divweu` intrinsic; known as `__builtin_divweu` in GCC.
        #[link_name = "llvm.ppc.divweu"]
        pub fn divweu(a: i32, b: i32) -> i32;
        /// The `llvm.ppc.divde` intrinsic; known as `__builtin_divde` in GCC.
        #[link_name = "llvm.ppc.divde"]
        pub fn divde(a: i64, b: i64) -> i64;
        /// The `llvm.ppc.divdeu` intrinsic; known as `__builtin_divdeu` in GCC.
        #[link_name = "llvm.ppc.divdeu"]
        pub fn divdeu(a: i64, b: i64) -> i64;
        /// The `llvm.ppc.bpermd` intrinsic; known as `__builtin_bpermd` in GCC.
        #[link_name = "llvm.ppc.bpermd"]
        pub fn bpermd(a: i64, b: i64) -> i64;
        /// The `llvm.ppc.altivec.dss` intrinsic; known as `__builtin_altivec_dss` in GCC.
        #[link_name = "llvm.ppc.altivec.dss"]
        pub fn altivec_dss(a: i32) -> ();
        /// The `llvm.ppc.altivec.dssall` intrinsic; known as `__builtin_altivec_dssall` in GCC.
        #[link_name = "llvm.ppc.altivec.dssall"]
        pub fn altivec_dssall() -> ();
        /// The `llvm.ppc.altivec.dst` intrinsic; known as `__builtin_altivec_dst` in GCC.
        #[link_name = "llvm.ppc.altivec.dst"]
        pub fn altivec_dst(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.ppc.altivec.dstt` intrinsic; known as `__builtin_altivec_dstt` in GCC.
        #[link_name = "llvm.ppc.altivec.dstt"]
        pub fn altivec_dstt(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.ppc.altivec.dstst` intrinsic; known as `__builtin_altivec_dstst` in GCC.
        #[link_name = "llvm.ppc.altivec.dstst"]
        pub fn altivec_dstst(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.ppc.altivec.dststt` intrinsic; known as `__builtin_altivec_dststt` in GCC.
        #[link_name = "llvm.ppc.altivec.dststt"]
        pub fn altivec_dststt(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.ppc.altivec.mfvscr` intrinsic; known as `__builtin_altivec_mfvscr` in GCC.
        #[link_name = "llvm.ppc.altivec.mfvscr"]
        pub fn altivec_mfvscr() -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.mtvscr` intrinsic; known as `__builtin_altivec_mtvscr` in GCC.
        #[link_name = "llvm.ppc.altivec.mtvscr"]
        pub fn altivec_mtvscr(a: ::simdty::i32x4) -> ();
        /// The `llvm.ppc.altivec.lvx` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvx"]
        pub fn altivec_lvx(a: *mut i8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.lvxl` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvxl"]
        pub fn altivec_lvxl(a: *mut i8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.lvebx` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvebx"]
        pub fn altivec_lvebx(a: *mut i8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.lvehx` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvehx"]
        pub fn altivec_lvehx(a: *mut i8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.lvewx` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvewx"]
        pub fn altivec_lvewx(a: *mut i8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.stvx` intrinsic.
        #[link_name = "llvm.ppc.altivec.stvx"]
        pub fn altivec_stvx(a: ::simdty::i32x4, b: *mut i8) -> ();
        /// The `llvm.ppc.altivec.stvxl` intrinsic.
        #[link_name = "llvm.ppc.altivec.stvxl"]
        pub fn altivec_stvxl(a: ::simdty::i32x4, b: *mut i8) -> ();
        /// The `llvm.ppc.altivec.stvebx` intrinsic.
        #[link_name = "llvm.ppc.altivec.stvebx"]
        pub fn altivec_stvebx(a: ::simdty::i8x16, b: *mut i8) -> ();
        /// The `llvm.ppc.altivec.stvehx` intrinsic.
        #[link_name = "llvm.ppc.altivec.stvehx"]
        pub fn altivec_stvehx(a: ::simdty::i16x8, b: *mut i8) -> ();
        /// The `llvm.ppc.altivec.stvewx` intrinsic.
        #[link_name = "llvm.ppc.altivec.stvewx"]
        pub fn altivec_stvewx(a: ::simdty::i32x4, b: *mut i8) -> ();
        /// The `llvm.ppc.altivec.vcmpbfp` intrinsic; known as `__builtin_altivec_vcmpbfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpbfp"]
        pub fn altivec_vcmpbfp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpeqfp` intrinsic; known as `__builtin_altivec_vcmpeqfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpeqfp"]
        pub fn altivec_vcmpeqfp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpgefp` intrinsic; known as `__builtin_altivec_vcmpgefp` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgefp"]
        pub fn altivec_vcmpgefp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpgtfp` intrinsic; known as `__builtin_altivec_vcmpgtfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtfp"]
        pub fn altivec_vcmpgtfp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpequd` intrinsic; known as `__builtin_altivec_vcmpequd` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequd"]
        pub fn altivec_vcmpequd(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vcmpgtsd` intrinsic; known as `__builtin_altivec_vcmpgtsd` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsd"]
        pub fn altivec_vcmpgtsd(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vcmpgtud` intrinsic; known as `__builtin_altivec_vcmpgtud` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtud"]
        pub fn altivec_vcmpgtud(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vcmpequw` intrinsic; known as `__builtin_altivec_vcmpequw` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequw"]
        pub fn altivec_vcmpequw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpgtsw` intrinsic; known as `__builtin_altivec_vcmpgtsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsw"]
        pub fn altivec_vcmpgtsw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpgtuw` intrinsic; known as `__builtin_altivec_vcmpgtuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtuw"]
        pub fn altivec_vcmpgtuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vcmpequh` intrinsic; known as `__builtin_altivec_vcmpequh` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequh"]
        pub fn altivec_vcmpequh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vcmpgtsh` intrinsic; known as `__builtin_altivec_vcmpgtsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsh"]
        pub fn altivec_vcmpgtsh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vcmpgtuh` intrinsic; known as `__builtin_altivec_vcmpgtuh` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtuh"]
        pub fn altivec_vcmpgtuh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vcmpequb` intrinsic; known as `__builtin_altivec_vcmpequb` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequb"]
        pub fn altivec_vcmpequb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vcmpgtsb` intrinsic; known as `__builtin_altivec_vcmpgtsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsb"]
        pub fn altivec_vcmpgtsb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vcmpgtub` intrinsic; known as `__builtin_altivec_vcmpgtub` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtub"]
        pub fn altivec_vcmpgtub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vcmpbfp.p` intrinsic; known as `__builtin_altivec_vcmpbfp_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpbfp.p"]
        pub fn altivec_vcmpbfp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpeqfp.p` intrinsic; known as `__builtin_altivec_vcmpeqfp_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpeqfp.p"]
        pub fn altivec_vcmpeqfp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpgefp.p` intrinsic; known as `__builtin_altivec_vcmpgefp_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgefp.p"]
        pub fn altivec_vcmpgefp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtfp.p` intrinsic; known as `__builtin_altivec_vcmpgtfp_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtfp.p"]
        pub fn altivec_vcmpgtfp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpequd.p` intrinsic; known as `__builtin_altivec_vcmpequd_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequd.p"]
        pub fn altivec_vcmpequd_p(a: i32, b: ::simdty::i64x2, c: ::simdty::i64x2) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtsd.p` intrinsic; known as `__builtin_altivec_vcmpgtsd_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsd.p"]
        pub fn altivec_vcmpgtsd_p(a: i32, b: ::simdty::i64x2, c: ::simdty::i64x2) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtud.p` intrinsic; known as `__builtin_altivec_vcmpgtud_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtud.p"]
        pub fn altivec_vcmpgtud_p(a: i32, b: ::simdty::i64x2, c: ::simdty::i64x2) -> i32;
        /// The `llvm.ppc.altivec.vcmpequw.p` intrinsic; known as `__builtin_altivec_vcmpequw_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequw.p"]
        pub fn altivec_vcmpequw_p(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtsw.p` intrinsic; known as `__builtin_altivec_vcmpgtsw_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsw.p"]
        pub fn altivec_vcmpgtsw_p(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtuw.p` intrinsic; known as `__builtin_altivec_vcmpgtuw_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtuw.p"]
        pub fn altivec_vcmpgtuw_p(a: i32, b: ::simdty::i32x4, c: ::simdty::i32x4) -> i32;
        /// The `llvm.ppc.altivec.vcmpequh.p` intrinsic; known as `__builtin_altivec_vcmpequh_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequh.p"]
        pub fn altivec_vcmpequh_p(a: i32, b: ::simdty::i16x8, c: ::simdty::i16x8) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtsh.p` intrinsic; known as `__builtin_altivec_vcmpgtsh_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsh.p"]
        pub fn altivec_vcmpgtsh_p(a: i32, b: ::simdty::i16x8, c: ::simdty::i16x8) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtuh.p` intrinsic; known as `__builtin_altivec_vcmpgtuh_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtuh.p"]
        pub fn altivec_vcmpgtuh_p(a: i32, b: ::simdty::i16x8, c: ::simdty::i16x8) -> i32;
        /// The `llvm.ppc.altivec.vcmpequb.p` intrinsic; known as `__builtin_altivec_vcmpequb_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpequb.p"]
        pub fn altivec_vcmpequb_p(a: i32, b: ::simdty::i8x16, c: ::simdty::i8x16) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtsb.p` intrinsic; known as `__builtin_altivec_vcmpgtsb_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtsb.p"]
        pub fn altivec_vcmpgtsb_p(a: i32, b: ::simdty::i8x16, c: ::simdty::i8x16) -> i32;
        /// The `llvm.ppc.altivec.vcmpgtub.p` intrinsic; known as `__builtin_altivec_vcmpgtub_p` in GCC.
        #[link_name = "llvm.ppc.altivec.vcmpgtub.p"]
        pub fn altivec_vcmpgtub_p(a: i32, b: ::simdty::i8x16, c: ::simdty::i8x16) -> i32;
        /// The `llvm.ppc.altivec.vavgsb` intrinsic; known as `__builtin_altivec_vavgsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vavgsb"]
        pub fn altivec_vavgsb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vavgsh` intrinsic; known as `__builtin_altivec_vavgsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vavgsh"]
        pub fn altivec_vavgsh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vavgsw` intrinsic; known as `__builtin_altivec_vavgsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vavgsw"]
        pub fn altivec_vavgsw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vavgub` intrinsic; known as `__builtin_altivec_vavgub` in GCC.
        #[link_name = "llvm.ppc.altivec.vavgub"]
        pub fn altivec_vavgub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vavguh` intrinsic; known as `__builtin_altivec_vavguh` in GCC.
        #[link_name = "llvm.ppc.altivec.vavguh"]
        pub fn altivec_vavguh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vavguw` intrinsic; known as `__builtin_altivec_vavguw` in GCC.
        #[link_name = "llvm.ppc.altivec.vavguw"]
        pub fn altivec_vavguw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmaxfp` intrinsic; known as `__builtin_altivec_vmaxfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxfp"]
        pub fn altivec_vmaxfp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vmaxsb` intrinsic; known as `__builtin_altivec_vmaxsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxsb"]
        pub fn altivec_vmaxsb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vmaxsh` intrinsic; known as `__builtin_altivec_vmaxsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxsh"]
        pub fn altivec_vmaxsh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmaxsw` intrinsic; known as `__builtin_altivec_vmaxsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxsw"]
        pub fn altivec_vmaxsw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmaxsd` intrinsic; known as `__builtin_altivec_vmaxsd` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxsd"]
        pub fn altivec_vmaxsd(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vmaxub` intrinsic; known as `__builtin_altivec_vmaxub` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxub"]
        pub fn altivec_vmaxub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vmaxuh` intrinsic; known as `__builtin_altivec_vmaxuh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxuh"]
        pub fn altivec_vmaxuh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmaxuw` intrinsic; known as `__builtin_altivec_vmaxuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxuw"]
        pub fn altivec_vmaxuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmaxud` intrinsic; known as `__builtin_altivec_vmaxud` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaxud"]
        pub fn altivec_vmaxud(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vminfp` intrinsic; known as `__builtin_altivec_vminfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vminfp"]
        pub fn altivec_vminfp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vminsb` intrinsic; known as `__builtin_altivec_vminsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vminsb"]
        pub fn altivec_vminsb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vminsh` intrinsic; known as `__builtin_altivec_vminsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vminsh"]
        pub fn altivec_vminsh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vminsw` intrinsic; known as `__builtin_altivec_vminsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vminsw"]
        pub fn altivec_vminsw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vminsd` intrinsic; known as `__builtin_altivec_vminsd` in GCC.
        #[link_name = "llvm.ppc.altivec.vminsd"]
        pub fn altivec_vminsd(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vminub` intrinsic; known as `__builtin_altivec_vminub` in GCC.
        #[link_name = "llvm.ppc.altivec.vminub"]
        pub fn altivec_vminub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vminuh` intrinsic; known as `__builtin_altivec_vminuh` in GCC.
        #[link_name = "llvm.ppc.altivec.vminuh"]
        pub fn altivec_vminuh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vminuw` intrinsic; known as `__builtin_altivec_vminuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vminuw"]
        pub fn altivec_vminuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vminud` intrinsic; known as `__builtin_altivec_vminud` in GCC.
        #[link_name = "llvm.ppc.altivec.vminud"]
        pub fn altivec_vminud(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vaddubs` intrinsic; known as `__builtin_altivec_vaddubs` in GCC.
        #[link_name = "llvm.ppc.altivec.vaddubs"]
        pub fn altivec_vaddubs(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vaddsbs` intrinsic; known as `__builtin_altivec_vaddsbs` in GCC.
        #[link_name = "llvm.ppc.altivec.vaddsbs"]
        pub fn altivec_vaddsbs(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vadduhs` intrinsic; known as `__builtin_altivec_vadduhs` in GCC.
        #[link_name = "llvm.ppc.altivec.vadduhs"]
        pub fn altivec_vadduhs(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vaddshs` intrinsic; known as `__builtin_altivec_vaddshs` in GCC.
        #[link_name = "llvm.ppc.altivec.vaddshs"]
        pub fn altivec_vaddshs(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vadduws` intrinsic; known as `__builtin_altivec_vadduws` in GCC.
        #[link_name = "llvm.ppc.altivec.vadduws"]
        pub fn altivec_vadduws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vaddsws` intrinsic; known as `__builtin_altivec_vaddsws` in GCC.
        #[link_name = "llvm.ppc.altivec.vaddsws"]
        pub fn altivec_vaddsws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vaddcuw` intrinsic; known as `__builtin_altivec_vaddcuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vaddcuw"]
        pub fn altivec_vaddcuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsububs` intrinsic; known as `__builtin_altivec_vsububs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsububs"]
        pub fn altivec_vsububs(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vsubsbs` intrinsic; known as `__builtin_altivec_vsubsbs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubsbs"]
        pub fn altivec_vsubsbs(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vsubuhs` intrinsic; known as `__builtin_altivec_vsubuhs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubuhs"]
        pub fn altivec_vsubuhs(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vsubshs` intrinsic; known as `__builtin_altivec_vsubshs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubshs"]
        pub fn altivec_vsubshs(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vsubuws` intrinsic; known as `__builtin_altivec_vsubuws` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubuws"]
        pub fn altivec_vsubuws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsubsws` intrinsic; known as `__builtin_altivec_vsubsws` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubsws"]
        pub fn altivec_vsubsws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsubcuw` intrinsic; known as `__builtin_altivec_vsubcuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vsubcuw"]
        pub fn altivec_vsubcuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmhaddshs` intrinsic; known as `__builtin_altivec_vmhaddshs` in GCC.
        #[link_name = "llvm.ppc.altivec.vmhaddshs"]
        pub fn altivec_vmhaddshs(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmhraddshs` intrinsic; known as `__builtin_altivec_vmhraddshs` in GCC.
        #[link_name = "llvm.ppc.altivec.vmhraddshs"]
        pub fn altivec_vmhraddshs(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmaddfp` intrinsic; known as `__builtin_altivec_vmaddfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vmaddfp"]
        pub fn altivec_vmaddfp(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vnmsubfp` intrinsic; known as `__builtin_altivec_vnmsubfp` in GCC.
        #[link_name = "llvm.ppc.altivec.vnmsubfp"]
        pub fn altivec_vnmsubfp(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vmsummbm` intrinsic; known as `__builtin_altivec_vmsummbm` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsummbm"]
        pub fn altivec_vmsummbm(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmsumshm` intrinsic; known as `__builtin_altivec_vmsumshm` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsumshm"]
        pub fn altivec_vmsumshm(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmsumshs` intrinsic; known as `__builtin_altivec_vmsumshs` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsumshs"]
        pub fn altivec_vmsumshs(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmsumubm` intrinsic; known as `__builtin_altivec_vmsumubm` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsumubm"]
        pub fn altivec_vmsumubm(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmsumuhm` intrinsic; known as `__builtin_altivec_vmsumuhm` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsumuhm"]
        pub fn altivec_vmsumuhm(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmsumuhs` intrinsic; known as `__builtin_altivec_vmsumuhs` in GCC.
        #[link_name = "llvm.ppc.altivec.vmsumuhs"]
        pub fn altivec_vmsumuhs(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmulesb` intrinsic; known as `__builtin_altivec_vmulesb` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulesb"]
        pub fn altivec_vmulesb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmulesh` intrinsic; known as `__builtin_altivec_vmulesh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulesh"]
        pub fn altivec_vmulesh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmulesw` intrinsic; known as `__builtin_altivec_vmulesw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulesw"]
        pub fn altivec_vmulesw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vmuleub` intrinsic; known as `__builtin_altivec_vmuleub` in GCC.
        #[link_name = "llvm.ppc.altivec.vmuleub"]
        pub fn altivec_vmuleub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmuleuh` intrinsic; known as `__builtin_altivec_vmuleuh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmuleuh"]
        pub fn altivec_vmuleuh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmuleuw` intrinsic; known as `__builtin_altivec_vmuleuw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmuleuw"]
        pub fn altivec_vmuleuw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vmulosb` intrinsic; known as `__builtin_altivec_vmulosb` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulosb"]
        pub fn altivec_vmulosb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmulosh` intrinsic; known as `__builtin_altivec_vmulosh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulosh"]
        pub fn altivec_vmulosh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmulosw` intrinsic; known as `__builtin_altivec_vmulosw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulosw"]
        pub fn altivec_vmulosw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vmuloub` intrinsic; known as `__builtin_altivec_vmuloub` in GCC.
        #[link_name = "llvm.ppc.altivec.vmuloub"]
        pub fn altivec_vmuloub(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vmulouh` intrinsic; known as `__builtin_altivec_vmulouh` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulouh"]
        pub fn altivec_vmulouh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmulouw` intrinsic; known as `__builtin_altivec_vmulouw` in GCC.
        #[link_name = "llvm.ppc.altivec.vmulouw"]
        pub fn altivec_vmulouw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vsumsws` intrinsic; known as `__builtin_altivec_vsumsws` in GCC.
        #[link_name = "llvm.ppc.altivec.vsumsws"]
        pub fn altivec_vsumsws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsum2sws` intrinsic; known as `__builtin_altivec_vsum2sws` in GCC.
        #[link_name = "llvm.ppc.altivec.vsum2sws"]
        pub fn altivec_vsum2sws(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsum4sbs` intrinsic; known as `__builtin_altivec_vsum4sbs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsum4sbs"]
        pub fn altivec_vsum4sbs(a: ::simdty::i8x16, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsum4shs` intrinsic; known as `__builtin_altivec_vsum4shs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsum4shs"]
        pub fn altivec_vsum4shs(a: ::simdty::i16x8, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsum4ubs` intrinsic; known as `__builtin_altivec_vsum4ubs` in GCC.
        #[link_name = "llvm.ppc.altivec.vsum4ubs"]
        pub fn altivec_vsum4ubs(a: ::simdty::i8x16, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vmladduhm` intrinsic; known as `__builtin_altivec_vmladduhm` in GCC.
        #[link_name = "llvm.ppc.altivec.vmladduhm"]
        pub fn altivec_vmladduhm(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vpkpx` intrinsic; known as `__builtin_altivec_vpkpx` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkpx"]
        pub fn altivec_vpkpx(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vpkshss` intrinsic; known as `__builtin_altivec_vpkshss` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkshss"]
        pub fn altivec_vpkshss(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vpkshus` intrinsic; known as `__builtin_altivec_vpkshus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkshus"]
        pub fn altivec_vpkshus(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vpkswss` intrinsic; known as `__builtin_altivec_vpkswss` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkswss"]
        pub fn altivec_vpkswss(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vpkswus` intrinsic; known as `__builtin_altivec_vpkswus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkswus"]
        pub fn altivec_vpkswus(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vpksdss` intrinsic; known as `__builtin_altivec_vpksdss` in GCC.
        #[link_name = "llvm.ppc.altivec.vpksdss"]
        pub fn altivec_vpksdss(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vpksdus` intrinsic; known as `__builtin_altivec_vpksdus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpksdus"]
        pub fn altivec_vpksdus(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vpkuhus` intrinsic; known as `__builtin_altivec_vpkuhus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkuhus"]
        pub fn altivec_vpkuhus(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vpkuwus` intrinsic; known as `__builtin_altivec_vpkuwus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkuwus"]
        pub fn altivec_vpkuwus(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vpkudus` intrinsic; known as `__builtin_altivec_vpkudus` in GCC.
        #[link_name = "llvm.ppc.altivec.vpkudus"]
        pub fn altivec_vpkudus(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vupkhpx` intrinsic; known as `__builtin_altivec_vupkhpx` in GCC.
        #[link_name = "llvm.ppc.altivec.vupkhpx"]
        pub fn altivec_vupkhpx(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vupkhsb` intrinsic; known as `__builtin_altivec_vupkhsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vupkhsb"]
        pub fn altivec_vupkhsb(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vupkhsh` intrinsic; known as `__builtin_altivec_vupkhsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vupkhsh"]
        pub fn altivec_vupkhsh(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vupkhsw` intrinsic; known as `__builtin_altivec_vupkhsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vupkhsw"]
        pub fn altivec_vupkhsw(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vupklpx` intrinsic; known as `__builtin_altivec_vupklpx` in GCC.
        #[link_name = "llvm.ppc.altivec.vupklpx"]
        pub fn altivec_vupklpx(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vupklsb` intrinsic; known as `__builtin_altivec_vupklsb` in GCC.
        #[link_name = "llvm.ppc.altivec.vupklsb"]
        pub fn altivec_vupklsb(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vupklsh` intrinsic; known as `__builtin_altivec_vupklsh` in GCC.
        #[link_name = "llvm.ppc.altivec.vupklsh"]
        pub fn altivec_vupklsh(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vupklsw` intrinsic; known as `__builtin_altivec_vupklsw` in GCC.
        #[link_name = "llvm.ppc.altivec.vupklsw"]
        pub fn altivec_vupklsw(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vcfsx` intrinsic; known as `__builtin_altivec_vcfsx` in GCC.
        #[link_name = "llvm.ppc.altivec.vcfsx"]
        pub fn altivec_vcfsx(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vcfux` intrinsic; known as `__builtin_altivec_vcfux` in GCC.
        #[link_name = "llvm.ppc.altivec.vcfux"]
        pub fn altivec_vcfux(a: ::simdty::i32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vctsxs` intrinsic; known as `__builtin_altivec_vctsxs` in GCC.
        #[link_name = "llvm.ppc.altivec.vctsxs"]
        pub fn altivec_vctsxs(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vctuxs` intrinsic; known as `__builtin_altivec_vctuxs` in GCC.
        #[link_name = "llvm.ppc.altivec.vctuxs"]
        pub fn altivec_vctuxs(a: ::simdty::f32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vrfim` intrinsic; known as `__builtin_altivec_vrfim` in GCC.
        #[link_name = "llvm.ppc.altivec.vrfim"]
        pub fn altivec_vrfim(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vrfin` intrinsic; known as `__builtin_altivec_vrfin` in GCC.
        #[link_name = "llvm.ppc.altivec.vrfin"]
        pub fn altivec_vrfin(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vrfip` intrinsic; known as `__builtin_altivec_vrfip` in GCC.
        #[link_name = "llvm.ppc.altivec.vrfip"]
        pub fn altivec_vrfip(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vrfiz` intrinsic; known as `__builtin_altivec_vrfiz` in GCC.
        #[link_name = "llvm.ppc.altivec.vrfiz"]
        pub fn altivec_vrfiz(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vsl` intrinsic; known as `__builtin_altivec_vsl` in GCC.
        #[link_name = "llvm.ppc.altivec.vsl"]
        pub fn altivec_vsl(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vslo` intrinsic; known as `__builtin_altivec_vslo` in GCC.
        #[link_name = "llvm.ppc.altivec.vslo"]
        pub fn altivec_vslo(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vslb` intrinsic; known as `__builtin_altivec_vslb` in GCC.
        #[link_name = "llvm.ppc.altivec.vslb"]
        pub fn altivec_vslb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vslh` intrinsic; known as `__builtin_altivec_vslh` in GCC.
        #[link_name = "llvm.ppc.altivec.vslh"]
        pub fn altivec_vslh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vslw` intrinsic; known as `__builtin_altivec_vslw` in GCC.
        #[link_name = "llvm.ppc.altivec.vslw"]
        pub fn altivec_vslw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsr` intrinsic; known as `__builtin_altivec_vsr` in GCC.
        #[link_name = "llvm.ppc.altivec.vsr"]
        pub fn altivec_vsr(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsro` intrinsic; known as `__builtin_altivec_vsro` in GCC.
        #[link_name = "llvm.ppc.altivec.vsro"]
        pub fn altivec_vsro(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsrb` intrinsic; known as `__builtin_altivec_vsrb` in GCC.
        #[link_name = "llvm.ppc.altivec.vsrb"]
        pub fn altivec_vsrb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vsrh` intrinsic; known as `__builtin_altivec_vsrh` in GCC.
        #[link_name = "llvm.ppc.altivec.vsrh"]
        pub fn altivec_vsrh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vsrw` intrinsic; known as `__builtin_altivec_vsrw` in GCC.
        #[link_name = "llvm.ppc.altivec.vsrw"]
        pub fn altivec_vsrw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsrab` intrinsic; known as `__builtin_altivec_vsrab` in GCC.
        #[link_name = "llvm.ppc.altivec.vsrab"]
        pub fn altivec_vsrab(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vsrah` intrinsic; known as `__builtin_altivec_vsrah` in GCC.
        #[link_name = "llvm.ppc.altivec.vsrah"]
        pub fn altivec_vsrah(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vsraw` intrinsic; known as `__builtin_altivec_vsraw` in GCC.
        #[link_name = "llvm.ppc.altivec.vsraw"]
        pub fn altivec_vsraw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vrlb` intrinsic; known as `__builtin_altivec_vrlb` in GCC.
        #[link_name = "llvm.ppc.altivec.vrlb"]
        pub fn altivec_vrlb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vrlh` intrinsic; known as `__builtin_altivec_vrlh` in GCC.
        #[link_name = "llvm.ppc.altivec.vrlh"]
        pub fn altivec_vrlh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.vrlw` intrinsic; known as `__builtin_altivec_vrlw` in GCC.
        #[link_name = "llvm.ppc.altivec.vrlw"]
        pub fn altivec_vrlw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vrld` intrinsic; known as `__builtin_altivec_vrld` in GCC.
        #[link_name = "llvm.ppc.altivec.vrld"]
        pub fn altivec_vrld(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.lvsl` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvsl"]
        pub fn altivec_lvsl(a: *mut i8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.lvsr` intrinsic.
        #[link_name = "llvm.ppc.altivec.lvsr"]
        pub fn altivec_lvsr(a: *mut i8) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vperm` intrinsic; known as `__builtin_altivec_vperm_4si` in GCC.
        #[link_name = "llvm.ppc.altivec.vperm"]
        pub fn altivec_vperm(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vsel` intrinsic; known as `__builtin_altivec_vsel_4si` in GCC.
        #[link_name = "llvm.ppc.altivec.vsel"]
        pub fn altivec_vsel(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.vgbbd` intrinsic; known as `__builtin_altivec_vgbbd` in GCC.
        #[link_name = "llvm.ppc.altivec.vgbbd"]
        pub fn altivec_vgbbd(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.vbpermq` intrinsic; known as `__builtin_altivec_vbpermq` in GCC.
        #[link_name = "llvm.ppc.altivec.vbpermq"]
        pub fn altivec_vbpermq(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.vexptefp` intrinsic; known as `__builtin_altivec_vexptefp` in GCC.
        #[link_name = "llvm.ppc.altivec.vexptefp"]
        pub fn altivec_vexptefp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vlogefp` intrinsic; known as `__builtin_altivec_vlogefp` in GCC.
        #[link_name = "llvm.ppc.altivec.vlogefp"]
        pub fn altivec_vlogefp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vrefp` intrinsic; known as `__builtin_altivec_vrefp` in GCC.
        #[link_name = "llvm.ppc.altivec.vrefp"]
        pub fn altivec_vrefp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.vrsqrtefp` intrinsic; known as `__builtin_altivec_vrsqrtefp` in GCC.
        #[link_name = "llvm.ppc.altivec.vrsqrtefp"]
        pub fn altivec_vrsqrtefp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.altivec.crypto.vsbox` intrinsic; known as `__builtin_altivec_crypto_vsbox` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vsbox"]
        pub fn altivec_crypto_vsbox(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vpermxor` intrinsic; known as `__builtin_altivec_crypto_vpermxor` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vpermxor"]
        pub fn altivec_crypto_vpermxor(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.crypto.vshasigmad` intrinsic; known as `__builtin_altivec_crypto_vshasigmad` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vshasigmad"]
        pub fn altivec_crypto_vshasigmad(a: ::simdty::i64x2, b: i32, c: i32) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vshasigmaw` intrinsic; known as `__builtin_altivec_crypto_vshasigmaw` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vshasigmaw"]
        pub fn altivec_crypto_vshasigmaw(a: ::simdty::i32x4, b: i32, c: i32) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.crypto.vcipher` intrinsic; known as `__builtin_altivec_crypto_vcipher` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vcipher"]
        pub fn altivec_crypto_vcipher(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vcipherlast` intrinsic; known as `__builtin_altivec_crypto_vcipherlast` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vcipherlast"]
        pub fn altivec_crypto_vcipherlast(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vncipher` intrinsic; known as `__builtin_altivec_crypto_vncipher` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vncipher"]
        pub fn altivec_crypto_vncipher(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vncipherlast` intrinsic; known as `__builtin_altivec_crypto_vncipherlast` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vncipherlast"]
        pub fn altivec_crypto_vncipherlast(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.altivec.crypto.vpmsumb` intrinsic; known as `__builtin_altivec_crypto_vpmsumb` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vpmsumb"]
        pub fn altivec_crypto_vpmsumb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.ppc.altivec.crypto.vpmsumh` intrinsic; known as `__builtin_altivec_crypto_vpmsumh` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vpmsumh"]
        pub fn altivec_crypto_vpmsumh(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.ppc.altivec.crypto.vpmsumw` intrinsic; known as `__builtin_altivec_crypto_vpmsumw` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vpmsumw"]
        pub fn altivec_crypto_vpmsumw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.altivec.crypto.vpmsumd` intrinsic; known as `__builtin_altivec_crypto_vpmsumd` in GCC.
        #[link_name = "llvm.ppc.altivec.crypto.vpmsumd"]
        pub fn altivec_crypto_vpmsumd(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.vsx.lxvw4x` intrinsic.
        #[link_name = "llvm.ppc.vsx.lxvw4x"]
        pub fn vsx_lxvw4x(a: *mut i8) -> ::simdty::i32x4;
        /// The `llvm.ppc.vsx.lxvd2x` intrinsic.
        #[link_name = "llvm.ppc.vsx.lxvd2x"]
        pub fn vsx_lxvd2x(a: *mut i8) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.stxvw4x` intrinsic.
        #[link_name = "llvm.ppc.vsx.stxvw4x"]
        pub fn vsx_stxvw4x(a: ::simdty::i32x4, b: *mut i8) -> ();
        /// The `llvm.ppc.vsx.stxvd2x` intrinsic.
        #[link_name = "llvm.ppc.vsx.stxvd2x"]
        pub fn vsx_stxvd2x(a: ::simdty::f64x2, b: *mut i8) -> ();
        /// The `llvm.ppc.vsx.xvmaxdp` intrinsic; known as `__builtin_vsx_xvmaxdp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvmaxdp"]
        pub fn vsx_xvmaxdp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvmaxsp` intrinsic; known as `__builtin_vsx_xvmaxsp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvmaxsp"]
        pub fn vsx_xvmaxsp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xsmaxdp` intrinsic; known as `__builtin_vsx_xsmaxdp` in GCC.
        #[link_name = "llvm.ppc.vsx.xsmaxdp"]
        pub fn vsx_xsmaxdp(a: f64, b: f64) -> f64;
        /// The `llvm.ppc.vsx.xvmindp` intrinsic; known as `__builtin_vsx_xvmindp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvmindp"]
        pub fn vsx_xvmindp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvminsp` intrinsic; known as `__builtin_vsx_xvminsp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvminsp"]
        pub fn vsx_xvminsp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xsmindp` intrinsic; known as `__builtin_vsx_xsmindp` in GCC.
        #[link_name = "llvm.ppc.vsx.xsmindp"]
        pub fn vsx_xsmindp(a: f64, b: f64) -> f64;
        /// The `llvm.ppc.vsx.xvdivdp` intrinsic; known as `__builtin_vsx_xvdivdp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvdivdp"]
        pub fn vsx_xvdivdp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvdivsp` intrinsic; known as `__builtin_vsx_xvdivsp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvdivsp"]
        pub fn vsx_xvdivsp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xvrspip` intrinsic.
        #[link_name = "llvm.ppc.vsx.xvrspip"]
        pub fn vsx_xvrspip(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xvrdpip` intrinsic.
        #[link_name = "llvm.ppc.vsx.xvrdpip"]
        pub fn vsx_xvrdpip(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvresp` intrinsic; known as `__builtin_vsx_xvresp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvresp"]
        pub fn vsx_xvresp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xvredp` intrinsic; known as `__builtin_vsx_xvredp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvredp"]
        pub fn vsx_xvredp(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvrsqrtesp` intrinsic; known as `__builtin_vsx_xvrsqrtesp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvrsqrtesp"]
        pub fn vsx_xvrsqrtesp(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.ppc.vsx.xvrsqrtedp` intrinsic; known as `__builtin_vsx_xvrsqrtedp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvrsqrtedp"]
        pub fn vsx_xvrsqrtedp(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.ppc.vsx.xvcmpeqdp` intrinsic; known as `__builtin_vsx_xvcmpeqdp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpeqdp"]
        pub fn vsx_xvcmpeqdp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.vsx.xvcmpeqdp.p` intrinsic; known as `__builtin_vsx_xvcmpeqdp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpeqdp.p"]
        pub fn vsx_xvcmpeqdp_p(a: i32, b: ::simdty::f64x2, c: ::simdty::f64x2) -> i32;
        /// The `llvm.ppc.vsx.xvcmpeqsp` intrinsic; known as `__builtin_vsx_xvcmpeqsp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpeqsp"]
        pub fn vsx_xvcmpeqsp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.vsx.xvcmpeqsp.p` intrinsic; known as `__builtin_vsx_xvcmpeqsp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpeqsp.p"]
        pub fn vsx_xvcmpeqsp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.vsx.xvcmpgedp` intrinsic; known as `__builtin_vsx_xvcmpgedp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgedp"]
        pub fn vsx_xvcmpgedp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.vsx.xvcmpgedp.p` intrinsic; known as `__builtin_vsx_xvcmpgedp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgedp.p"]
        pub fn vsx_xvcmpgedp_p(a: i32, b: ::simdty::f64x2, c: ::simdty::f64x2) -> i32;
        /// The `llvm.ppc.vsx.xvcmpgesp` intrinsic; known as `__builtin_vsx_xvcmpgesp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgesp"]
        pub fn vsx_xvcmpgesp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.vsx.xvcmpgesp.p` intrinsic; known as `__builtin_vsx_xvcmpgesp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgesp.p"]
        pub fn vsx_xvcmpgesp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.vsx.xvcmpgtdp` intrinsic; known as `__builtin_vsx_xvcmpgtdp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgtdp"]
        pub fn vsx_xvcmpgtdp(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::i64x2;
        /// The `llvm.ppc.vsx.xvcmpgtdp.p` intrinsic; known as `__builtin_vsx_xvcmpgtdp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgtdp.p"]
        pub fn vsx_xvcmpgtdp_p(a: i32, b: ::simdty::f64x2, c: ::simdty::f64x2) -> i32;
        /// The `llvm.ppc.vsx.xvcmpgtsp` intrinsic; known as `__builtin_vsx_xvcmpgtsp` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgtsp"]
        pub fn vsx_xvcmpgtsp(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.vsx.xvcmpgtsp.p` intrinsic; known as `__builtin_vsx_xvcmpgtsp_p` in GCC.
        #[link_name = "llvm.ppc.vsx.xvcmpgtsp.p"]
        pub fn vsx_xvcmpgtsp_p(a: i32, b: ::simdty::f32x4, c: ::simdty::f32x4) -> i32;
        /// The `llvm.ppc.vsx.xxleqv` intrinsic; known as `__builtin_vsx_xxleqv` in GCC.
        #[link_name = "llvm.ppc.vsx.xxleqv"]
        pub fn vsx_xxleqv(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.ppc.qpx.qvfadd` intrinsic; known as `__builtin_qpx_qvfadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfadd"]
        pub fn qpx_qvfadd(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfadds` intrinsic; known as `__builtin_qpx_qvfadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfadds"]
        pub fn qpx_qvfadds(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfsub` intrinsic; known as `__builtin_qpx_qvfsub` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfsub"]
        pub fn qpx_qvfsub(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfsubs` intrinsic; known as `__builtin_qpx_qvfsubs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfsubs"]
        pub fn qpx_qvfsubs(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfre` intrinsic; known as `__builtin_qpx_qvfre` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfre"]
        pub fn qpx_qvfre(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfres` intrinsic; known as `__builtin_qpx_qvfres` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfres"]
        pub fn qpx_qvfres(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrsqrte` intrinsic; known as `__builtin_qpx_qvfrsqrte` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrsqrte"]
        pub fn qpx_qvfrsqrte(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrsqrtes` intrinsic; known as `__builtin_qpx_qvfrsqrtes` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrsqrtes"]
        pub fn qpx_qvfrsqrtes(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmul` intrinsic; known as `__builtin_qpx_qvfmul` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmul"]
        pub fn qpx_qvfmul(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmuls` intrinsic; known as `__builtin_qpx_qvfmuls` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmuls"]
        pub fn qpx_qvfmuls(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxmul` intrinsic; known as `__builtin_qpx_qvfxmul` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxmul"]
        pub fn qpx_qvfxmul(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxmuls` intrinsic; known as `__builtin_qpx_qvfxmuls` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxmuls"]
        pub fn qpx_qvfxmuls(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmadd` intrinsic; known as `__builtin_qpx_qvfmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmadd"]
        pub fn qpx_qvfmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmadds` intrinsic; known as `__builtin_qpx_qvfmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmadds"]
        pub fn qpx_qvfmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfnmadd` intrinsic; known as `__builtin_qpx_qvfnmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfnmadd"]
        pub fn qpx_qvfnmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfnmadds` intrinsic; known as `__builtin_qpx_qvfnmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfnmadds"]
        pub fn qpx_qvfnmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmsub` intrinsic; known as `__builtin_qpx_qvfmsub` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmsub"]
        pub fn qpx_qvfmsub(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfmsubs` intrinsic; known as `__builtin_qpx_qvfmsubs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfmsubs"]
        pub fn qpx_qvfmsubs(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfnmsub` intrinsic; known as `__builtin_qpx_qvfnmsub` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfnmsub"]
        pub fn qpx_qvfnmsub(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfnmsubs` intrinsic; known as `__builtin_qpx_qvfnmsubs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfnmsubs"]
        pub fn qpx_qvfnmsubs(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxmadd` intrinsic; known as `__builtin_qpx_qvfxmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxmadd"]
        pub fn qpx_qvfxmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxmadds` intrinsic; known as `__builtin_qpx_qvfxmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxmadds"]
        pub fn qpx_qvfxmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxnpmadd` intrinsic; known as `__builtin_qpx_qvfxxnpmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxnpmadd"]
        pub fn qpx_qvfxxnpmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxnpmadds` intrinsic; known as `__builtin_qpx_qvfxxnpmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxnpmadds"]
        pub fn qpx_qvfxxnpmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxcpnmadd` intrinsic; known as `__builtin_qpx_qvfxxcpnmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxcpnmadd"]
        pub fn qpx_qvfxxcpnmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxcpnmadds` intrinsic; known as `__builtin_qpx_qvfxxcpnmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxcpnmadds"]
        pub fn qpx_qvfxxcpnmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxmadd` intrinsic; known as `__builtin_qpx_qvfxxmadd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxmadd"]
        pub fn qpx_qvfxxmadd(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfxxmadds` intrinsic; known as `__builtin_qpx_qvfxxmadds` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfxxmadds"]
        pub fn qpx_qvfxxmadds(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfsel` intrinsic; known as `__builtin_qpx_qvfsel` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfsel"]
        pub fn qpx_qvfsel(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfperm` intrinsic; known as `__builtin_qpx_qvfperm` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfperm"]
        pub fn qpx_qvfperm(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctid` intrinsic; known as `__builtin_qpx_qvfctid` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctid"]
        pub fn qpx_qvfctid(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctidu` intrinsic; known as `__builtin_qpx_qvfctidu` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctidu"]
        pub fn qpx_qvfctidu(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctidz` intrinsic; known as `__builtin_qpx_qvfctidz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctidz"]
        pub fn qpx_qvfctidz(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctiduz` intrinsic; known as `__builtin_qpx_qvfctiduz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctiduz"]
        pub fn qpx_qvfctiduz(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctiw` intrinsic; known as `__builtin_qpx_qvfctiw` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctiw"]
        pub fn qpx_qvfctiw(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctiwu` intrinsic; known as `__builtin_qpx_qvfctiwu` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctiwu"]
        pub fn qpx_qvfctiwu(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctiwz` intrinsic; known as `__builtin_qpx_qvfctiwz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctiwz"]
        pub fn qpx_qvfctiwz(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfctiwuz` intrinsic; known as `__builtin_qpx_qvfctiwuz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfctiwuz"]
        pub fn qpx_qvfctiwuz(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcfid` intrinsic; known as `__builtin_qpx_qvfcfid` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcfid"]
        pub fn qpx_qvfcfid(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcfidu` intrinsic; known as `__builtin_qpx_qvfcfidu` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcfidu"]
        pub fn qpx_qvfcfidu(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcfids` intrinsic; known as `__builtin_qpx_qvfcfids` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcfids"]
        pub fn qpx_qvfcfids(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcfidus` intrinsic; known as `__builtin_qpx_qvfcfidus` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcfidus"]
        pub fn qpx_qvfcfidus(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrsp` intrinsic; known as `__builtin_qpx_qvfrsp` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrsp"]
        pub fn qpx_qvfrsp(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfriz` intrinsic; known as `__builtin_qpx_qvfriz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfriz"]
        pub fn qpx_qvfriz(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrin` intrinsic; known as `__builtin_qpx_qvfrin` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrin"]
        pub fn qpx_qvfrin(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrip` intrinsic; known as `__builtin_qpx_qvfrip` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrip"]
        pub fn qpx_qvfrip(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfrim` intrinsic; known as `__builtin_qpx_qvfrim` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfrim"]
        pub fn qpx_qvfrim(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfneg` intrinsic; known as `__builtin_qpx_qvfneg` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfneg"]
        pub fn qpx_qvfneg(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfabs` intrinsic; known as `__builtin_qpx_qvfabs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfabs"]
        pub fn qpx_qvfabs(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfnabs` intrinsic; known as `__builtin_qpx_qvfnabs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfnabs"]
        pub fn qpx_qvfnabs(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcpsgn` intrinsic; known as `__builtin_qpx_qvfcpsgn` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcpsgn"]
        pub fn qpx_qvfcpsgn(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvftstnan` intrinsic; known as `__builtin_qpx_qvftstnan` in GCC.
        #[link_name = "llvm.ppc.qpx.qvftstnan"]
        pub fn qpx_qvftstnan(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcmplt` intrinsic; known as `__builtin_qpx_qvfcmplt` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcmplt"]
        pub fn qpx_qvfcmplt(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcmpgt` intrinsic; known as `__builtin_qpx_qvfcmpgt` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcmpgt"]
        pub fn qpx_qvfcmpgt(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvfcmpeq` intrinsic; known as `__builtin_qpx_qvfcmpeq` in GCC.
        #[link_name = "llvm.ppc.qpx.qvfcmpeq"]
        pub fn qpx_qvfcmpeq(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfd` intrinsic; known as `__builtin_qpx_qvlfd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfd"]
        pub fn qpx_qvlfd(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfda` intrinsic; known as `__builtin_qpx_qvlfda` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfda"]
        pub fn qpx_qvlfda(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfs` intrinsic; known as `__builtin_qpx_qvlfs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfs"]
        pub fn qpx_qvlfs(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfsa` intrinsic; known as `__builtin_qpx_qvlfsa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfsa"]
        pub fn qpx_qvlfsa(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfcda` intrinsic; known as `__builtin_qpx_qvlfcda` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfcda"]
        pub fn qpx_qvlfcda(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfcd` intrinsic; known as `__builtin_qpx_qvlfcd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfcd"]
        pub fn qpx_qvlfcd(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfcsa` intrinsic; known as `__builtin_qpx_qvlfcsa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfcsa"]
        pub fn qpx_qvlfcsa(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfcs` intrinsic; known as `__builtin_qpx_qvlfcs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfcs"]
        pub fn qpx_qvlfcs(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfiwaa` intrinsic; known as `__builtin_qpx_qvlfiwaa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfiwaa"]
        pub fn qpx_qvlfiwaa(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfiwa` intrinsic; known as `__builtin_qpx_qvlfiwa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfiwa"]
        pub fn qpx_qvlfiwa(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfiwza` intrinsic; known as `__builtin_qpx_qvlfiwza` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfiwza"]
        pub fn qpx_qvlfiwza(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlfiwz` intrinsic; known as `__builtin_qpx_qvlfiwz` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlfiwz"]
        pub fn qpx_qvlfiwz(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlpcld` intrinsic; known as `__builtin_qpx_qvlpcld` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlpcld"]
        pub fn qpx_qvlpcld(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlpcls` intrinsic; known as `__builtin_qpx_qvlpcls` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlpcls"]
        pub fn qpx_qvlpcls(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlpcrd` intrinsic; known as `__builtin_qpx_qvlpcrd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlpcrd"]
        pub fn qpx_qvlpcrd(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvlpcrs` intrinsic; known as `__builtin_qpx_qvlpcrs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvlpcrs"]
        pub fn qpx_qvlpcrs(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvstfd` intrinsic; known as `__builtin_qpx_qvstfd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfd"]
        pub fn qpx_qvstfd(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfda` intrinsic; known as `__builtin_qpx_qvstfda` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfda"]
        pub fn qpx_qvstfda(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfs` intrinsic; known as `__builtin_qpx_qvstfs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfs"]
        pub fn qpx_qvstfs(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfsa` intrinsic; known as `__builtin_qpx_qvstfsa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfsa"]
        pub fn qpx_qvstfsa(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfcda` intrinsic; known as `__builtin_qpx_qvstfcda` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfcda"]
        pub fn qpx_qvstfcda(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfcd` intrinsic; known as `__builtin_qpx_qvstfcd` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfcd"]
        pub fn qpx_qvstfcd(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfcsa` intrinsic; known as `__builtin_qpx_qvstfcsa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfcsa"]
        pub fn qpx_qvstfcsa(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfcs` intrinsic; known as `__builtin_qpx_qvstfcs` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfcs"]
        pub fn qpx_qvstfcs(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfiwa` intrinsic; known as `__builtin_qpx_qvstfiwa` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfiwa"]
        pub fn qpx_qvstfiwa(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvstfiw` intrinsic; known as `__builtin_qpx_qvstfiw` in GCC.
        #[link_name = "llvm.ppc.qpx.qvstfiw"]
        pub fn qpx_qvstfiw(a: ::simdty::f64x4, b: *mut i8) -> ();
        /// The `llvm.ppc.qpx.qvflogical` intrinsic; known as `__builtin_qpx_qvflogical` in GCC.
        #[link_name = "llvm.ppc.qpx.qvflogical"]
        pub fn qpx_qvflogical(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i32) -> ::simdty::f64x4;
        /// The `llvm.ppc.qpx.qvgpci` intrinsic; known as `__builtin_qpx_qvgpci` in GCC.
        #[link_name = "llvm.ppc.qpx.qvgpci"]
        pub fn qpx_qvgpci(a: i32) -> ::simdty::f64x4;
        /// The `llvm.ppc.tbegin` intrinsic; known as `__builtin_tbegin` in GCC.
        #[link_name = "llvm.ppc.tbegin"]
        pub fn tbegin(a: i32) -> i32;
        /// The `llvm.ppc.tend` intrinsic; known as `__builtin_tend` in GCC.
        #[link_name = "llvm.ppc.tend"]
        pub fn tend(a: i32) -> i32;
        /// The `llvm.ppc.tabort` intrinsic; known as `__builtin_tabort` in GCC.
        #[link_name = "llvm.ppc.tabort"]
        pub fn tabort(a: i32) -> i32;
        /// The `llvm.ppc.tabortwc` intrinsic; known as `__builtin_tabortwc` in GCC.
        #[link_name = "llvm.ppc.tabortwc"]
        pub fn tabortwc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.ppc.tabortwci` intrinsic; known as `__builtin_tabortwci` in GCC.
        #[link_name = "llvm.ppc.tabortwci"]
        pub fn tabortwci(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.ppc.tabortdc` intrinsic; known as `__builtin_tabortdc` in GCC.
        #[link_name = "llvm.ppc.tabortdc"]
        pub fn tabortdc(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.ppc.tabortdci` intrinsic; known as `__builtin_tabortdci` in GCC.
        #[link_name = "llvm.ppc.tabortdci"]
        pub fn tabortdci(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.ppc.tcheck` intrinsic; known as `__builtin_tcheck` in GCC.
        #[link_name = "llvm.ppc.tcheck"]
        pub fn tcheck() -> i32;
        /// The `llvm.ppc.treclaim` intrinsic; known as `__builtin_treclaim` in GCC.
        #[link_name = "llvm.ppc.treclaim"]
        pub fn treclaim(a: i32) -> i32;
        /// The `llvm.ppc.trechkpt` intrinsic; known as `__builtin_trechkpt` in GCC.
        #[link_name = "llvm.ppc.trechkpt"]
        pub fn trechkpt() -> i32;
        /// The `llvm.ppc.tsr` intrinsic; known as `__builtin_tsr` in GCC.
        #[link_name = "llvm.ppc.tsr"]
        pub fn tsr(a: i32) -> i32;
        /// The `llvm.ppc.get.texasr` intrinsic; known as `__builtin_get_texasr` in GCC.
        #[link_name = "llvm.ppc.get.texasr"]
        pub fn get_texasr() -> i64;
        /// The `llvm.ppc.get.texasru` intrinsic; known as `__builtin_get_texasru` in GCC.
        #[link_name = "llvm.ppc.get.texasru"]
        pub fn get_texasru() -> i64;
        /// The `llvm.ppc.get.tfhar` intrinsic; known as `__builtin_get_tfhar` in GCC.
        #[link_name = "llvm.ppc.get.tfhar"]
        pub fn get_tfhar() -> i64;
        /// The `llvm.ppc.get.tfiar` intrinsic; known as `__builtin_get_tfiar` in GCC.
        #[link_name = "llvm.ppc.get.tfiar"]
        pub fn get_tfiar() -> i64;
        /// The `llvm.ppc.set.texasr` intrinsic; known as `__builtin_set_texasr` in GCC.
        #[link_name = "llvm.ppc.set.texasr"]
        pub fn set_texasr(a: i64) -> ();
        /// The `llvm.ppc.set.texasru` intrinsic; known as `__builtin_set_texasru` in GCC.
        #[link_name = "llvm.ppc.set.texasru"]
        pub fn set_texasru(a: i64) -> ();
        /// The `llvm.ppc.set.tfhar` intrinsic; known as `__builtin_set_tfhar` in GCC.
        #[link_name = "llvm.ppc.set.tfhar"]
        pub fn set_tfhar(a: i64) -> ();
        /// The `llvm.ppc.set.tfiar` intrinsic; known as `__builtin_set_tfiar` in GCC.
        #[link_name = "llvm.ppc.set.tfiar"]
        pub fn set_tfiar(a: i64) -> ();
        /// The `llvm.ppc.tendall` intrinsic; known as `__builtin_tendall` in GCC.
        #[link_name = "llvm.ppc.tendall"]
        pub fn tendall() -> i32;
        /// The `llvm.ppc.tresume` intrinsic; known as `__builtin_tresume` in GCC.
        #[link_name = "llvm.ppc.tresume"]
        pub fn tresume() -> i32;
        /// The `llvm.ppc.tsuspend` intrinsic; known as `__builtin_tsuspend` in GCC.
        #[link_name = "llvm.ppc.tsuspend"]
        pub fn tsuspend() -> i32;
        /// The `llvm.ppc.ttest` intrinsic; known as `__builtin_ttest` in GCC.
        #[link_name = "llvm.ppc.ttest"]
        pub fn ttest() -> i64;
    }
}
/// LLVM intrinsics for the r600 architecture.
pub mod r600 {
    extern {
        /// The `llvm.r600.read.workdim` intrinsic.
        #[link_name = "llvm.r600.read.workdim"]
        pub fn read_workdim() -> i32;
        /// The `llvm.r600.group.barrier` intrinsic; known as `__builtin_r600_group_barrier` in GCC.
        #[link_name = "llvm.r600.group.barrier"]
        pub fn group_barrier() -> ();
        /// The `llvm.r600.rat.store.typed` intrinsic; known as `__builtin_r600_rat_store_typed` in GCC.
        #[link_name = "llvm.r600.rat.store.typed"]
        pub fn rat_store_typed(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32) -> ();
        /// The `llvm.r600.recipsqrt.ieee.v4f32` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.ieee.v4f32"]
        pub fn recipsqrt_ieee_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.r600.recipsqrt.ieee.f32` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.ieee.f32"]
        pub fn recipsqrt_ieee_f32(a: f32) -> f32;
        /// The `llvm.r600.recipsqrt.ieee.v2f64` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.ieee.v2f64"]
        pub fn recipsqrt_ieee_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.r600.recipsqrt.ieee.f64` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.ieee.f64"]
        pub fn recipsqrt_ieee_f64(a: f64) -> f64;
        /// The `llvm.r600.recipsqrt.clamped.v4f32` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.clamped.v4f32"]
        pub fn recipsqrt_clamped_v4f32(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.r600.recipsqrt.clamped.f32` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.clamped.f32"]
        pub fn recipsqrt_clamped_f32(a: f32) -> f32;
        /// The `llvm.r600.recipsqrt.clamped.v2f64` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.clamped.v2f64"]
        pub fn recipsqrt_clamped_v2f64(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.r600.recipsqrt.clamped.f64` intrinsic.
        #[link_name = "llvm.r600.recipsqrt.clamped.f64"]
        pub fn recipsqrt_clamped_f64(a: f64) -> f64;
    }
}
/// LLVM intrinsics for the x86 architecture.
pub mod x86 {
    extern {
        /// The `llvm.x86.int` intrinsic.
        #[link_name = "llvm.x86.int"]
        pub fn int(a: i8) -> ();
        /// The `llvm.x86.seh.lsda` intrinsic.
        #[link_name = "llvm.x86.seh.lsda"]
        pub fn seh_lsda(a: *mut i8) -> *mut i8;
        /// The `llvm.x86.seh.ehregnode` intrinsic.
        #[link_name = "llvm.x86.seh.ehregnode"]
        pub fn seh_ehregnode(a: *mut i8) -> ();
        /// The `llvm.x86.seh.ehguard` intrinsic.
        #[link_name = "llvm.x86.seh.ehguard"]
        pub fn seh_ehguard(a: *mut i8) -> ();
        /// The `llvm.x86.seh.recoverfp` intrinsic.
        #[link_name = "llvm.x86.seh.recoverfp"]
        pub fn seh_recoverfp(a: *mut i8, b: *mut i8) -> *mut i8;
        /// The `llvm.x86.flags.read.u32` intrinsic; known as `__builtin_ia32_readeflags_u32` in GCC.
        #[link_name = "llvm.x86.flags.read.u32"]
        pub fn flags_read_u32() -> i32;
        /// The `llvm.x86.flags.read.u64` intrinsic; known as `__builtin_ia32_readeflags_u64` in GCC.
        #[link_name = "llvm.x86.flags.read.u64"]
        pub fn flags_read_u64() -> i64;
        /// The `llvm.x86.flags.write.u32` intrinsic; known as `__builtin_ia32_writeeflags_u32` in GCC.
        #[link_name = "llvm.x86.flags.write.u32"]
        pub fn flags_write_u32(a: i32) -> ();
        /// The `llvm.x86.flags.write.u64` intrinsic; known as `__builtin_ia32_writeeflags_u64` in GCC.
        #[link_name = "llvm.x86.flags.write.u64"]
        pub fn flags_write_u64(a: i64) -> ();
        /// The `llvm.x86.rdtsc` intrinsic; known as `__builtin_ia32_rdtsc` in GCC.
        #[link_name = "llvm.x86.rdtsc"]
        pub fn rdtsc() -> i64;
        /// The `llvm.x86.rdtscp` intrinsic; known as `__builtin_ia32_rdtscp` in GCC.
        #[link_name = "llvm.x86.rdtscp"]
        pub fn rdtscp(a: *mut i8) -> i64;
        /// The `llvm.x86.rdpmc` intrinsic; known as `__builtin_ia32_rdpmc` in GCC.
        #[link_name = "llvm.x86.rdpmc"]
        pub fn rdpmc(a: i32) -> i64;
        /// The `llvm.x86.sse.add.ss` intrinsic.
        #[link_name = "llvm.x86.sse.add.ss"]
        pub fn sse_add_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.sub.ss` intrinsic.
        #[link_name = "llvm.x86.sse.sub.ss"]
        pub fn sse_sub_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.mul.ss` intrinsic.
        #[link_name = "llvm.x86.sse.mul.ss"]
        pub fn sse_mul_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.div.ss` intrinsic.
        #[link_name = "llvm.x86.sse.div.ss"]
        pub fn sse_div_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.sqrt.ss` intrinsic; known as `__builtin_ia32_sqrtss` in GCC.
        #[link_name = "llvm.x86.sse.sqrt.ss"]
        pub fn sse_sqrt_ss(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.sqrt.ps` intrinsic; known as `__builtin_ia32_sqrtps` in GCC.
        #[link_name = "llvm.x86.sse.sqrt.ps"]
        pub fn sse_sqrt_ps(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.rcp.ss` intrinsic; known as `__builtin_ia32_rcpss` in GCC.
        #[link_name = "llvm.x86.sse.rcp.ss"]
        pub fn sse_rcp_ss(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.rcp.ps` intrinsic; known as `__builtin_ia32_rcpps` in GCC.
        #[link_name = "llvm.x86.sse.rcp.ps"]
        pub fn sse_rcp_ps(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.rsqrt.ss` intrinsic; known as `__builtin_ia32_rsqrtss` in GCC.
        #[link_name = "llvm.x86.sse.rsqrt.ss"]
        pub fn sse_rsqrt_ss(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.rsqrt.ps` intrinsic; known as `__builtin_ia32_rsqrtps` in GCC.
        #[link_name = "llvm.x86.sse.rsqrt.ps"]
        pub fn sse_rsqrt_ps(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.min.ss` intrinsic; known as `__builtin_ia32_minss` in GCC.
        #[link_name = "llvm.x86.sse.min.ss"]
        pub fn sse_min_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.min.ps` intrinsic; known as `__builtin_ia32_minps` in GCC.
        #[link_name = "llvm.x86.sse.min.ps"]
        pub fn sse_min_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.max.ss` intrinsic; known as `__builtin_ia32_maxss` in GCC.
        #[link_name = "llvm.x86.sse.max.ss"]
        pub fn sse_max_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.max.ps` intrinsic; known as `__builtin_ia32_maxps` in GCC.
        #[link_name = "llvm.x86.sse.max.ps"]
        pub fn sse_max_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.cmp.ss` intrinsic; known as `__builtin_ia32_cmpss` in GCC.
        #[link_name = "llvm.x86.sse.cmp.ss"]
        pub fn sse_cmp_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.cmp.ps` intrinsic.
        #[link_name = "llvm.x86.sse.cmp.ps"]
        pub fn sse_cmp_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.comieq.ss` intrinsic; known as `__builtin_ia32_comieq` in GCC.
        #[link_name = "llvm.x86.sse.comieq.ss"]
        pub fn sse_comieq_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.comilt.ss` intrinsic; known as `__builtin_ia32_comilt` in GCC.
        #[link_name = "llvm.x86.sse.comilt.ss"]
        pub fn sse_comilt_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.comile.ss` intrinsic; known as `__builtin_ia32_comile` in GCC.
        #[link_name = "llvm.x86.sse.comile.ss"]
        pub fn sse_comile_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.comigt.ss` intrinsic; known as `__builtin_ia32_comigt` in GCC.
        #[link_name = "llvm.x86.sse.comigt.ss"]
        pub fn sse_comigt_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.comige.ss` intrinsic; known as `__builtin_ia32_comige` in GCC.
        #[link_name = "llvm.x86.sse.comige.ss"]
        pub fn sse_comige_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.comineq.ss` intrinsic; known as `__builtin_ia32_comineq` in GCC.
        #[link_name = "llvm.x86.sse.comineq.ss"]
        pub fn sse_comineq_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomieq.ss` intrinsic; known as `__builtin_ia32_ucomieq` in GCC.
        #[link_name = "llvm.x86.sse.ucomieq.ss"]
        pub fn sse_ucomieq_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomilt.ss` intrinsic; known as `__builtin_ia32_ucomilt` in GCC.
        #[link_name = "llvm.x86.sse.ucomilt.ss"]
        pub fn sse_ucomilt_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomile.ss` intrinsic; known as `__builtin_ia32_ucomile` in GCC.
        #[link_name = "llvm.x86.sse.ucomile.ss"]
        pub fn sse_ucomile_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomigt.ss` intrinsic; known as `__builtin_ia32_ucomigt` in GCC.
        #[link_name = "llvm.x86.sse.ucomigt.ss"]
        pub fn sse_ucomigt_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomige.ss` intrinsic; known as `__builtin_ia32_ucomige` in GCC.
        #[link_name = "llvm.x86.sse.ucomige.ss"]
        pub fn sse_ucomige_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.ucomineq.ss` intrinsic; known as `__builtin_ia32_ucomineq` in GCC.
        #[link_name = "llvm.x86.sse.ucomineq.ss"]
        pub fn sse_ucomineq_ss(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.cvtss2si` intrinsic; known as `__builtin_ia32_cvtss2si` in GCC.
        #[link_name = "llvm.x86.sse.cvtss2si"]
        pub fn sse_cvtss2si(a: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.cvtss2si64` intrinsic; known as `__builtin_ia32_cvtss2si64` in GCC.
        #[link_name = "llvm.x86.sse.cvtss2si64"]
        pub fn sse_cvtss2si64(a: ::simdty::f32x4) -> i64;
        /// The `llvm.x86.sse.cvttss2si` intrinsic; known as `__builtin_ia32_cvttss2si` in GCC.
        #[link_name = "llvm.x86.sse.cvttss2si"]
        pub fn sse_cvttss2si(a: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse.cvttss2si64` intrinsic; known as `__builtin_ia32_cvttss2si64` in GCC.
        #[link_name = "llvm.x86.sse.cvttss2si64"]
        pub fn sse_cvttss2si64(a: ::simdty::f32x4) -> i64;
        /// The `llvm.x86.sse.cvtsi2ss` intrinsic; known as `__builtin_ia32_cvtsi2ss` in GCC.
        #[link_name = "llvm.x86.sse.cvtsi2ss"]
        pub fn sse_cvtsi2ss(a: ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.cvtsi642ss` intrinsic; known as `__builtin_ia32_cvtsi642ss` in GCC.
        #[link_name = "llvm.x86.sse.cvtsi642ss"]
        pub fn sse_cvtsi642ss(a: ::simdty::f32x4, b: i64) -> ::simdty::f32x4;
        /// The `llvm.x86.sse.sfence` intrinsic; known as `__builtin_ia32_sfence` in GCC.
        #[link_name = "llvm.x86.sse.sfence"]
        pub fn sse_sfence() -> ();
        /// The `llvm.x86.sse.stmxcsr` intrinsic.
        #[link_name = "llvm.x86.sse.stmxcsr"]
        pub fn sse_stmxcsr(a: *mut i8) -> ();
        /// The `llvm.x86.sse.ldmxcsr` intrinsic.
        #[link_name = "llvm.x86.sse.ldmxcsr"]
        pub fn sse_ldmxcsr(a: *mut i8) -> ();
        /// The `llvm.x86.sse.movmsk.ps` intrinsic; known as `__builtin_ia32_movmskps` in GCC.
        #[link_name = "llvm.x86.sse.movmsk.ps"]
        pub fn sse_movmsk_ps(a: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.sse2.add.sd` intrinsic.
        #[link_name = "llvm.x86.sse2.add.sd"]
        pub fn sse2_add_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.sub.sd` intrinsic.
        #[link_name = "llvm.x86.sse2.sub.sd"]
        pub fn sse2_sub_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.mul.sd` intrinsic.
        #[link_name = "llvm.x86.sse2.mul.sd"]
        pub fn sse2_mul_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.div.sd` intrinsic.
        #[link_name = "llvm.x86.sse2.div.sd"]
        pub fn sse2_div_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.sqrt.sd` intrinsic; known as `__builtin_ia32_sqrtsd` in GCC.
        #[link_name = "llvm.x86.sse2.sqrt.sd"]
        pub fn sse2_sqrt_sd(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.sqrt.pd` intrinsic; known as `__builtin_ia32_sqrtpd` in GCC.
        #[link_name = "llvm.x86.sse2.sqrt.pd"]
        pub fn sse2_sqrt_pd(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.min.sd` intrinsic; known as `__builtin_ia32_minsd` in GCC.
        #[link_name = "llvm.x86.sse2.min.sd"]
        pub fn sse2_min_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.min.pd` intrinsic; known as `__builtin_ia32_minpd` in GCC.
        #[link_name = "llvm.x86.sse2.min.pd"]
        pub fn sse2_min_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.max.sd` intrinsic; known as `__builtin_ia32_maxsd` in GCC.
        #[link_name = "llvm.x86.sse2.max.sd"]
        pub fn sse2_max_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.max.pd` intrinsic; known as `__builtin_ia32_maxpd` in GCC.
        #[link_name = "llvm.x86.sse2.max.pd"]
        pub fn sse2_max_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.cmp.sd` intrinsic; known as `__builtin_ia32_cmpsd` in GCC.
        #[link_name = "llvm.x86.sse2.cmp.sd"]
        pub fn sse2_cmp_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.cmp.pd` intrinsic.
        #[link_name = "llvm.x86.sse2.cmp.pd"]
        pub fn sse2_cmp_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.comieq.sd` intrinsic; known as `__builtin_ia32_comisdeq` in GCC.
        #[link_name = "llvm.x86.sse2.comieq.sd"]
        pub fn sse2_comieq_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.comilt.sd` intrinsic; known as `__builtin_ia32_comisdlt` in GCC.
        #[link_name = "llvm.x86.sse2.comilt.sd"]
        pub fn sse2_comilt_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.comile.sd` intrinsic; known as `__builtin_ia32_comisdle` in GCC.
        #[link_name = "llvm.x86.sse2.comile.sd"]
        pub fn sse2_comile_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.comigt.sd` intrinsic; known as `__builtin_ia32_comisdgt` in GCC.
        #[link_name = "llvm.x86.sse2.comigt.sd"]
        pub fn sse2_comigt_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.comige.sd` intrinsic; known as `__builtin_ia32_comisdge` in GCC.
        #[link_name = "llvm.x86.sse2.comige.sd"]
        pub fn sse2_comige_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.comineq.sd` intrinsic; known as `__builtin_ia32_comisdneq` in GCC.
        #[link_name = "llvm.x86.sse2.comineq.sd"]
        pub fn sse2_comineq_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomieq.sd` intrinsic; known as `__builtin_ia32_ucomisdeq` in GCC.
        #[link_name = "llvm.x86.sse2.ucomieq.sd"]
        pub fn sse2_ucomieq_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomilt.sd` intrinsic; known as `__builtin_ia32_ucomisdlt` in GCC.
        #[link_name = "llvm.x86.sse2.ucomilt.sd"]
        pub fn sse2_ucomilt_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomile.sd` intrinsic; known as `__builtin_ia32_ucomisdle` in GCC.
        #[link_name = "llvm.x86.sse2.ucomile.sd"]
        pub fn sse2_ucomile_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomigt.sd` intrinsic; known as `__builtin_ia32_ucomisdgt` in GCC.
        #[link_name = "llvm.x86.sse2.ucomigt.sd"]
        pub fn sse2_ucomigt_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomige.sd` intrinsic; known as `__builtin_ia32_ucomisdge` in GCC.
        #[link_name = "llvm.x86.sse2.ucomige.sd"]
        pub fn sse2_ucomige_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.ucomineq.sd` intrinsic; known as `__builtin_ia32_ucomisdneq` in GCC.
        #[link_name = "llvm.x86.sse2.ucomineq.sd"]
        pub fn sse2_ucomineq_sd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.padds.b` intrinsic; known as `__builtin_ia32_paddsb128` in GCC.
        #[link_name = "llvm.x86.sse2.padds.b"]
        pub fn sse2_padds_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.padds.w` intrinsic; known as `__builtin_ia32_paddsw128` in GCC.
        #[link_name = "llvm.x86.sse2.padds.w"]
        pub fn sse2_padds_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.paddus.b` intrinsic; known as `__builtin_ia32_paddusb128` in GCC.
        #[link_name = "llvm.x86.sse2.paddus.b"]
        pub fn sse2_paddus_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.paddus.w` intrinsic; known as `__builtin_ia32_paddusw128` in GCC.
        #[link_name = "llvm.x86.sse2.paddus.w"]
        pub fn sse2_paddus_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psubs.b` intrinsic; known as `__builtin_ia32_psubsb128` in GCC.
        #[link_name = "llvm.x86.sse2.psubs.b"]
        pub fn sse2_psubs_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.psubs.w` intrinsic; known as `__builtin_ia32_psubsw128` in GCC.
        #[link_name = "llvm.x86.sse2.psubs.w"]
        pub fn sse2_psubs_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psubus.b` intrinsic; known as `__builtin_ia32_psubusb128` in GCC.
        #[link_name = "llvm.x86.sse2.psubus.b"]
        pub fn sse2_psubus_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.psubus.w` intrinsic; known as `__builtin_ia32_psubusw128` in GCC.
        #[link_name = "llvm.x86.sse2.psubus.w"]
        pub fn sse2_psubus_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.pmulhu.w` intrinsic; known as `__builtin_ia32_pmulhuw128` in GCC.
        #[link_name = "llvm.x86.sse2.pmulhu.w"]
        pub fn sse2_pmulhu_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.pmulh.w` intrinsic; known as `__builtin_ia32_pmulhw128` in GCC.
        #[link_name = "llvm.x86.sse2.pmulh.w"]
        pub fn sse2_pmulh_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.pmulu.dq` intrinsic; known as `__builtin_ia32_pmuludq128` in GCC.
        #[link_name = "llvm.x86.sse2.pmulu.dq"]
        pub fn sse2_pmulu_dq(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.pmadd.wd` intrinsic; known as `__builtin_ia32_pmaddwd128` in GCC.
        #[link_name = "llvm.x86.sse2.pmadd.wd"]
        pub fn sse2_pmadd_wd(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.pavg.b` intrinsic; known as `__builtin_ia32_pavgb128` in GCC.
        #[link_name = "llvm.x86.sse2.pavg.b"]
        pub fn sse2_pavg_b(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.pavg.w` intrinsic; known as `__builtin_ia32_pavgw128` in GCC.
        #[link_name = "llvm.x86.sse2.pavg.w"]
        pub fn sse2_pavg_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psad.bw` intrinsic; known as `__builtin_ia32_psadbw128` in GCC.
        #[link_name = "llvm.x86.sse2.psad.bw"]
        pub fn sse2_psad_bw(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.psll.w` intrinsic; known as `__builtin_ia32_psllw128` in GCC.
        #[link_name = "llvm.x86.sse2.psll.w"]
        pub fn sse2_psll_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psll.d` intrinsic; known as `__builtin_ia32_pslld128` in GCC.
        #[link_name = "llvm.x86.sse2.psll.d"]
        pub fn sse2_psll_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.psll.q` intrinsic; known as `__builtin_ia32_psllq128` in GCC.
        #[link_name = "llvm.x86.sse2.psll.q"]
        pub fn sse2_psll_q(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.psrl.w` intrinsic; known as `__builtin_ia32_psrlw128` in GCC.
        #[link_name = "llvm.x86.sse2.psrl.w"]
        pub fn sse2_psrl_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psrl.d` intrinsic; known as `__builtin_ia32_psrld128` in GCC.
        #[link_name = "llvm.x86.sse2.psrl.d"]
        pub fn sse2_psrl_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.psrl.q` intrinsic; known as `__builtin_ia32_psrlq128` in GCC.
        #[link_name = "llvm.x86.sse2.psrl.q"]
        pub fn sse2_psrl_q(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.psra.w` intrinsic; known as `__builtin_ia32_psraw128` in GCC.
        #[link_name = "llvm.x86.sse2.psra.w"]
        pub fn sse2_psra_w(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psra.d` intrinsic; known as `__builtin_ia32_psrad128` in GCC.
        #[link_name = "llvm.x86.sse2.psra.d"]
        pub fn sse2_psra_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.pslli.w` intrinsic; known as `__builtin_ia32_psllwi128` in GCC.
        #[link_name = "llvm.x86.sse2.pslli.w"]
        pub fn sse2_pslli_w(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.pslli.d` intrinsic; known as `__builtin_ia32_pslldi128` in GCC.
        #[link_name = "llvm.x86.sse2.pslli.d"]
        pub fn sse2_pslli_d(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.pslli.q` intrinsic; known as `__builtin_ia32_psllqi128` in GCC.
        #[link_name = "llvm.x86.sse2.pslli.q"]
        pub fn sse2_pslli_q(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.psrli.w` intrinsic; known as `__builtin_ia32_psrlwi128` in GCC.
        #[link_name = "llvm.x86.sse2.psrli.w"]
        pub fn sse2_psrli_w(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psrli.d` intrinsic; known as `__builtin_ia32_psrldi128` in GCC.
        #[link_name = "llvm.x86.sse2.psrli.d"]
        pub fn sse2_psrli_d(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.psrli.q` intrinsic; known as `__builtin_ia32_psrlqi128` in GCC.
        #[link_name = "llvm.x86.sse2.psrli.q"]
        pub fn sse2_psrli_q(a: ::simdty::i64x2, b: i32) -> ::simdty::i64x2;
        /// The `llvm.x86.sse2.psrai.w` intrinsic; known as `__builtin_ia32_psrawi128` in GCC.
        #[link_name = "llvm.x86.sse2.psrai.w"]
        pub fn sse2_psrai_w(a: ::simdty::i16x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.psrai.d` intrinsic; known as `__builtin_ia32_psradi128` in GCC.
        #[link_name = "llvm.x86.sse2.psrai.d"]
        pub fn sse2_psrai_d(a: ::simdty::i32x4, b: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.cvtdq2ps` intrinsic; known as `__builtin_ia32_cvtdq2ps` in GCC.
        #[link_name = "llvm.x86.sse2.cvtdq2ps"]
        pub fn sse2_cvtdq2ps(a: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse2.cvtpd2dq` intrinsic; known as `__builtin_ia32_cvtpd2dq` in GCC.
        #[link_name = "llvm.x86.sse2.cvtpd2dq"]
        pub fn sse2_cvtpd2dq(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.cvttpd2dq` intrinsic; known as `__builtin_ia32_cvttpd2dq` in GCC.
        #[link_name = "llvm.x86.sse2.cvttpd2dq"]
        pub fn sse2_cvttpd2dq(a: ::simdty::f64x2) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.cvtpd2ps` intrinsic; known as `__builtin_ia32_cvtpd2ps` in GCC.
        #[link_name = "llvm.x86.sse2.cvtpd2ps"]
        pub fn sse2_cvtpd2ps(a: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.x86.sse2.cvtps2dq` intrinsic; known as `__builtin_ia32_cvtps2dq` in GCC.
        #[link_name = "llvm.x86.sse2.cvtps2dq"]
        pub fn sse2_cvtps2dq(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.cvttps2dq` intrinsic; known as `__builtin_ia32_cvttps2dq` in GCC.
        #[link_name = "llvm.x86.sse2.cvttps2dq"]
        pub fn sse2_cvttps2dq(a: ::simdty::f32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse2.cvtsd2si` intrinsic; known as `__builtin_ia32_cvtsd2si` in GCC.
        #[link_name = "llvm.x86.sse2.cvtsd2si"]
        pub fn sse2_cvtsd2si(a: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.cvtsd2si64` intrinsic; known as `__builtin_ia32_cvtsd2si64` in GCC.
        #[link_name = "llvm.x86.sse2.cvtsd2si64"]
        pub fn sse2_cvtsd2si64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.x86.sse2.cvttsd2si` intrinsic; known as `__builtin_ia32_cvttsd2si` in GCC.
        #[link_name = "llvm.x86.sse2.cvttsd2si"]
        pub fn sse2_cvttsd2si(a: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.cvttsd2si64` intrinsic; known as `__builtin_ia32_cvttsd2si64` in GCC.
        #[link_name = "llvm.x86.sse2.cvttsd2si64"]
        pub fn sse2_cvttsd2si64(a: ::simdty::f64x2) -> i64;
        /// The `llvm.x86.sse2.cvtsi2sd` intrinsic; known as `__builtin_ia32_cvtsi2sd` in GCC.
        #[link_name = "llvm.x86.sse2.cvtsi2sd"]
        pub fn sse2_cvtsi2sd(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.cvtsi642sd` intrinsic; known as `__builtin_ia32_cvtsi642sd` in GCC.
        #[link_name = "llvm.x86.sse2.cvtsi642sd"]
        pub fn sse2_cvtsi642sd(a: ::simdty::f64x2, b: i64) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.cvtsd2ss` intrinsic; known as `__builtin_ia32_cvtsd2ss` in GCC.
        #[link_name = "llvm.x86.sse2.cvtsd2ss"]
        pub fn sse2_cvtsd2ss(a: ::simdty::f32x4, b: ::simdty::f64x2) -> ::simdty::f32x4;
        /// The `llvm.x86.sse2.cvtss2sd` intrinsic; known as `__builtin_ia32_cvtss2sd` in GCC.
        #[link_name = "llvm.x86.sse2.cvtss2sd"]
        pub fn sse2_cvtss2sd(a: ::simdty::f64x2, b: ::simdty::f32x4) -> ::simdty::f64x2;
        /// The `llvm.x86.sse2.packsswb.128` intrinsic; known as `__builtin_ia32_packsswb128` in GCC.
        #[link_name = "llvm.x86.sse2.packsswb.128"]
        pub fn sse2_packsswb_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.packssdw.128` intrinsic; known as `__builtin_ia32_packssdw128` in GCC.
        #[link_name = "llvm.x86.sse2.packssdw.128"]
        pub fn sse2_packssdw_128(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.x86.sse2.packuswb.128` intrinsic; known as `__builtin_ia32_packuswb128` in GCC.
        #[link_name = "llvm.x86.sse2.packuswb.128"]
        pub fn sse2_packuswb_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i8x16;
        /// The `llvm.x86.sse2.movmsk.pd` intrinsic; known as `__builtin_ia32_movmskpd` in GCC.
        #[link_name = "llvm.x86.sse2.movmsk.pd"]
        pub fn sse2_movmsk_pd(a: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.sse2.pmovmskb.128` intrinsic; known as `__builtin_ia32_pmovmskb128` in GCC.
        #[link_name = "llvm.x86.sse2.pmovmskb.128"]
        pub fn sse2_pmovmskb_128(a: ::simdty::i8x16) -> i32;
        /// The `llvm.x86.sse2.maskmov.dqu` intrinsic; known as `__builtin_ia32_maskmovdqu` in GCC.
        #[link_name = "llvm.x86.sse2.maskmov.dqu"]
        pub fn sse2_maskmov_dqu(a: ::simdty::i8x16, b: ::simdty::i8x16, c: *mut i8) -> ();
        /// The `llvm.x86.sse2.clflush` intrinsic; known as `__builtin_ia32_clflush` in GCC.
        #[link_name = "llvm.x86.sse2.clflush"]
        pub fn sse2_clflush(a: *mut i8) -> ();
        /// The `llvm.x86.sse2.lfence` intrinsic; known as `__builtin_ia32_lfence` in GCC.
        #[link_name = "llvm.x86.sse2.lfence"]
        pub fn sse2_lfence() -> ();
        /// The `llvm.x86.sse2.mfence` intrinsic; known as `__builtin_ia32_mfence` in GCC.
        #[link_name = "llvm.x86.sse2.mfence"]
        pub fn sse2_mfence() -> ();
        /// The `llvm.x86.sse2.pause` intrinsic; known as `__builtin_ia32_pause` in GCC.
        #[link_name = "llvm.x86.sse2.pause"]
        pub fn sse2_pause() -> ();
        /// The `llvm.x86.sse3.addsub.ps` intrinsic; known as `__builtin_ia32_addsubps` in GCC.
        #[link_name = "llvm.x86.sse3.addsub.ps"]
        pub fn sse3_addsub_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse3.addsub.pd` intrinsic; known as `__builtin_ia32_addsubpd` in GCC.
        #[link_name = "llvm.x86.sse3.addsub.pd"]
        pub fn sse3_addsub_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse3.hadd.ps` intrinsic; known as `__builtin_ia32_haddps` in GCC.
        #[link_name = "llvm.x86.sse3.hadd.ps"]
        pub fn sse3_hadd_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse3.hadd.pd` intrinsic; known as `__builtin_ia32_haddpd` in GCC.
        #[link_name = "llvm.x86.sse3.hadd.pd"]
        pub fn sse3_hadd_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse3.hsub.ps` intrinsic; known as `__builtin_ia32_hsubps` in GCC.
        #[link_name = "llvm.x86.sse3.hsub.ps"]
        pub fn sse3_hsub_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse3.hsub.pd` intrinsic; known as `__builtin_ia32_hsubpd` in GCC.
        #[link_name = "llvm.x86.sse3.hsub.pd"]
        pub fn sse3_hsub_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse3.ldu.dq` intrinsic; known as `__builtin_ia32_lddqu` in GCC.
        #[link_name = "llvm.x86.sse3.ldu.dq"]
        pub fn sse3_ldu_dq(a: *mut i8) -> ::simdty::i8x16;
        /// The `llvm.x86.sse3.monitor` intrinsic; known as `__builtin_ia32_monitor` in GCC.
        #[link_name = "llvm.x86.sse3.monitor"]
        pub fn sse3_monitor(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.sse3.mwait` intrinsic; known as `__builtin_ia32_mwait` in GCC.
        #[link_name = "llvm.x86.sse3.mwait"]
        pub fn sse3_mwait(a: i32, b: i32) -> ();
        /// The `llvm.x86.ssse3.phadd.w.128` intrinsic; known as `__builtin_ia32_phaddw128` in GCC.
        #[link_name = "llvm.x86.ssse3.phadd.w.128"]
        pub fn ssse3_phadd_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.phadd.d.128` intrinsic; known as `__builtin_ia32_phaddd128` in GCC.
        #[link_name = "llvm.x86.ssse3.phadd.d.128"]
        pub fn ssse3_phadd_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.ssse3.phadd.sw.128` intrinsic; known as `__builtin_ia32_phaddsw128` in GCC.
        #[link_name = "llvm.x86.ssse3.phadd.sw.128"]
        pub fn ssse3_phadd_sw_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.phsub.w.128` intrinsic; known as `__builtin_ia32_phsubw128` in GCC.
        #[link_name = "llvm.x86.ssse3.phsub.w.128"]
        pub fn ssse3_phsub_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.phsub.d.128` intrinsic; known as `__builtin_ia32_phsubd128` in GCC.
        #[link_name = "llvm.x86.ssse3.phsub.d.128"]
        pub fn ssse3_phsub_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.ssse3.phsub.sw.128` intrinsic; known as `__builtin_ia32_phsubsw128` in GCC.
        #[link_name = "llvm.x86.ssse3.phsub.sw.128"]
        pub fn ssse3_phsub_sw_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.pmadd.ub.sw.128` intrinsic; known as `__builtin_ia32_pmaddubsw128` in GCC.
        #[link_name = "llvm.x86.ssse3.pmadd.ub.sw.128"]
        pub fn ssse3_pmadd_ub_sw_128(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.pmul.hr.sw.128` intrinsic; known as `__builtin_ia32_pmulhrsw128` in GCC.
        #[link_name = "llvm.x86.ssse3.pmul.hr.sw.128"]
        pub fn ssse3_pmul_hr_sw_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.pshuf.b.128` intrinsic; known as `__builtin_ia32_pshufb128` in GCC.
        #[link_name = "llvm.x86.ssse3.pshuf.b.128"]
        pub fn ssse3_pshuf_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.ssse3.psign.b.128` intrinsic; known as `__builtin_ia32_psignb128` in GCC.
        #[link_name = "llvm.x86.ssse3.psign.b.128"]
        pub fn ssse3_psign_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.ssse3.psign.w.128` intrinsic; known as `__builtin_ia32_psignw128` in GCC.
        #[link_name = "llvm.x86.ssse3.psign.w.128"]
        pub fn ssse3_psign_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.psign.d.128` intrinsic; known as `__builtin_ia32_psignd128` in GCC.
        #[link_name = "llvm.x86.ssse3.psign.d.128"]
        pub fn ssse3_psign_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.ssse3.pabs.b.128` intrinsic; known as `__builtin_ia32_pabsb128` in GCC.
        #[link_name = "llvm.x86.ssse3.pabs.b.128"]
        pub fn ssse3_pabs_b_128(a: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.ssse3.pabs.w.128` intrinsic; known as `__builtin_ia32_pabsw128` in GCC.
        #[link_name = "llvm.x86.ssse3.pabs.w.128"]
        pub fn ssse3_pabs_w_128(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.ssse3.pabs.d.128` intrinsic; known as `__builtin_ia32_pabsd128` in GCC.
        #[link_name = "llvm.x86.ssse3.pabs.d.128"]
        pub fn ssse3_pabs_d_128(a: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sse41.round.ss` intrinsic; known as `__builtin_ia32_roundss` in GCC.
        #[link_name = "llvm.x86.sse41.round.ss"]
        pub fn sse41_round_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.sse41.round.ps` intrinsic; known as `__builtin_ia32_roundps` in GCC.
        #[link_name = "llvm.x86.sse41.round.ps"]
        pub fn sse41_round_ps(a: ::simdty::f32x4, b: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.sse41.round.sd` intrinsic; known as `__builtin_ia32_roundsd` in GCC.
        #[link_name = "llvm.x86.sse41.round.sd"]
        pub fn sse41_round_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.sse41.round.pd` intrinsic; known as `__builtin_ia32_roundpd` in GCC.
        #[link_name = "llvm.x86.sse41.round.pd"]
        pub fn sse41_round_pd(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.sse41.phminposuw` intrinsic; known as `__builtin_ia32_phminposuw128` in GCC.
        #[link_name = "llvm.x86.sse41.phminposuw"]
        pub fn sse41_phminposuw(a: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.aesni.aesimc` intrinsic; known as `__builtin_ia32_aesimc128` in GCC.
        #[link_name = "llvm.x86.aesni.aesimc"]
        pub fn aesni_aesimc(a: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.aesni.aesenc` intrinsic; known as `__builtin_ia32_aesenc128` in GCC.
        #[link_name = "llvm.x86.aesni.aesenc"]
        pub fn aesni_aesenc(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.aesni.aesenclast` intrinsic; known as `__builtin_ia32_aesenclast128` in GCC.
        #[link_name = "llvm.x86.aesni.aesenclast"]
        pub fn aesni_aesenclast(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.aesni.aesdec` intrinsic; known as `__builtin_ia32_aesdec128` in GCC.
        #[link_name = "llvm.x86.aesni.aesdec"]
        pub fn aesni_aesdec(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.aesni.aesdeclast` intrinsic; known as `__builtin_ia32_aesdeclast128` in GCC.
        #[link_name = "llvm.x86.aesni.aesdeclast"]
        pub fn aesni_aesdeclast(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.aesni.aeskeygenassist` intrinsic; known as `__builtin_ia32_aeskeygenassist128` in GCC.
        #[link_name = "llvm.x86.aesni.aeskeygenassist"]
        pub fn aesni_aeskeygenassist(a: ::simdty::i64x2, b: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.pclmulqdq` intrinsic; known as `__builtin_ia32_pclmulqdq128` in GCC.
        #[link_name = "llvm.x86.pclmulqdq"]
        pub fn pclmulqdq(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.sse41.packusdw` intrinsic; known as `__builtin_ia32_packusdw128` in GCC.
        #[link_name = "llvm.x86.sse41.packusdw"]
        pub fn sse41_packusdw(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i16x8;
        /// The `llvm.x86.sse41.pmuldq` intrinsic; known as `__builtin_ia32_pmuldq128` in GCC.
        #[link_name = "llvm.x86.sse41.pmuldq"]
        pub fn sse41_pmuldq(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.x86.sse41.insertps` intrinsic; known as `__builtin_ia32_insertps128` in GCC.
        #[link_name = "llvm.x86.sse41.insertps"]
        pub fn sse41_insertps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.sse41.pblendvb` intrinsic; known as `__builtin_ia32_pblendvb128` in GCC.
        #[link_name = "llvm.x86.sse41.pblendvb"]
        pub fn sse41_pblendvb(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.sse41.blendvpd` intrinsic; known as `__builtin_ia32_blendvpd` in GCC.
        #[link_name = "llvm.x86.sse41.blendvpd"]
        pub fn sse41_blendvpd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.sse41.blendvps` intrinsic; known as `__builtin_ia32_blendvps` in GCC.
        #[link_name = "llvm.x86.sse41.blendvps"]
        pub fn sse41_blendvps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.sse41.dppd` intrinsic; known as `__builtin_ia32_dppd` in GCC.
        #[link_name = "llvm.x86.sse41.dppd"]
        pub fn sse41_dppd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.sse41.dpps` intrinsic; known as `__builtin_ia32_dpps` in GCC.
        #[link_name = "llvm.x86.sse41.dpps"]
        pub fn sse41_dpps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.sse41.mpsadbw` intrinsic; known as `__builtin_ia32_mpsadbw128` in GCC.
        #[link_name = "llvm.x86.sse41.mpsadbw"]
        pub fn sse41_mpsadbw(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.sse41.movntdqa` intrinsic; known as `__builtin_ia32_movntdqa` in GCC.
        #[link_name = "llvm.x86.sse41.movntdqa"]
        pub fn sse41_movntdqa(a: *mut i8) -> ::simdty::i64x2;
        /// The `llvm.x86.sse41.ptestz` intrinsic; known as `__builtin_ia32_ptestz128` in GCC.
        #[link_name = "llvm.x86.sse41.ptestz"]
        pub fn sse41_ptestz(a: ::simdty::i64x2, b: ::simdty::i64x2) -> i32;
        /// The `llvm.x86.sse41.ptestc` intrinsic; known as `__builtin_ia32_ptestc128` in GCC.
        #[link_name = "llvm.x86.sse41.ptestc"]
        pub fn sse41_ptestc(a: ::simdty::i64x2, b: ::simdty::i64x2) -> i32;
        /// The `llvm.x86.sse41.ptestnzc` intrinsic; known as `__builtin_ia32_ptestnzc128` in GCC.
        #[link_name = "llvm.x86.sse41.ptestnzc"]
        pub fn sse41_ptestnzc(a: ::simdty::i64x2, b: ::simdty::i64x2) -> i32;
        /// The `llvm.x86.sse42.crc32.32.8` intrinsic; known as `__builtin_ia32_crc32qi` in GCC.
        #[link_name = "llvm.x86.sse42.crc32.32.8"]
        pub fn sse42_crc32_32_8(a: i32, b: i8) -> i32;
        /// The `llvm.x86.sse42.crc32.32.16` intrinsic; known as `__builtin_ia32_crc32hi` in GCC.
        #[link_name = "llvm.x86.sse42.crc32.32.16"]
        pub fn sse42_crc32_32_16(a: i32, b: i16) -> i32;
        /// The `llvm.x86.sse42.crc32.32.32` intrinsic; known as `__builtin_ia32_crc32si` in GCC.
        #[link_name = "llvm.x86.sse42.crc32.32.32"]
        pub fn sse42_crc32_32_32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.sse42.crc32.64.64` intrinsic; known as `__builtin_ia32_crc32di` in GCC.
        #[link_name = "llvm.x86.sse42.crc32.64.64"]
        pub fn sse42_crc32_64_64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.sse42.pcmpistrm128` intrinsic; known as `__builtin_ia32_pcmpistrm128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistrm128"]
        pub fn sse42_pcmpistrm128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.sse42.pcmpistri128` intrinsic; known as `__builtin_ia32_pcmpistri128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistri128"]
        pub fn sse42_pcmpistri128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpistria128` intrinsic; known as `__builtin_ia32_pcmpistria128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistria128"]
        pub fn sse42_pcmpistria128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpistric128` intrinsic; known as `__builtin_ia32_pcmpistric128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistric128"]
        pub fn sse42_pcmpistric128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpistrio128` intrinsic; known as `__builtin_ia32_pcmpistrio128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistrio128"]
        pub fn sse42_pcmpistrio128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpistris128` intrinsic; known as `__builtin_ia32_pcmpistris128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistris128"]
        pub fn sse42_pcmpistris128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpistriz128` intrinsic; known as `__builtin_ia32_pcmpistriz128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpistriz128"]
        pub fn sse42_pcmpistriz128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestrm128` intrinsic; known as `__builtin_ia32_pcmpestrm128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestrm128"]
        pub fn sse42_pcmpestrm128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.sse42.pcmpestri128` intrinsic; known as `__builtin_ia32_pcmpestri128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestri128"]
        pub fn sse42_pcmpestri128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestria128` intrinsic; known as `__builtin_ia32_pcmpestria128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestria128"]
        pub fn sse42_pcmpestria128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestric128` intrinsic; known as `__builtin_ia32_pcmpestric128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestric128"]
        pub fn sse42_pcmpestric128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestrio128` intrinsic; known as `__builtin_ia32_pcmpestrio128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestrio128"]
        pub fn sse42_pcmpestrio128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestris128` intrinsic; known as `__builtin_ia32_pcmpestris128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestris128"]
        pub fn sse42_pcmpestris128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse42.pcmpestriz128` intrinsic; known as `__builtin_ia32_pcmpestriz128` in GCC.
        #[link_name = "llvm.x86.sse42.pcmpestriz128"]
        pub fn sse42_pcmpestriz128(a: ::simdty::i8x16, b: i32, c: ::simdty::i8x16, d: i32, e: i8) -> i32;
        /// The `llvm.x86.sse4a.extrqi` intrinsic; known as `__builtin_ia32_extrqi` in GCC.
        #[link_name = "llvm.x86.sse4a.extrqi"]
        pub fn sse4a_extrqi(a: ::simdty::i64x2, b: i8, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.sse4a.extrq` intrinsic; known as `__builtin_ia32_extrq` in GCC.
        #[link_name = "llvm.x86.sse4a.extrq"]
        pub fn sse4a_extrq(a: ::simdty::i64x2, b: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.x86.sse4a.insertqi` intrinsic; known as `__builtin_ia32_insertqi` in GCC.
        #[link_name = "llvm.x86.sse4a.insertqi"]
        pub fn sse4a_insertqi(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.sse4a.insertq` intrinsic; known as `__builtin_ia32_insertq` in GCC.
        #[link_name = "llvm.x86.sse4a.insertq"]
        pub fn sse4a_insertq(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.avx.addsub.pd.256` intrinsic; known as `__builtin_ia32_addsubpd256` in GCC.
        #[link_name = "llvm.x86.avx.addsub.pd.256"]
        pub fn avx_addsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.addsub.ps.256` intrinsic; known as `__builtin_ia32_addsubps256` in GCC.
        #[link_name = "llvm.x86.avx.addsub.ps.256"]
        pub fn avx_addsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.max.pd.256` intrinsic; known as `__builtin_ia32_maxpd256` in GCC.
        #[link_name = "llvm.x86.avx.max.pd.256"]
        pub fn avx_max_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.max.ps.256` intrinsic; known as `__builtin_ia32_maxps256` in GCC.
        #[link_name = "llvm.x86.avx.max.ps.256"]
        pub fn avx_max_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.min.pd.256` intrinsic; known as `__builtin_ia32_minpd256` in GCC.
        #[link_name = "llvm.x86.avx.min.pd.256"]
        pub fn avx_min_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.min.ps.256` intrinsic; known as `__builtin_ia32_minps256` in GCC.
        #[link_name = "llvm.x86.avx.min.ps.256"]
        pub fn avx_min_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.sqrt.pd.256` intrinsic; known as `__builtin_ia32_sqrtpd256` in GCC.
        #[link_name = "llvm.x86.avx.sqrt.pd.256"]
        pub fn avx_sqrt_pd_256(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.sqrt.ps.256` intrinsic; known as `__builtin_ia32_sqrtps256` in GCC.
        #[link_name = "llvm.x86.avx.sqrt.ps.256"]
        pub fn avx_sqrt_ps_256(a: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.rsqrt.ps.256` intrinsic; known as `__builtin_ia32_rsqrtps256` in GCC.
        #[link_name = "llvm.x86.avx.rsqrt.ps.256"]
        pub fn avx_rsqrt_ps_256(a: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.rcp.ps.256` intrinsic; known as `__builtin_ia32_rcpps256` in GCC.
        #[link_name = "llvm.x86.avx.rcp.ps.256"]
        pub fn avx_rcp_ps_256(a: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.round.pd.256` intrinsic; known as `__builtin_ia32_roundpd256` in GCC.
        #[link_name = "llvm.x86.avx.round.pd.256"]
        pub fn avx_round_pd_256(a: ::simdty::f64x4, b: i32) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.round.ps.256` intrinsic; known as `__builtin_ia32_roundps256` in GCC.
        #[link_name = "llvm.x86.avx.round.ps.256"]
        pub fn avx_round_ps_256(a: ::simdty::f32x8, b: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.hadd.pd.256` intrinsic; known as `__builtin_ia32_haddpd256` in GCC.
        #[link_name = "llvm.x86.avx.hadd.pd.256"]
        pub fn avx_hadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.hsub.ps.256` intrinsic; known as `__builtin_ia32_hsubps256` in GCC.
        #[link_name = "llvm.x86.avx.hsub.ps.256"]
        pub fn avx_hsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.hsub.pd.256` intrinsic; known as `__builtin_ia32_hsubpd256` in GCC.
        #[link_name = "llvm.x86.avx.hsub.pd.256"]
        pub fn avx_hsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.hadd.ps.256` intrinsic; known as `__builtin_ia32_haddps256` in GCC.
        #[link_name = "llvm.x86.avx.hadd.ps.256"]
        pub fn avx_hadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.vpermilvar.pd` intrinsic; known as `__builtin_ia32_vpermilvarpd` in GCC.
        #[link_name = "llvm.x86.avx.vpermilvar.pd"]
        pub fn avx_vpermilvar_pd(a: ::simdty::f64x2, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.avx.vpermilvar.ps` intrinsic; known as `__builtin_ia32_vpermilvarps` in GCC.
        #[link_name = "llvm.x86.avx.vpermilvar.ps"]
        pub fn avx_vpermilvar_ps(a: ::simdty::f32x4, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.avx.vpermilvar.pd.256` intrinsic; known as `__builtin_ia32_vpermilvarpd256` in GCC.
        #[link_name = "llvm.x86.avx.vpermilvar.pd.256"]
        pub fn avx_vpermilvar_pd_256(a: ::simdty::f64x4, b: ::simdty::i64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.vpermilvar.ps.256` intrinsic; known as `__builtin_ia32_vpermilvarps256` in GCC.
        #[link_name = "llvm.x86.avx.vpermilvar.ps.256"]
        pub fn avx_vpermilvar_ps_256(a: ::simdty::f32x8, b: ::simdty::i32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.vperm2f128.pd.256` intrinsic; known as `__builtin_ia32_vperm2f128_pd256` in GCC.
        #[link_name = "llvm.x86.avx.vperm2f128.pd.256"]
        pub fn avx_vperm2f128_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.vperm2f128.ps.256` intrinsic; known as `__builtin_ia32_vperm2f128_ps256` in GCC.
        #[link_name = "llvm.x86.avx.vperm2f128.ps.256"]
        pub fn avx_vperm2f128_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.vperm2f128.si.256` intrinsic; known as `__builtin_ia32_vperm2f128_si256` in GCC.
        #[link_name = "llvm.x86.avx.vperm2f128.si.256"]
        pub fn avx_vperm2f128_si_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.d.128` intrinsic; known as `__builtin_ia32_vpermi2vard128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.d.128"]
        pub fn avx512_mask_vpermi2var_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.vpermi2var.d.256` intrinsic; known as `__builtin_ia32_vpermi2vard256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.d.256"]
        pub fn avx512_mask_vpermi2var_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.d.512` intrinsic; known as `__builtin_ia32_vpermi2vard512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.d.512"]
        pub fn avx512_mask_vpermi2var_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.vpermi2var.hi.128` intrinsic; known as `__builtin_ia32_vpermi2varhi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.hi.128"]
        pub fn avx512_mask_vpermi2var_hi_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.hi.256` intrinsic; known as `__builtin_ia32_vpermi2varhi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.hi.256"]
        pub fn avx512_mask_vpermi2var_hi_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.vpermi2var.hi.512` intrinsic; known as `__builtin_ia32_vpermi2varhi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.hi.512"]
        pub fn avx512_mask_vpermi2var_hi_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.vpermi2var.pd.128` intrinsic; known as `__builtin_ia32_vpermi2varpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.pd.128"]
        pub fn avx512_mask_vpermi2var_pd_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vpermi2var.pd.256` intrinsic; known as `__builtin_ia32_vpermi2varpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.pd.256"]
        pub fn avx512_mask_vpermi2var_pd_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vpermi2var.pd.512` intrinsic; known as `__builtin_ia32_vpermi2varpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.pd.512"]
        pub fn avx512_mask_vpermi2var_pd_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.ps.128` intrinsic; known as `__builtin_ia32_vpermi2varps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.ps.128"]
        pub fn avx512_mask_vpermi2var_ps_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vpermi2var.ps.256` intrinsic; known as `__builtin_ia32_vpermi2varps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.ps.256"]
        pub fn avx512_mask_vpermi2var_ps_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.ps.512` intrinsic; known as `__builtin_ia32_vpermi2varps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.ps.512"]
        pub fn avx512_mask_vpermi2var_ps_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vpermi2var.q.128` intrinsic; known as `__builtin_ia32_vpermi2varq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.q.128"]
        pub fn avx512_mask_vpermi2var_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vpermi2var.q.256` intrinsic; known as `__builtin_ia32_vpermi2varq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.q.256"]
        pub fn avx512_mask_vpermi2var_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.vpermi2var.q.512` intrinsic; known as `__builtin_ia32_vpermi2varq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.q.512"]
        pub fn avx512_mask_vpermi2var_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.vpermt2var.d.512` intrinsic; known as `__builtin_ia32_vpermt2vard512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.d.512"]
        pub fn avx512_mask_vpermt2var_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.q.512` intrinsic; known as `__builtin_ia32_vpermt2varq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.q.512"]
        pub fn avx512_mask_vpermt2var_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.vpermt2var.ps.512` intrinsic; known as `__builtin_ia32_vpermt2varps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.ps.512"]
        pub fn avx512_mask_vpermt2var_ps_512(a: ::simdty::i32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.pd.512` intrinsic; known as `__builtin_ia32_vpermt2varpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.pd.512"]
        pub fn avx512_mask_vpermt2var_pd_512(a: ::simdty::i64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vpermt2var.d.128` intrinsic; known as `__builtin_ia32_vpermt2vard128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.d.128"]
        pub fn avx512_mask_vpermt2var_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.d.128` intrinsic; known as `__builtin_ia32_vpermt2vard128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.d.128"]
        pub fn avx512_maskz_vpermt2var_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.vpermt2var.d.256` intrinsic; known as `__builtin_ia32_vpermt2vard256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.d.256"]
        pub fn avx512_mask_vpermt2var_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.maskz.vpermt2var.d.256` intrinsic; known as `__builtin_ia32_vpermt2vard256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.d.256"]
        pub fn avx512_maskz_vpermt2var_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.maskz.vpermt2var.d.512` intrinsic; known as `__builtin_ia32_vpermt2vard512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.d.512"]
        pub fn avx512_maskz_vpermt2var_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.hi.128` intrinsic; known as `__builtin_ia32_vpermt2varhi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.hi.128"]
        pub fn avx512_mask_vpermt2var_hi_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.maskz.vpermt2var.hi.128` intrinsic; known as `__builtin_ia32_vpermt2varhi128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.hi.128"]
        pub fn avx512_maskz_vpermt2var_hi_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.vpermt2var.hi.256` intrinsic; known as `__builtin_ia32_vpermt2varhi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.hi.256"]
        pub fn avx512_mask_vpermt2var_hi_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.maskz.vpermt2var.hi.256` intrinsic; known as `__builtin_ia32_vpermt2varhi256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.hi.256"]
        pub fn avx512_maskz_vpermt2var_hi_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.hi.512` intrinsic; known as `__builtin_ia32_vpermt2varhi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.hi.512"]
        pub fn avx512_mask_vpermt2var_hi_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.maskz.vpermt2var.hi.512` intrinsic; known as `__builtin_ia32_vpermt2varhi512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.hi.512"]
        pub fn avx512_maskz_vpermt2var_hi_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.vpermt2var.pd.128` intrinsic; known as `__builtin_ia32_vpermt2varpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.pd.128"]
        pub fn avx512_mask_vpermt2var_pd_128(a: ::simdty::i64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.vpermt2var.pd.128` intrinsic; known as `__builtin_ia32_vpermt2varpd128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.pd.128"]
        pub fn avx512_maskz_vpermt2var_pd_128(a: ::simdty::i64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vpermt2var.pd.256` intrinsic; known as `__builtin_ia32_vpermt2varpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.pd.256"]
        pub fn avx512_mask_vpermt2var_pd_256(a: ::simdty::i64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.pd.256` intrinsic; known as `__builtin_ia32_vpermt2varpd256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.pd.256"]
        pub fn avx512_maskz_vpermt2var_pd_256(a: ::simdty::i64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.pd.512` intrinsic; known as `__builtin_ia32_vpermt2varpd512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.pd.512"]
        pub fn avx512_maskz_vpermt2var_pd_512(a: ::simdty::i64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vpermt2var.ps.128` intrinsic; known as `__builtin_ia32_vpermt2varps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.ps.128"]
        pub fn avx512_mask_vpermt2var_ps_128(a: ::simdty::i32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.ps.128` intrinsic; known as `__builtin_ia32_vpermt2varps128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.ps.128"]
        pub fn avx512_maskz_vpermt2var_ps_128(a: ::simdty::i32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vpermt2var.ps.256` intrinsic; known as `__builtin_ia32_vpermt2varps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.ps.256"]
        pub fn avx512_mask_vpermt2var_ps_256(a: ::simdty::i32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.maskz.vpermt2var.ps.256` intrinsic; known as `__builtin_ia32_vpermt2varps256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.ps.256"]
        pub fn avx512_maskz_vpermt2var_ps_256(a: ::simdty::i32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.maskz.vpermt2var.ps.512` intrinsic; known as `__builtin_ia32_vpermt2varps512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.ps.512"]
        pub fn avx512_maskz_vpermt2var_ps_512(a: ::simdty::i32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.q.128` intrinsic; known as `__builtin_ia32_vpermt2varq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.q.128"]
        pub fn avx512_mask_vpermt2var_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.maskz.vpermt2var.q.128` intrinsic; known as `__builtin_ia32_vpermt2varq128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.q.128"]
        pub fn avx512_maskz_vpermt2var_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vpermt2var.q.256` intrinsic; known as `__builtin_ia32_vpermt2varq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.q.256"]
        pub fn avx512_mask_vpermt2var_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.q.256` intrinsic; known as `__builtin_ia32_vpermt2varq256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.q.256"]
        pub fn avx512_maskz_vpermt2var_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.maskz.vpermt2var.q.512` intrinsic; known as `__builtin_ia32_vpermt2varq512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.q.512"]
        pub fn avx512_maskz_vpermt2var_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.vpermi2var.qi.128` intrinsic; known as `__builtin_ia32_vpermi2varqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.qi.128"]
        pub fn avx512_mask_vpermi2var_qi_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.vpermt2var.qi.128` intrinsic; known as `__builtin_ia32_vpermt2varqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.qi.128"]
        pub fn avx512_mask_vpermt2var_qi_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.maskz.vpermt2var.qi.128` intrinsic; known as `__builtin_ia32_vpermt2varqi128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.qi.128"]
        pub fn avx512_maskz_vpermt2var_qi_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.vpermi2var.qi.256` intrinsic; known as `__builtin_ia32_vpermi2varqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.qi.256"]
        pub fn avx512_mask_vpermi2var_qi_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.vpermt2var.qi.256` intrinsic; known as `__builtin_ia32_vpermt2varqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.qi.256"]
        pub fn avx512_mask_vpermt2var_qi_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.maskz.vpermt2var.qi.256` intrinsic; known as `__builtin_ia32_vpermt2varqi256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.qi.256"]
        pub fn avx512_maskz_vpermt2var_qi_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.vpermi2var.qi.512` intrinsic; known as `__builtin_ia32_vpermi2varqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermi2var.qi.512"]
        pub fn avx512_mask_vpermi2var_qi_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.vpermt2var.qi.512` intrinsic; known as `__builtin_ia32_vpermt2varqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermt2var.qi.512"]
        pub fn avx512_mask_vpermt2var_qi_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.maskz.vpermt2var.qi.512` intrinsic; known as `__builtin_ia32_vpermt2varqi512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpermt2var.qi.512"]
        pub fn avx512_maskz_vpermt2var_qi_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.vpermilvar.pd.256` intrinsic; known as `__builtin_ia32_vpermilvarpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.pd.256"]
        pub fn avx512_mask_vpermilvar_pd_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vpermilvar.pd.512` intrinsic; known as `__builtin_ia32_vpermilvarpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.pd.512"]
        pub fn avx512_mask_vpermilvar_pd_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vpermilvar.pd.128` intrinsic; known as `__builtin_ia32_vpermilvarpd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.pd.128"]
        pub fn avx512_mask_vpermilvar_pd_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vpermilvar.ps.256` intrinsic; known as `__builtin_ia32_vpermilvarps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.ps.256"]
        pub fn avx512_mask_vpermilvar_ps_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vpermilvar.ps.512` intrinsic; known as `__builtin_ia32_vpermilvarps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.ps.512"]
        pub fn avx512_mask_vpermilvar_ps_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vpermilvar.ps.128` intrinsic; known as `__builtin_ia32_vpermilvarps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpermilvar.ps.128"]
        pub fn avx512_mask_vpermilvar_ps_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.pshuf.b.128` intrinsic; known as `__builtin_ia32_pshufb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pshuf.b.128"]
        pub fn avx512_mask_pshuf_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pshuf.b.256` intrinsic; known as `__builtin_ia32_pshufb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pshuf.b.256"]
        pub fn avx512_mask_pshuf_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pshuf.b.512` intrinsic; known as `__builtin_ia32_pshufb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pshuf.b.512"]
        pub fn avx512_mask_pshuf_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.shuf.f32x4.256` intrinsic; known as `__builtin_ia32_shuf_f32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.f32x4.256"]
        pub fn avx512_mask_shuf_f32x4_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i32, d: ::simdty::f32x8, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.shuf.f32x4` intrinsic; known as `__builtin_ia32_shuf_f32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.f32x4"]
        pub fn avx512_mask_shuf_f32x4(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i32, d: ::simdty::f32x16, e: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.shuf.f64x2.256` intrinsic; known as `__builtin_ia32_shuf_f64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.f64x2.256"]
        pub fn avx512_mask_shuf_f64x2_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i32, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.shuf.f64x2` intrinsic; known as `__builtin_ia32_shuf_f64x2_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.f64x2"]
        pub fn avx512_mask_shuf_f64x2(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i32, d: ::simdty::f64x8, e: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.shuf.i32x4.256` intrinsic; known as `__builtin_ia32_shuf_i32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.i32x4.256"]
        pub fn avx512_mask_shuf_i32x4_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i32, d: ::simdty::i32x8, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.shuf.i32x4` intrinsic; known as `__builtin_ia32_shuf_i32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.i32x4"]
        pub fn avx512_mask_shuf_i32x4(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32, d: ::simdty::i32x16, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.shuf.i64x2.256` intrinsic; known as `__builtin_ia32_shuf_i64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.i64x2.256"]
        pub fn avx512_mask_shuf_i64x2_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i32, d: ::simdty::i64x4, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.shuf.i64x2` intrinsic; known as `__builtin_ia32_shuf_i64x2_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.i64x2"]
        pub fn avx512_mask_shuf_i64x2(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i32, d: ::simdty::i64x8, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.shuf.pd.128` intrinsic; known as `__builtin_ia32_shufpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.pd.128"]
        pub fn avx512_mask_shuf_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: ::simdty::f64x2, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.shuf.pd.256` intrinsic; known as `__builtin_ia32_shufpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.pd.256"]
        pub fn avx512_mask_shuf_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i32, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.shuf.pd.512` intrinsic; known as `__builtin_ia32_shufpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.pd.512"]
        pub fn avx512_mask_shuf_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i32, d: ::simdty::f64x8, e: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.shuf.ps.128` intrinsic; known as `__builtin_ia32_shufps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.ps.128"]
        pub fn avx512_mask_shuf_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: ::simdty::f32x4, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.shuf.ps.256` intrinsic; known as `__builtin_ia32_shufps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.ps.256"]
        pub fn avx512_mask_shuf_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i32, d: ::simdty::f32x8, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.shuf.ps.512` intrinsic; known as `__builtin_ia32_shufps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.shuf.ps.512"]
        pub fn avx512_mask_shuf_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i32, d: ::simdty::f32x16, e: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx.blendv.pd.256` intrinsic; known as `__builtin_ia32_blendvpd256` in GCC.
        #[link_name = "llvm.x86.avx.blendv.pd.256"]
        pub fn avx_blendv_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.blendv.ps.256` intrinsic; known as `__builtin_ia32_blendvps256` in GCC.
        #[link_name = "llvm.x86.avx.blendv.ps.256"]
        pub fn avx_blendv_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.dp.ps.256` intrinsic; known as `__builtin_ia32_dpps256` in GCC.
        #[link_name = "llvm.x86.avx.dp.ps.256"]
        pub fn avx_dp_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.cmp.pd.256` intrinsic.
        #[link_name = "llvm.x86.avx.cmp.pd.256"]
        pub fn avx_cmp_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.cmp.ps.256` intrinsic.
        #[link_name = "llvm.x86.avx.cmp.ps.256"]
        pub fn avx_cmp_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.cvtdq2.ps.256` intrinsic; known as `__builtin_ia32_cvtdq2ps256` in GCC.
        #[link_name = "llvm.x86.avx.cvtdq2.ps.256"]
        pub fn avx_cvtdq2_ps_256(a: ::simdty::i32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.cvt.pd2.ps.256` intrinsic; known as `__builtin_ia32_cvtpd2ps256` in GCC.
        #[link_name = "llvm.x86.avx.cvt.pd2.ps.256"]
        pub fn avx_cvt_pd2_ps_256(a: ::simdty::f64x4) -> ::simdty::f32x4;
        /// The `llvm.x86.avx.cvt.ps2dq.256` intrinsic; known as `__builtin_ia32_cvtps2dq256` in GCC.
        #[link_name = "llvm.x86.avx.cvt.ps2dq.256"]
        pub fn avx_cvt_ps2dq_256(a: ::simdty::f32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx.cvtt.pd2dq.256` intrinsic; known as `__builtin_ia32_cvttpd2dq256` in GCC.
        #[link_name = "llvm.x86.avx.cvtt.pd2dq.256"]
        pub fn avx_cvtt_pd2dq_256(a: ::simdty::f64x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx.cvt.pd2dq.256` intrinsic; known as `__builtin_ia32_cvtpd2dq256` in GCC.
        #[link_name = "llvm.x86.avx.cvt.pd2dq.256"]
        pub fn avx_cvt_pd2dq_256(a: ::simdty::f64x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx.cvtt.ps2dq.256` intrinsic; known as `__builtin_ia32_cvttps2dq256` in GCC.
        #[link_name = "llvm.x86.avx.cvtt.ps2dq.256"]
        pub fn avx_cvtt_ps2dq_256(a: ::simdty::f32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx.vtestz.pd` intrinsic; known as `__builtin_ia32_vtestzpd` in GCC.
        #[link_name = "llvm.x86.avx.vtestz.pd"]
        pub fn avx_vtestz_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.avx.vtestc.pd` intrinsic; known as `__builtin_ia32_vtestcpd` in GCC.
        #[link_name = "llvm.x86.avx.vtestc.pd"]
        pub fn avx_vtestc_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.avx.vtestnzc.pd` intrinsic; known as `__builtin_ia32_vtestnzcpd` in GCC.
        #[link_name = "llvm.x86.avx.vtestnzc.pd"]
        pub fn avx_vtestnzc_pd(a: ::simdty::f64x2, b: ::simdty::f64x2) -> i32;
        /// The `llvm.x86.avx.vtestz.ps` intrinsic; known as `__builtin_ia32_vtestzps` in GCC.
        #[link_name = "llvm.x86.avx.vtestz.ps"]
        pub fn avx_vtestz_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.avx.vtestc.ps` intrinsic; known as `__builtin_ia32_vtestcps` in GCC.
        #[link_name = "llvm.x86.avx.vtestc.ps"]
        pub fn avx_vtestc_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.avx.vtestnzc.ps` intrinsic; known as `__builtin_ia32_vtestnzcps` in GCC.
        #[link_name = "llvm.x86.avx.vtestnzc.ps"]
        pub fn avx_vtestnzc_ps(a: ::simdty::f32x4, b: ::simdty::f32x4) -> i32;
        /// The `llvm.x86.avx.vtestz.pd.256` intrinsic; known as `__builtin_ia32_vtestzpd256` in GCC.
        #[link_name = "llvm.x86.avx.vtestz.pd.256"]
        pub fn avx_vtestz_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> i32;
        /// The `llvm.x86.avx.vtestc.pd.256` intrinsic; known as `__builtin_ia32_vtestcpd256` in GCC.
        #[link_name = "llvm.x86.avx.vtestc.pd.256"]
        pub fn avx_vtestc_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> i32;
        /// The `llvm.x86.avx.vtestnzc.pd.256` intrinsic; known as `__builtin_ia32_vtestnzcpd256` in GCC.
        #[link_name = "llvm.x86.avx.vtestnzc.pd.256"]
        pub fn avx_vtestnzc_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4) -> i32;
        /// The `llvm.x86.avx.vtestz.ps.256` intrinsic; known as `__builtin_ia32_vtestzps256` in GCC.
        #[link_name = "llvm.x86.avx.vtestz.ps.256"]
        pub fn avx_vtestz_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> i32;
        /// The `llvm.x86.avx.vtestc.ps.256` intrinsic; known as `__builtin_ia32_vtestcps256` in GCC.
        #[link_name = "llvm.x86.avx.vtestc.ps.256"]
        pub fn avx_vtestc_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> i32;
        /// The `llvm.x86.avx.vtestnzc.ps.256` intrinsic; known as `__builtin_ia32_vtestnzcps256` in GCC.
        #[link_name = "llvm.x86.avx.vtestnzc.ps.256"]
        pub fn avx_vtestnzc_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8) -> i32;
        /// The `llvm.x86.avx.ptestz.256` intrinsic; known as `__builtin_ia32_ptestz256` in GCC.
        #[link_name = "llvm.x86.avx.ptestz.256"]
        pub fn avx_ptestz_256(a: ::simdty::i64x4, b: ::simdty::i64x4) -> i32;
        /// The `llvm.x86.avx.ptestc.256` intrinsic; known as `__builtin_ia32_ptestc256` in GCC.
        #[link_name = "llvm.x86.avx.ptestc.256"]
        pub fn avx_ptestc_256(a: ::simdty::i64x4, b: ::simdty::i64x4) -> i32;
        /// The `llvm.x86.avx.ptestnzc.256` intrinsic; known as `__builtin_ia32_ptestnzc256` in GCC.
        #[link_name = "llvm.x86.avx.ptestnzc.256"]
        pub fn avx_ptestnzc_256(a: ::simdty::i64x4, b: ::simdty::i64x4) -> i32;
        /// The `llvm.x86.avx512.ptestm.d.512` intrinsic; known as `__builtin_ia32_ptestmd512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.d.512"]
        pub fn avx512_ptestm_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestm.q.512` intrinsic; known as `__builtin_ia32_ptestmq512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.q.512"]
        pub fn avx512_ptestm_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.b.128` intrinsic; known as `__builtin_ia32_ptestmb128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.b.128"]
        pub fn avx512_ptestm_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestm.b.256` intrinsic; known as `__builtin_ia32_ptestmb256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.b.256"]
        pub fn avx512_ptestm_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32) -> i32;
        /// The `llvm.x86.avx512.ptestm.b.512` intrinsic; known as `__builtin_ia32_ptestmb512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.b.512"]
        pub fn avx512_ptestm_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i64) -> i64;
        /// The `llvm.x86.avx512.ptestm.d.128` intrinsic; known as `__builtin_ia32_ptestmd128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.d.128"]
        pub fn avx512_ptestm_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.d.256` intrinsic; known as `__builtin_ia32_ptestmd256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.d.256"]
        pub fn avx512_ptestm_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.q.128` intrinsic; known as `__builtin_ia32_ptestmq128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.q.128"]
        pub fn avx512_ptestm_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.q.256` intrinsic; known as `__builtin_ia32_ptestmq256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.q.256"]
        pub fn avx512_ptestm_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.w.128` intrinsic; known as `__builtin_ia32_ptestmw128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.w.128"]
        pub fn avx512_ptestm_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestm.w.256` intrinsic; known as `__builtin_ia32_ptestmw256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.w.256"]
        pub fn avx512_ptestm_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestm.w.512` intrinsic; known as `__builtin_ia32_ptestmw512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestm.w.512"]
        pub fn avx512_ptestm_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: i32) -> i32;
        /// The `llvm.x86.avx512.ptestnm.b.128` intrinsic; known as `__builtin_ia32_ptestnmb128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.b.128"]
        pub fn avx512_ptestnm_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestnm.b.256` intrinsic; known as `__builtin_ia32_ptestnmb256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.b.256"]
        pub fn avx512_ptestnm_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32) -> i32;
        /// The `llvm.x86.avx512.ptestnm.b.512` intrinsic; known as `__builtin_ia32_ptestnmb512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.b.512"]
        pub fn avx512_ptestnm_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i64) -> i64;
        /// The `llvm.x86.avx512.ptestnm.d.128` intrinsic; known as `__builtin_ia32_ptestnmd128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.d.128"]
        pub fn avx512_ptestnm_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.d.256` intrinsic; known as `__builtin_ia32_ptestnmd256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.d.256"]
        pub fn avx512_ptestnm_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.d.512` intrinsic; known as `__builtin_ia32_ptestnmd512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.d.512"]
        pub fn avx512_ptestnm_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestnm.q.128` intrinsic; known as `__builtin_ia32_ptestnmq128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.q.128"]
        pub fn avx512_ptestnm_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.q.256` intrinsic; known as `__builtin_ia32_ptestnmq256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.q.256"]
        pub fn avx512_ptestnm_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.q.512` intrinsic; known as `__builtin_ia32_ptestnmq512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.q.512"]
        pub fn avx512_ptestnm_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.w.128` intrinsic; known as `__builtin_ia32_ptestnmw128` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.w.128"]
        pub fn avx512_ptestnm_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i8) -> i8;
        /// The `llvm.x86.avx512.ptestnm.w.256` intrinsic; known as `__builtin_ia32_ptestnmw256` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.w.256"]
        pub fn avx512_ptestnm_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: i16) -> i16;
        /// The `llvm.x86.avx512.ptestnm.w.512` intrinsic; known as `__builtin_ia32_ptestnmw512` in GCC.
        #[link_name = "llvm.x86.avx512.ptestnm.w.512"]
        pub fn avx512_ptestnm_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: i32) -> i32;
        /// The `llvm.x86.avx512.mask.fpclass.pd.128` intrinsic; known as `__builtin_ia32_fpclasspd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.pd.128"]
        pub fn avx512_mask_fpclass_pd_128(a: ::simdty::f64x2, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.pd.256` intrinsic; known as `__builtin_ia32_fpclasspd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.pd.256"]
        pub fn avx512_mask_fpclass_pd_256(a: ::simdty::f64x4, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.pd.512` intrinsic; known as `__builtin_ia32_fpclasspd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.pd.512"]
        pub fn avx512_mask_fpclass_pd_512(a: ::simdty::f64x8, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.ps.128` intrinsic; known as `__builtin_ia32_fpclassps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.ps.128"]
        pub fn avx512_mask_fpclass_ps_128(a: ::simdty::f32x4, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.ps.256` intrinsic; known as `__builtin_ia32_fpclassps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.ps.256"]
        pub fn avx512_mask_fpclass_ps_256(a: ::simdty::f32x8, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.ps.512` intrinsic; known as `__builtin_ia32_fpclassps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.ps.512"]
        pub fn avx512_mask_fpclass_ps_512(a: ::simdty::f32x16, b: i32, c: i16) -> i16;
        /// The `llvm.x86.avx512.mask.fpclass.sd` intrinsic; known as `__builtin_ia32_fpclasssd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.sd"]
        pub fn avx512_mask_fpclass_sd(a: ::simdty::f64x2, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx512.mask.fpclass.ss` intrinsic; known as `__builtin_ia32_fpclassss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fpclass.ss"]
        pub fn avx512_mask_fpclass_ss(a: ::simdty::f32x4, b: i32, c: i8) -> i8;
        /// The `llvm.x86.avx.movmsk.pd.256` intrinsic; known as `__builtin_ia32_movmskpd256` in GCC.
        #[link_name = "llvm.x86.avx.movmsk.pd.256"]
        pub fn avx_movmsk_pd_256(a: ::simdty::f64x4) -> i32;
        /// The `llvm.x86.avx.movmsk.ps.256` intrinsic; known as `__builtin_ia32_movmskps256` in GCC.
        #[link_name = "llvm.x86.avx.movmsk.ps.256"]
        pub fn avx_movmsk_ps_256(a: ::simdty::f32x8) -> i32;
        /// The `llvm.x86.avx.vzeroall` intrinsic; known as `__builtin_ia32_vzeroall` in GCC.
        #[link_name = "llvm.x86.avx.vzeroall"]
        pub fn avx_vzeroall() -> ();
        /// The `llvm.x86.avx.vzeroupper` intrinsic; known as `__builtin_ia32_vzeroupper` in GCC.
        #[link_name = "llvm.x86.avx.vzeroupper"]
        pub fn avx_vzeroupper() -> ();
        /// The `llvm.x86.avx.vbroadcastf128.pd.256` intrinsic; known as `__builtin_ia32_vbroadcastf128_pd256` in GCC.
        #[link_name = "llvm.x86.avx.vbroadcastf128.pd.256"]
        pub fn avx_vbroadcastf128_pd_256(a: *mut i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.vbroadcastf128.ps.256` intrinsic; known as `__builtin_ia32_vbroadcastf128_ps256` in GCC.
        #[link_name = "llvm.x86.avx.vbroadcastf128.ps.256"]
        pub fn avx_vbroadcastf128_ps_256(a: *mut i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx.ldu.dq.256` intrinsic; known as `__builtin_ia32_lddqu256` in GCC.
        #[link_name = "llvm.x86.avx.ldu.dq.256"]
        pub fn avx_ldu_dq_256(a: *mut i8) -> ::simdty::i8x32;
        /// The `llvm.x86.avx.maskload.pd` intrinsic; known as `__builtin_ia32_maskloadpd` in GCC.
        #[link_name = "llvm.x86.avx.maskload.pd"]
        pub fn avx_maskload_pd(a: *mut i8, b: ::simdty::i64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.avx.maskload.ps` intrinsic; known as `__builtin_ia32_maskloadps` in GCC.
        #[link_name = "llvm.x86.avx.maskload.ps"]
        pub fn avx_maskload_ps(a: *mut i8, b: ::simdty::i32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.avx.maskload.pd.256` intrinsic; known as `__builtin_ia32_maskloadpd256` in GCC.
        #[link_name = "llvm.x86.avx.maskload.pd.256"]
        pub fn avx_maskload_pd_256(a: *mut i8, b: ::simdty::i64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx.maskload.ps.256` intrinsic; known as `__builtin_ia32_maskloadps256` in GCC.
        #[link_name = "llvm.x86.avx.maskload.ps.256"]
        pub fn avx_maskload_ps_256(a: *mut i8, b: ::simdty::i32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.move.ss` intrinsic; known as `__builtin_ia32_movss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.move.ss"]
        pub fn avx512_mask_move_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.move.sd` intrinsic; known as `__builtin_ia32_movsd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.move.sd"]
        pub fn avx512_mask_move_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx.maskstore.pd` intrinsic; known as `__builtin_ia32_maskstorepd` in GCC.
        #[link_name = "llvm.x86.avx.maskstore.pd"]
        pub fn avx_maskstore_pd(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::f64x2) -> ();
        /// The `llvm.x86.avx.maskstore.ps` intrinsic; known as `__builtin_ia32_maskstoreps` in GCC.
        #[link_name = "llvm.x86.avx.maskstore.ps"]
        pub fn avx_maskstore_ps(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::f32x4) -> ();
        /// The `llvm.x86.avx.maskstore.pd.256` intrinsic; known as `__builtin_ia32_maskstorepd256` in GCC.
        #[link_name = "llvm.x86.avx.maskstore.pd.256"]
        pub fn avx_maskstore_pd_256(a: *mut i8, b: ::simdty::i64x4, c: ::simdty::f64x4) -> ();
        /// The `llvm.x86.avx.maskstore.ps.256` intrinsic; known as `__builtin_ia32_maskstoreps256` in GCC.
        #[link_name = "llvm.x86.avx.maskstore.ps.256"]
        pub fn avx_maskstore_ps_256(a: *mut i8, b: ::simdty::i32x8, c: ::simdty::f32x8) -> ();
        /// The `llvm.x86.avx512.mask.store.ss` intrinsic; known as `__builtin_ia32_storess_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.store.ss"]
        pub fn avx512_mask_store_ss(a: *mut i8, b: ::simdty::f32x4, c: i8) -> ();
        /// The `llvm.x86.avx2.padds.b` intrinsic; known as `__builtin_ia32_paddsb256` in GCC.
        #[link_name = "llvm.x86.avx2.padds.b"]
        pub fn avx2_padds_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.padds.w` intrinsic; known as `__builtin_ia32_paddsw256` in GCC.
        #[link_name = "llvm.x86.avx2.padds.w"]
        pub fn avx2_padds_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.paddus.b` intrinsic; known as `__builtin_ia32_paddusb256` in GCC.
        #[link_name = "llvm.x86.avx2.paddus.b"]
        pub fn avx2_paddus_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.paddus.w` intrinsic; known as `__builtin_ia32_paddusw256` in GCC.
        #[link_name = "llvm.x86.avx2.paddus.w"]
        pub fn avx2_paddus_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psubs.b` intrinsic; known as `__builtin_ia32_psubsb256` in GCC.
        #[link_name = "llvm.x86.avx2.psubs.b"]
        pub fn avx2_psubs_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.psubs.w` intrinsic; known as `__builtin_ia32_psubsw256` in GCC.
        #[link_name = "llvm.x86.avx2.psubs.w"]
        pub fn avx2_psubs_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psubus.b` intrinsic; known as `__builtin_ia32_psubusb256` in GCC.
        #[link_name = "llvm.x86.avx2.psubus.b"]
        pub fn avx2_psubus_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.psubus.w` intrinsic; known as `__builtin_ia32_psubusw256` in GCC.
        #[link_name = "llvm.x86.avx2.psubus.w"]
        pub fn avx2_psubus_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pmulhu.w` intrinsic; known as `__builtin_ia32_pmulhuw256` in GCC.
        #[link_name = "llvm.x86.avx2.pmulhu.w"]
        pub fn avx2_pmulhu_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pmulh.w` intrinsic; known as `__builtin_ia32_pmulhw256` in GCC.
        #[link_name = "llvm.x86.avx2.pmulh.w"]
        pub fn avx2_pmulh_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pmulu.dq` intrinsic; known as `__builtin_ia32_pmuludq256` in GCC.
        #[link_name = "llvm.x86.avx2.pmulu.dq"]
        pub fn avx2_pmulu_dq(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.pmul.dq` intrinsic; known as `__builtin_ia32_pmuldq256` in GCC.
        #[link_name = "llvm.x86.avx2.pmul.dq"]
        pub fn avx2_pmul_dq(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.pmadd.wd` intrinsic; known as `__builtin_ia32_pmaddwd256` in GCC.
        #[link_name = "llvm.x86.avx2.pmadd.wd"]
        pub fn avx2_pmadd_wd(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.pavg.b` intrinsic; known as `__builtin_ia32_pavgb256` in GCC.
        #[link_name = "llvm.x86.avx2.pavg.b"]
        pub fn avx2_pavg_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.pavg.w` intrinsic; known as `__builtin_ia32_pavgw256` in GCC.
        #[link_name = "llvm.x86.avx2.pavg.w"]
        pub fn avx2_pavg_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psad.bw` intrinsic; known as `__builtin_ia32_psadbw256` in GCC.
        #[link_name = "llvm.x86.avx2.psad.bw"]
        pub fn avx2_psad_bw(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmaxs.b.128` intrinsic; known as `__builtin_ia32_pmaxsb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.b.128"]
        pub fn avx512_mask_pmaxs_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmaxs.b.256` intrinsic; known as `__builtin_ia32_pmaxsb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.b.256"]
        pub fn avx512_mask_pmaxs_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmaxs.b.512` intrinsic; known as `__builtin_ia32_pmaxsb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.b.512"]
        pub fn avx512_mask_pmaxs_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pmaxu.b.128` intrinsic; known as `__builtin_ia32_pmaxub128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.b.128"]
        pub fn avx512_mask_pmaxu_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmaxu.b.256` intrinsic; known as `__builtin_ia32_pmaxub256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.b.256"]
        pub fn avx512_mask_pmaxu_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmaxu.b.512` intrinsic; known as `__builtin_ia32_pmaxub512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.b.512"]
        pub fn avx512_mask_pmaxu_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pmaxs.w.128` intrinsic; known as `__builtin_ia32_pmaxsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.w.128"]
        pub fn avx512_mask_pmaxs_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmaxs.w.256` intrinsic; known as `__builtin_ia32_pmaxsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.w.256"]
        pub fn avx512_mask_pmaxs_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmaxs.w.512` intrinsic; known as `__builtin_ia32_pmaxsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.w.512"]
        pub fn avx512_mask_pmaxs_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmaxu.w.128` intrinsic; known as `__builtin_ia32_pmaxuw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.w.128"]
        pub fn avx512_mask_pmaxu_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmaxu.w.256` intrinsic; known as `__builtin_ia32_pmaxuw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.w.256"]
        pub fn avx512_mask_pmaxu_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmaxu.w.512` intrinsic; known as `__builtin_ia32_pmaxuw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.w.512"]
        pub fn avx512_mask_pmaxu_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmins.b.128` intrinsic; known as `__builtin_ia32_pminsb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.b.128"]
        pub fn avx512_mask_pmins_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmins.b.256` intrinsic; known as `__builtin_ia32_pminsb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.b.256"]
        pub fn avx512_mask_pmins_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmins.b.512` intrinsic; known as `__builtin_ia32_pminsb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.b.512"]
        pub fn avx512_mask_pmins_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pminu.b.128` intrinsic; known as `__builtin_ia32_pminub128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.b.128"]
        pub fn avx512_mask_pminu_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pminu.b.256` intrinsic; known as `__builtin_ia32_pminub256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.b.256"]
        pub fn avx512_mask_pminu_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pminu.b.512` intrinsic; known as `__builtin_ia32_pminub512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.b.512"]
        pub fn avx512_mask_pminu_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pmins.w.128` intrinsic; known as `__builtin_ia32_pminsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.w.128"]
        pub fn avx512_mask_pmins_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmins.w.256` intrinsic; known as `__builtin_ia32_pminsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.w.256"]
        pub fn avx512_mask_pmins_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmins.w.512` intrinsic; known as `__builtin_ia32_pminsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.w.512"]
        pub fn avx512_mask_pmins_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pminu.w.128` intrinsic; known as `__builtin_ia32_pminuw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.w.128"]
        pub fn avx512_mask_pminu_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pminu.w.256` intrinsic; known as `__builtin_ia32_pminuw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.w.256"]
        pub fn avx512_mask_pminu_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pminu.w.512` intrinsic; known as `__builtin_ia32_pminuw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.w.512"]
        pub fn avx512_mask_pminu_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmaxu.d.512` intrinsic; known as `__builtin_ia32_pmaxud512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.d.512"]
        pub fn avx512_mask_pmaxu_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmaxu.d.256` intrinsic; known as `__builtin_ia32_pmaxud256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.d.256"]
        pub fn avx512_mask_pmaxu_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmaxu.d.128` intrinsic; known as `__builtin_ia32_pmaxud128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.d.128"]
        pub fn avx512_mask_pmaxu_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmaxs.d.512` intrinsic; known as `__builtin_ia32_pmaxsd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.d.512"]
        pub fn avx512_mask_pmaxs_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmaxs.d.256` intrinsic; known as `__builtin_ia32_pmaxsd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.d.256"]
        pub fn avx512_mask_pmaxs_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmaxs.d.128` intrinsic; known as `__builtin_ia32_pmaxsd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.d.128"]
        pub fn avx512_mask_pmaxs_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmaxu.q.512` intrinsic; known as `__builtin_ia32_pmaxuq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.q.512"]
        pub fn avx512_mask_pmaxu_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmaxu.q.256` intrinsic; known as `__builtin_ia32_pmaxuq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.q.256"]
        pub fn avx512_mask_pmaxu_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmaxu.q.128` intrinsic; known as `__builtin_ia32_pmaxuq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxu.q.128"]
        pub fn avx512_mask_pmaxu_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmaxs.q.512` intrinsic; known as `__builtin_ia32_pmaxsq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.q.512"]
        pub fn avx512_mask_pmaxs_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmaxs.q.256` intrinsic; known as `__builtin_ia32_pmaxsq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.q.256"]
        pub fn avx512_mask_pmaxs_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmaxs.q.128` intrinsic; known as `__builtin_ia32_pmaxsq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaxs.q.128"]
        pub fn avx512_mask_pmaxs_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pminu.d.512` intrinsic; known as `__builtin_ia32_pminud512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.d.512"]
        pub fn avx512_mask_pminu_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pminu.d.256` intrinsic; known as `__builtin_ia32_pminud256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.d.256"]
        pub fn avx512_mask_pminu_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pminu.d.128` intrinsic; known as `__builtin_ia32_pminud128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.d.128"]
        pub fn avx512_mask_pminu_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmins.d.512` intrinsic; known as `__builtin_ia32_pminsd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.d.512"]
        pub fn avx512_mask_pmins_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmins.d.256` intrinsic; known as `__builtin_ia32_pminsd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.d.256"]
        pub fn avx512_mask_pmins_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmins.d.128` intrinsic; known as `__builtin_ia32_pminsd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.d.128"]
        pub fn avx512_mask_pmins_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pminu.q.512` intrinsic; known as `__builtin_ia32_pminuq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.q.512"]
        pub fn avx512_mask_pminu_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pminu.q.256` intrinsic; known as `__builtin_ia32_pminuq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.q.256"]
        pub fn avx512_mask_pminu_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pminu.q.128` intrinsic; known as `__builtin_ia32_pminuq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pminu.q.128"]
        pub fn avx512_mask_pminu_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmins.q.512` intrinsic; known as `__builtin_ia32_pminsq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.q.512"]
        pub fn avx512_mask_pmins_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmins.q.256` intrinsic; known as `__builtin_ia32_pminsq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.q.256"]
        pub fn avx512_mask_pmins_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmins.q.128` intrinsic; known as `__builtin_ia32_pminsq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmins.q.128"]
        pub fn avx512_mask_pmins_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.psll.w` intrinsic; known as `__builtin_ia32_psllw256` in GCC.
        #[link_name = "llvm.x86.avx2.psll.w"]
        pub fn avx2_psll_w(a: ::simdty::i16x16, b: ::simdty::i16x8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psll.d` intrinsic; known as `__builtin_ia32_pslld256` in GCC.
        #[link_name = "llvm.x86.avx2.psll.d"]
        pub fn avx2_psll_d(a: ::simdty::i32x8, b: ::simdty::i32x4) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.psll.q` intrinsic; known as `__builtin_ia32_psllq256` in GCC.
        #[link_name = "llvm.x86.avx2.psll.q"]
        pub fn avx2_psll_q(a: ::simdty::i64x4, b: ::simdty::i64x2) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psrl.w` intrinsic; known as `__builtin_ia32_psrlw256` in GCC.
        #[link_name = "llvm.x86.avx2.psrl.w"]
        pub fn avx2_psrl_w(a: ::simdty::i16x16, b: ::simdty::i16x8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psrl.d` intrinsic; known as `__builtin_ia32_psrld256` in GCC.
        #[link_name = "llvm.x86.avx2.psrl.d"]
        pub fn avx2_psrl_d(a: ::simdty::i32x8, b: ::simdty::i32x4) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.psrl.q` intrinsic; known as `__builtin_ia32_psrlq256` in GCC.
        #[link_name = "llvm.x86.avx2.psrl.q"]
        pub fn avx2_psrl_q(a: ::simdty::i64x4, b: ::simdty::i64x2) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psra.w` intrinsic; known as `__builtin_ia32_psraw256` in GCC.
        #[link_name = "llvm.x86.avx2.psra.w"]
        pub fn avx2_psra_w(a: ::simdty::i16x16, b: ::simdty::i16x8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psra.d` intrinsic; known as `__builtin_ia32_psrad256` in GCC.
        #[link_name = "llvm.x86.avx2.psra.d"]
        pub fn avx2_psra_d(a: ::simdty::i32x8, b: ::simdty::i32x4) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.pslli.w` intrinsic; known as `__builtin_ia32_psllwi256` in GCC.
        #[link_name = "llvm.x86.avx2.pslli.w"]
        pub fn avx2_pslli_w(a: ::simdty::i16x16, b: i32) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pslli.d` intrinsic; known as `__builtin_ia32_pslldi256` in GCC.
        #[link_name = "llvm.x86.avx2.pslli.d"]
        pub fn avx2_pslli_d(a: ::simdty::i32x8, b: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.pslli.q` intrinsic; known as `__builtin_ia32_psllqi256` in GCC.
        #[link_name = "llvm.x86.avx2.pslli.q"]
        pub fn avx2_pslli_q(a: ::simdty::i64x4, b: i32) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psrli.w` intrinsic; known as `__builtin_ia32_psrlwi256` in GCC.
        #[link_name = "llvm.x86.avx2.psrli.w"]
        pub fn avx2_psrli_w(a: ::simdty::i16x16, b: i32) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psrli.d` intrinsic; known as `__builtin_ia32_psrldi256` in GCC.
        #[link_name = "llvm.x86.avx2.psrli.d"]
        pub fn avx2_psrli_d(a: ::simdty::i32x8, b: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.psrli.q` intrinsic; known as `__builtin_ia32_psrlqi256` in GCC.
        #[link_name = "llvm.x86.avx2.psrli.q"]
        pub fn avx2_psrli_q(a: ::simdty::i64x4, b: i32) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psrai.w` intrinsic; known as `__builtin_ia32_psrawi256` in GCC.
        #[link_name = "llvm.x86.avx2.psrai.w"]
        pub fn avx2_psrai_w(a: ::simdty::i16x16, b: i32) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psrai.d` intrinsic; known as `__builtin_ia32_psradi256` in GCC.
        #[link_name = "llvm.x86.avx2.psrai.d"]
        pub fn avx2_psrai_d(a: ::simdty::i32x8, b: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psrl.w.128` intrinsic; known as `__builtin_ia32_psrlw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.w.128"]
        pub fn avx512_mask_psrl_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psrl.w.256` intrinsic; known as `__builtin_ia32_psrlw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.w.256"]
        pub fn avx512_mask_psrl_w_256(a: ::simdty::i16x16, b: ::simdty::i16x8, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psrl.w.512` intrinsic; known as `__builtin_ia32_psrlw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.w.512"]
        pub fn avx512_mask_psrl_w_512(a: ::simdty::i16x32, b: ::simdty::i16x8, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psrl.wi.128` intrinsic; known as `__builtin_ia32_psrlwi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.wi.128"]
        pub fn avx512_mask_psrl_wi_128(a: ::simdty::i16x8, b: i32, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psrl.wi.256` intrinsic; known as `__builtin_ia32_psrlwi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.wi.256"]
        pub fn avx512_mask_psrl_wi_256(a: ::simdty::i16x16, b: i32, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psrl.wi.512` intrinsic; known as `__builtin_ia32_psrlwi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.wi.512"]
        pub fn avx512_mask_psrl_wi_512(a: ::simdty::i16x32, b: i32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psra.w.128` intrinsic; known as `__builtin_ia32_psraw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.w.128"]
        pub fn avx512_mask_psra_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psra.w.256` intrinsic; known as `__builtin_ia32_psraw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.w.256"]
        pub fn avx512_mask_psra_w_256(a: ::simdty::i16x16, b: ::simdty::i16x8, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psra.w.512` intrinsic; known as `__builtin_ia32_psraw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.w.512"]
        pub fn avx512_mask_psra_w_512(a: ::simdty::i16x32, b: ::simdty::i16x8, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psra.wi.128` intrinsic; known as `__builtin_ia32_psrawi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.wi.128"]
        pub fn avx512_mask_psra_wi_128(a: ::simdty::i16x8, b: i32, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psra.wi.256` intrinsic; known as `__builtin_ia32_psrawi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.wi.256"]
        pub fn avx512_mask_psra_wi_256(a: ::simdty::i16x16, b: i32, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psra.wi.512` intrinsic; known as `__builtin_ia32_psrawi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.wi.512"]
        pub fn avx512_mask_psra_wi_512(a: ::simdty::i16x32, b: i32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psll.d` intrinsic; known as `__builtin_ia32_pslld512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.d"]
        pub fn avx512_mask_psll_d(a: ::simdty::i32x16, b: ::simdty::i32x4, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psll.q` intrinsic; known as `__builtin_ia32_psllq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.q"]
        pub fn avx512_mask_psll_q(a: ::simdty::i64x8, b: ::simdty::i64x2, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psrl.d` intrinsic; known as `__builtin_ia32_psrld512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.d"]
        pub fn avx512_mask_psrl_d(a: ::simdty::i32x16, b: ::simdty::i32x4, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psrl.q` intrinsic; known as `__builtin_ia32_psrlq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.q"]
        pub fn avx512_mask_psrl_q(a: ::simdty::i64x8, b: ::simdty::i64x2, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psra.d` intrinsic; known as `__builtin_ia32_psrad512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.d"]
        pub fn avx512_mask_psra_d(a: ::simdty::i32x16, b: ::simdty::i32x4, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psra.q` intrinsic; known as `__builtin_ia32_psraq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.q"]
        pub fn avx512_mask_psra_q(a: ::simdty::i64x8, b: ::simdty::i64x2, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psll.w.128` intrinsic; known as `__builtin_ia32_psllw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.w.128"]
        pub fn avx512_mask_psll_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psll.w.256` intrinsic; known as `__builtin_ia32_psllw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.w.256"]
        pub fn avx512_mask_psll_w_256(a: ::simdty::i16x16, b: ::simdty::i16x8, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psll.w.512` intrinsic; known as `__builtin_ia32_psllw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.w.512"]
        pub fn avx512_mask_psll_w_512(a: ::simdty::i16x32, b: ::simdty::i16x8, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psll.wi.128` intrinsic; known as `__builtin_ia32_psllwi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.wi.128"]
        pub fn avx512_mask_psll_wi_128(a: ::simdty::i16x8, b: i32, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psll.wi.256` intrinsic; known as `__builtin_ia32_psllwi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.wi.256"]
        pub fn avx512_mask_psll_wi_256(a: ::simdty::i16x16, b: i32, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psll.wi.512` intrinsic; known as `__builtin_ia32_psllwi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.wi.512"]
        pub fn avx512_mask_psll_wi_512(a: ::simdty::i16x32, b: i32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psllv16.hi` intrinsic; known as `__builtin_ia32_psllv16hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv16.hi"]
        pub fn avx512_mask_psllv16_hi(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psllv2.di` intrinsic; known as `__builtin_ia32_psllv2di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv2.di"]
        pub fn avx512_mask_psllv2_di(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psllv32hi` intrinsic; known as `__builtin_ia32_psllv32hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv32hi"]
        pub fn avx512_mask_psllv32hi(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psllv4.di` intrinsic; known as `__builtin_ia32_psllv4di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv4.di"]
        pub fn avx512_mask_psllv4_di(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psllv4.si` intrinsic; known as `__builtin_ia32_psllv4si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv4.si"]
        pub fn avx512_mask_psllv4_si(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psllv8.hi` intrinsic; known as `__builtin_ia32_psllv8hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv8.hi"]
        pub fn avx512_mask_psllv8_hi(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psllv8.si` intrinsic; known as `__builtin_ia32_psllv8si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv8.si"]
        pub fn avx512_mask_psllv8_si(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psra.d.128` intrinsic; known as `__builtin_ia32_psrad128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.d.128"]
        pub fn avx512_mask_psra_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psra.d.256` intrinsic; known as `__builtin_ia32_psrad256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.d.256"]
        pub fn avx512_mask_psra_d_256(a: ::simdty::i32x8, b: ::simdty::i32x4, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psra.di.128` intrinsic; known as `__builtin_ia32_psradi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.di.128"]
        pub fn avx512_mask_psra_di_128(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psra.di.256` intrinsic; known as `__builtin_ia32_psradi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.di.256"]
        pub fn avx512_mask_psra_di_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psra.di.512` intrinsic; known as `__builtin_ia32_psradi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.di.512"]
        pub fn avx512_mask_psra_di_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psra.q.128` intrinsic; known as `__builtin_ia32_psraq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.q.128"]
        pub fn avx512_mask_psra_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psra.q.256` intrinsic; known as `__builtin_ia32_psraq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.q.256"]
        pub fn avx512_mask_psra_q_256(a: ::simdty::i64x4, b: ::simdty::i64x2, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psra.qi.128` intrinsic; known as `__builtin_ia32_psraqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.qi.128"]
        pub fn avx512_mask_psra_qi_128(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psra.qi.256` intrinsic; known as `__builtin_ia32_psraqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.qi.256"]
        pub fn avx512_mask_psra_qi_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psra.qi.512` intrinsic; known as `__builtin_ia32_psraqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psra.qi.512"]
        pub fn avx512_mask_psra_qi_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psrl.d.128` intrinsic; known as `__builtin_ia32_psrld128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.d.128"]
        pub fn avx512_mask_psrl_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psrl.d.256` intrinsic; known as `__builtin_ia32_psrld256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.d.256"]
        pub fn avx512_mask_psrl_d_256(a: ::simdty::i32x8, b: ::simdty::i32x4, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psrl.di.128` intrinsic; known as `__builtin_ia32_psrldi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.di.128"]
        pub fn avx512_mask_psrl_di_128(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psrl.di.256` intrinsic; known as `__builtin_ia32_psrldi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.di.256"]
        pub fn avx512_mask_psrl_di_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psrl.di.512` intrinsic; known as `__builtin_ia32_psrldi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.di.512"]
        pub fn avx512_mask_psrl_di_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psrl.q.128` intrinsic; known as `__builtin_ia32_psrlq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.q.128"]
        pub fn avx512_mask_psrl_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psrl.q.256` intrinsic; known as `__builtin_ia32_psrlq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.q.256"]
        pub fn avx512_mask_psrl_q_256(a: ::simdty::i64x4, b: ::simdty::i64x2, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psrl.qi.128` intrinsic; known as `__builtin_ia32_psrlqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.qi.128"]
        pub fn avx512_mask_psrl_qi_128(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psrl.qi.256` intrinsic; known as `__builtin_ia32_psrlqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.qi.256"]
        pub fn avx512_mask_psrl_qi_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psrl.qi.512` intrinsic; known as `__builtin_ia32_psrlqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrl.qi.512"]
        pub fn avx512_mask_psrl_qi_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmultishift.qb.128` intrinsic; known as `__builtin_ia32_vpmultishiftqb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmultishift.qb.128"]
        pub fn avx512_mask_pmultishift_qb_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmultishift.qb.256` intrinsic; known as `__builtin_ia32_vpmultishiftqb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmultishift.qb.256"]
        pub fn avx512_mask_pmultishift_qb_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmultishift.qb.512` intrinsic; known as `__builtin_ia32_vpmultishiftqb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmultishift.qb.512"]
        pub fn avx512_mask_pmultishift_qb_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx2.packsswb` intrinsic; known as `__builtin_ia32_packsswb256` in GCC.
        #[link_name = "llvm.x86.avx2.packsswb"]
        pub fn avx2_packsswb(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.packssdw` intrinsic; known as `__builtin_ia32_packssdw256` in GCC.
        #[link_name = "llvm.x86.avx2.packssdw"]
        pub fn avx2_packssdw(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.packuswb` intrinsic; known as `__builtin_ia32_packuswb256` in GCC.
        #[link_name = "llvm.x86.avx2.packuswb"]
        pub fn avx2_packuswb(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.packusdw` intrinsic; known as `__builtin_ia32_packusdw256` in GCC.
        #[link_name = "llvm.x86.avx2.packusdw"]
        pub fn avx2_packusdw(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pabs.b` intrinsic; known as `__builtin_ia32_pabsb256` in GCC.
        #[link_name = "llvm.x86.avx2.pabs.b"]
        pub fn avx2_pabs_b(a: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.pabs.w` intrinsic; known as `__builtin_ia32_pabsw256` in GCC.
        #[link_name = "llvm.x86.avx2.pabs.w"]
        pub fn avx2_pabs_w(a: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pabs.d` intrinsic; known as `__builtin_ia32_pabsd256` in GCC.
        #[link_name = "llvm.x86.avx2.pabs.d"]
        pub fn avx2_pabs_d(a: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pabs.b.128` intrinsic; known as `__builtin_ia32_pabsb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.b.128"]
        pub fn avx512_mask_pabs_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pabs.b.256` intrinsic; known as `__builtin_ia32_pabsb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.b.256"]
        pub fn avx512_mask_pabs_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pabs.b.512` intrinsic; known as `__builtin_ia32_pabsb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.b.512"]
        pub fn avx512_mask_pabs_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pabs.d.128` intrinsic; known as `__builtin_ia32_pabsd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.d.128"]
        pub fn avx512_mask_pabs_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pabs.d.256` intrinsic; known as `__builtin_ia32_pabsd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.d.256"]
        pub fn avx512_mask_pabs_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pabs.d.512` intrinsic; known as `__builtin_ia32_pabsd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.d.512"]
        pub fn avx512_mask_pabs_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pabs.q.128` intrinsic; known as `__builtin_ia32_pabsq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.q.128"]
        pub fn avx512_mask_pabs_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pabs.q.256` intrinsic; known as `__builtin_ia32_pabsq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.q.256"]
        pub fn avx512_mask_pabs_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pabs.q.512` intrinsic; known as `__builtin_ia32_pabsq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.q.512"]
        pub fn avx512_mask_pabs_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pabs.w.128` intrinsic; known as `__builtin_ia32_pabsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.w.128"]
        pub fn avx512_mask_pabs_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pabs.w.256` intrinsic; known as `__builtin_ia32_pabsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.w.256"]
        pub fn avx512_mask_pabs_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pabs.w.512` intrinsic; known as `__builtin_ia32_pabsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pabs.w.512"]
        pub fn avx512_mask_pabs_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx2.phadd.w` intrinsic; known as `__builtin_ia32_phaddw256` in GCC.
        #[link_name = "llvm.x86.avx2.phadd.w"]
        pub fn avx2_phadd_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.phadd.d` intrinsic; known as `__builtin_ia32_phaddd256` in GCC.
        #[link_name = "llvm.x86.avx2.phadd.d"]
        pub fn avx2_phadd_d(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.phadd.sw` intrinsic; known as `__builtin_ia32_phaddsw256` in GCC.
        #[link_name = "llvm.x86.avx2.phadd.sw"]
        pub fn avx2_phadd_sw(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.phsub.w` intrinsic; known as `__builtin_ia32_phsubw256` in GCC.
        #[link_name = "llvm.x86.avx2.phsub.w"]
        pub fn avx2_phsub_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.phsub.d` intrinsic; known as `__builtin_ia32_phsubd256` in GCC.
        #[link_name = "llvm.x86.avx2.phsub.d"]
        pub fn avx2_phsub_d(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.phsub.sw` intrinsic; known as `__builtin_ia32_phsubsw256` in GCC.
        #[link_name = "llvm.x86.avx2.phsub.sw"]
        pub fn avx2_phsub_sw(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.pmadd.ub.sw` intrinsic; known as `__builtin_ia32_pmaddubsw256` in GCC.
        #[link_name = "llvm.x86.avx2.pmadd.ub.sw"]
        pub fn avx2_pmadd_ub_sw(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psign.b` intrinsic; known as `__builtin_ia32_psignb256` in GCC.
        #[link_name = "llvm.x86.avx2.psign.b"]
        pub fn avx2_psign_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.psign.w` intrinsic; known as `__builtin_ia32_psignw256` in GCC.
        #[link_name = "llvm.x86.avx2.psign.w"]
        pub fn avx2_psign_w(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.psign.d` intrinsic; known as `__builtin_ia32_psignd256` in GCC.
        #[link_name = "llvm.x86.avx2.psign.d"]
        pub fn avx2_psign_d(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.pmul.hr.sw` intrinsic; known as `__builtin_ia32_pmulhrsw256` in GCC.
        #[link_name = "llvm.x86.avx2.pmul.hr.sw"]
        pub fn avx2_pmul_hr_sw(a: ::simdty::i16x16, b: ::simdty::i16x16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmul.hr.sw.128` intrinsic; known as `__builtin_ia32_pmulhrsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.hr.sw.128"]
        pub fn avx512_mask_pmul_hr_sw_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmul.hr.sw.256` intrinsic; known as `__builtin_ia32_pmulhrsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.hr.sw.256"]
        pub fn avx512_mask_pmul_hr_sw_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmul.hr.sw.512` intrinsic; known as `__builtin_ia32_pmulhrsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.hr.sw.512"]
        pub fn avx512_mask_pmul_hr_sw_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx2.pblendvb` intrinsic; known as `__builtin_ia32_pblendvb256` in GCC.
        #[link_name = "llvm.x86.avx2.pblendvb"]
        pub fn avx2_pblendvb(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pbroadcast.b.gpr.128` intrinsic; known as `__builtin_ia32_pbroadcastb128_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.b.gpr.128"]
        pub fn avx512_mask_pbroadcast_b_gpr_128(a: i8, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pbroadcast.b.gpr.256` intrinsic; known as `__builtin_ia32_pbroadcastb256_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.b.gpr.256"]
        pub fn avx512_mask_pbroadcast_b_gpr_256(a: i8, b: ::simdty::i8x32, c: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pbroadcast.b.gpr.512` intrinsic; known as `__builtin_ia32_pbroadcastb512_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.b.gpr.512"]
        pub fn avx512_mask_pbroadcast_b_gpr_512(a: i8, b: ::simdty::i8x64, c: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pbroadcast.w.gpr.128` intrinsic; known as `__builtin_ia32_pbroadcastw128_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.w.gpr.128"]
        pub fn avx512_mask_pbroadcast_w_gpr_128(a: i16, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pbroadcast.w.gpr.256` intrinsic; known as `__builtin_ia32_pbroadcastw256_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.w.gpr.256"]
        pub fn avx512_mask_pbroadcast_w_gpr_256(a: i16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pbroadcast.w.gpr.512` intrinsic; known as `__builtin_ia32_pbroadcastw512_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.w.gpr.512"]
        pub fn avx512_mask_pbroadcast_w_gpr_512(a: i16, b: ::simdty::i16x32, c: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pbroadcast.d.gpr.128` intrinsic; known as `__builtin_ia32_pbroadcastd128_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.d.gpr.128"]
        pub fn avx512_mask_pbroadcast_d_gpr_128(a: i32, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pbroadcast.d.gpr.256` intrinsic; known as `__builtin_ia32_pbroadcastd256_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.d.gpr.256"]
        pub fn avx512_mask_pbroadcast_d_gpr_256(a: i32, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pbroadcast.d.gpr.512` intrinsic; known as `__builtin_ia32_pbroadcastd512_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.d.gpr.512"]
        pub fn avx512_mask_pbroadcast_d_gpr_512(a: i32, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pbroadcast.q.gpr.128` intrinsic; known as `__builtin_ia32_pbroadcastq128_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.q.gpr.128"]
        pub fn avx512_mask_pbroadcast_q_gpr_128(a: i64, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pbroadcast.q.gpr.256` intrinsic; known as `__builtin_ia32_pbroadcastq256_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.q.gpr.256"]
        pub fn avx512_mask_pbroadcast_q_gpr_256(a: i64, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pbroadcast.q.gpr.512` intrinsic; known as `__builtin_ia32_pbroadcastq512_gpr_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.q.gpr.512"]
        pub fn avx512_mask_pbroadcast_q_gpr_512(a: i64, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pbroadcast.q.mem.512` intrinsic; known as `__builtin_ia32_pbroadcastq512_mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pbroadcast.q.mem.512"]
        pub fn avx512_mask_pbroadcast_q_mem_512(a: i64, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx2.permd` intrinsic; known as `__builtin_ia32_permvarsi256` in GCC.
        #[link_name = "llvm.x86.avx2.permd"]
        pub fn avx2_permd(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.permps` intrinsic; known as `__builtin_ia32_permvarsf256` in GCC.
        #[link_name = "llvm.x86.avx2.permps"]
        pub fn avx2_permps(a: ::simdty::f32x8, b: ::simdty::i32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx2.vperm2i128` intrinsic; known as `__builtin_ia32_permti256` in GCC.
        #[link_name = "llvm.x86.avx2.vperm2i128"]
        pub fn avx2_vperm2i128(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.vextractf32x4.512` intrinsic; known as `__builtin_ia32_extractf32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf32x4.512"]
        pub fn avx512_mask_vextractf32x4_512(a: ::simdty::f32x16, b: i32, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vextracti32x4.512` intrinsic; known as `__builtin_ia32_extracti32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti32x4.512"]
        pub fn avx512_mask_vextracti32x4_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.vextractf32x4.256` intrinsic; known as `__builtin_ia32_extractf32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf32x4.256"]
        pub fn avx512_mask_vextractf32x4_256(a: ::simdty::f32x8, b: i32, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vextracti32x4.256` intrinsic; known as `__builtin_ia32_extracti32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti32x4.256"]
        pub fn avx512_mask_vextracti32x4_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.vextractf64x2.256` intrinsic; known as `__builtin_ia32_extractf64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf64x2.256"]
        pub fn avx512_mask_vextractf64x2_256(a: ::simdty::f64x4, b: i32, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vextracti64x2.256` intrinsic; known as `__builtin_ia32_extracti64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti64x2.256"]
        pub fn avx512_mask_vextracti64x2_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vextractf64x2.512` intrinsic; known as `__builtin_ia32_extractf64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf64x2.512"]
        pub fn avx512_mask_vextractf64x2_512(a: ::simdty::f64x8, b: i32, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vextracti64x2.512` intrinsic; known as `__builtin_ia32_extracti64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti64x2.512"]
        pub fn avx512_mask_vextracti64x2_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vextractf32x8.512` intrinsic; known as `__builtin_ia32_extractf32x8_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf32x8.512"]
        pub fn avx512_mask_vextractf32x8_512(a: ::simdty::f32x16, b: i32, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vextracti32x8.512` intrinsic; known as `__builtin_ia32_extracti32x8_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti32x8.512"]
        pub fn avx512_mask_vextracti32x8_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.vextractf64x4.512` intrinsic; known as `__builtin_ia32_extractf64x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextractf64x4.512"]
        pub fn avx512_mask_vextractf64x4_512(a: ::simdty::f64x8, b: i32, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vextracti64x4.512` intrinsic; known as `__builtin_ia32_extracti64x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vextracti64x4.512"]
        pub fn avx512_mask_vextracti64x4_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.insertf32x4.256` intrinsic; known as `__builtin_ia32_insertf32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf32x4.256"]
        pub fn avx512_mask_insertf32x4_256(a: ::simdty::f32x8, b: ::simdty::f32x4, c: i32, d: ::simdty::f32x8, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.insertf32x4.512` intrinsic; known as `__builtin_ia32_insertf32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf32x4.512"]
        pub fn avx512_mask_insertf32x4_512(a: ::simdty::f32x16, b: ::simdty::f32x4, c: i32, d: ::simdty::f32x16, e: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.insertf32x8.512` intrinsic; known as `__builtin_ia32_insertf32x8_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf32x8.512"]
        pub fn avx512_mask_insertf32x8_512(a: ::simdty::f32x16, b: ::simdty::f32x8, c: i32, d: ::simdty::f32x16, e: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.insertf64x2.256` intrinsic; known as `__builtin_ia32_insertf64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf64x2.256"]
        pub fn avx512_mask_insertf64x2_256(a: ::simdty::f64x4, b: ::simdty::f64x2, c: i32, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.insertf64x2.512` intrinsic; known as `__builtin_ia32_insertf64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf64x2.512"]
        pub fn avx512_mask_insertf64x2_512(a: ::simdty::f64x8, b: ::simdty::f64x2, c: i32, d: ::simdty::f64x8, e: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.insertf64x4.512` intrinsic; known as `__builtin_ia32_insertf64x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.insertf64x4.512"]
        pub fn avx512_mask_insertf64x4_512(a: ::simdty::f64x8, b: ::simdty::f64x4, c: i32, d: ::simdty::f64x8, e: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.inserti32x4.256` intrinsic; known as `__builtin_ia32_inserti32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti32x4.256"]
        pub fn avx512_mask_inserti32x4_256(a: ::simdty::i32x8, b: ::simdty::i32x4, c: i32, d: ::simdty::i32x8, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.inserti32x4.512` intrinsic; known as `__builtin_ia32_inserti32x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti32x4.512"]
        pub fn avx512_mask_inserti32x4_512(a: ::simdty::i32x16, b: ::simdty::i32x4, c: i32, d: ::simdty::i32x16, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.inserti32x8.512` intrinsic; known as `__builtin_ia32_inserti32x8_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti32x8.512"]
        pub fn avx512_mask_inserti32x8_512(a: ::simdty::i32x16, b: ::simdty::i32x8, c: i32, d: ::simdty::i32x16, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.inserti64x2.256` intrinsic; known as `__builtin_ia32_inserti64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti64x2.256"]
        pub fn avx512_mask_inserti64x2_256(a: ::simdty::i64x4, b: ::simdty::i64x2, c: i32, d: ::simdty::i64x4, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.inserti64x2.512` intrinsic; known as `__builtin_ia32_inserti64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti64x2.512"]
        pub fn avx512_mask_inserti64x2_512(a: ::simdty::i64x8, b: ::simdty::i64x2, c: i32, d: ::simdty::i64x8, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.inserti64x4.512` intrinsic; known as `__builtin_ia32_inserti64x4_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.inserti64x4.512"]
        pub fn avx512_mask_inserti64x4_512(a: ::simdty::i64x8, b: ::simdty::i64x4, c: i32, d: ::simdty::i64x8, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx2.maskload.d` intrinsic; known as `__builtin_ia32_maskloadd` in GCC.
        #[link_name = "llvm.x86.avx2.maskload.d"]
        pub fn avx2_maskload_d(a: *mut i8, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.maskload.q` intrinsic; known as `__builtin_ia32_maskloadq` in GCC.
        #[link_name = "llvm.x86.avx2.maskload.q"]
        pub fn avx2_maskload_q(a: *mut i8, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.maskload.d.256` intrinsic; known as `__builtin_ia32_maskloadd256` in GCC.
        #[link_name = "llvm.x86.avx2.maskload.d.256"]
        pub fn avx2_maskload_d_256(a: *mut i8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.maskload.q.256` intrinsic; known as `__builtin_ia32_maskloadq256` in GCC.
        #[link_name = "llvm.x86.avx2.maskload.q.256"]
        pub fn avx2_maskload_q_256(a: *mut i8, b: ::simdty::i64x4) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.maskstore.d` intrinsic; known as `__builtin_ia32_maskstored` in GCC.
        #[link_name = "llvm.x86.avx2.maskstore.d"]
        pub fn avx2_maskstore_d(a: *mut i8, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ();
        /// The `llvm.x86.avx2.maskstore.q` intrinsic; known as `__builtin_ia32_maskstoreq` in GCC.
        #[link_name = "llvm.x86.avx2.maskstore.q"]
        pub fn avx2_maskstore_q(a: *mut i8, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ();
        /// The `llvm.x86.avx2.maskstore.d.256` intrinsic; known as `__builtin_ia32_maskstored256` in GCC.
        #[link_name = "llvm.x86.avx2.maskstore.d.256"]
        pub fn avx2_maskstore_d_256(a: *mut i8, b: ::simdty::i32x8, c: ::simdty::i32x8) -> ();
        /// The `llvm.x86.avx2.maskstore.q.256` intrinsic; known as `__builtin_ia32_maskstoreq256` in GCC.
        #[link_name = "llvm.x86.avx2.maskstore.q.256"]
        pub fn avx2_maskstore_q_256(a: *mut i8, b: ::simdty::i64x4, c: ::simdty::i64x4) -> ();
        /// The `llvm.x86.avx2.psllv.d` intrinsic; known as `__builtin_ia32_psllv4si` in GCC.
        #[link_name = "llvm.x86.avx2.psllv.d"]
        pub fn avx2_psllv_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.psllv.d.256` intrinsic; known as `__builtin_ia32_psllv8si` in GCC.
        #[link_name = "llvm.x86.avx2.psllv.d.256"]
        pub fn avx2_psllv_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.psllv.q` intrinsic; known as `__builtin_ia32_psllv2di` in GCC.
        #[link_name = "llvm.x86.avx2.psllv.q"]
        pub fn avx2_psllv_q(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.psllv.q.256` intrinsic; known as `__builtin_ia32_psllv4di` in GCC.
        #[link_name = "llvm.x86.avx2.psllv.q.256"]
        pub fn avx2_psllv_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psrlv.d` intrinsic; known as `__builtin_ia32_psrlv4si` in GCC.
        #[link_name = "llvm.x86.avx2.psrlv.d"]
        pub fn avx2_psrlv_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.psrlv.d.256` intrinsic; known as `__builtin_ia32_psrlv8si` in GCC.
        #[link_name = "llvm.x86.avx2.psrlv.d.256"]
        pub fn avx2_psrlv_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.psrlv.q` intrinsic; known as `__builtin_ia32_psrlv2di` in GCC.
        #[link_name = "llvm.x86.avx2.psrlv.q"]
        pub fn avx2_psrlv_q(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.psrlv.q.256` intrinsic; known as `__builtin_ia32_psrlv4di` in GCC.
        #[link_name = "llvm.x86.avx2.psrlv.q.256"]
        pub fn avx2_psrlv_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.psrav.d` intrinsic; known as `__builtin_ia32_psrav4si` in GCC.
        #[link_name = "llvm.x86.avx2.psrav.d"]
        pub fn avx2_psrav_d(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.psrav.d.256` intrinsic; known as `__builtin_ia32_psrav8si` in GCC.
        #[link_name = "llvm.x86.avx2.psrav.d.256"]
        pub fn avx2_psrav_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psllv.d` intrinsic; known as `__builtin_ia32_psllv16si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv.d"]
        pub fn avx512_mask_psllv_d(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psllv.q` intrinsic; known as `__builtin_ia32_psllv8di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psllv.q"]
        pub fn avx512_mask_psllv_q(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psrav.d` intrinsic; known as `__builtin_ia32_psrav16si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav.d"]
        pub fn avx512_mask_psrav_d(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psrav.q` intrinsic; known as `__builtin_ia32_psrav8di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav.q"]
        pub fn avx512_mask_psrav_q(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psrlv.d` intrinsic; known as `__builtin_ia32_psrlv16si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv.d"]
        pub fn avx512_mask_psrlv_d(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psrlv.q` intrinsic; known as `__builtin_ia32_psrlv8di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv.q"]
        pub fn avx512_mask_psrlv_q(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psll.d.128` intrinsic; known as `__builtin_ia32_pslld128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.d.128"]
        pub fn avx512_mask_psll_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psll.d.256` intrinsic; known as `__builtin_ia32_pslld256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.d.256"]
        pub fn avx512_mask_psll_d_256(a: ::simdty::i32x8, b: ::simdty::i32x4, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psll.di.128` intrinsic; known as `__builtin_ia32_pslldi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.di.128"]
        pub fn avx512_mask_psll_di_128(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psll.di.256` intrinsic; known as `__builtin_ia32_pslldi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.di.256"]
        pub fn avx512_mask_psll_di_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psll.di.512` intrinsic; known as `__builtin_ia32_pslldi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.di.512"]
        pub fn avx512_mask_psll_di_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psll.q.128` intrinsic; known as `__builtin_ia32_psllq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.q.128"]
        pub fn avx512_mask_psll_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psll.q.256` intrinsic; known as `__builtin_ia32_psllq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.q.256"]
        pub fn avx512_mask_psll_q_256(a: ::simdty::i64x4, b: ::simdty::i64x2, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psll.qi.128` intrinsic; known as `__builtin_ia32_psllqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.qi.128"]
        pub fn avx512_mask_psll_qi_128(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psll.qi.256` intrinsic; known as `__builtin_ia32_psllqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.qi.256"]
        pub fn avx512_mask_psll_qi_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psll.qi.512` intrinsic; known as `__builtin_ia32_psllqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psll.qi.512"]
        pub fn avx512_mask_psll_qi_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psrav16.hi` intrinsic; known as `__builtin_ia32_psrav16hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav16.hi"]
        pub fn avx512_mask_psrav16_hi(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psrav32.hi` intrinsic; known as `__builtin_ia32_psrav32hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav32.hi"]
        pub fn avx512_mask_psrav32_hi(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psrav4.si` intrinsic; known as `__builtin_ia32_psrav4si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav4.si"]
        pub fn avx512_mask_psrav4_si(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psrav8.hi` intrinsic; known as `__builtin_ia32_psrav8hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav8.hi"]
        pub fn avx512_mask_psrav8_hi(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psrav8.si` intrinsic; known as `__builtin_ia32_psrav8si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav8.si"]
        pub fn avx512_mask_psrav8_si(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psrav.q.128` intrinsic; known as `__builtin_ia32_psravq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav.q.128"]
        pub fn avx512_mask_psrav_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psrav.q.256` intrinsic; known as `__builtin_ia32_psravq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrav.q.256"]
        pub fn avx512_mask_psrav_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psrlv16.hi` intrinsic; known as `__builtin_ia32_psrlv16hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv16.hi"]
        pub fn avx512_mask_psrlv16_hi(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psrlv2.di` intrinsic; known as `__builtin_ia32_psrlv2di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv2.di"]
        pub fn avx512_mask_psrlv2_di(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psrlv32hi` intrinsic; known as `__builtin_ia32_psrlv32hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv32hi"]
        pub fn avx512_mask_psrlv32hi(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psrlv4.di` intrinsic; known as `__builtin_ia32_psrlv4di_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv4.di"]
        pub fn avx512_mask_psrlv4_di(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psrlv4.si` intrinsic; known as `__builtin_ia32_psrlv4si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv4.si"]
        pub fn avx512_mask_psrlv4_si(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psrlv8.hi` intrinsic; known as `__builtin_ia32_psrlv8hi_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv8.hi"]
        pub fn avx512_mask_psrlv8_hi(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psrlv8.si` intrinsic; known as `__builtin_ia32_psrlv8si_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psrlv8.si"]
        pub fn avx512_mask_psrlv8_si(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.prorv.d.128` intrinsic; known as `__builtin_ia32_prorvd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.d.128"]
        pub fn avx512_mask_prorv_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.prorv.d.256` intrinsic; known as `__builtin_ia32_prorvd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.d.256"]
        pub fn avx512_mask_prorv_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.prorv.d.512` intrinsic; known as `__builtin_ia32_prorvd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.d.512"]
        pub fn avx512_mask_prorv_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.prorv.q.128` intrinsic; known as `__builtin_ia32_prorvq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.q.128"]
        pub fn avx512_mask_prorv_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.prorv.q.256` intrinsic; known as `__builtin_ia32_prorvq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.q.256"]
        pub fn avx512_mask_prorv_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.prorv.q.512` intrinsic; known as `__builtin_ia32_prorvq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prorv.q.512"]
        pub fn avx512_mask_prorv_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.prol.d.128` intrinsic; known as `__builtin_ia32_prold128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.d.128"]
        pub fn avx512_mask_prol_d_128(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.prol.d.256` intrinsic; known as `__builtin_ia32_prold256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.d.256"]
        pub fn avx512_mask_prol_d_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.prol.d.512` intrinsic; known as `__builtin_ia32_prold512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.d.512"]
        pub fn avx512_mask_prol_d_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.prol.q.128` intrinsic; known as `__builtin_ia32_prolq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.q.128"]
        pub fn avx512_mask_prol_q_128(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.prol.q.256` intrinsic; known as `__builtin_ia32_prolq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.q.256"]
        pub fn avx512_mask_prol_q_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.prol.q.512` intrinsic; known as `__builtin_ia32_prolq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prol.q.512"]
        pub fn avx512_mask_prol_q_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.prolv.d.128` intrinsic; known as `__builtin_ia32_prolvd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.d.128"]
        pub fn avx512_mask_prolv_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.prolv.d.256` intrinsic; known as `__builtin_ia32_prolvd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.d.256"]
        pub fn avx512_mask_prolv_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.prolv.d.512` intrinsic; known as `__builtin_ia32_prolvd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.d.512"]
        pub fn avx512_mask_prolv_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.prolv.q.128` intrinsic; known as `__builtin_ia32_prolvq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.q.128"]
        pub fn avx512_mask_prolv_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.prolv.q.256` intrinsic; known as `__builtin_ia32_prolvq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.q.256"]
        pub fn avx512_mask_prolv_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.prolv.q.512` intrinsic; known as `__builtin_ia32_prolvq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.prolv.q.512"]
        pub fn avx512_mask_prolv_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pror.d.128` intrinsic; known as `__builtin_ia32_prord128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.d.128"]
        pub fn avx512_mask_pror_d_128(a: ::simdty::i32x4, b: i32, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pror.d.256` intrinsic; known as `__builtin_ia32_prord256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.d.256"]
        pub fn avx512_mask_pror_d_256(a: ::simdty::i32x8, b: i32, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pror.d.512` intrinsic; known as `__builtin_ia32_prord512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.d.512"]
        pub fn avx512_mask_pror_d_512(a: ::simdty::i32x16, b: i32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pror.q.128` intrinsic; known as `__builtin_ia32_prorq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.q.128"]
        pub fn avx512_mask_pror_q_128(a: ::simdty::i64x2, b: i32, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pror.q.256` intrinsic; known as `__builtin_ia32_prorq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.q.256"]
        pub fn avx512_mask_pror_q_256(a: ::simdty::i64x4, b: i32, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pror.q.512` intrinsic; known as `__builtin_ia32_prorq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pror.q.512"]
        pub fn avx512_mask_pror_q_512(a: ::simdty::i64x8, b: i32, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx2.gather.d.pd` intrinsic; known as `__builtin_ia32_gatherd_pd` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.pd"]
        pub fn avx2_gather_d_pd(a: ::simdty::f64x2, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::f64x2, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx2.gather.d.pd.256` intrinsic; known as `__builtin_ia32_gatherd_pd256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.pd.256"]
        pub fn avx2_gather_d_pd_256(a: ::simdty::f64x4, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx2.gather.q.pd` intrinsic; known as `__builtin_ia32_gatherq_pd` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.pd"]
        pub fn avx2_gather_q_pd(a: ::simdty::f64x2, b: *mut i8, c: ::simdty::i64x2, d: ::simdty::f64x2, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx2.gather.q.pd.256` intrinsic; known as `__builtin_ia32_gatherq_pd256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.pd.256"]
        pub fn avx2_gather_q_pd_256(a: ::simdty::f64x4, b: *mut i8, c: ::simdty::i64x4, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx2.gather.d.ps` intrinsic; known as `__builtin_ia32_gatherd_ps` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.ps"]
        pub fn avx2_gather_d_ps(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::f32x4, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx2.gather.d.ps.256` intrinsic; known as `__builtin_ia32_gatherd_ps256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.ps.256"]
        pub fn avx2_gather_d_ps_256(a: ::simdty::f32x8, b: *mut i8, c: ::simdty::i32x8, d: ::simdty::f32x8, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx2.gather.q.ps` intrinsic; known as `__builtin_ia32_gatherq_ps` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.ps"]
        pub fn avx2_gather_q_ps(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i64x2, d: ::simdty::f32x4, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx2.gather.q.ps.256` intrinsic; known as `__builtin_ia32_gatherq_ps256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.ps.256"]
        pub fn avx2_gather_q_ps_256(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i64x4, d: ::simdty::f32x4, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx2.gather.d.q` intrinsic; known as `__builtin_ia32_gatherd_q` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.q"]
        pub fn avx2_gather_d_q(a: ::simdty::i64x2, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::i64x2, e: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.gather.d.q.256` intrinsic; known as `__builtin_ia32_gatherd_q256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.q.256"]
        pub fn avx2_gather_d_q_256(a: ::simdty::i64x4, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::i64x4, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.gather.q.q` intrinsic; known as `__builtin_ia32_gatherq_q` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.q"]
        pub fn avx2_gather_q_q(a: ::simdty::i64x2, b: *mut i8, c: ::simdty::i64x2, d: ::simdty::i64x2, e: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx2.gather.q.q.256` intrinsic; known as `__builtin_ia32_gatherq_q256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.q.256"]
        pub fn avx2_gather_q_q_256(a: ::simdty::i64x4, b: *mut i8, c: ::simdty::i64x4, d: ::simdty::i64x4, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx2.gather.d.d` intrinsic; known as `__builtin_ia32_gatherd_d` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.d"]
        pub fn avx2_gather_d_d(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i32x4, d: ::simdty::i32x4, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.gather.d.d.256` intrinsic; known as `__builtin_ia32_gatherd_d256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.d.d.256"]
        pub fn avx2_gather_d_d_256(a: ::simdty::i32x8, b: *mut i8, c: ::simdty::i32x8, d: ::simdty::i32x8, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx2.gather.q.d` intrinsic; known as `__builtin_ia32_gatherq_d` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.d"]
        pub fn avx2_gather_q_d(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i64x2, d: ::simdty::i32x4, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.gather.q.d.256` intrinsic; known as `__builtin_ia32_gatherq_d256` in GCC.
        #[link_name = "llvm.x86.avx2.gather.q.d.256"]
        pub fn avx2_gather_q_d_256(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i64x4, d: ::simdty::i32x4, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx2.pmovmskb` intrinsic; known as `__builtin_ia32_pmovmskb256` in GCC.
        #[link_name = "llvm.x86.avx2.pmovmskb"]
        pub fn avx2_pmovmskb(a: ::simdty::i8x32) -> i32;
        /// The `llvm.x86.avx2.pshuf.b` intrinsic; known as `__builtin_ia32_pshufb256` in GCC.
        #[link_name = "llvm.x86.avx2.pshuf.b"]
        pub fn avx2_pshuf_b(a: ::simdty::i8x32, b: ::simdty::i8x32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx2.mpsadbw` intrinsic; known as `__builtin_ia32_mpsadbw256` in GCC.
        #[link_name = "llvm.x86.avx2.mpsadbw"]
        pub fn avx2_mpsadbw(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i8) -> ::simdty::i16x16;
        /// The `llvm.x86.avx2.movntdqa` intrinsic; known as `__builtin_ia32_movntdqa256` in GCC.
        #[link_name = "llvm.x86.avx2.movntdqa"]
        pub fn avx2_movntdqa(a: *mut i8) -> ::simdty::i64x4;
        /// The `llvm.x86.fma.vfmadd.ss` intrinsic; known as `__builtin_ia32_vfmaddss` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.ss"]
        pub fn fma_vfmadd_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmadd.sd` intrinsic; known as `__builtin_ia32_vfmaddsd` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.sd"]
        pub fn fma_vfmadd_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmadd.ps` intrinsic; known as `__builtin_ia32_vfmaddps` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.ps"]
        pub fn fma_vfmadd_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmadd.pd` intrinsic; known as `__builtin_ia32_vfmaddpd` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.pd"]
        pub fn fma_vfmadd_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmadd.ps.256` intrinsic; known as `__builtin_ia32_vfmaddps256` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.ps.256"]
        pub fn fma_vfmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfmadd.pd.256` intrinsic; known as `__builtin_ia32_vfmaddpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfmadd.pd.256"]
        pub fn fma_vfmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.fma.vfmsub.ss` intrinsic; known as `__builtin_ia32_vfmsubss` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.ss"]
        pub fn fma_vfmsub_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmsub.sd` intrinsic; known as `__builtin_ia32_vfmsubsd` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.sd"]
        pub fn fma_vfmsub_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmsub.ps` intrinsic; known as `__builtin_ia32_vfmsubps` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.ps"]
        pub fn fma_vfmsub_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmsub.pd` intrinsic; known as `__builtin_ia32_vfmsubpd` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.pd"]
        pub fn fma_vfmsub_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmsub.ps.256` intrinsic; known as `__builtin_ia32_vfmsubps256` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.ps.256"]
        pub fn fma_vfmsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfmsub.pd.256` intrinsic; known as `__builtin_ia32_vfmsubpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfmsub.pd.256"]
        pub fn fma_vfmsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.fma.vfnmadd.ss` intrinsic; known as `__builtin_ia32_vfnmaddss` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.ss"]
        pub fn fma_vfnmadd_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfnmadd.sd` intrinsic; known as `__builtin_ia32_vfnmaddsd` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.sd"]
        pub fn fma_vfnmadd_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfnmadd.ps` intrinsic; known as `__builtin_ia32_vfnmaddps` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.ps"]
        pub fn fma_vfnmadd_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfnmadd.pd` intrinsic; known as `__builtin_ia32_vfnmaddpd` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.pd"]
        pub fn fma_vfnmadd_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfnmadd.ps.256` intrinsic; known as `__builtin_ia32_vfnmaddps256` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.ps.256"]
        pub fn fma_vfnmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfnmadd.pd.256` intrinsic; known as `__builtin_ia32_vfnmaddpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfnmadd.pd.256"]
        pub fn fma_vfnmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.fma.vfnmsub.ss` intrinsic; known as `__builtin_ia32_vfnmsubss` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.ss"]
        pub fn fma_vfnmsub_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfnmsub.sd` intrinsic; known as `__builtin_ia32_vfnmsubsd` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.sd"]
        pub fn fma_vfnmsub_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfnmsub.ps` intrinsic; known as `__builtin_ia32_vfnmsubps` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.ps"]
        pub fn fma_vfnmsub_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfnmsub.pd` intrinsic; known as `__builtin_ia32_vfnmsubpd` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.pd"]
        pub fn fma_vfnmsub_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfnmsub.ps.256` intrinsic; known as `__builtin_ia32_vfnmsubps256` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.ps.256"]
        pub fn fma_vfnmsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfnmsub.pd.256` intrinsic; known as `__builtin_ia32_vfnmsubpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfnmsub.pd.256"]
        pub fn fma_vfnmsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.fma.vfmaddsub.ps` intrinsic; known as `__builtin_ia32_vfmaddsubps` in GCC.
        #[link_name = "llvm.x86.fma.vfmaddsub.ps"]
        pub fn fma_vfmaddsub_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmaddsub.pd` intrinsic; known as `__builtin_ia32_vfmaddsubpd` in GCC.
        #[link_name = "llvm.x86.fma.vfmaddsub.pd"]
        pub fn fma_vfmaddsub_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmaddsub.ps.256` intrinsic; known as `__builtin_ia32_vfmaddsubps256` in GCC.
        #[link_name = "llvm.x86.fma.vfmaddsub.ps.256"]
        pub fn fma_vfmaddsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfmaddsub.pd.256` intrinsic; known as `__builtin_ia32_vfmaddsubpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfmaddsub.pd.256"]
        pub fn fma_vfmaddsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.fma.vfmsubadd.ps` intrinsic; known as `__builtin_ia32_vfmsubaddps` in GCC.
        #[link_name = "llvm.x86.fma.vfmsubadd.ps"]
        pub fn fma_vfmsubadd_ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.fma.vfmsubadd.pd` intrinsic; known as `__builtin_ia32_vfmsubaddpd` in GCC.
        #[link_name = "llvm.x86.fma.vfmsubadd.pd"]
        pub fn fma_vfmsubadd_pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.fma.vfmsubadd.ps.256` intrinsic; known as `__builtin_ia32_vfmsubaddps256` in GCC.
        #[link_name = "llvm.x86.fma.vfmsubadd.ps.256"]
        pub fn fma_vfmsubadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.fma.vfmsubadd.pd.256` intrinsic; known as `__builtin_ia32_vfmsubaddpd256` in GCC.
        #[link_name = "llvm.x86.fma.vfmsubadd.pd.256"]
        pub fn fma_vfmsubadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vfmadd.pd.128` intrinsic; known as `__builtin_ia32_vfmaddpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.pd.128"]
        pub fn avx512_mask_vfmadd_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfmadd.pd.128` intrinsic; known as `__builtin_ia32_vfmaddpd128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.pd.128"]
        pub fn avx512_mask3_vfmadd_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.vfmadd.pd.128` intrinsic; known as `__builtin_ia32_vfmaddpd128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.pd.128"]
        pub fn avx512_maskz_vfmadd_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vfmadd.pd.256` intrinsic; known as `__builtin_ia32_vfmaddpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.pd.256"]
        pub fn avx512_mask_vfmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask3.vfmadd.pd.256` intrinsic; known as `__builtin_ia32_vfmaddpd256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.pd.256"]
        pub fn avx512_mask3_vfmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.maskz.vfmadd.pd.256` intrinsic; known as `__builtin_ia32_vfmaddpd256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.pd.256"]
        pub fn avx512_maskz_vfmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vfmadd.pd.512` intrinsic; known as `__builtin_ia32_vfmaddpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.pd.512"]
        pub fn avx512_mask_vfmadd_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask3.vfmadd.pd.512` intrinsic; known as `__builtin_ia32_vfmaddpd512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.pd.512"]
        pub fn avx512_mask3_vfmadd_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.maskz.vfmadd.pd.512` intrinsic; known as `__builtin_ia32_vfmaddpd512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.pd.512"]
        pub fn avx512_maskz_vfmadd_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vfmadd.ps.128` intrinsic; known as `__builtin_ia32_vfmaddps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.ps.128"]
        pub fn avx512_mask_vfmadd_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmadd.ps.128` intrinsic; known as `__builtin_ia32_vfmaddps128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.ps.128"]
        pub fn avx512_mask3_vfmadd_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.vfmadd.ps.128` intrinsic; known as `__builtin_ia32_vfmaddps128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.ps.128"]
        pub fn avx512_maskz_vfmadd_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vfmadd.ps.256` intrinsic; known as `__builtin_ia32_vfmaddps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.ps.256"]
        pub fn avx512_mask_vfmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask3.vfmadd.ps.256` intrinsic; known as `__builtin_ia32_vfmaddps256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.ps.256"]
        pub fn avx512_mask3_vfmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.maskz.vfmadd.ps.256` intrinsic; known as `__builtin_ia32_vfmaddps256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.ps.256"]
        pub fn avx512_maskz_vfmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vfmadd.ps.512` intrinsic; known as `__builtin_ia32_vfmaddps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.ps.512"]
        pub fn avx512_mask_vfmadd_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask3.vfmadd.ps.512` intrinsic; known as `__builtin_ia32_vfmaddps512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.ps.512"]
        pub fn avx512_mask3_vfmadd_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.maskz.vfmadd.ps.512` intrinsic; known as `__builtin_ia32_vfmaddps512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.ps.512"]
        pub fn avx512_maskz_vfmadd_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vfmaddsub.pd.128` intrinsic; known as `__builtin_ia32_vfmaddsubpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.pd.128"]
        pub fn avx512_mask_vfmaddsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.pd.128` intrinsic; known as `__builtin_ia32_vfmaddsubpd128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.pd.128"]
        pub fn avx512_mask3_vfmaddsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.pd.128` intrinsic; known as `__builtin_ia32_vfmaddsubpd128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.pd.128"]
        pub fn avx512_maskz_vfmaddsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vfmaddsub.pd.256` intrinsic; known as `__builtin_ia32_vfmaddsubpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.pd.256"]
        pub fn avx512_mask_vfmaddsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.pd.256` intrinsic; known as `__builtin_ia32_vfmaddsubpd256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.pd.256"]
        pub fn avx512_mask3_vfmaddsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.pd.256` intrinsic; known as `__builtin_ia32_vfmaddsubpd256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.pd.256"]
        pub fn avx512_maskz_vfmaddsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vfmaddsub.pd.512` intrinsic; known as `__builtin_ia32_vfmaddsubpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.pd.512"]
        pub fn avx512_mask_vfmaddsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.pd.512` intrinsic; known as `__builtin_ia32_vfmaddsubpd512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.pd.512"]
        pub fn avx512_mask3_vfmaddsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.pd.512` intrinsic; known as `__builtin_ia32_vfmaddsubpd512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.pd.512"]
        pub fn avx512_maskz_vfmaddsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vfmaddsub.ps.128` intrinsic; known as `__builtin_ia32_vfmaddsubps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.ps.128"]
        pub fn avx512_mask_vfmaddsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.ps.128` intrinsic; known as `__builtin_ia32_vfmaddsubps128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.ps.128"]
        pub fn avx512_mask3_vfmaddsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.ps.128` intrinsic; known as `__builtin_ia32_vfmaddsubps128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.ps.128"]
        pub fn avx512_maskz_vfmaddsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vfmaddsub.ps.256` intrinsic; known as `__builtin_ia32_vfmaddsubps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.ps.256"]
        pub fn avx512_mask_vfmaddsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.ps.256` intrinsic; known as `__builtin_ia32_vfmaddsubps256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.ps.256"]
        pub fn avx512_mask3_vfmaddsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.ps.256` intrinsic; known as `__builtin_ia32_vfmaddsubps256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.ps.256"]
        pub fn avx512_maskz_vfmaddsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vfmaddsub.ps.512` intrinsic; known as `__builtin_ia32_vfmaddsubps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmaddsub.ps.512"]
        pub fn avx512_mask_vfmaddsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask3.vfmaddsub.ps.512` intrinsic; known as `__builtin_ia32_vfmaddsubps512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmaddsub.ps.512"]
        pub fn avx512_mask3_vfmaddsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.maskz.vfmaddsub.ps.512` intrinsic; known as `__builtin_ia32_vfmaddsubps512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmaddsub.ps.512"]
        pub fn avx512_maskz_vfmaddsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vfmadd.sd` intrinsic; known as `__builtin_ia32_vfmaddsd3_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.sd"]
        pub fn avx512_mask_vfmadd_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vfmadd.ss` intrinsic; known as `__builtin_ia32_vfmaddss3_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfmadd.ss"]
        pub fn avx512_mask_vfmadd_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.vfmadd.sd` intrinsic; known as `__builtin_ia32_vfmaddsd3_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.sd"]
        pub fn avx512_maskz_vfmadd_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.vfmadd.ss` intrinsic; known as `__builtin_ia32_vfmaddss3_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vfmadd.ss"]
        pub fn avx512_maskz_vfmadd_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmadd.sd` intrinsic; known as `__builtin_ia32_vfmaddsd3_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.sd"]
        pub fn avx512_mask3_vfmadd_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfmadd.ss` intrinsic; known as `__builtin_ia32_vfmaddss3_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmadd.ss"]
        pub fn avx512_mask3_vfmadd_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmsub.pd.128` intrinsic; known as `__builtin_ia32_vfmsubpd128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.pd.128"]
        pub fn avx512_mask3_vfmsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfmsub.pd.256` intrinsic; known as `__builtin_ia32_vfmsubpd256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.pd.256"]
        pub fn avx512_mask3_vfmsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask3.vfmsub.pd.512` intrinsic; known as `__builtin_ia32_vfmsubpd512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.pd.512"]
        pub fn avx512_mask3_vfmsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask3.vfmsub.ps.128` intrinsic; known as `__builtin_ia32_vfmsubps128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.ps.128"]
        pub fn avx512_mask3_vfmsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmsub.ps.256` intrinsic; known as `__builtin_ia32_vfmsubps256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.ps.256"]
        pub fn avx512_mask3_vfmsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask3.vfmsub.ps.512` intrinsic; known as `__builtin_ia32_vfmsubps512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsub.ps.512"]
        pub fn avx512_mask3_vfmsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.pd.128` intrinsic; known as `__builtin_ia32_vfmsubaddpd128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.pd.128"]
        pub fn avx512_mask3_vfmsubadd_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.pd.256` intrinsic; known as `__builtin_ia32_vfmsubaddpd256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.pd.256"]
        pub fn avx512_mask3_vfmsubadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.pd.512` intrinsic; known as `__builtin_ia32_vfmsubaddpd512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.pd.512"]
        pub fn avx512_mask3_vfmsubadd_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.ps.128` intrinsic; known as `__builtin_ia32_vfmsubaddps128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.ps.128"]
        pub fn avx512_mask3_vfmsubadd_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.ps.256` intrinsic; known as `__builtin_ia32_vfmsubaddps256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.ps.256"]
        pub fn avx512_mask3_vfmsubadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask3.vfmsubadd.ps.512` intrinsic; known as `__builtin_ia32_vfmsubaddps512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfmsubadd.ps.512"]
        pub fn avx512_mask3_vfmsubadd_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vfnmadd.pd.128` intrinsic; known as `__builtin_ia32_vfnmaddpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.pd.128"]
        pub fn avx512_mask_vfnmadd_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vfnmadd.pd.256` intrinsic; known as `__builtin_ia32_vfnmaddpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.pd.256"]
        pub fn avx512_mask_vfnmadd_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vfnmadd.pd.512` intrinsic; known as `__builtin_ia32_vfnmaddpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.pd.512"]
        pub fn avx512_mask_vfnmadd_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vfnmadd.ps.128` intrinsic; known as `__builtin_ia32_vfnmaddps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.ps.128"]
        pub fn avx512_mask_vfnmadd_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vfnmadd.ps.256` intrinsic; known as `__builtin_ia32_vfnmaddps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.ps.256"]
        pub fn avx512_mask_vfnmadd_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vfnmadd.ps.512` intrinsic; known as `__builtin_ia32_vfnmaddps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmadd.ps.512"]
        pub fn avx512_mask_vfnmadd_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vfnmsub.pd.128` intrinsic; known as `__builtin_ia32_vfnmsubpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.pd.128"]
        pub fn avx512_mask_vfnmsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask3.vfnmsub.pd.128` intrinsic; known as `__builtin_ia32_vfnmsubpd128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.pd.128"]
        pub fn avx512_mask3_vfnmsub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.vfnmsub.pd.256` intrinsic; known as `__builtin_ia32_vfnmsubpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.pd.256"]
        pub fn avx512_mask_vfnmsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask3.vfnmsub.pd.256` intrinsic; known as `__builtin_ia32_vfnmsubpd256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.pd.256"]
        pub fn avx512_mask3_vfnmsub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.vfnmsub.pd.512` intrinsic; known as `__builtin_ia32_vfnmsubpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.pd.512"]
        pub fn avx512_mask_vfnmsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask3.vfnmsub.pd.512` intrinsic; known as `__builtin_ia32_vfnmsubpd512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.pd.512"]
        pub fn avx512_mask3_vfnmsub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.vfnmsub.ps.128` intrinsic; known as `__builtin_ia32_vfnmsubps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.ps.128"]
        pub fn avx512_mask_vfnmsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask3.vfnmsub.ps.128` intrinsic; known as `__builtin_ia32_vfnmsubps128_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.ps.128"]
        pub fn avx512_mask3_vfnmsub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vfnmsub.ps.256` intrinsic; known as `__builtin_ia32_vfnmsubps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.ps.256"]
        pub fn avx512_mask_vfnmsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask3.vfnmsub.ps.256` intrinsic; known as `__builtin_ia32_vfnmsubps256_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.ps.256"]
        pub fn avx512_mask3_vfnmsub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vfnmsub.ps.512` intrinsic; known as `__builtin_ia32_vfnmsubps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vfnmsub.ps.512"]
        pub fn avx512_mask_vfnmsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask3.vfnmsub.ps.512` intrinsic; known as `__builtin_ia32_vfnmsubps512_mask3` in GCC.
        #[link_name = "llvm.x86.avx512.mask3.vfnmsub.ps.512"]
        pub fn avx512_mask3_vfnmsub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vpmadd52h.uq.128` intrinsic; known as `__builtin_ia32_vpmadd52huq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52h.uq.128"]
        pub fn avx512_mask_vpmadd52h_uq_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.maskz.vpmadd52h.uq.128` intrinsic; known as `__builtin_ia32_vpmadd52huq128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52h.uq.128"]
        pub fn avx512_maskz_vpmadd52h_uq_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vpmadd52l.uq.128` intrinsic; known as `__builtin_ia32_vpmadd52luq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52l.uq.128"]
        pub fn avx512_mask_vpmadd52l_uq_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.maskz.vpmadd52l.uq.128` intrinsic; known as `__builtin_ia32_vpmadd52luq128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52l.uq.128"]
        pub fn avx512_maskz_vpmadd52l_uq_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.vpmadd52h.uq.256` intrinsic; known as `__builtin_ia32_vpmadd52huq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52h.uq.256"]
        pub fn avx512_mask_vpmadd52h_uq_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.maskz.vpmadd52h.uq.256` intrinsic; known as `__builtin_ia32_vpmadd52huq256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52h.uq.256"]
        pub fn avx512_maskz_vpmadd52h_uq_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.vpmadd52l.uq.256` intrinsic; known as `__builtin_ia32_vpmadd52luq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52l.uq.256"]
        pub fn avx512_mask_vpmadd52l_uq_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.maskz.vpmadd52l.uq.256` intrinsic; known as `__builtin_ia32_vpmadd52luq256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52l.uq.256"]
        pub fn avx512_maskz_vpmadd52l_uq_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.vpmadd52h.uq.512` intrinsic; known as `__builtin_ia32_vpmadd52huq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52h.uq.512"]
        pub fn avx512_mask_vpmadd52h_uq_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.maskz.vpmadd52h.uq.512` intrinsic; known as `__builtin_ia32_vpmadd52huq512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52h.uq.512"]
        pub fn avx512_maskz_vpmadd52h_uq_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.vpmadd52l.uq.512` intrinsic; known as `__builtin_ia32_vpmadd52luq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vpmadd52l.uq.512"]
        pub fn avx512_mask_vpmadd52l_uq_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.maskz.vpmadd52l.uq.512` intrinsic; known as `__builtin_ia32_vpmadd52luq512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.vpmadd52l.uq.512"]
        pub fn avx512_maskz_vpmadd52l_uq_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.xop.vpermil2pd` intrinsic; known as `__builtin_ia32_vpermil2pd` in GCC.
        #[link_name = "llvm.x86.xop.vpermil2pd"]
        pub fn xop_vpermil2pd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.xop.vpermil2pd.256` intrinsic; known as `__builtin_ia32_vpermil2pd256` in GCC.
        #[link_name = "llvm.x86.xop.vpermil2pd.256"]
        pub fn xop_vpermil2pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.xop.vpermil2ps` intrinsic; known as `__builtin_ia32_vpermil2ps` in GCC.
        #[link_name = "llvm.x86.xop.vpermil2ps"]
        pub fn xop_vpermil2ps(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.xop.vpermil2ps.256` intrinsic; known as `__builtin_ia32_vpermil2ps256` in GCC.
        #[link_name = "llvm.x86.xop.vpermil2ps.256"]
        pub fn xop_vpermil2ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.xop.vfrcz.pd` intrinsic; known as `__builtin_ia32_vfrczpd` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.pd"]
        pub fn xop_vfrcz_pd(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.xop.vfrcz.ps` intrinsic; known as `__builtin_ia32_vfrczps` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.ps"]
        pub fn xop_vfrcz_ps(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.xop.vfrcz.sd` intrinsic; known as `__builtin_ia32_vfrczsd` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.sd"]
        pub fn xop_vfrcz_sd(a: ::simdty::f64x2) -> ::simdty::f64x2;
        /// The `llvm.x86.xop.vfrcz.ss` intrinsic; known as `__builtin_ia32_vfrczss` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.ss"]
        pub fn xop_vfrcz_ss(a: ::simdty::f32x4) -> ::simdty::f32x4;
        /// The `llvm.x86.xop.vfrcz.pd.256` intrinsic; known as `__builtin_ia32_vfrczpd256` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.pd.256"]
        pub fn xop_vfrcz_pd_256(a: ::simdty::f64x4) -> ::simdty::f64x4;
        /// The `llvm.x86.xop.vfrcz.ps.256` intrinsic; known as `__builtin_ia32_vfrczps256` in GCC.
        #[link_name = "llvm.x86.xop.vfrcz.ps.256"]
        pub fn xop_vfrcz_ps_256(a: ::simdty::f32x8) -> ::simdty::f32x8;
        /// The `llvm.x86.xop.vpcmov` intrinsic; known as `__builtin_ia32_vpcmov` in GCC.
        #[link_name = "llvm.x86.xop.vpcmov"]
        pub fn xop_vpcmov(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpcmov.256` intrinsic; known as `__builtin_ia32_vpcmov_256` in GCC.
        #[link_name = "llvm.x86.xop.vpcmov.256"]
        pub fn xop_vpcmov_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4) -> ::simdty::i64x4;
        /// The `llvm.x86.xop.vpcomb` intrinsic; known as `__builtin_ia32_vpcomb` in GCC.
        #[link_name = "llvm.x86.xop.vpcomb"]
        pub fn xop_vpcomb(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vpcomw` intrinsic; known as `__builtin_ia32_vpcomw` in GCC.
        #[link_name = "llvm.x86.xop.vpcomw"]
        pub fn xop_vpcomw(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpcomd` intrinsic; known as `__builtin_ia32_vpcomd` in GCC.
        #[link_name = "llvm.x86.xop.vpcomd"]
        pub fn xop_vpcomd(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpcomq` intrinsic; known as `__builtin_ia32_vpcomq` in GCC.
        #[link_name = "llvm.x86.xop.vpcomq"]
        pub fn xop_vpcomq(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpcomub` intrinsic; known as `__builtin_ia32_vpcomub` in GCC.
        #[link_name = "llvm.x86.xop.vpcomub"]
        pub fn xop_vpcomub(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vpcomuw` intrinsic; known as `__builtin_ia32_vpcomuw` in GCC.
        #[link_name = "llvm.x86.xop.vpcomuw"]
        pub fn xop_vpcomuw(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpcomud` intrinsic; known as `__builtin_ia32_vpcomud` in GCC.
        #[link_name = "llvm.x86.xop.vpcomud"]
        pub fn xop_vpcomud(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpcomuq` intrinsic; known as `__builtin_ia32_vpcomuq` in GCC.
        #[link_name = "llvm.x86.xop.vpcomuq"]
        pub fn xop_vpcomuq(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphaddbd` intrinsic; known as `__builtin_ia32_vphaddbd` in GCC.
        #[link_name = "llvm.x86.xop.vphaddbd"]
        pub fn xop_vphaddbd(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vphaddbq` intrinsic; known as `__builtin_ia32_vphaddbq` in GCC.
        #[link_name = "llvm.x86.xop.vphaddbq"]
        pub fn xop_vphaddbq(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphaddbw` intrinsic; known as `__builtin_ia32_vphaddbw` in GCC.
        #[link_name = "llvm.x86.xop.vphaddbw"]
        pub fn xop_vphaddbw(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vphadddq` intrinsic; known as `__builtin_ia32_vphadddq` in GCC.
        #[link_name = "llvm.x86.xop.vphadddq"]
        pub fn xop_vphadddq(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphaddubd` intrinsic; known as `__builtin_ia32_vphaddubd` in GCC.
        #[link_name = "llvm.x86.xop.vphaddubd"]
        pub fn xop_vphaddubd(a: ::simdty::i8x16) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vphaddubq` intrinsic; known as `__builtin_ia32_vphaddubq` in GCC.
        #[link_name = "llvm.x86.xop.vphaddubq"]
        pub fn xop_vphaddubq(a: ::simdty::i8x16) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphaddubw` intrinsic; known as `__builtin_ia32_vphaddubw` in GCC.
        #[link_name = "llvm.x86.xop.vphaddubw"]
        pub fn xop_vphaddubw(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vphaddudq` intrinsic; known as `__builtin_ia32_vphaddudq` in GCC.
        #[link_name = "llvm.x86.xop.vphaddudq"]
        pub fn xop_vphaddudq(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphadduwd` intrinsic; known as `__builtin_ia32_vphadduwd` in GCC.
        #[link_name = "llvm.x86.xop.vphadduwd"]
        pub fn xop_vphadduwd(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vphadduwq` intrinsic; known as `__builtin_ia32_vphadduwq` in GCC.
        #[link_name = "llvm.x86.xop.vphadduwq"]
        pub fn xop_vphadduwq(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphaddwd` intrinsic; known as `__builtin_ia32_vphaddwd` in GCC.
        #[link_name = "llvm.x86.xop.vphaddwd"]
        pub fn xop_vphaddwd(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vphaddwq` intrinsic; known as `__builtin_ia32_vphaddwq` in GCC.
        #[link_name = "llvm.x86.xop.vphaddwq"]
        pub fn xop_vphaddwq(a: ::simdty::i16x8) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphsubbw` intrinsic; known as `__builtin_ia32_vphsubbw` in GCC.
        #[link_name = "llvm.x86.xop.vphsubbw"]
        pub fn xop_vphsubbw(a: ::simdty::i8x16) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vphsubdq` intrinsic; known as `__builtin_ia32_vphsubdq` in GCC.
        #[link_name = "llvm.x86.xop.vphsubdq"]
        pub fn xop_vphsubdq(a: ::simdty::i32x4) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vphsubwd` intrinsic; known as `__builtin_ia32_vphsubwd` in GCC.
        #[link_name = "llvm.x86.xop.vphsubwd"]
        pub fn xop_vphsubwd(a: ::simdty::i16x8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmacsdd` intrinsic; known as `__builtin_ia32_vpmacsdd` in GCC.
        #[link_name = "llvm.x86.xop.vpmacsdd"]
        pub fn xop_vpmacsdd(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmacsdqh` intrinsic; known as `__builtin_ia32_vpmacsdqh` in GCC.
        #[link_name = "llvm.x86.xop.vpmacsdqh"]
        pub fn xop_vpmacsdqh(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpmacsdql` intrinsic; known as `__builtin_ia32_vpmacsdql` in GCC.
        #[link_name = "llvm.x86.xop.vpmacsdql"]
        pub fn xop_vpmacsdql(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpmacssdd` intrinsic; known as `__builtin_ia32_vpmacssdd` in GCC.
        #[link_name = "llvm.x86.xop.vpmacssdd"]
        pub fn xop_vpmacssdd(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmacssdqh` intrinsic; known as `__builtin_ia32_vpmacssdqh` in GCC.
        #[link_name = "llvm.x86.xop.vpmacssdqh"]
        pub fn xop_vpmacssdqh(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpmacssdql` intrinsic; known as `__builtin_ia32_vpmacssdql` in GCC.
        #[link_name = "llvm.x86.xop.vpmacssdql"]
        pub fn xop_vpmacssdql(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpmacsswd` intrinsic; known as `__builtin_ia32_vpmacsswd` in GCC.
        #[link_name = "llvm.x86.xop.vpmacsswd"]
        pub fn xop_vpmacsswd(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmacssww` intrinsic; known as `__builtin_ia32_vpmacssww` in GCC.
        #[link_name = "llvm.x86.xop.vpmacssww"]
        pub fn xop_vpmacssww(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpmacswd` intrinsic; known as `__builtin_ia32_vpmacswd` in GCC.
        #[link_name = "llvm.x86.xop.vpmacswd"]
        pub fn xop_vpmacswd(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmacsww` intrinsic; known as `__builtin_ia32_vpmacsww` in GCC.
        #[link_name = "llvm.x86.xop.vpmacsww"]
        pub fn xop_vpmacsww(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpmadcsswd` intrinsic; known as `__builtin_ia32_vpmadcsswd` in GCC.
        #[link_name = "llvm.x86.xop.vpmadcsswd"]
        pub fn xop_vpmadcsswd(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpmadcswd` intrinsic; known as `__builtin_ia32_vpmadcswd` in GCC.
        #[link_name = "llvm.x86.xop.vpmadcswd"]
        pub fn xop_vpmadcswd(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpperm` intrinsic; known as `__builtin_ia32_vpperm` in GCC.
        #[link_name = "llvm.x86.xop.vpperm"]
        pub fn xop_vpperm(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vprotb` intrinsic; known as `__builtin_ia32_vprotb` in GCC.
        #[link_name = "llvm.x86.xop.vprotb"]
        pub fn xop_vprotb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vprotd` intrinsic; known as `__builtin_ia32_vprotd` in GCC.
        #[link_name = "llvm.x86.xop.vprotd"]
        pub fn xop_vprotd(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vprotq` intrinsic; known as `__builtin_ia32_vprotq` in GCC.
        #[link_name = "llvm.x86.xop.vprotq"]
        pub fn xop_vprotq(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vprotw` intrinsic; known as `__builtin_ia32_vprotw` in GCC.
        #[link_name = "llvm.x86.xop.vprotw"]
        pub fn xop_vprotw(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vprotbi` intrinsic; known as `__builtin_ia32_vprotbi` in GCC.
        #[link_name = "llvm.x86.xop.vprotbi"]
        pub fn xop_vprotbi(a: ::simdty::i8x16, b: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vprotdi` intrinsic; known as `__builtin_ia32_vprotdi` in GCC.
        #[link_name = "llvm.x86.xop.vprotdi"]
        pub fn xop_vprotdi(a: ::simdty::i32x4, b: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vprotqi` intrinsic; known as `__builtin_ia32_vprotqi` in GCC.
        #[link_name = "llvm.x86.xop.vprotqi"]
        pub fn xop_vprotqi(a: ::simdty::i64x2, b: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vprotwi` intrinsic; known as `__builtin_ia32_vprotwi` in GCC.
        #[link_name = "llvm.x86.xop.vprotwi"]
        pub fn xop_vprotwi(a: ::simdty::i16x8, b: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpshab` intrinsic; known as `__builtin_ia32_vpshab` in GCC.
        #[link_name = "llvm.x86.xop.vpshab"]
        pub fn xop_vpshab(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vpshad` intrinsic; known as `__builtin_ia32_vpshad` in GCC.
        #[link_name = "llvm.x86.xop.vpshad"]
        pub fn xop_vpshad(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpshaq` intrinsic; known as `__builtin_ia32_vpshaq` in GCC.
        #[link_name = "llvm.x86.xop.vpshaq"]
        pub fn xop_vpshaq(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpshaw` intrinsic; known as `__builtin_ia32_vpshaw` in GCC.
        #[link_name = "llvm.x86.xop.vpshaw"]
        pub fn xop_vpshaw(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.xop.vpshlb` intrinsic; known as `__builtin_ia32_vpshlb` in GCC.
        #[link_name = "llvm.x86.xop.vpshlb"]
        pub fn xop_vpshlb(a: ::simdty::i8x16, b: ::simdty::i8x16) -> ::simdty::i8x16;
        /// The `llvm.x86.xop.vpshld` intrinsic; known as `__builtin_ia32_vpshld` in GCC.
        #[link_name = "llvm.x86.xop.vpshld"]
        pub fn xop_vpshld(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.xop.vpshlq` intrinsic; known as `__builtin_ia32_vpshlq` in GCC.
        #[link_name = "llvm.x86.xop.vpshlq"]
        pub fn xop_vpshlq(a: ::simdty::i64x2, b: ::simdty::i64x2) -> ::simdty::i64x2;
        /// The `llvm.x86.xop.vpshlw` intrinsic; known as `__builtin_ia32_vpshlw` in GCC.
        #[link_name = "llvm.x86.xop.vpshlw"]
        pub fn xop_vpshlw(a: ::simdty::i16x8, b: ::simdty::i16x8) -> ::simdty::i16x8;
        /// The `llvm.x86.mmx.emms` intrinsic; known as `__builtin_ia32_emms` in GCC.
        #[link_name = "llvm.x86.mmx.emms"]
        pub fn mmx_emms() -> ();
        /// The `llvm.x86.mmx.femms` intrinsic; known as `__builtin_ia32_femms` in GCC.
        #[link_name = "llvm.x86.mmx.femms"]
        pub fn mmx_femms() -> ();
        /// The `llvm.x86.avx512.mask.permvar.df.256` intrinsic; known as `__builtin_ia32_permvardf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.df.256"]
        pub fn avx512_mask_permvar_df_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.permvar.df.512` intrinsic; known as `__builtin_ia32_permvardf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.df.512"]
        pub fn avx512_mask_permvar_df_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.permvar.di.256` intrinsic; known as `__builtin_ia32_permvardi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.di.256"]
        pub fn avx512_mask_permvar_di_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.permvar.di.512` intrinsic; known as `__builtin_ia32_permvardi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.di.512"]
        pub fn avx512_mask_permvar_di_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.permvar.hi.128` intrinsic; known as `__builtin_ia32_permvarhi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.hi.128"]
        pub fn avx512_mask_permvar_hi_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.permvar.hi.256` intrinsic; known as `__builtin_ia32_permvarhi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.hi.256"]
        pub fn avx512_mask_permvar_hi_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.permvar.hi.512` intrinsic; known as `__builtin_ia32_permvarhi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.hi.512"]
        pub fn avx512_mask_permvar_hi_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.permvar.qi.128` intrinsic; known as `__builtin_ia32_permvarqi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.qi.128"]
        pub fn avx512_mask_permvar_qi_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.permvar.qi.256` intrinsic; known as `__builtin_ia32_permvarqi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.qi.256"]
        pub fn avx512_mask_permvar_qi_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.permvar.qi.512` intrinsic; known as `__builtin_ia32_permvarqi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.qi.512"]
        pub fn avx512_mask_permvar_qi_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.permvar.sf.256` intrinsic; known as `__builtin_ia32_permvarsf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.sf.256"]
        pub fn avx512_mask_permvar_sf_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.permvar.sf.512` intrinsic; known as `__builtin_ia32_permvarsf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.sf.512"]
        pub fn avx512_mask_permvar_sf_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.permvar.si.256` intrinsic; known as `__builtin_ia32_permvarsi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.si.256"]
        pub fn avx512_mask_permvar_si_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.permvar.si.512` intrinsic; known as `__builtin_ia32_permvarsi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.permvar.si.512"]
        pub fn avx512_mask_permvar_si_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.bmi.bextr.32` intrinsic; known as `__builtin_ia32_bextr_u32` in GCC.
        #[link_name = "llvm.x86.bmi.bextr.32"]
        pub fn bmi_bextr_32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.bmi.bextr.64` intrinsic; known as `__builtin_ia32_bextr_u64` in GCC.
        #[link_name = "llvm.x86.bmi.bextr.64"]
        pub fn bmi_bextr_64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.bmi.bzhi.32` intrinsic; known as `__builtin_ia32_bzhi_si` in GCC.
        #[link_name = "llvm.x86.bmi.bzhi.32"]
        pub fn bmi_bzhi_32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.bmi.bzhi.64` intrinsic; known as `__builtin_ia32_bzhi_di` in GCC.
        #[link_name = "llvm.x86.bmi.bzhi.64"]
        pub fn bmi_bzhi_64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.bmi.pdep.32` intrinsic; known as `__builtin_ia32_pdep_si` in GCC.
        #[link_name = "llvm.x86.bmi.pdep.32"]
        pub fn bmi_pdep_32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.bmi.pdep.64` intrinsic; known as `__builtin_ia32_pdep_di` in GCC.
        #[link_name = "llvm.x86.bmi.pdep.64"]
        pub fn bmi_pdep_64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.bmi.pext.32` intrinsic; known as `__builtin_ia32_pext_si` in GCC.
        #[link_name = "llvm.x86.bmi.pext.32"]
        pub fn bmi_pext_32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.bmi.pext.64` intrinsic; known as `__builtin_ia32_pext_di` in GCC.
        #[link_name = "llvm.x86.bmi.pext.64"]
        pub fn bmi_pext_64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.rdfsbase.32` intrinsic; known as `__builtin_ia32_rdfsbase32` in GCC.
        #[link_name = "llvm.x86.rdfsbase.32"]
        pub fn rdfsbase_32() -> i32;
        /// The `llvm.x86.rdgsbase.32` intrinsic; known as `__builtin_ia32_rdgsbase32` in GCC.
        #[link_name = "llvm.x86.rdgsbase.32"]
        pub fn rdgsbase_32() -> i32;
        /// The `llvm.x86.rdfsbase.64` intrinsic; known as `__builtin_ia32_rdfsbase64` in GCC.
        #[link_name = "llvm.x86.rdfsbase.64"]
        pub fn rdfsbase_64() -> i64;
        /// The `llvm.x86.rdgsbase.64` intrinsic; known as `__builtin_ia32_rdgsbase64` in GCC.
        #[link_name = "llvm.x86.rdgsbase.64"]
        pub fn rdgsbase_64() -> i64;
        /// The `llvm.x86.wrfsbase.32` intrinsic; known as `__builtin_ia32_wrfsbase32` in GCC.
        #[link_name = "llvm.x86.wrfsbase.32"]
        pub fn wrfsbase_32(a: i32) -> ();
        /// The `llvm.x86.wrgsbase.32` intrinsic; known as `__builtin_ia32_wrgsbase32` in GCC.
        #[link_name = "llvm.x86.wrgsbase.32"]
        pub fn wrgsbase_32(a: i32) -> ();
        /// The `llvm.x86.wrfsbase.64` intrinsic; known as `__builtin_ia32_wrfsbase64` in GCC.
        #[link_name = "llvm.x86.wrfsbase.64"]
        pub fn wrfsbase_64(a: i64) -> ();
        /// The `llvm.x86.wrgsbase.64` intrinsic; known as `__builtin_ia32_wrgsbase64` in GCC.
        #[link_name = "llvm.x86.wrgsbase.64"]
        pub fn wrgsbase_64(a: i64) -> ();
        /// The `llvm.x86.fxrstor` intrinsic; known as `__builtin_ia32_fxrstor` in GCC.
        #[link_name = "llvm.x86.fxrstor"]
        pub fn fxrstor(a: *mut i8) -> ();
        /// The `llvm.x86.fxrstor64` intrinsic; known as `__builtin_ia32_fxrstor64` in GCC.
        #[link_name = "llvm.x86.fxrstor64"]
        pub fn fxrstor64(a: *mut i8) -> ();
        /// The `llvm.x86.fxsave` intrinsic; known as `__builtin_ia32_fxsave` in GCC.
        #[link_name = "llvm.x86.fxsave"]
        pub fn fxsave(a: *mut i8) -> ();
        /// The `llvm.x86.fxsave64` intrinsic; known as `__builtin_ia32_fxsave64` in GCC.
        #[link_name = "llvm.x86.fxsave64"]
        pub fn fxsave64(a: *mut i8) -> ();
        /// The `llvm.x86.xsave` intrinsic.
        #[link_name = "llvm.x86.xsave"]
        pub fn xsave(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsave64` intrinsic.
        #[link_name = "llvm.x86.xsave64"]
        pub fn xsave64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xrstor` intrinsic.
        #[link_name = "llvm.x86.xrstor"]
        pub fn xrstor(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xrstor64` intrinsic.
        #[link_name = "llvm.x86.xrstor64"]
        pub fn xrstor64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsaveopt` intrinsic.
        #[link_name = "llvm.x86.xsaveopt"]
        pub fn xsaveopt(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsaveopt64` intrinsic.
        #[link_name = "llvm.x86.xsaveopt64"]
        pub fn xsaveopt64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xrstors` intrinsic.
        #[link_name = "llvm.x86.xrstors"]
        pub fn xrstors(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xrstors64` intrinsic.
        #[link_name = "llvm.x86.xrstors64"]
        pub fn xrstors64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsavec` intrinsic.
        #[link_name = "llvm.x86.xsavec"]
        pub fn xsavec(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsavec64` intrinsic.
        #[link_name = "llvm.x86.xsavec64"]
        pub fn xsavec64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsaves` intrinsic.
        #[link_name = "llvm.x86.xsaves"]
        pub fn xsaves(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.xsaves64` intrinsic.
        #[link_name = "llvm.x86.xsaves64"]
        pub fn xsaves64(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.clflushopt` intrinsic; known as `__builtin_ia32_clflushopt` in GCC.
        #[link_name = "llvm.x86.clflushopt"]
        pub fn clflushopt(a: *mut i8) -> ();
        /// The `llvm.x86.rdpkru` intrinsic; known as `__builtin_ia32_rdpkru` in GCC.
        #[link_name = "llvm.x86.rdpkru"]
        pub fn rdpkru() -> i32;
        /// The `llvm.x86.wrpkru` intrinsic; known as `__builtin_ia32_wrpkru` in GCC.
        #[link_name = "llvm.x86.wrpkru"]
        pub fn wrpkru(a: i32) -> ();
        /// The `llvm.x86.vcvtph2ps.128` intrinsic; known as `__builtin_ia32_vcvtph2ps` in GCC.
        #[link_name = "llvm.x86.vcvtph2ps.128"]
        pub fn vcvtph2ps_128(a: ::simdty::i16x8) -> ::simdty::f32x4;
        /// The `llvm.x86.vcvtph2ps.256` intrinsic; known as `__builtin_ia32_vcvtph2ps256` in GCC.
        #[link_name = "llvm.x86.vcvtph2ps.256"]
        pub fn vcvtph2ps_256(a: ::simdty::i16x8) -> ::simdty::f32x8;
        /// The `llvm.x86.vcvtps2ph.128` intrinsic; known as `__builtin_ia32_vcvtps2ph` in GCC.
        #[link_name = "llvm.x86.vcvtps2ph.128"]
        pub fn vcvtps2ph_128(a: ::simdty::f32x4, b: i32) -> ::simdty::i16x8;
        /// The `llvm.x86.vcvtps2ph.256` intrinsic; known as `__builtin_ia32_vcvtps2ph256` in GCC.
        #[link_name = "llvm.x86.vcvtps2ph.256"]
        pub fn vcvtps2ph_256(a: ::simdty::f32x8, b: i32) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.vcvtph2ps.512` intrinsic; known as `__builtin_ia32_vcvtph2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtph2ps.512"]
        pub fn avx512_mask_vcvtph2ps_512(a: ::simdty::i16x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.vcvtph2ps.256` intrinsic; known as `__builtin_ia32_vcvtph2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtph2ps.256"]
        pub fn avx512_mask_vcvtph2ps_256(a: ::simdty::i16x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.vcvtph2ps.128` intrinsic; known as `__builtin_ia32_vcvtph2ps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtph2ps.128"]
        pub fn avx512_mask_vcvtph2ps_128(a: ::simdty::i16x8, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.vcvtps2ph.512` intrinsic; known as `__builtin_ia32_vcvtps2ph512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtps2ph.512"]
        pub fn avx512_mask_vcvtps2ph_512(a: ::simdty::f32x16, b: i32, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.vcvtps2ph.256` intrinsic; known as `__builtin_ia32_vcvtps2ph256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtps2ph.256"]
        pub fn avx512_mask_vcvtps2ph_256(a: ::simdty::f32x8, b: i32, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.vcvtps2ph.128` intrinsic; known as `__builtin_ia32_vcvtps2ph_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.vcvtps2ph.128"]
        pub fn avx512_mask_vcvtps2ph_128(a: ::simdty::f32x4, b: i32, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.tbm.bextri.u32` intrinsic; known as `__builtin_ia32_bextri_u32` in GCC.
        #[link_name = "llvm.x86.tbm.bextri.u32"]
        pub fn tbm_bextri_u32(a: i32, b: i32) -> i32;
        /// The `llvm.x86.tbm.bextri.u64` intrinsic; known as `__builtin_ia32_bextri_u64` in GCC.
        #[link_name = "llvm.x86.tbm.bextri.u64"]
        pub fn tbm_bextri_u64(a: i64, b: i64) -> i64;
        /// The `llvm.x86.addcarryx.u32` intrinsic; known as `__builtin_ia32_addcarryx_u32` in GCC.
        #[link_name = "llvm.x86.addcarryx.u32"]
        pub fn addcarryx_u32(a: i8, b: i32, c: i32, d: *mut i8) -> i8;
        /// The `llvm.x86.addcarryx.u64` intrinsic; known as `__builtin_ia32_addcarryx_u64` in GCC.
        #[link_name = "llvm.x86.addcarryx.u64"]
        pub fn addcarryx_u64(a: i8, b: i64, c: i64, d: *mut i8) -> i8;
        /// The `llvm.x86.addcarry.u32` intrinsic; known as `__builtin_ia32_addcarry_u32` in GCC.
        #[link_name = "llvm.x86.addcarry.u32"]
        pub fn addcarry_u32(a: i8, b: i32, c: i32, d: *mut i8) -> i8;
        /// The `llvm.x86.addcarry.u64` intrinsic; known as `__builtin_ia32_addcarry_u64` in GCC.
        #[link_name = "llvm.x86.addcarry.u64"]
        pub fn addcarry_u64(a: i8, b: i64, c: i64, d: *mut i8) -> i8;
        /// The `llvm.x86.subborrow.u32` intrinsic; known as `__builtin_ia32_subborrow_u32` in GCC.
        #[link_name = "llvm.x86.subborrow.u32"]
        pub fn subborrow_u32(a: i8, b: i32, c: i32, d: *mut i8) -> i8;
        /// The `llvm.x86.subborrow.u64` intrinsic; known as `__builtin_ia32_subborrow_u64` in GCC.
        #[link_name = "llvm.x86.subborrow.u64"]
        pub fn subborrow_u64(a: i8, b: i64, c: i64, d: *mut i8) -> i8;
        /// The `llvm.x86.xbegin` intrinsic; known as `__builtin_ia32_xbegin` in GCC.
        #[link_name = "llvm.x86.xbegin"]
        pub fn xbegin() -> i32;
        /// The `llvm.x86.xend` intrinsic; known as `__builtin_ia32_xend` in GCC.
        #[link_name = "llvm.x86.xend"]
        pub fn xend() -> ();
        /// The `llvm.x86.xabort` intrinsic; known as `__builtin_ia32_xabort` in GCC.
        #[link_name = "llvm.x86.xabort"]
        pub fn xabort(a: i8) -> ();
        /// The `llvm.x86.xtest` intrinsic; known as `__builtin_ia32_xtest` in GCC.
        #[link_name = "llvm.x86.xtest"]
        pub fn xtest() -> i32;
        /// The `llvm.x86.avx512.kand.w` intrinsic; known as `__builtin_ia32_kandhi` in GCC.
        #[link_name = "llvm.x86.avx512.kand.w"]
        pub fn avx512_kand_w(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.kandn.w` intrinsic; known as `__builtin_ia32_kandnhi` in GCC.
        #[link_name = "llvm.x86.avx512.kandn.w"]
        pub fn avx512_kandn_w(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.knot.w` intrinsic; known as `__builtin_ia32_knothi` in GCC.
        #[link_name = "llvm.x86.avx512.knot.w"]
        pub fn avx512_knot_w(a: i16) -> i16;
        /// The `llvm.x86.avx512.kor.w` intrinsic; known as `__builtin_ia32_korhi` in GCC.
        #[link_name = "llvm.x86.avx512.kor.w"]
        pub fn avx512_kor_w(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.kxor.w` intrinsic; known as `__builtin_ia32_kxorhi` in GCC.
        #[link_name = "llvm.x86.avx512.kxor.w"]
        pub fn avx512_kxor_w(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.kxnor.w` intrinsic; known as `__builtin_ia32_kxnorhi` in GCC.
        #[link_name = "llvm.x86.avx512.kxnor.w"]
        pub fn avx512_kxnor_w(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.kunpck.bw` intrinsic; known as `__builtin_ia32_kunpckhi` in GCC.
        #[link_name = "llvm.x86.avx512.kunpck.bw"]
        pub fn avx512_kunpck_bw(a: i16, b: i16) -> i16;
        /// The `llvm.x86.avx512.kunpck.wd` intrinsic; known as `__builtin_ia32_kunpcksi` in GCC.
        #[link_name = "llvm.x86.avx512.kunpck.wd"]
        pub fn avx512_kunpck_wd(a: i32, b: i32) -> i32;
        /// The `llvm.x86.avx512.kunpck.dq` intrinsic; known as `__builtin_ia32_kunpckdi` in GCC.
        #[link_name = "llvm.x86.avx512.kunpck.dq"]
        pub fn avx512_kunpck_dq(a: i64, b: i64) -> i64;
        /// The `llvm.x86.avx512.kortestz.w` intrinsic; known as `__builtin_ia32_kortestzhi` in GCC.
        #[link_name = "llvm.x86.avx512.kortestz.w"]
        pub fn avx512_kortestz_w(a: i16, b: i16) -> i32;
        /// The `llvm.x86.avx512.kortestc.w` intrinsic; known as `__builtin_ia32_kortestchi` in GCC.
        #[link_name = "llvm.x86.avx512.kortestc.w"]
        pub fn avx512_kortestc_w(a: i16, b: i16) -> i32;
        /// The `llvm.x86.avx512.mask.pmovsxb.d.128` intrinsic; known as `__builtin_ia32_pmovsxbd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.d.128"]
        pub fn avx512_mask_pmovsxb_d_128(a: ::simdty::i8x16, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovsxb.d.256` intrinsic; known as `__builtin_ia32_pmovsxbd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.d.256"]
        pub fn avx512_mask_pmovsxb_d_256(a: ::simdty::i8x16, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovsxb.d.512` intrinsic; known as `__builtin_ia32_pmovsxbd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.d.512"]
        pub fn avx512_mask_pmovsxb_d_512(a: ::simdty::i8x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmovsxb.q.128` intrinsic; known as `__builtin_ia32_pmovsxbq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.q.128"]
        pub fn avx512_mask_pmovsxb_q_128(a: ::simdty::i8x16, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovsxb.q.256` intrinsic; known as `__builtin_ia32_pmovsxbq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.q.256"]
        pub fn avx512_mask_pmovsxb_q_256(a: ::simdty::i8x16, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovsxb.q.512` intrinsic; known as `__builtin_ia32_pmovsxbq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.q.512"]
        pub fn avx512_mask_pmovsxb_q_512(a: ::simdty::i8x16, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmovsxb.w.128` intrinsic; known as `__builtin_ia32_pmovsxbw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.w.128"]
        pub fn avx512_mask_pmovsxb_w_128(a: ::simdty::i8x16, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovsxb.w.256` intrinsic; known as `__builtin_ia32_pmovsxbw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.w.256"]
        pub fn avx512_mask_pmovsxb_w_256(a: ::simdty::i8x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmovsxb.w.512` intrinsic; known as `__builtin_ia32_pmovsxbw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxb.w.512"]
        pub fn avx512_mask_pmovsxb_w_512(a: ::simdty::i8x32, b: ::simdty::i16x32, c: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmovsxd.q.128` intrinsic; known as `__builtin_ia32_pmovsxdq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxd.q.128"]
        pub fn avx512_mask_pmovsxd_q_128(a: ::simdty::i32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovsxd.q.256` intrinsic; known as `__builtin_ia32_pmovsxdq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxd.q.256"]
        pub fn avx512_mask_pmovsxd_q_256(a: ::simdty::i32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovsxd.q.512` intrinsic; known as `__builtin_ia32_pmovsxdq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxd.q.512"]
        pub fn avx512_mask_pmovsxd_q_512(a: ::simdty::i32x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmovsxw.d.128` intrinsic; known as `__builtin_ia32_pmovsxwd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.d.128"]
        pub fn avx512_mask_pmovsxw_d_128(a: ::simdty::i16x8, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovsxw.d.256` intrinsic; known as `__builtin_ia32_pmovsxwd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.d.256"]
        pub fn avx512_mask_pmovsxw_d_256(a: ::simdty::i16x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovsxw.d.512` intrinsic; known as `__builtin_ia32_pmovsxwd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.d.512"]
        pub fn avx512_mask_pmovsxw_d_512(a: ::simdty::i16x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmovsxw.q.128` intrinsic; known as `__builtin_ia32_pmovsxwq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.q.128"]
        pub fn avx512_mask_pmovsxw_q_128(a: ::simdty::i16x8, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovsxw.q.256` intrinsic; known as `__builtin_ia32_pmovsxwq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.q.256"]
        pub fn avx512_mask_pmovsxw_q_256(a: ::simdty::i16x8, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovsxw.q.512` intrinsic; known as `__builtin_ia32_pmovsxwq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovsxw.q.512"]
        pub fn avx512_mask_pmovsxw_q_512(a: ::simdty::i16x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.cvttss2si` intrinsic; known as `__builtin_ia32_vcvttss2si32` in GCC.
        #[link_name = "llvm.x86.avx512.cvttss2si"]
        pub fn avx512_cvttss2si(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.x86.avx512.cvttss2si64` intrinsic; known as `__builtin_ia32_vcvttss2si64` in GCC.
        #[link_name = "llvm.x86.avx512.cvttss2si64"]
        pub fn avx512_cvttss2si64(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.x86.avx512.cvttss2usi` intrinsic; known as `__builtin_ia32_vcvttss2usi32` in GCC.
        #[link_name = "llvm.x86.avx512.cvttss2usi"]
        pub fn avx512_cvttss2usi(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.x86.avx512.cvttss2usi64` intrinsic; known as `__builtin_ia32_vcvttss2usi64` in GCC.
        #[link_name = "llvm.x86.avx512.cvttss2usi64"]
        pub fn avx512_cvttss2usi64(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.x86.avx512.cvtusi2ss` intrinsic; known as `__builtin_ia32_cvtusi2ss32` in GCC.
        #[link_name = "llvm.x86.avx512.cvtusi2ss"]
        pub fn avx512_cvtusi2ss(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.cvtusi642ss` intrinsic; known as `__builtin_ia32_cvtusi2ss64` in GCC.
        #[link_name = "llvm.x86.avx512.cvtusi642ss"]
        pub fn avx512_cvtusi642ss(a: ::simdty::f32x4, b: i64, c: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.cvttsd2si` intrinsic; known as `__builtin_ia32_vcvttsd2si32` in GCC.
        #[link_name = "llvm.x86.avx512.cvttsd2si"]
        pub fn avx512_cvttsd2si(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.x86.avx512.cvttsd2si64` intrinsic; known as `__builtin_ia32_vcvttsd2si64` in GCC.
        #[link_name = "llvm.x86.avx512.cvttsd2si64"]
        pub fn avx512_cvttsd2si64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.x86.avx512.cvttsd2usi` intrinsic; known as `__builtin_ia32_vcvttsd2usi32` in GCC.
        #[link_name = "llvm.x86.avx512.cvttsd2usi"]
        pub fn avx512_cvttsd2usi(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.x86.avx512.cvttsd2usi64` intrinsic; known as `__builtin_ia32_vcvttsd2usi64` in GCC.
        #[link_name = "llvm.x86.avx512.cvttsd2usi64"]
        pub fn avx512_cvttsd2usi64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.x86.avx512.cvtusi2sd` intrinsic; known as `__builtin_ia32_cvtusi2sd32` in GCC.
        #[link_name = "llvm.x86.avx512.cvtusi2sd"]
        pub fn avx512_cvtusi2sd(a: ::simdty::f64x2, b: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.cvtusi642sd` intrinsic; known as `__builtin_ia32_cvtusi2sd64` in GCC.
        #[link_name = "llvm.x86.avx512.cvtusi642sd"]
        pub fn avx512_cvtusi642sd(a: ::simdty::f64x2, b: i64, c: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.vcvtss2usi32` intrinsic; known as `__builtin_ia32_vcvtss2usi32` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtss2usi32"]
        pub fn avx512_vcvtss2usi32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.x86.avx512.vcvtss2usi64` intrinsic; known as `__builtin_ia32_vcvtss2usi64` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtss2usi64"]
        pub fn avx512_vcvtss2usi64(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.x86.avx512.vcvtss2si32` intrinsic; known as `__builtin_ia32_vcvtss2si32` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtss2si32"]
        pub fn avx512_vcvtss2si32(a: ::simdty::f32x4, b: i32) -> i32;
        /// The `llvm.x86.avx512.vcvtss2si64` intrinsic; known as `__builtin_ia32_vcvtss2si64` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtss2si64"]
        pub fn avx512_vcvtss2si64(a: ::simdty::f32x4, b: i32) -> i64;
        /// The `llvm.x86.avx512.vcvtsd2usi32` intrinsic; known as `__builtin_ia32_vcvtsd2usi32` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtsd2usi32"]
        pub fn avx512_vcvtsd2usi32(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.x86.avx512.vcvtsd2usi64` intrinsic; known as `__builtin_ia32_vcvtsd2usi64` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtsd2usi64"]
        pub fn avx512_vcvtsd2usi64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.x86.avx512.vcvtsd2si32` intrinsic; known as `__builtin_ia32_vcvtsd2si32` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtsd2si32"]
        pub fn avx512_vcvtsd2si32(a: ::simdty::f64x2, b: i32) -> i32;
        /// The `llvm.x86.avx512.vcvtsd2si64` intrinsic; known as `__builtin_ia32_vcvtsd2si64` in GCC.
        #[link_name = "llvm.x86.avx512.vcvtsd2si64"]
        pub fn avx512_vcvtsd2si64(a: ::simdty::f64x2, b: i32) -> i64;
        /// The `llvm.x86.avx512.cvtsi2ss32` intrinsic; known as `__builtin_ia32_cvtsi2ss32` in GCC.
        #[link_name = "llvm.x86.avx512.cvtsi2ss32"]
        pub fn avx512_cvtsi2ss32(a: ::simdty::f32x4, b: i32, c: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.cvtsi2ss64` intrinsic; known as `__builtin_ia32_cvtsi2ss64` in GCC.
        #[link_name = "llvm.x86.avx512.cvtsi2ss64"]
        pub fn avx512_cvtsi2ss64(a: ::simdty::f32x4, b: i64, c: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.cvtsi2sd32` intrinsic; known as `__builtin_ia32_cvtsi2sd32` in GCC.
        #[link_name = "llvm.x86.avx512.cvtsi2sd32"]
        pub fn avx512_cvtsi2sd32(a: ::simdty::f64x2, b: i32, c: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.cvtsi2sd64` intrinsic; known as `__builtin_ia32_cvtsi2sd64` in GCC.
        #[link_name = "llvm.x86.avx512.cvtsi2sd64"]
        pub fn avx512_cvtsi2sd64(a: ::simdty::f64x2, b: i64, c: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.cvtb2mask.128` intrinsic; known as `__builtin_ia32_cvtb2mask128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtb2mask.128"]
        pub fn avx512_cvtb2mask_128(a: ::simdty::i8x16) -> i16;
        /// The `llvm.x86.avx512.cvtb2mask.256` intrinsic; known as `__builtin_ia32_cvtb2mask256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtb2mask.256"]
        pub fn avx512_cvtb2mask_256(a: ::simdty::i8x32) -> i32;
        /// The `llvm.x86.avx512.cvtb2mask.512` intrinsic; known as `__builtin_ia32_cvtb2mask512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtb2mask.512"]
        pub fn avx512_cvtb2mask_512(a: ::simdty::i8x64) -> i64;
        /// The `llvm.x86.avx512.cvtw2mask.128` intrinsic; known as `__builtin_ia32_cvtw2mask128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtw2mask.128"]
        pub fn avx512_cvtw2mask_128(a: ::simdty::i16x8) -> i8;
        /// The `llvm.x86.avx512.cvtw2mask.256` intrinsic; known as `__builtin_ia32_cvtw2mask256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtw2mask.256"]
        pub fn avx512_cvtw2mask_256(a: ::simdty::i16x16) -> i16;
        /// The `llvm.x86.avx512.cvtw2mask.512` intrinsic; known as `__builtin_ia32_cvtw2mask512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtw2mask.512"]
        pub fn avx512_cvtw2mask_512(a: ::simdty::i16x32) -> i32;
        /// The `llvm.x86.avx512.cvtd2mask.128` intrinsic; known as `__builtin_ia32_cvtd2mask128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtd2mask.128"]
        pub fn avx512_cvtd2mask_128(a: ::simdty::i32x4) -> i8;
        /// The `llvm.x86.avx512.cvtd2mask.256` intrinsic; known as `__builtin_ia32_cvtd2mask256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtd2mask.256"]
        pub fn avx512_cvtd2mask_256(a: ::simdty::i32x8) -> i8;
        /// The `llvm.x86.avx512.cvtd2mask.512` intrinsic; known as `__builtin_ia32_cvtd2mask512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtd2mask.512"]
        pub fn avx512_cvtd2mask_512(a: ::simdty::i32x16) -> i16;
        /// The `llvm.x86.avx512.cvtq2mask.128` intrinsic; known as `__builtin_ia32_cvtq2mask128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtq2mask.128"]
        pub fn avx512_cvtq2mask_128(a: ::simdty::i64x2) -> i8;
        /// The `llvm.x86.avx512.cvtq2mask.256` intrinsic; known as `__builtin_ia32_cvtq2mask256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtq2mask.256"]
        pub fn avx512_cvtq2mask_256(a: ::simdty::i64x4) -> i8;
        /// The `llvm.x86.avx512.cvtq2mask.512` intrinsic; known as `__builtin_ia32_cvtq2mask512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtq2mask.512"]
        pub fn avx512_cvtq2mask_512(a: ::simdty::i64x8) -> i8;
        /// The `llvm.x86.avx512.cvtmask2b.128` intrinsic; known as `__builtin_ia32_cvtmask2b128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2b.128"]
        pub fn avx512_cvtmask2b_128(a: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.cvtmask2b.256` intrinsic; known as `__builtin_ia32_cvtmask2b256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2b.256"]
        pub fn avx512_cvtmask2b_256(a: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.cvtmask2b.512` intrinsic; known as `__builtin_ia32_cvtmask2b512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2b.512"]
        pub fn avx512_cvtmask2b_512(a: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.cvtmask2w.128` intrinsic; known as `__builtin_ia32_cvtmask2w128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2w.128"]
        pub fn avx512_cvtmask2w_128(a: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.cvtmask2w.256` intrinsic; known as `__builtin_ia32_cvtmask2w256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2w.256"]
        pub fn avx512_cvtmask2w_256(a: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.cvtmask2w.512` intrinsic; known as `__builtin_ia32_cvtmask2w512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2w.512"]
        pub fn avx512_cvtmask2w_512(a: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.cvtmask2d.128` intrinsic; known as `__builtin_ia32_cvtmask2d128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2d.128"]
        pub fn avx512_cvtmask2d_128(a: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.cvtmask2d.256` intrinsic; known as `__builtin_ia32_cvtmask2d256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2d.256"]
        pub fn avx512_cvtmask2d_256(a: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.cvtmask2d.512` intrinsic; known as `__builtin_ia32_cvtmask2d512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2d.512"]
        pub fn avx512_cvtmask2d_512(a: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.cvtmask2q.128` intrinsic; known as `__builtin_ia32_cvtmask2q128` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2q.128"]
        pub fn avx512_cvtmask2q_128(a: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.cvtmask2q.256` intrinsic; known as `__builtin_ia32_cvtmask2q256` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2q.256"]
        pub fn avx512_cvtmask2q_256(a: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.cvtmask2q.512` intrinsic; known as `__builtin_ia32_cvtmask2q512` in GCC.
        #[link_name = "llvm.x86.avx512.cvtmask2q.512"]
        pub fn avx512_cvtmask2q_512(a: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.packsswb.128` intrinsic; known as `__builtin_ia32_packsswb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packsswb.128"]
        pub fn avx512_mask_packsswb_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.packsswb.256` intrinsic; known as `__builtin_ia32_packsswb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packsswb.256"]
        pub fn avx512_mask_packsswb_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.packsswb.512` intrinsic; known as `__builtin_ia32_packsswb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packsswb.512"]
        pub fn avx512_mask_packsswb_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.packssdw.128` intrinsic; known as `__builtin_ia32_packssdw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packssdw.128"]
        pub fn avx512_mask_packssdw_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.packssdw.256` intrinsic; known as `__builtin_ia32_packssdw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packssdw.256"]
        pub fn avx512_mask_packssdw_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.packssdw.512` intrinsic; known as `__builtin_ia32_packssdw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packssdw.512"]
        pub fn avx512_mask_packssdw_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.packuswb.128` intrinsic; known as `__builtin_ia32_packuswb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packuswb.128"]
        pub fn avx512_mask_packuswb_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.packuswb.256` intrinsic; known as `__builtin_ia32_packuswb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packuswb.256"]
        pub fn avx512_mask_packuswb_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.packuswb.512` intrinsic; known as `__builtin_ia32_packuswb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packuswb.512"]
        pub fn avx512_mask_packuswb_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.packusdw.128` intrinsic; known as `__builtin_ia32_packusdw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packusdw.128"]
        pub fn avx512_mask_packusdw_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.packusdw.256` intrinsic; known as `__builtin_ia32_packusdw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packusdw.256"]
        pub fn avx512_mask_packusdw_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.packusdw.512` intrinsic; known as `__builtin_ia32_packusdw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.packusdw.512"]
        pub fn avx512_mask_packusdw_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.cvtdq2pd.128` intrinsic; known as `__builtin_ia32_cvtdq2pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2pd.128"]
        pub fn avx512_mask_cvtdq2pd_128(a: ::simdty::i32x4, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtdq2pd.256` intrinsic; known as `__builtin_ia32_cvtdq2pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2pd.256"]
        pub fn avx512_mask_cvtdq2pd_256(a: ::simdty::i32x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.cvtdq2pd.512` intrinsic; known as `__builtin_ia32_cvtdq2pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2pd.512"]
        pub fn avx512_mask_cvtdq2pd_512(a: ::simdty::i32x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.cvtdq2ps.128` intrinsic; known as `__builtin_ia32_cvtdq2ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2ps.128"]
        pub fn avx512_mask_cvtdq2ps_128(a: ::simdty::i32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtdq2ps.256` intrinsic; known as `__builtin_ia32_cvtdq2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2ps.256"]
        pub fn avx512_mask_cvtdq2ps_256(a: ::simdty::i32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.cvtdq2ps.512` intrinsic; known as `__builtin_ia32_cvtdq2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtdq2ps.512"]
        pub fn avx512_mask_cvtdq2ps_512(a: ::simdty::i32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.cvtpd2dq.128` intrinsic; known as `__builtin_ia32_cvtpd2dq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2dq.128"]
        pub fn avx512_mask_cvtpd2dq_128(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2dq.256` intrinsic; known as `__builtin_ia32_cvtpd2dq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2dq.256"]
        pub fn avx512_mask_cvtpd2dq_256(a: ::simdty::f64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2dq.512` intrinsic; known as `__builtin_ia32_cvtpd2dq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2dq.512"]
        pub fn avx512_mask_cvtpd2dq_512(a: ::simdty::f64x8, b: ::simdty::i32x8, c: i8, d: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvtpd2ps.256` intrinsic; known as `__builtin_ia32_cvtpd2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2ps.256"]
        pub fn avx512_mask_cvtpd2ps_256(a: ::simdty::f64x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2ps.512` intrinsic; known as `__builtin_ia32_cvtpd2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2ps.512"]
        pub fn avx512_mask_cvtpd2ps_512(a: ::simdty::f64x8, b: ::simdty::f32x8, c: i8, d: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.cvtsd2ss.round` intrinsic; known as `__builtin_ia32_cvtsd2ss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtsd2ss.round"]
        pub fn avx512_mask_cvtsd2ss_round(a: ::simdty::f32x4, b: ::simdty::f64x2, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtss2sd.round` intrinsic; known as `__builtin_ia32_cvtss2sd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtss2sd.round"]
        pub fn avx512_mask_cvtss2sd_round(a: ::simdty::f64x2, b: ::simdty::f32x4, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtpd2ps` intrinsic; known as `__builtin_ia32_cvtpd2ps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2ps"]
        pub fn avx512_mask_cvtpd2ps(a: ::simdty::f64x2, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2qq.128` intrinsic; known as `__builtin_ia32_cvtpd2qq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2qq.128"]
        pub fn avx512_mask_cvtpd2qq_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvtpd2qq.256` intrinsic; known as `__builtin_ia32_cvtpd2qq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2qq.256"]
        pub fn avx512_mask_cvtpd2qq_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvtpd2qq.512` intrinsic; known as `__builtin_ia32_cvtpd2qq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2qq.512"]
        pub fn avx512_mask_cvtpd2qq_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvtpd2udq.128` intrinsic; known as `__builtin_ia32_cvtpd2udq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2udq.128"]
        pub fn avx512_mask_cvtpd2udq_128(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2udq.256` intrinsic; known as `__builtin_ia32_cvtpd2udq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2udq.256"]
        pub fn avx512_mask_cvtpd2udq_256(a: ::simdty::f64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtpd2udq.512` intrinsic; known as `__builtin_ia32_cvtpd2udq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2udq.512"]
        pub fn avx512_mask_cvtpd2udq_512(a: ::simdty::f64x8, b: ::simdty::i32x8, c: i8, d: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvtpd2uqq.128` intrinsic; known as `__builtin_ia32_cvtpd2uqq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2uqq.128"]
        pub fn avx512_mask_cvtpd2uqq_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvtpd2uqq.256` intrinsic; known as `__builtin_ia32_cvtpd2uqq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2uqq.256"]
        pub fn avx512_mask_cvtpd2uqq_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvtpd2uqq.512` intrinsic; known as `__builtin_ia32_cvtpd2uqq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtpd2uqq.512"]
        pub fn avx512_mask_cvtpd2uqq_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvtps2dq.128` intrinsic; known as `__builtin_ia32_cvtps2dq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2dq.128"]
        pub fn avx512_mask_cvtps2dq_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtps2dq.256` intrinsic; known as `__builtin_ia32_cvtps2dq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2dq.256"]
        pub fn avx512_mask_cvtps2dq_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvtps2dq.512` intrinsic; known as `__builtin_ia32_cvtps2dq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2dq.512"]
        pub fn avx512_mask_cvtps2dq_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: i16, d: i32) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.cvtps2pd.128` intrinsic; known as `__builtin_ia32_cvtps2pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2pd.128"]
        pub fn avx512_mask_cvtps2pd_128(a: ::simdty::f32x4, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtps2pd.256` intrinsic; known as `__builtin_ia32_cvtps2pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2pd.256"]
        pub fn avx512_mask_cvtps2pd_256(a: ::simdty::f32x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.cvtps2pd.512` intrinsic; known as `__builtin_ia32_cvtps2pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2pd.512"]
        pub fn avx512_mask_cvtps2pd_512(a: ::simdty::f32x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.cvtps2qq.128` intrinsic; known as `__builtin_ia32_cvtps2qq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2qq.128"]
        pub fn avx512_mask_cvtps2qq_128(a: ::simdty::f32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvtps2qq.256` intrinsic; known as `__builtin_ia32_cvtps2qq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2qq.256"]
        pub fn avx512_mask_cvtps2qq_256(a: ::simdty::f32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvtps2qq.512` intrinsic; known as `__builtin_ia32_cvtps2qq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2qq.512"]
        pub fn avx512_mask_cvtps2qq_512(a: ::simdty::f32x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvtps2udq.128` intrinsic; known as `__builtin_ia32_cvtps2udq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2udq.128"]
        pub fn avx512_mask_cvtps2udq_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvtps2udq.256` intrinsic; known as `__builtin_ia32_cvtps2udq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2udq.256"]
        pub fn avx512_mask_cvtps2udq_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvtps2udq.512` intrinsic; known as `__builtin_ia32_cvtps2udq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2udq.512"]
        pub fn avx512_mask_cvtps2udq_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: i16, d: i32) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.cvtps2uqq.128` intrinsic; known as `__builtin_ia32_cvtps2uqq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2uqq.128"]
        pub fn avx512_mask_cvtps2uqq_128(a: ::simdty::f32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvtps2uqq.256` intrinsic; known as `__builtin_ia32_cvtps2uqq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2uqq.256"]
        pub fn avx512_mask_cvtps2uqq_256(a: ::simdty::f32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvtps2uqq.512` intrinsic; known as `__builtin_ia32_cvtps2uqq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtps2uqq.512"]
        pub fn avx512_mask_cvtps2uqq_512(a: ::simdty::f32x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvtqq2pd.128` intrinsic; known as `__builtin_ia32_cvtqq2pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2pd.128"]
        pub fn avx512_mask_cvtqq2pd_128(a: ::simdty::i64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtqq2pd.256` intrinsic; known as `__builtin_ia32_cvtqq2pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2pd.256"]
        pub fn avx512_mask_cvtqq2pd_256(a: ::simdty::i64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.cvtqq2pd.512` intrinsic; known as `__builtin_ia32_cvtqq2pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2pd.512"]
        pub fn avx512_mask_cvtqq2pd_512(a: ::simdty::i64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.cvtqq2ps.128` intrinsic; known as `__builtin_ia32_cvtqq2ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2ps.128"]
        pub fn avx512_mask_cvtqq2ps_128(a: ::simdty::i64x2, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtqq2ps.256` intrinsic; known as `__builtin_ia32_cvtqq2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2ps.256"]
        pub fn avx512_mask_cvtqq2ps_256(a: ::simdty::i64x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtqq2ps.512` intrinsic; known as `__builtin_ia32_cvtqq2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtqq2ps.512"]
        pub fn avx512_mask_cvtqq2ps_512(a: ::simdty::i64x8, b: ::simdty::f32x8, c: i8, d: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.cvttpd2dq.128` intrinsic; known as `__builtin_ia32_cvttpd2dq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2dq.128"]
        pub fn avx512_mask_cvttpd2dq_128(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttpd2dq.256` intrinsic; known as `__builtin_ia32_cvttpd2dq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2dq.256"]
        pub fn avx512_mask_cvttpd2dq_256(a: ::simdty::f64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttpd2dq.512` intrinsic; known as `__builtin_ia32_cvttpd2dq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2dq.512"]
        pub fn avx512_mask_cvttpd2dq_512(a: ::simdty::f64x8, b: ::simdty::i32x8, c: i8, d: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvttpd2qq.128` intrinsic; known as `__builtin_ia32_cvttpd2qq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2qq.128"]
        pub fn avx512_mask_cvttpd2qq_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvttpd2qq.256` intrinsic; known as `__builtin_ia32_cvttpd2qq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2qq.256"]
        pub fn avx512_mask_cvttpd2qq_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvttpd2qq.512` intrinsic; known as `__builtin_ia32_cvttpd2qq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2qq.512"]
        pub fn avx512_mask_cvttpd2qq_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvttpd2udq.128` intrinsic; known as `__builtin_ia32_cvttpd2udq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2udq.128"]
        pub fn avx512_mask_cvttpd2udq_128(a: ::simdty::f64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttpd2udq.256` intrinsic; known as `__builtin_ia32_cvttpd2udq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2udq.256"]
        pub fn avx512_mask_cvttpd2udq_256(a: ::simdty::f64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttpd2udq.512` intrinsic; known as `__builtin_ia32_cvttpd2udq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2udq.512"]
        pub fn avx512_mask_cvttpd2udq_512(a: ::simdty::f64x8, b: ::simdty::i32x8, c: i8, d: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvttpd2uqq.128` intrinsic; known as `__builtin_ia32_cvttpd2uqq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2uqq.128"]
        pub fn avx512_mask_cvttpd2uqq_128(a: ::simdty::f64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvttpd2uqq.256` intrinsic; known as `__builtin_ia32_cvttpd2uqq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2uqq.256"]
        pub fn avx512_mask_cvttpd2uqq_256(a: ::simdty::f64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvttpd2uqq.512` intrinsic; known as `__builtin_ia32_cvttpd2uqq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttpd2uqq.512"]
        pub fn avx512_mask_cvttpd2uqq_512(a: ::simdty::f64x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvttps2dq.128` intrinsic; known as `__builtin_ia32_cvttps2dq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2dq.128"]
        pub fn avx512_mask_cvttps2dq_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttps2dq.256` intrinsic; known as `__builtin_ia32_cvttps2dq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2dq.256"]
        pub fn avx512_mask_cvttps2dq_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvttps2dq.512` intrinsic; known as `__builtin_ia32_cvttps2dq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2dq.512"]
        pub fn avx512_mask_cvttps2dq_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: i16, d: i32) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.cvttps2qq.128` intrinsic; known as `__builtin_ia32_cvttps2qq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2qq.128"]
        pub fn avx512_mask_cvttps2qq_128(a: ::simdty::f32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvttps2qq.256` intrinsic; known as `__builtin_ia32_cvttps2qq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2qq.256"]
        pub fn avx512_mask_cvttps2qq_256(a: ::simdty::f32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvttps2qq.512` intrinsic; known as `__builtin_ia32_cvttps2qq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2qq.512"]
        pub fn avx512_mask_cvttps2qq_512(a: ::simdty::f32x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvttps2udq.128` intrinsic; known as `__builtin_ia32_cvttps2udq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2udq.128"]
        pub fn avx512_mask_cvttps2udq_128(a: ::simdty::f32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.cvttps2udq.256` intrinsic; known as `__builtin_ia32_cvttps2udq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2udq.256"]
        pub fn avx512_mask_cvttps2udq_256(a: ::simdty::f32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.cvttps2udq.512` intrinsic; known as `__builtin_ia32_cvttps2udq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2udq.512"]
        pub fn avx512_mask_cvttps2udq_512(a: ::simdty::f32x16, b: ::simdty::i32x16, c: i16, d: i32) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.cvttps2uqq.128` intrinsic; known as `__builtin_ia32_cvttps2uqq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2uqq.128"]
        pub fn avx512_mask_cvttps2uqq_128(a: ::simdty::f32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.cvttps2uqq.256` intrinsic; known as `__builtin_ia32_cvttps2uqq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2uqq.256"]
        pub fn avx512_mask_cvttps2uqq_256(a: ::simdty::f32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.cvttps2uqq.512` intrinsic; known as `__builtin_ia32_cvttps2uqq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvttps2uqq.512"]
        pub fn avx512_mask_cvttps2uqq_512(a: ::simdty::f32x8, b: ::simdty::i64x8, c: i8, d: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cvtudq2pd.128` intrinsic; known as `__builtin_ia32_cvtudq2pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2pd.128"]
        pub fn avx512_mask_cvtudq2pd_128(a: ::simdty::i32x4, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtudq2pd.256` intrinsic; known as `__builtin_ia32_cvtudq2pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2pd.256"]
        pub fn avx512_mask_cvtudq2pd_256(a: ::simdty::i32x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.cvtudq2pd.512` intrinsic; known as `__builtin_ia32_cvtudq2pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2pd.512"]
        pub fn avx512_mask_cvtudq2pd_512(a: ::simdty::i32x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.cvtudq2ps.128` intrinsic; known as `__builtin_ia32_cvtudq2ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2ps.128"]
        pub fn avx512_mask_cvtudq2ps_128(a: ::simdty::i32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtudq2ps.256` intrinsic; known as `__builtin_ia32_cvtudq2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2ps.256"]
        pub fn avx512_mask_cvtudq2ps_256(a: ::simdty::i32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.cvtudq2ps.512` intrinsic; known as `__builtin_ia32_cvtudq2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtudq2ps.512"]
        pub fn avx512_mask_cvtudq2ps_512(a: ::simdty::i32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.cvtuqq2pd.128` intrinsic; known as `__builtin_ia32_cvtuqq2pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2pd.128"]
        pub fn avx512_mask_cvtuqq2pd_128(a: ::simdty::i64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.cvtuqq2pd.256` intrinsic; known as `__builtin_ia32_cvtuqq2pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2pd.256"]
        pub fn avx512_mask_cvtuqq2pd_256(a: ::simdty::i64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.cvtuqq2pd.512` intrinsic; known as `__builtin_ia32_cvtuqq2pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2pd.512"]
        pub fn avx512_mask_cvtuqq2pd_512(a: ::simdty::i64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.cvtuqq2ps.128` intrinsic; known as `__builtin_ia32_cvtuqq2ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2ps.128"]
        pub fn avx512_mask_cvtuqq2ps_128(a: ::simdty::i64x2, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtuqq2ps.256` intrinsic; known as `__builtin_ia32_cvtuqq2ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2ps.256"]
        pub fn avx512_mask_cvtuqq2ps_256(a: ::simdty::i64x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.cvtuqq2ps.512` intrinsic; known as `__builtin_ia32_cvtuqq2ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cvtuqq2ps.512"]
        pub fn avx512_mask_cvtuqq2ps_512(a: ::simdty::i64x8, b: ::simdty::f32x8, c: i8, d: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.rndscale.pd.128` intrinsic; known as `__builtin_ia32_rndscalepd_128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.pd.128"]
        pub fn avx512_mask_rndscale_pd_128(a: ::simdty::f64x2, b: i32, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.rndscale.pd.256` intrinsic; known as `__builtin_ia32_rndscalepd_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.pd.256"]
        pub fn avx512_mask_rndscale_pd_256(a: ::simdty::f64x4, b: i32, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.rndscale.pd.512` intrinsic; known as `__builtin_ia32_rndscalepd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.pd.512"]
        pub fn avx512_mask_rndscale_pd_512(a: ::simdty::f64x8, b: i32, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.rndscale.ps.128` intrinsic; known as `__builtin_ia32_rndscaleps_128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.ps.128"]
        pub fn avx512_mask_rndscale_ps_128(a: ::simdty::f32x4, b: i32, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.rndscale.ps.256` intrinsic; known as `__builtin_ia32_rndscaleps_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.ps.256"]
        pub fn avx512_mask_rndscale_ps_256(a: ::simdty::f32x8, b: i32, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.rndscale.ps.512` intrinsic; known as `__builtin_ia32_rndscaleps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.ps.512"]
        pub fn avx512_mask_rndscale_ps_512(a: ::simdty::f32x16, b: i32, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.reduce.pd.128` intrinsic; known as `__builtin_ia32_reducepd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.pd.128"]
        pub fn avx512_mask_reduce_pd_128(a: ::simdty::f64x2, b: i32, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.reduce.pd.256` intrinsic; known as `__builtin_ia32_reducepd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.pd.256"]
        pub fn avx512_mask_reduce_pd_256(a: ::simdty::f64x4, b: i32, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.reduce.pd.512` intrinsic; known as `__builtin_ia32_reducepd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.pd.512"]
        pub fn avx512_mask_reduce_pd_512(a: ::simdty::f64x8, b: i32, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.reduce.ps.128` intrinsic; known as `__builtin_ia32_reduceps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.ps.128"]
        pub fn avx512_mask_reduce_ps_128(a: ::simdty::f32x4, b: i32, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.reduce.ps.256` intrinsic; known as `__builtin_ia32_reduceps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.ps.256"]
        pub fn avx512_mask_reduce_ps_256(a: ::simdty::f32x8, b: i32, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.reduce.ps.512` intrinsic; known as `__builtin_ia32_reduceps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.ps.512"]
        pub fn avx512_mask_reduce_ps_512(a: ::simdty::f32x16, b: i32, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.range.pd.128` intrinsic; known as `__builtin_ia32_rangepd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.pd.128"]
        pub fn avx512_mask_range_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: ::simdty::f64x2, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.range.pd.256` intrinsic; known as `__builtin_ia32_rangepd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.pd.256"]
        pub fn avx512_mask_range_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i32, d: ::simdty::f64x4, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.range.pd.512` intrinsic; known as `__builtin_ia32_rangepd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.pd.512"]
        pub fn avx512_mask_range_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i32, d: ::simdty::f64x8, e: i8, f: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.range.ps.128` intrinsic; known as `__builtin_ia32_rangeps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.ps.128"]
        pub fn avx512_mask_range_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: ::simdty::f32x4, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.range.ps.256` intrinsic; known as `__builtin_ia32_rangeps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.ps.256"]
        pub fn avx512_mask_range_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i32, d: ::simdty::f32x8, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.range.ps.512` intrinsic; known as `__builtin_ia32_rangeps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.ps.512"]
        pub fn avx512_mask_range_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i32, d: ::simdty::f32x16, e: i16, f: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.vbroadcast.ss.512` intrinsic; known as `__builtin_ia32_vbroadcastss512` in GCC.
        #[link_name = "llvm.x86.avx512.vbroadcast.ss.512"]
        pub fn avx512_vbroadcast_ss_512(a: *mut i8) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.vbroadcast.sd.512` intrinsic; known as `__builtin_ia32_vbroadcastsd512` in GCC.
        #[link_name = "llvm.x86.avx512.vbroadcast.sd.512"]
        pub fn avx512_vbroadcast_sd_512(a: *mut i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.broadcastf32x2.256` intrinsic; known as `__builtin_ia32_broadcastf32x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf32x2.256"]
        pub fn avx512_mask_broadcastf32x2_256(a: ::simdty::f32x4, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.broadcastf32x2.512` intrinsic; known as `__builtin_ia32_broadcastf32x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf32x2.512"]
        pub fn avx512_mask_broadcastf32x2_512(a: ::simdty::f32x4, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.broadcasti32x2.128` intrinsic; known as `__builtin_ia32_broadcasti32x2_128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x2.128"]
        pub fn avx512_mask_broadcasti32x2_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.broadcasti32x2.256` intrinsic; known as `__builtin_ia32_broadcasti32x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x2.256"]
        pub fn avx512_mask_broadcasti32x2_256(a: ::simdty::i32x4, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.broadcasti32x2.512` intrinsic; known as `__builtin_ia32_broadcasti32x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x2.512"]
        pub fn avx512_mask_broadcasti32x2_512(a: ::simdty::i32x4, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.broadcastf32x4.256` intrinsic; known as `__builtin_ia32_broadcastf32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf32x4.256"]
        pub fn avx512_mask_broadcastf32x4_256(a: ::simdty::f32x4, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.broadcastf32x4.512` intrinsic; known as `__builtin_ia32_broadcastf32x4_512` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf32x4.512"]
        pub fn avx512_mask_broadcastf32x4_512(a: ::simdty::f32x4, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.broadcastf32x8.512` intrinsic; known as `__builtin_ia32_broadcastf32x8_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf32x8.512"]
        pub fn avx512_mask_broadcastf32x8_512(a: ::simdty::f32x8, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.broadcastf64x2.256` intrinsic; known as `__builtin_ia32_broadcastf64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf64x2.256"]
        pub fn avx512_mask_broadcastf64x2_256(a: ::simdty::f64x2, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.broadcastf64x2.512` intrinsic; known as `__builtin_ia32_broadcastf64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf64x2.512"]
        pub fn avx512_mask_broadcastf64x2_512(a: ::simdty::f64x2, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.broadcastf64x4.512` intrinsic; known as `__builtin_ia32_broadcastf64x4_512` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcastf64x4.512"]
        pub fn avx512_mask_broadcastf64x4_512(a: ::simdty::f64x4, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.broadcasti32x4.256` intrinsic; known as `__builtin_ia32_broadcasti32x4_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x4.256"]
        pub fn avx512_mask_broadcasti32x4_256(a: ::simdty::i32x4, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.broadcasti32x4.512` intrinsic; known as `__builtin_ia32_broadcasti32x4_512` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x4.512"]
        pub fn avx512_mask_broadcasti32x4_512(a: ::simdty::i32x4, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.broadcasti32x8.512` intrinsic; known as `__builtin_ia32_broadcasti32x8_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti32x8.512"]
        pub fn avx512_mask_broadcasti32x8_512(a: ::simdty::i32x8, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.broadcasti64x2.256` intrinsic; known as `__builtin_ia32_broadcasti64x2_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti64x2.256"]
        pub fn avx512_mask_broadcasti64x2_256(a: ::simdty::i64x2, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.broadcasti64x2.512` intrinsic; known as `__builtin_ia32_broadcasti64x2_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti64x2.512"]
        pub fn avx512_mask_broadcasti64x2_512(a: ::simdty::i64x2, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.broadcasti64x4.512` intrinsic; known as `__builtin_ia32_broadcasti64x4_512` in GCC.
        #[link_name = "llvm.x86.avx512.mask.broadcasti64x4.512"]
        pub fn avx512_mask_broadcasti64x4_512(a: ::simdty::i64x4, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.broadcastmw.512` intrinsic; known as `__builtin_ia32_broadcastmw512` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmw.512"]
        pub fn avx512_broadcastmw_512(a: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.broadcastmw.256` intrinsic; known as `__builtin_ia32_broadcastmw256` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmw.256"]
        pub fn avx512_broadcastmw_256(a: i16) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.broadcastmw.128` intrinsic; known as `__builtin_ia32_broadcastmw128` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmw.128"]
        pub fn avx512_broadcastmw_128(a: i16) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.broadcastmb.512` intrinsic; known as `__builtin_ia32_broadcastmb512` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmb.512"]
        pub fn avx512_broadcastmb_512(a: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.broadcastmb.256` intrinsic; known as `__builtin_ia32_broadcastmb256` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmb.256"]
        pub fn avx512_broadcastmb_256(a: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.broadcastmb.128` intrinsic; known as `__builtin_ia32_broadcastmb128` in GCC.
        #[link_name = "llvm.x86.avx512.broadcastmb.128"]
        pub fn avx512_broadcastmb_128(a: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.pmovzxbq` intrinsic; known as `__builtin_ia32_pmovzxbq512` in GCC.
        #[link_name = "llvm.x86.avx512.pmovzxbq"]
        pub fn avx512_pmovzxbq(a: ::simdty::i8x16) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.pmovzxwd` intrinsic; known as `__builtin_ia32_pmovzxwd512` in GCC.
        #[link_name = "llvm.x86.avx512.pmovzxwd"]
        pub fn avx512_pmovzxwd(a: ::simdty::i16x16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.pmovzxbd` intrinsic; known as `__builtin_ia32_pmovzxbd512` in GCC.
        #[link_name = "llvm.x86.avx512.pmovzxbd"]
        pub fn avx512_pmovzxbd(a: ::simdty::i8x16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.pmovzxwq` intrinsic; known as `__builtin_ia32_pmovzxwq512` in GCC.
        #[link_name = "llvm.x86.avx512.pmovzxwq"]
        pub fn avx512_pmovzxwq(a: ::simdty::i16x8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.pmovzxdq` intrinsic; known as `__builtin_ia32_pmovzxdq512` in GCC.
        #[link_name = "llvm.x86.avx512.pmovzxdq"]
        pub fn avx512_pmovzxdq(a: ::simdty::i32x8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmovzxb.d.128` intrinsic; known as `__builtin_ia32_pmovzxbd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.d.128"]
        pub fn avx512_mask_pmovzxb_d_128(a: ::simdty::i8x16, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovzxb.d.256` intrinsic; known as `__builtin_ia32_pmovzxbd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.d.256"]
        pub fn avx512_mask_pmovzxb_d_256(a: ::simdty::i8x16, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovzxb.d.512` intrinsic; known as `__builtin_ia32_pmovzxbd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.d.512"]
        pub fn avx512_mask_pmovzxb_d_512(a: ::simdty::i8x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmovzxb.q.128` intrinsic; known as `__builtin_ia32_pmovzxbq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.q.128"]
        pub fn avx512_mask_pmovzxb_q_128(a: ::simdty::i8x16, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovzxb.q.256` intrinsic; known as `__builtin_ia32_pmovzxbq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.q.256"]
        pub fn avx512_mask_pmovzxb_q_256(a: ::simdty::i8x16, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovzxb.q.512` intrinsic; known as `__builtin_ia32_pmovzxbq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.q.512"]
        pub fn avx512_mask_pmovzxb_q_512(a: ::simdty::i8x16, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmovzxb.w.128` intrinsic; known as `__builtin_ia32_pmovzxbw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.w.128"]
        pub fn avx512_mask_pmovzxb_w_128(a: ::simdty::i8x16, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovzxb.w.256` intrinsic; known as `__builtin_ia32_pmovzxbw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.w.256"]
        pub fn avx512_mask_pmovzxb_w_256(a: ::simdty::i8x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmovzxb.w.512` intrinsic; known as `__builtin_ia32_pmovzxbw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxb.w.512"]
        pub fn avx512_mask_pmovzxb_w_512(a: ::simdty::i8x32, b: ::simdty::i16x32, c: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmovzxd.q.128` intrinsic; known as `__builtin_ia32_pmovzxdq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxd.q.128"]
        pub fn avx512_mask_pmovzxd_q_128(a: ::simdty::i32x4, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovzxd.q.256` intrinsic; known as `__builtin_ia32_pmovzxdq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxd.q.256"]
        pub fn avx512_mask_pmovzxd_q_256(a: ::simdty::i32x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovzxd.q.512` intrinsic; known as `__builtin_ia32_pmovzxdq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxd.q.512"]
        pub fn avx512_mask_pmovzxd_q_512(a: ::simdty::i32x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmovzxw.d.128` intrinsic; known as `__builtin_ia32_pmovzxwd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.d.128"]
        pub fn avx512_mask_pmovzxw_d_128(a: ::simdty::i16x8, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovzxw.d.256` intrinsic; known as `__builtin_ia32_pmovzxwd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.d.256"]
        pub fn avx512_mask_pmovzxw_d_256(a: ::simdty::i16x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovzxw.d.512` intrinsic; known as `__builtin_ia32_pmovzxwd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.d.512"]
        pub fn avx512_mask_pmovzxw_d_512(a: ::simdty::i16x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmovzxw.q.128` intrinsic; known as `__builtin_ia32_pmovzxwq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.q.128"]
        pub fn avx512_mask_pmovzxw_q_128(a: ::simdty::i16x8, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmovzxw.q.256` intrinsic; known as `__builtin_ia32_pmovzxwq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.q.256"]
        pub fn avx512_mask_pmovzxw_q_256(a: ::simdty::i16x8, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmovzxw.q.512` intrinsic; known as `__builtin_ia32_pmovzxwq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovzxw.q.512"]
        pub fn avx512_mask_pmovzxw_q_512(a: ::simdty::i16x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.add.ps.128` intrinsic; known as `__builtin_ia32_addps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.ps.128"]
        pub fn avx512_mask_add_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.add.ps.256` intrinsic; known as `__builtin_ia32_addps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.ps.256"]
        pub fn avx512_mask_add_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.add.ps.512` intrinsic; known as `__builtin_ia32_addps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.ps.512"]
        pub fn avx512_mask_add_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.add.pd.128` intrinsic; known as `__builtin_ia32_addpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.pd.128"]
        pub fn avx512_mask_add_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.add.pd.256` intrinsic; known as `__builtin_ia32_addpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.pd.256"]
        pub fn avx512_mask_add_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.add.pd.512` intrinsic; known as `__builtin_ia32_addpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.pd.512"]
        pub fn avx512_mask_add_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.sub.ps.128` intrinsic; known as `__builtin_ia32_subps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.ps.128"]
        pub fn avx512_mask_sub_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.sub.ps.256` intrinsic; known as `__builtin_ia32_subps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.ps.256"]
        pub fn avx512_mask_sub_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.sub.ps.512` intrinsic; known as `__builtin_ia32_subps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.ps.512"]
        pub fn avx512_mask_sub_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.sub.pd.128` intrinsic; known as `__builtin_ia32_subpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.pd.128"]
        pub fn avx512_mask_sub_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.sub.pd.256` intrinsic; known as `__builtin_ia32_subpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.pd.256"]
        pub fn avx512_mask_sub_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.sub.pd.512` intrinsic; known as `__builtin_ia32_subpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.pd.512"]
        pub fn avx512_mask_sub_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.mul.ps.128` intrinsic; known as `__builtin_ia32_mulps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.ps.128"]
        pub fn avx512_mask_mul_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.mul.ps.256` intrinsic; known as `__builtin_ia32_mulps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.ps.256"]
        pub fn avx512_mask_mul_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.mul.ps.512` intrinsic; known as `__builtin_ia32_mulps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.ps.512"]
        pub fn avx512_mask_mul_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.mul.pd.128` intrinsic; known as `__builtin_ia32_mulpd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.pd.128"]
        pub fn avx512_mask_mul_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.mul.pd.256` intrinsic; known as `__builtin_ia32_mulpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.pd.256"]
        pub fn avx512_mask_mul_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.mul.pd.512` intrinsic; known as `__builtin_ia32_mulpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.pd.512"]
        pub fn avx512_mask_mul_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.div.ps.128` intrinsic; known as `__builtin_ia32_divps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.ps.128"]
        pub fn avx512_mask_div_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.div.ps.256` intrinsic; known as `__builtin_ia32_divps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.ps.256"]
        pub fn avx512_mask_div_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.div.ps.512` intrinsic; known as `__builtin_ia32_divps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.ps.512"]
        pub fn avx512_mask_div_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.div.pd.128` intrinsic; known as `__builtin_ia32_divpd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.pd.128"]
        pub fn avx512_mask_div_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.div.pd.256` intrinsic; known as `__builtin_ia32_divpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.pd.256"]
        pub fn avx512_mask_div_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.div.pd.512` intrinsic; known as `__builtin_ia32_divpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.pd.512"]
        pub fn avx512_mask_div_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.max.ps.128` intrinsic; known as `__builtin_ia32_maxps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.ps.128"]
        pub fn avx512_mask_max_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.max.ps.256` intrinsic; known as `__builtin_ia32_maxps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.ps.256"]
        pub fn avx512_mask_max_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.max.ps.512` intrinsic; known as `__builtin_ia32_maxps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.ps.512"]
        pub fn avx512_mask_max_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.max.pd.128` intrinsic; known as `__builtin_ia32_maxpd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.pd.128"]
        pub fn avx512_mask_max_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.max.pd.256` intrinsic; known as `__builtin_ia32_maxpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.pd.256"]
        pub fn avx512_mask_max_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.max.pd.512` intrinsic; known as `__builtin_ia32_maxpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.pd.512"]
        pub fn avx512_mask_max_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.min.ps.128` intrinsic; known as `__builtin_ia32_minps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.ps.128"]
        pub fn avx512_mask_min_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.min.ps.256` intrinsic; known as `__builtin_ia32_minps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.ps.256"]
        pub fn avx512_mask_min_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.min.ps.512` intrinsic; known as `__builtin_ia32_minps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.ps.512"]
        pub fn avx512_mask_min_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.min.pd.128` intrinsic; known as `__builtin_ia32_minpd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.pd.128"]
        pub fn avx512_mask_min_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.min.pd.256` intrinsic; known as `__builtin_ia32_minpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.pd.256"]
        pub fn avx512_mask_min_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.min.pd.512` intrinsic; known as `__builtin_ia32_minpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.pd.512"]
        pub fn avx512_mask_min_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.add.ss.round` intrinsic; known as `__builtin_ia32_addss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.ss.round"]
        pub fn avx512_mask_add_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.div.ss.round` intrinsic; known as `__builtin_ia32_divss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.ss.round"]
        pub fn avx512_mask_div_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.mul.ss.round` intrinsic; known as `__builtin_ia32_mulss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.ss.round"]
        pub fn avx512_mask_mul_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.sub.ss.round` intrinsic; known as `__builtin_ia32_subss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.ss.round"]
        pub fn avx512_mask_sub_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.max.ss.round` intrinsic; known as `__builtin_ia32_maxss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.ss.round"]
        pub fn avx512_mask_max_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.min.ss.round` intrinsic; known as `__builtin_ia32_minss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.ss.round"]
        pub fn avx512_mask_min_ss_round(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.add.sd.round` intrinsic; known as `__builtin_ia32_addsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.add.sd.round"]
        pub fn avx512_mask_add_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.div.sd.round` intrinsic; known as `__builtin_ia32_divsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.div.sd.round"]
        pub fn avx512_mask_div_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.mul.sd.round` intrinsic; known as `__builtin_ia32_mulsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.mul.sd.round"]
        pub fn avx512_mask_mul_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.sub.sd.round` intrinsic; known as `__builtin_ia32_subsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sub.sd.round"]
        pub fn avx512_mask_sub_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.max.sd.round` intrinsic; known as `__builtin_ia32_maxsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.max.sd.round"]
        pub fn avx512_mask_max_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.min.sd.round` intrinsic; known as `__builtin_ia32_minsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.min.sd.round"]
        pub fn avx512_mask_min_sd_round(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.rndscale.ss` intrinsic; known as `__builtin_ia32_rndscaless_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.ss"]
        pub fn avx512_mask_rndscale_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.rndscale.sd` intrinsic; known as `__builtin_ia32_rndscalesd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.rndscale.sd"]
        pub fn avx512_mask_rndscale_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.range.ss` intrinsic; known as `__builtin_ia32_rangess128_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.ss"]
        pub fn avx512_mask_range_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.range.sd` intrinsic; known as `__builtin_ia32_rangesd128_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.range.sd"]
        pub fn avx512_mask_range_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.reduce.ss` intrinsic; known as `__builtin_ia32_reducess_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.ss"]
        pub fn avx512_mask_reduce_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.reduce.sd` intrinsic; known as `__builtin_ia32_reducesd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.reduce.sd"]
        pub fn avx512_mask_reduce_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.scalef.sd` intrinsic; known as `__builtin_ia32_scalefsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.sd"]
        pub fn avx512_mask_scalef_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.scalef.ss` intrinsic; known as `__builtin_ia32_scalefss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.ss"]
        pub fn avx512_mask_scalef_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.scalef.pd.128` intrinsic; known as `__builtin_ia32_scalefpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.pd.128"]
        pub fn avx512_mask_scalef_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.scalef.pd.256` intrinsic; known as `__builtin_ia32_scalefpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.pd.256"]
        pub fn avx512_mask_scalef_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.scalef.pd.512` intrinsic; known as `__builtin_ia32_scalefpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.pd.512"]
        pub fn avx512_mask_scalef_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.scalef.ps.128` intrinsic; known as `__builtin_ia32_scalefps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.ps.128"]
        pub fn avx512_mask_scalef_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.scalef.ps.256` intrinsic; known as `__builtin_ia32_scalefps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.ps.256"]
        pub fn avx512_mask_scalef_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.scalef.ps.512` intrinsic; known as `__builtin_ia32_scalefps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.scalef.ps.512"]
        pub fn avx512_mask_scalef_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.sqrt.ss` intrinsic; known as `__builtin_ia32_sqrtss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.ss"]
        pub fn avx512_mask_sqrt_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.sqrt.sd` intrinsic; known as `__builtin_ia32_sqrtsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.sd"]
        pub fn avx512_mask_sqrt_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.sqrt.pd.128` intrinsic; known as `__builtin_ia32_sqrtpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.pd.128"]
        pub fn avx512_mask_sqrt_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.sqrt.pd.256` intrinsic; known as `__builtin_ia32_sqrtpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.pd.256"]
        pub fn avx512_mask_sqrt_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.sqrt.pd.512` intrinsic; known as `__builtin_ia32_sqrtpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.pd.512"]
        pub fn avx512_mask_sqrt_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.sqrt.ps.128` intrinsic; known as `__builtin_ia32_sqrtps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.ps.128"]
        pub fn avx512_mask_sqrt_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.sqrt.ps.256` intrinsic; known as `__builtin_ia32_sqrtps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.ps.256"]
        pub fn avx512_mask_sqrt_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.sqrt.ps.512` intrinsic; known as `__builtin_ia32_sqrtps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.sqrt.ps.512"]
        pub fn avx512_mask_sqrt_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.fixupimm.pd.128` intrinsic; known as `__builtin_ia32_fixupimmpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.pd.128"]
        pub fn avx512_mask_fixupimm_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::i64x2, d: i32, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.fixupimm.pd.128` intrinsic; known as `__builtin_ia32_fixupimmpd128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.pd.128"]
        pub fn avx512_maskz_fixupimm_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::i64x2, d: i32, e: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.fixupimm.pd.256` intrinsic; known as `__builtin_ia32_fixupimmpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.pd.256"]
        pub fn avx512_mask_fixupimm_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::i64x4, d: i32, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.maskz.fixupimm.pd.256` intrinsic; known as `__builtin_ia32_fixupimmpd256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.pd.256"]
        pub fn avx512_maskz_fixupimm_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::i64x4, d: i32, e: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.fixupimm.pd.512` intrinsic; known as `__builtin_ia32_fixupimmpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.pd.512"]
        pub fn avx512_mask_fixupimm_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::i64x8, d: i32, e: i8, f: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.maskz.fixupimm.pd.512` intrinsic; known as `__builtin_ia32_fixupimmpd512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.pd.512"]
        pub fn avx512_maskz_fixupimm_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::i64x8, d: i32, e: i8, f: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.fixupimm.ps.128` intrinsic; known as `__builtin_ia32_fixupimmps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.ps.128"]
        pub fn avx512_mask_fixupimm_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::i32x4, d: i32, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.fixupimm.ps.128` intrinsic; known as `__builtin_ia32_fixupimmps128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.ps.128"]
        pub fn avx512_maskz_fixupimm_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::i32x4, d: i32, e: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.fixupimm.ps.256` intrinsic; known as `__builtin_ia32_fixupimmps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.ps.256"]
        pub fn avx512_mask_fixupimm_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::i32x8, d: i32, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.maskz.fixupimm.ps.256` intrinsic; known as `__builtin_ia32_fixupimmps256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.ps.256"]
        pub fn avx512_maskz_fixupimm_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::i32x8, d: i32, e: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.fixupimm.ps.512` intrinsic; known as `__builtin_ia32_fixupimmps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.ps.512"]
        pub fn avx512_mask_fixupimm_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::i32x16, d: i32, e: i16, f: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.maskz.fixupimm.ps.512` intrinsic; known as `__builtin_ia32_fixupimmps512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.ps.512"]
        pub fn avx512_maskz_fixupimm_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::i32x16, d: i32, e: i16, f: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.fixupimm.sd` intrinsic; known as `__builtin_ia32_fixupimmsd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.sd"]
        pub fn avx512_mask_fixupimm_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::i64x2, d: i32, e: i8, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.maskz.fixupimm.sd` intrinsic; known as `__builtin_ia32_fixupimmsd_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.sd"]
        pub fn avx512_maskz_fixupimm_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::i64x2, d: i32, e: i8, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.fixupimm.ss` intrinsic; known as `__builtin_ia32_fixupimmss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.fixupimm.ss"]
        pub fn avx512_mask_fixupimm_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::i32x4, d: i32, e: i8, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.maskz.fixupimm.ss` intrinsic; known as `__builtin_ia32_fixupimmss_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.fixupimm.ss"]
        pub fn avx512_maskz_fixupimm_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::i32x4, d: i32, e: i8, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.getexp.pd.128` intrinsic; known as `__builtin_ia32_getexppd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.pd.128"]
        pub fn avx512_mask_getexp_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.getexp.pd.256` intrinsic; known as `__builtin_ia32_getexppd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.pd.256"]
        pub fn avx512_mask_getexp_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.getexp.pd.512` intrinsic; known as `__builtin_ia32_getexppd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.pd.512"]
        pub fn avx512_mask_getexp_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.getexp.ps.128` intrinsic; known as `__builtin_ia32_getexpps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.ps.128"]
        pub fn avx512_mask_getexp_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.getexp.ps.256` intrinsic; known as `__builtin_ia32_getexpps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.ps.256"]
        pub fn avx512_mask_getexp_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.getexp.ps.512` intrinsic; known as `__builtin_ia32_getexpps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.ps.512"]
        pub fn avx512_mask_getexp_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.getexp.ss` intrinsic; known as `__builtin_ia32_getexpss128_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.ss"]
        pub fn avx512_mask_getexp_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.getexp.sd` intrinsic; known as `__builtin_ia32_getexpsd128_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getexp.sd"]
        pub fn avx512_mask_getexp_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.getmant.pd.128` intrinsic; known as `__builtin_ia32_getmantpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.pd.128"]
        pub fn avx512_mask_getmant_pd_128(a: ::simdty::f64x2, b: i32, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.getmant.pd.256` intrinsic; known as `__builtin_ia32_getmantpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.pd.256"]
        pub fn avx512_mask_getmant_pd_256(a: ::simdty::f64x4, b: i32, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.getmant.pd.512` intrinsic; known as `__builtin_ia32_getmantpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.pd.512"]
        pub fn avx512_mask_getmant_pd_512(a: ::simdty::f64x8, b: i32, c: ::simdty::f64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.getmant.ps.128` intrinsic; known as `__builtin_ia32_getmantps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.ps.128"]
        pub fn avx512_mask_getmant_ps_128(a: ::simdty::f32x4, b: i32, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.getmant.ps.256` intrinsic; known as `__builtin_ia32_getmantps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.ps.256"]
        pub fn avx512_mask_getmant_ps_256(a: ::simdty::f32x8, b: i32, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.getmant.ps.512` intrinsic; known as `__builtin_ia32_getmantps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.ps.512"]
        pub fn avx512_mask_getmant_ps_512(a: ::simdty::f32x16, b: i32, c: ::simdty::f32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.getmant.ss` intrinsic; known as `__builtin_ia32_getmantss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.ss"]
        pub fn avx512_mask_getmant_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: ::simdty::f32x4, e: i8, f: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.getmant.sd` intrinsic; known as `__builtin_ia32_getmantsd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.getmant.sd"]
        pub fn avx512_mask_getmant_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: ::simdty::f64x2, e: i8, f: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rsqrt14.ss` intrinsic; known as `__builtin_ia32_rsqrt14ss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.ss"]
        pub fn avx512_rsqrt14_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rsqrt14.sd` intrinsic; known as `__builtin_ia32_rsqrt14sd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.sd"]
        pub fn avx512_rsqrt14_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rsqrt14.pd.128` intrinsic; known as `__builtin_ia32_rsqrt14pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.pd.128"]
        pub fn avx512_rsqrt14_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rsqrt14.pd.256` intrinsic; known as `__builtin_ia32_rsqrt14pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.pd.256"]
        pub fn avx512_rsqrt14_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.rsqrt14.pd.512` intrinsic; known as `__builtin_ia32_rsqrt14pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.pd.512"]
        pub fn avx512_rsqrt14_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.rsqrt14.ps.128` intrinsic; known as `__builtin_ia32_rsqrt14ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.ps.128"]
        pub fn avx512_rsqrt14_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rsqrt14.ps.256` intrinsic; known as `__builtin_ia32_rsqrt14ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.ps.256"]
        pub fn avx512_rsqrt14_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.rsqrt14.ps.512` intrinsic; known as `__builtin_ia32_rsqrt14ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt14.ps.512"]
        pub fn avx512_rsqrt14_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.rcp14.ss` intrinsic; known as `__builtin_ia32_rcp14ss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.ss"]
        pub fn avx512_rcp14_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rcp14.sd` intrinsic; known as `__builtin_ia32_rcp14sd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.sd"]
        pub fn avx512_rcp14_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rcp14.pd.128` intrinsic; known as `__builtin_ia32_rcp14pd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.pd.128"]
        pub fn avx512_rcp14_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rcp14.pd.256` intrinsic; known as `__builtin_ia32_rcp14pd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.pd.256"]
        pub fn avx512_rcp14_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.rcp14.pd.512` intrinsic; known as `__builtin_ia32_rcp14pd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.pd.512"]
        pub fn avx512_rcp14_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.rcp14.ps.128` intrinsic; known as `__builtin_ia32_rcp14ps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.ps.128"]
        pub fn avx512_rcp14_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rcp14.ps.256` intrinsic; known as `__builtin_ia32_rcp14ps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.ps.256"]
        pub fn avx512_rcp14_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.rcp14.ps.512` intrinsic; known as `__builtin_ia32_rcp14ps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp14.ps.512"]
        pub fn avx512_rcp14_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.rcp28.ps` intrinsic; known as `__builtin_ia32_rcp28ps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp28.ps"]
        pub fn avx512_rcp28_ps(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.rcp28.pd` intrinsic; known as `__builtin_ia32_rcp28pd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp28.pd"]
        pub fn avx512_rcp28_pd(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.exp2.ps` intrinsic; known as `__builtin_ia32_exp2ps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.exp2.ps"]
        pub fn avx512_exp2_ps(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.exp2.pd` intrinsic; known as `__builtin_ia32_exp2pd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.exp2.pd"]
        pub fn avx512_exp2_pd(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.rcp28.ss` intrinsic; known as `__builtin_ia32_rcp28ss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp28.ss"]
        pub fn avx512_rcp28_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rcp28.sd` intrinsic; known as `__builtin_ia32_rcp28sd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rcp28.sd"]
        pub fn avx512_rcp28_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.rsqrt28.ps` intrinsic; known as `__builtin_ia32_rsqrt28ps_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt28.ps"]
        pub fn avx512_rsqrt28_ps(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16, d: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.rsqrt28.pd` intrinsic; known as `__builtin_ia32_rsqrt28pd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt28.pd"]
        pub fn avx512_rsqrt28_pd(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8, d: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.rsqrt28.ss` intrinsic; known as `__builtin_ia32_rsqrt28ss_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt28.ss"]
        pub fn avx512_rsqrt28_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.rsqrt28.sd` intrinsic; known as `__builtin_ia32_rsqrt28sd_round_mask` in GCC.
        #[link_name = "llvm.x86.avx512.rsqrt28.sd"]
        pub fn avx512_rsqrt28_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.psad.bw.512` intrinsic; known as `__builtin_ia32_psadbw512` in GCC.
        #[link_name = "llvm.x86.avx512.psad.bw.512"]
        pub fn avx512_psad_bw_512(a: ::simdty::i8x64, b: ::simdty::i8x64) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.and.pd.128` intrinsic; known as `__builtin_ia32_andpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.pd.128"]
        pub fn avx512_mask_and_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.and.pd.256` intrinsic; known as `__builtin_ia32_andpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.pd.256"]
        pub fn avx512_mask_and_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.and.pd.512` intrinsic; known as `__builtin_ia32_andpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.pd.512"]
        pub fn avx512_mask_and_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.and.ps.128` intrinsic; known as `__builtin_ia32_andps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.ps.128"]
        pub fn avx512_mask_and_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.and.ps.256` intrinsic; known as `__builtin_ia32_andps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.ps.256"]
        pub fn avx512_mask_and_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.and.ps.512` intrinsic; known as `__builtin_ia32_andps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.and.ps.512"]
        pub fn avx512_mask_and_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.andn.pd.128` intrinsic; known as `__builtin_ia32_andnpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.pd.128"]
        pub fn avx512_mask_andn_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.andn.pd.256` intrinsic; known as `__builtin_ia32_andnpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.pd.256"]
        pub fn avx512_mask_andn_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.andn.pd.512` intrinsic; known as `__builtin_ia32_andnpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.pd.512"]
        pub fn avx512_mask_andn_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.andn.ps.128` intrinsic; known as `__builtin_ia32_andnps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.ps.128"]
        pub fn avx512_mask_andn_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.andn.ps.256` intrinsic; known as `__builtin_ia32_andnps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.ps.256"]
        pub fn avx512_mask_andn_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.andn.ps.512` intrinsic; known as `__builtin_ia32_andnps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.andn.ps.512"]
        pub fn avx512_mask_andn_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.or.pd.128` intrinsic; known as `__builtin_ia32_orpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.pd.128"]
        pub fn avx512_mask_or_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.or.pd.256` intrinsic; known as `__builtin_ia32_orpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.pd.256"]
        pub fn avx512_mask_or_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.or.pd.512` intrinsic; known as `__builtin_ia32_orpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.pd.512"]
        pub fn avx512_mask_or_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.or.ps.128` intrinsic; known as `__builtin_ia32_orps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.ps.128"]
        pub fn avx512_mask_or_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.or.ps.256` intrinsic; known as `__builtin_ia32_orps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.ps.256"]
        pub fn avx512_mask_or_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.or.ps.512` intrinsic; known as `__builtin_ia32_orps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.or.ps.512"]
        pub fn avx512_mask_or_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.xor.pd.128` intrinsic; known as `__builtin_ia32_xorpd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.pd.128"]
        pub fn avx512_mask_xor_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: ::simdty::f64x2, d: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.xor.pd.256` intrinsic; known as `__builtin_ia32_xorpd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.pd.256"]
        pub fn avx512_mask_xor_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: ::simdty::f64x4, d: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.xor.pd.512` intrinsic; known as `__builtin_ia32_xorpd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.pd.512"]
        pub fn avx512_mask_xor_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: ::simdty::f64x8, d: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.xor.ps.128` intrinsic; known as `__builtin_ia32_xorps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.ps.128"]
        pub fn avx512_mask_xor_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: ::simdty::f32x4, d: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.xor.ps.256` intrinsic; known as `__builtin_ia32_xorps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.ps.256"]
        pub fn avx512_mask_xor_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: ::simdty::f32x8, d: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.xor.ps.512` intrinsic; known as `__builtin_ia32_xorps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.xor.ps.512"]
        pub fn avx512_mask_xor_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: ::simdty::f32x16, d: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.padd.b.128` intrinsic; known as `__builtin_ia32_paddb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.b.128"]
        pub fn avx512_mask_padd_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.padd.b.256` intrinsic; known as `__builtin_ia32_paddb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.b.256"]
        pub fn avx512_mask_padd_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.padd.b.512` intrinsic; known as `__builtin_ia32_paddb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.b.512"]
        pub fn avx512_mask_padd_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.padd.w.128` intrinsic; known as `__builtin_ia32_paddw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.w.128"]
        pub fn avx512_mask_padd_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.padd.w.256` intrinsic; known as `__builtin_ia32_paddw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.w.256"]
        pub fn avx512_mask_padd_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.padd.w.512` intrinsic; known as `__builtin_ia32_paddw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.w.512"]
        pub fn avx512_mask_padd_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.padds.b.128` intrinsic; known as `__builtin_ia32_paddsb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.b.128"]
        pub fn avx512_mask_padds_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.padds.b.256` intrinsic; known as `__builtin_ia32_paddsb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.b.256"]
        pub fn avx512_mask_padds_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.padds.b.512` intrinsic; known as `__builtin_ia32_paddsb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.b.512"]
        pub fn avx512_mask_padds_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.padds.w.128` intrinsic; known as `__builtin_ia32_paddsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.w.128"]
        pub fn avx512_mask_padds_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.padds.w.256` intrinsic; known as `__builtin_ia32_paddsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.w.256"]
        pub fn avx512_mask_padds_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.padds.w.512` intrinsic; known as `__builtin_ia32_paddsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padds.w.512"]
        pub fn avx512_mask_padds_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.paddus.b.128` intrinsic; known as `__builtin_ia32_paddusb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.b.128"]
        pub fn avx512_mask_paddus_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.paddus.b.256` intrinsic; known as `__builtin_ia32_paddusb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.b.256"]
        pub fn avx512_mask_paddus_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.paddus.b.512` intrinsic; known as `__builtin_ia32_paddusb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.b.512"]
        pub fn avx512_mask_paddus_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.paddus.w.128` intrinsic; known as `__builtin_ia32_paddusw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.w.128"]
        pub fn avx512_mask_paddus_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.paddus.w.256` intrinsic; known as `__builtin_ia32_paddusw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.w.256"]
        pub fn avx512_mask_paddus_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.paddus.w.512` intrinsic; known as `__builtin_ia32_paddusw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.paddus.w.512"]
        pub fn avx512_mask_paddus_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.padd.d.128` intrinsic; known as `__builtin_ia32_paddd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.d.128"]
        pub fn avx512_mask_padd_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.padd.d.256` intrinsic; known as `__builtin_ia32_paddd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.d.256"]
        pub fn avx512_mask_padd_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.padd.d.512` intrinsic; known as `__builtin_ia32_paddd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.d.512"]
        pub fn avx512_mask_padd_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.padd.q.128` intrinsic; known as `__builtin_ia32_paddq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.q.128"]
        pub fn avx512_mask_padd_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.padd.q.256` intrinsic; known as `__builtin_ia32_paddq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.q.256"]
        pub fn avx512_mask_padd_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.padd.q.512` intrinsic; known as `__builtin_ia32_paddq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.padd.q.512"]
        pub fn avx512_mask_padd_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.psub.b.128` intrinsic; known as `__builtin_ia32_psubb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.b.128"]
        pub fn avx512_mask_psub_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.psub.b.256` intrinsic; known as `__builtin_ia32_psubb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.b.256"]
        pub fn avx512_mask_psub_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.psub.b.512` intrinsic; known as `__builtin_ia32_psubb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.b.512"]
        pub fn avx512_mask_psub_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.psub.w.128` intrinsic; known as `__builtin_ia32_psubw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.w.128"]
        pub fn avx512_mask_psub_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psub.w.256` intrinsic; known as `__builtin_ia32_psubw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.w.256"]
        pub fn avx512_mask_psub_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psub.w.512` intrinsic; known as `__builtin_ia32_psubw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.w.512"]
        pub fn avx512_mask_psub_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psubs.b.128` intrinsic; known as `__builtin_ia32_psubsb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.b.128"]
        pub fn avx512_mask_psubs_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.psubs.b.256` intrinsic; known as `__builtin_ia32_psubsb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.b.256"]
        pub fn avx512_mask_psubs_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.psubs.b.512` intrinsic; known as `__builtin_ia32_psubsb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.b.512"]
        pub fn avx512_mask_psubs_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.psubs.w.128` intrinsic; known as `__builtin_ia32_psubsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.w.128"]
        pub fn avx512_mask_psubs_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psubs.w.256` intrinsic; known as `__builtin_ia32_psubsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.w.256"]
        pub fn avx512_mask_psubs_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psubs.w.512` intrinsic; known as `__builtin_ia32_psubsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubs.w.512"]
        pub fn avx512_mask_psubs_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psubus.b.128` intrinsic; known as `__builtin_ia32_psubusb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.b.128"]
        pub fn avx512_mask_psubus_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.psubus.b.256` intrinsic; known as `__builtin_ia32_psubusb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.b.256"]
        pub fn avx512_mask_psubus_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.psubus.b.512` intrinsic; known as `__builtin_ia32_psubusb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.b.512"]
        pub fn avx512_mask_psubus_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.psubus.w.128` intrinsic; known as `__builtin_ia32_psubusw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.w.128"]
        pub fn avx512_mask_psubus_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.psubus.w.256` intrinsic; known as `__builtin_ia32_psubusw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.w.256"]
        pub fn avx512_mask_psubus_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.psubus.w.512` intrinsic; known as `__builtin_ia32_psubusw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psubus.w.512"]
        pub fn avx512_mask_psubus_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.psub.d.128` intrinsic; known as `__builtin_ia32_psubd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.d.128"]
        pub fn avx512_mask_psub_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.psub.d.256` intrinsic; known as `__builtin_ia32_psubd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.d.256"]
        pub fn avx512_mask_psub_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.psub.d.512` intrinsic; known as `__builtin_ia32_psubd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.d.512"]
        pub fn avx512_mask_psub_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.psub.q.128` intrinsic; known as `__builtin_ia32_psubq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.q.128"]
        pub fn avx512_mask_psub_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.psub.q.256` intrinsic; known as `__builtin_ia32_psubq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.q.256"]
        pub fn avx512_mask_psub_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.psub.q.512` intrinsic; known as `__builtin_ia32_psubq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.psub.q.512"]
        pub fn avx512_mask_psub_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmulu.dq.128` intrinsic; known as `__builtin_ia32_pmuludq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulu.dq.128"]
        pub fn avx512_mask_pmulu_dq_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmul.dq.128` intrinsic; known as `__builtin_ia32_pmuldq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.dq.128"]
        pub fn avx512_mask_pmul_dq_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmulu.dq.256` intrinsic; known as `__builtin_ia32_pmuludq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulu.dq.256"]
        pub fn avx512_mask_pmulu_dq_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmul.dq.256` intrinsic; known as `__builtin_ia32_pmuldq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.dq.256"]
        pub fn avx512_mask_pmul_dq_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmulu.dq.512` intrinsic; known as `__builtin_ia32_pmuludq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulu.dq.512"]
        pub fn avx512_mask_pmulu_dq_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmul.dq.512` intrinsic; known as `__builtin_ia32_pmuldq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmul.dq.512"]
        pub fn avx512_mask_pmul_dq_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmull.w.128` intrinsic; known as `__builtin_ia32_pmullw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.w.128"]
        pub fn avx512_mask_pmull_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmull.w.256` intrinsic; known as `__builtin_ia32_pmullw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.w.256"]
        pub fn avx512_mask_pmull_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmull.w.512` intrinsic; known as `__builtin_ia32_pmullw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.w.512"]
        pub fn avx512_mask_pmull_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmull.d.128` intrinsic; known as `__builtin_ia32_pmulld128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.d.128"]
        pub fn avx512_mask_pmull_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmull.d.256` intrinsic; known as `__builtin_ia32_pmulld256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.d.256"]
        pub fn avx512_mask_pmull_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmull.d.512` intrinsic; known as `__builtin_ia32_pmulld512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.d.512"]
        pub fn avx512_mask_pmull_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmull.q.128` intrinsic; known as `__builtin_ia32_pmullq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.q.128"]
        pub fn avx512_mask_pmull_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmull.q.256` intrinsic; known as `__builtin_ia32_pmullq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.q.256"]
        pub fn avx512_mask_pmull_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pmull.q.512` intrinsic; known as `__builtin_ia32_pmullq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmull.q.512"]
        pub fn avx512_mask_pmull_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.pmulhu.w.512` intrinsic; known as `__builtin_ia32_pmulhuw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulhu.w.512"]
        pub fn avx512_mask_pmulhu_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmulh.w.512` intrinsic; known as `__builtin_ia32_pmulhw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulh.w.512"]
        pub fn avx512_mask_pmulh_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pmulhu.w.128` intrinsic; known as `__builtin_ia32_pmulhuw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulhu.w.128"]
        pub fn avx512_mask_pmulhu_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmulhu.w.256` intrinsic; known as `__builtin_ia32_pmulhuw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulhu.w.256"]
        pub fn avx512_mask_pmulhu_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmulh.w.128` intrinsic; known as `__builtin_ia32_pmulhw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulh.w.128"]
        pub fn avx512_mask_pmulh_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmulh.w.256` intrinsic; known as `__builtin_ia32_pmulhw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmulh.w.256"]
        pub fn avx512_mask_pmulh_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pavg.b.512` intrinsic; known as `__builtin_ia32_pavgb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.b.512"]
        pub fn avx512_mask_pavg_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i8x64, d: i64) -> ::simdty::i8x64;
        /// The `llvm.x86.avx512.mask.pavg.w.512` intrinsic; known as `__builtin_ia32_pavgw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.w.512"]
        pub fn avx512_mask_pavg_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.pavg.b.128` intrinsic; known as `__builtin_ia32_pavgb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.b.128"]
        pub fn avx512_mask_pavg_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i8x16, d: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pavg.b.256` intrinsic; known as `__builtin_ia32_pavgb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.b.256"]
        pub fn avx512_mask_pavg_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i8x32, d: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pavg.w.128` intrinsic; known as `__builtin_ia32_pavgw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.w.128"]
        pub fn avx512_mask_pavg_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pavg.w.256` intrinsic; known as `__builtin_ia32_pavgw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pavg.w.256"]
        pub fn avx512_mask_pavg_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmaddw.d.128` intrinsic; known as `__builtin_ia32_pmaddwd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddw.d.128"]
        pub fn avx512_mask_pmaddw_d_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: ::simdty::i32x4, d: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmaddw.d.256` intrinsic; known as `__builtin_ia32_pmaddwd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddw.d.256"]
        pub fn avx512_mask_pmaddw_d_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: ::simdty::i32x8, d: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmaddw.d.512` intrinsic; known as `__builtin_ia32_pmaddwd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddw.d.512"]
        pub fn avx512_mask_pmaddw_d_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: ::simdty::i32x16, d: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pmaddubs.w.128` intrinsic; known as `__builtin_ia32_pmaddubsw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddubs.w.128"]
        pub fn avx512_mask_pmaddubs_w_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: ::simdty::i16x8, d: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmaddubs.w.256` intrinsic; known as `__builtin_ia32_pmaddubsw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddubs.w.256"]
        pub fn avx512_mask_pmaddubs_w_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: ::simdty::i16x16, d: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmaddubs.w.512` intrinsic; known as `__builtin_ia32_pmaddubsw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmaddubs.w.512"]
        pub fn avx512_mask_pmaddubs_w_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: ::simdty::i16x32, d: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.mask.dbpsadbw.128` intrinsic; known as `__builtin_ia32_dbpsadbw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.dbpsadbw.128"]
        pub fn avx512_mask_dbpsadbw_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32, d: ::simdty::i16x8, e: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.dbpsadbw.256` intrinsic; known as `__builtin_ia32_dbpsadbw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.dbpsadbw.256"]
        pub fn avx512_mask_dbpsadbw_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32, d: ::simdty::i16x16, e: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.dbpsadbw.512` intrinsic; known as `__builtin_ia32_dbpsadbw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.dbpsadbw.512"]
        pub fn avx512_mask_dbpsadbw_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i32, d: ::simdty::i16x32, e: i32) -> ::simdty::i16x32;
        /// The `llvm.x86.avx512.gather.dpd.512` intrinsic; known as `__builtin_ia32_gathersiv8df` in GCC.
        #[link_name = "llvm.x86.avx512.gather.dpd.512"]
        pub fn avx512_gather_dpd_512(a: ::simdty::f64x8, b: *mut i8, c: ::simdty::i32x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.gather.dps.512` intrinsic; known as `__builtin_ia32_gathersiv16sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather.dps.512"]
        pub fn avx512_gather_dps_512(a: ::simdty::f32x16, b: *mut i8, c: ::simdty::i32x16, d: i16, e: i32) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.gather.qpd.512` intrinsic; known as `__builtin_ia32_gatherdiv8df` in GCC.
        #[link_name = "llvm.x86.avx512.gather.qpd.512"]
        pub fn avx512_gather_qpd_512(a: ::simdty::f64x8, b: *mut i8, c: ::simdty::i64x8, d: i8, e: i32) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.gather.qps.512` intrinsic; known as `__builtin_ia32_gatherdiv16sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather.qps.512"]
        pub fn avx512_gather_qps_512(a: ::simdty::f32x8, b: *mut i8, c: ::simdty::i64x8, d: i8, e: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.gather.dpq.512` intrinsic; known as `__builtin_ia32_gathersiv8di` in GCC.
        #[link_name = "llvm.x86.avx512.gather.dpq.512"]
        pub fn avx512_gather_dpq_512(a: ::simdty::i64x8, b: *mut i8, c: ::simdty::i32x8, d: i8, e: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.gather.dpi.512` intrinsic; known as `__builtin_ia32_gathersiv16si` in GCC.
        #[link_name = "llvm.x86.avx512.gather.dpi.512"]
        pub fn avx512_gather_dpi_512(a: ::simdty::i32x16, b: *mut i8, c: ::simdty::i32x16, d: i16, e: i32) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.gather.qpq.512` intrinsic; known as `__builtin_ia32_gatherdiv8di` in GCC.
        #[link_name = "llvm.x86.avx512.gather.qpq.512"]
        pub fn avx512_gather_qpq_512(a: ::simdty::i64x8, b: *mut i8, c: ::simdty::i64x8, d: i8, e: i32) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.gather.qpi.512` intrinsic; known as `__builtin_ia32_gatherdiv16si` in GCC.
        #[link_name = "llvm.x86.avx512.gather.qpi.512"]
        pub fn avx512_gather_qpi_512(a: ::simdty::i32x8, b: *mut i8, c: ::simdty::i64x8, d: i8, e: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.gather3div2.df` intrinsic; known as `__builtin_ia32_gather3div2df` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div2.df"]
        pub fn avx512_gather3div2_df(a: ::simdty::f64x2, b: *mut i8, c: ::simdty::i64x2, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.gather3div2.di` intrinsic; known as `__builtin_ia32_gather3div2di` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div2.di"]
        pub fn avx512_gather3div2_di(a: ::simdty::i64x2, b: *mut i8, c: ::simdty::i64x2, d: i8, e: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.gather3div4.df` intrinsic; known as `__builtin_ia32_gather3div4df` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div4.df"]
        pub fn avx512_gather3div4_df(a: ::simdty::f64x4, b: *mut i8, c: ::simdty::i64x4, d: i8, e: i32) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.gather3div4.di` intrinsic; known as `__builtin_ia32_gather3div4di` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div4.di"]
        pub fn avx512_gather3div4_di(a: ::simdty::i64x4, b: *mut i8, c: ::simdty::i64x4, d: i8, e: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.gather3div4.sf` intrinsic; known as `__builtin_ia32_gather3div4sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div4.sf"]
        pub fn avx512_gather3div4_sf(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i64x2, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.gather3div4.si` intrinsic; known as `__builtin_ia32_gather3div4si` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div4.si"]
        pub fn avx512_gather3div4_si(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i64x2, d: i8, e: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.gather3div8.sf` intrinsic; known as `__builtin_ia32_gather3div8sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div8.sf"]
        pub fn avx512_gather3div8_sf(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i64x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.gather3div8.si` intrinsic; known as `__builtin_ia32_gather3div8si` in GCC.
        #[link_name = "llvm.x86.avx512.gather3div8.si"]
        pub fn avx512_gather3div8_si(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i64x4, d: i8, e: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.gather3siv2.df` intrinsic; known as `__builtin_ia32_gather3siv2df` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv2.df"]
        pub fn avx512_gather3siv2_df(a: ::simdty::f64x2, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.gather3siv2.di` intrinsic; known as `__builtin_ia32_gather3siv2di` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv2.di"]
        pub fn avx512_gather3siv2_di(a: ::simdty::i64x2, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.gather3siv4.df` intrinsic; known as `__builtin_ia32_gather3siv4df` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv4.df"]
        pub fn avx512_gather3siv4_df(a: ::simdty::f64x4, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.gather3siv4.di` intrinsic; known as `__builtin_ia32_gather3siv4di` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv4.di"]
        pub fn avx512_gather3siv4_di(a: ::simdty::i64x4, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.gather3siv4.sf` intrinsic; known as `__builtin_ia32_gather3siv4sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv4.sf"]
        pub fn avx512_gather3siv4_sf(a: ::simdty::f32x4, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.gather3siv4.si` intrinsic; known as `__builtin_ia32_gather3siv4si` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv4.si"]
        pub fn avx512_gather3siv4_si(a: ::simdty::i32x4, b: *mut i8, c: ::simdty::i32x4, d: i8, e: i32) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.gather3siv8.sf` intrinsic; known as `__builtin_ia32_gather3siv8sf` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv8.sf"]
        pub fn avx512_gather3siv8_sf(a: ::simdty::f32x8, b: *mut i8, c: ::simdty::i32x8, d: i8, e: i32) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.gather3siv8.si` intrinsic; known as `__builtin_ia32_gather3siv8si` in GCC.
        #[link_name = "llvm.x86.avx512.gather3siv8.si"]
        pub fn avx512_gather3siv8_si(a: ::simdty::i32x8, b: *mut i8, c: ::simdty::i32x8, d: i8, e: i32) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.scatter.dpd.512` intrinsic; known as `__builtin_ia32_scattersiv8df` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.dpd.512"]
        pub fn avx512_scatter_dpd_512(a: *mut i8, b: i8, c: ::simdty::i32x8, d: ::simdty::f64x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.dps.512` intrinsic; known as `__builtin_ia32_scattersiv16sf` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.dps.512"]
        pub fn avx512_scatter_dps_512(a: *mut i8, b: i16, c: ::simdty::i32x16, d: ::simdty::f32x16, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.qpd.512` intrinsic; known as `__builtin_ia32_scatterdiv8df` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.qpd.512"]
        pub fn avx512_scatter_qpd_512(a: *mut i8, b: i8, c: ::simdty::i64x8, d: ::simdty::f64x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.qps.512` intrinsic; known as `__builtin_ia32_scatterdiv16sf` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.qps.512"]
        pub fn avx512_scatter_qps_512(a: *mut i8, b: i8, c: ::simdty::i64x8, d: ::simdty::f32x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.dpq.512` intrinsic; known as `__builtin_ia32_scattersiv8di` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.dpq.512"]
        pub fn avx512_scatter_dpq_512(a: *mut i8, b: i8, c: ::simdty::i32x8, d: ::simdty::i64x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.dpi.512` intrinsic; known as `__builtin_ia32_scattersiv16si` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.dpi.512"]
        pub fn avx512_scatter_dpi_512(a: *mut i8, b: i16, c: ::simdty::i32x16, d: ::simdty::i32x16, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.qpq.512` intrinsic; known as `__builtin_ia32_scatterdiv8di` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.qpq.512"]
        pub fn avx512_scatter_qpq_512(a: *mut i8, b: i8, c: ::simdty::i64x8, d: ::simdty::i64x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatter.qpi.512` intrinsic; known as `__builtin_ia32_scatterdiv16si` in GCC.
        #[link_name = "llvm.x86.avx512.scatter.qpi.512"]
        pub fn avx512_scatter_qpi_512(a: *mut i8, b: i8, c: ::simdty::i64x8, d: ::simdty::i32x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv2.df` intrinsic; known as `__builtin_ia32_scatterdiv2df` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv2.df"]
        pub fn avx512_scatterdiv2_df(a: *mut i8, b: i8, c: ::simdty::i64x2, d: ::simdty::f64x2, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv2.di` intrinsic; known as `__builtin_ia32_scatterdiv2di` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv2.di"]
        pub fn avx512_scatterdiv2_di(a: *mut i8, b: i8, c: ::simdty::i64x2, d: ::simdty::i64x2, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv4.df` intrinsic; known as `__builtin_ia32_scatterdiv4df` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv4.df"]
        pub fn avx512_scatterdiv4_df(a: *mut i8, b: i8, c: ::simdty::i64x4, d: ::simdty::f64x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv4.di` intrinsic; known as `__builtin_ia32_scatterdiv4di` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv4.di"]
        pub fn avx512_scatterdiv4_di(a: *mut i8, b: i8, c: ::simdty::i64x4, d: ::simdty::i64x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv4.sf` intrinsic; known as `__builtin_ia32_scatterdiv4sf` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv4.sf"]
        pub fn avx512_scatterdiv4_sf(a: *mut i8, b: i8, c: ::simdty::i64x2, d: ::simdty::f32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv4.si` intrinsic; known as `__builtin_ia32_scatterdiv4si` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv4.si"]
        pub fn avx512_scatterdiv4_si(a: *mut i8, b: i8, c: ::simdty::i64x2, d: ::simdty::i32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv8.sf` intrinsic; known as `__builtin_ia32_scatterdiv8sf` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv8.sf"]
        pub fn avx512_scatterdiv8_sf(a: *mut i8, b: i8, c: ::simdty::i64x4, d: ::simdty::f32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterdiv8.si` intrinsic; known as `__builtin_ia32_scatterdiv8si` in GCC.
        #[link_name = "llvm.x86.avx512.scatterdiv8.si"]
        pub fn avx512_scatterdiv8_si(a: *mut i8, b: i8, c: ::simdty::i64x4, d: ::simdty::i32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv2.df` intrinsic; known as `__builtin_ia32_scattersiv2df` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv2.df"]
        pub fn avx512_scattersiv2_df(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::f64x2, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv2.di` intrinsic; known as `__builtin_ia32_scattersiv2di` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv2.di"]
        pub fn avx512_scattersiv2_di(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::i64x2, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv4.df` intrinsic; known as `__builtin_ia32_scattersiv4df` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv4.df"]
        pub fn avx512_scattersiv4_df(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::f64x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv4.di` intrinsic; known as `__builtin_ia32_scattersiv4di` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv4.di"]
        pub fn avx512_scattersiv4_di(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::i64x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv4.sf` intrinsic; known as `__builtin_ia32_scattersiv4sf` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv4.sf"]
        pub fn avx512_scattersiv4_sf(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::f32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv4.si` intrinsic; known as `__builtin_ia32_scattersiv4si` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv4.si"]
        pub fn avx512_scattersiv4_si(a: *mut i8, b: i8, c: ::simdty::i32x4, d: ::simdty::i32x4, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv8.sf` intrinsic; known as `__builtin_ia32_scattersiv8sf` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv8.sf"]
        pub fn avx512_scattersiv8_sf(a: *mut i8, b: i8, c: ::simdty::i32x8, d: ::simdty::f32x8, e: i32) -> ();
        /// The `llvm.x86.avx512.scattersiv8.si` intrinsic; known as `__builtin_ia32_scattersiv8si` in GCC.
        #[link_name = "llvm.x86.avx512.scattersiv8.si"]
        pub fn avx512_scattersiv8_si(a: *mut i8, b: i8, c: ::simdty::i32x8, d: ::simdty::i32x8, e: i32) -> ();
        /// The `llvm.x86.avx512.gatherpf.dpd.512` intrinsic; known as `__builtin_ia32_gatherpfdpd` in GCC.
        #[link_name = "llvm.x86.avx512.gatherpf.dpd.512"]
        pub fn avx512_gatherpf_dpd_512(a: i8, b: ::simdty::i32x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.gatherpf.dps.512` intrinsic; known as `__builtin_ia32_gatherpfdps` in GCC.
        #[link_name = "llvm.x86.avx512.gatherpf.dps.512"]
        pub fn avx512_gatherpf_dps_512(a: i16, b: ::simdty::i32x16, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.gatherpf.qpd.512` intrinsic; known as `__builtin_ia32_gatherpfqpd` in GCC.
        #[link_name = "llvm.x86.avx512.gatherpf.qpd.512"]
        pub fn avx512_gatherpf_qpd_512(a: i8, b: ::simdty::i64x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.gatherpf.qps.512` intrinsic; known as `__builtin_ia32_gatherpfqps` in GCC.
        #[link_name = "llvm.x86.avx512.gatherpf.qps.512"]
        pub fn avx512_gatherpf_qps_512(a: i8, b: ::simdty::i64x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterpf.dpd.512` intrinsic; known as `__builtin_ia32_scatterpfdpd` in GCC.
        #[link_name = "llvm.x86.avx512.scatterpf.dpd.512"]
        pub fn avx512_scatterpf_dpd_512(a: i8, b: ::simdty::i32x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterpf.dps.512` intrinsic; known as `__builtin_ia32_scatterpfdps` in GCC.
        #[link_name = "llvm.x86.avx512.scatterpf.dps.512"]
        pub fn avx512_scatterpf_dps_512(a: i16, b: ::simdty::i32x16, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterpf.qpd.512` intrinsic; known as `__builtin_ia32_scatterpfqpd` in GCC.
        #[link_name = "llvm.x86.avx512.scatterpf.qpd.512"]
        pub fn avx512_scatterpf_qpd_512(a: i8, b: ::simdty::i64x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.scatterpf.qps.512` intrinsic; known as `__builtin_ia32_scatterpfqps` in GCC.
        #[link_name = "llvm.x86.avx512.scatterpf.qps.512"]
        pub fn avx512_scatterpf_qps_512(a: i8, b: ::simdty::i64x8, c: *mut i8, d: i32, e: i32) -> ();
        /// The `llvm.x86.avx512.mask.conflict.d.128` intrinsic; known as `__builtin_ia32_vpconflictsi_128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.d.128"]
        pub fn avx512_mask_conflict_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.conflict.d.256` intrinsic; known as `__builtin_ia32_vpconflictsi_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.d.256"]
        pub fn avx512_mask_conflict_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.conflict.d.512` intrinsic; known as `__builtin_ia32_vpconflictsi_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.d.512"]
        pub fn avx512_mask_conflict_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.conflict.q.128` intrinsic; known as `__builtin_ia32_vpconflictdi_128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.q.128"]
        pub fn avx512_mask_conflict_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.conflict.q.256` intrinsic; known as `__builtin_ia32_vpconflictdi_256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.q.256"]
        pub fn avx512_mask_conflict_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.conflict.q.512` intrinsic; known as `__builtin_ia32_vpconflictdi_512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.conflict.q.512"]
        pub fn avx512_mask_conflict_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.lzcnt.d.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.d.128"]
        pub fn avx512_mask_lzcnt_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.lzcnt.d.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.d.256"]
        pub fn avx512_mask_lzcnt_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.lzcnt.d.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.d.512"]
        pub fn avx512_mask_lzcnt_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.lzcnt.q.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.q.128"]
        pub fn avx512_mask_lzcnt_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.lzcnt.q.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.q.256"]
        pub fn avx512_mask_lzcnt_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.lzcnt.q.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.lzcnt.q.512"]
        pub fn avx512_mask_lzcnt_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.valign.q.512` intrinsic; known as `__builtin_ia32_alignq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.q.512"]
        pub fn avx512_mask_valign_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i32, d: ::simdty::i64x8, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.valign.d.512` intrinsic; known as `__builtin_ia32_alignd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.d.512"]
        pub fn avx512_mask_valign_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32, d: ::simdty::i32x16, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.valign.q.256` intrinsic; known as `__builtin_ia32_alignq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.q.256"]
        pub fn avx512_mask_valign_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i32, d: ::simdty::i64x4, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.valign.d.256` intrinsic; known as `__builtin_ia32_alignd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.d.256"]
        pub fn avx512_mask_valign_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i32, d: ::simdty::i32x8, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.valign.q.128` intrinsic; known as `__builtin_ia32_alignq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.q.128"]
        pub fn avx512_mask_valign_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32, d: ::simdty::i64x2, e: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.valign.d.128` intrinsic; known as `__builtin_ia32_alignd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.valign.d.128"]
        pub fn avx512_mask_valign_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32, d: ::simdty::i32x4, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.vcomi.sd` intrinsic; known as `__builtin_ia32_vcomisd` in GCC.
        #[link_name = "llvm.x86.avx512.vcomi.sd"]
        pub fn avx512_vcomi_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.vcomi.ss` intrinsic; known as `__builtin_ia32_vcomiss` in GCC.
        #[link_name = "llvm.x86.avx512.vcomi.ss"]
        pub fn avx512_vcomi_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.mask.cmp.b.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.b.512"]
        pub fn avx512_mask_cmp_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i32, d: i64) -> i64;
        /// The `llvm.x86.avx512.mask.cmp.w.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.w.512"]
        pub fn avx512_mask_cmp_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.mask.cmp.d.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.d.512"]
        pub fn avx512_mask_cmp_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.cmp.q.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.q.512"]
        pub fn avx512_mask_cmp_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.b.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.b.512"]
        pub fn avx512_mask_ucmp_b_512(a: ::simdty::i8x64, b: ::simdty::i8x64, c: i32, d: i64) -> i64;
        /// The `llvm.x86.avx512.mask.ucmp.w.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.w.512"]
        pub fn avx512_mask_ucmp_w_512(a: ::simdty::i16x32, b: ::simdty::i16x32, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.mask.ucmp.d.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.d.512"]
        pub fn avx512_mask_ucmp_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.ucmp.q.512` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.q.512"]
        pub fn avx512_mask_ucmp_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.b.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.b.256"]
        pub fn avx512_mask_cmp_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.mask.cmp.w.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.w.256"]
        pub fn avx512_mask_cmp_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.cmp.d.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.d.256"]
        pub fn avx512_mask_cmp_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.q.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.q.256"]
        pub fn avx512_mask_cmp_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.b.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.b.256"]
        pub fn avx512_mask_ucmp_b_256(a: ::simdty::i8x32, b: ::simdty::i8x32, c: i32, d: i32) -> i32;
        /// The `llvm.x86.avx512.mask.ucmp.w.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.w.256"]
        pub fn avx512_mask_ucmp_w_256(a: ::simdty::i16x16, b: ::simdty::i16x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.ucmp.d.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.d.256"]
        pub fn avx512_mask_ucmp_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.q.256` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.q.256"]
        pub fn avx512_mask_ucmp_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.b.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.b.128"]
        pub fn avx512_mask_cmp_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.cmp.w.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.w.128"]
        pub fn avx512_mask_cmp_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.d.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.d.128"]
        pub fn avx512_mask_cmp_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.q.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.cmp.q.128"]
        pub fn avx512_mask_cmp_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.b.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.b.128"]
        pub fn avx512_mask_ucmp_b_128(a: ::simdty::i8x16, b: ::simdty::i8x16, c: i32, d: i16) -> i16;
        /// The `llvm.x86.avx512.mask.ucmp.w.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.w.128"]
        pub fn avx512_mask_ucmp_w_128(a: ::simdty::i16x8, b: ::simdty::i16x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.d.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.d.128"]
        pub fn avx512_mask_ucmp_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.ucmp.q.128` intrinsic.
        #[link_name = "llvm.x86.avx512.mask.ucmp.q.128"]
        pub fn avx512_mask_ucmp_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.compress.ps.512` intrinsic; known as `__builtin_ia32_compresssf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.ps.512"]
        pub fn avx512_mask_compress_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.compress.pd.512` intrinsic; known as `__builtin_ia32_compressdf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.pd.512"]
        pub fn avx512_mask_compress_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.compress.ps.256` intrinsic; known as `__builtin_ia32_compresssf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.ps.256"]
        pub fn avx512_mask_compress_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.compress.pd.256` intrinsic; known as `__builtin_ia32_compressdf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.pd.256"]
        pub fn avx512_mask_compress_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.compress.ps.128` intrinsic; known as `__builtin_ia32_compresssf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.ps.128"]
        pub fn avx512_mask_compress_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.compress.pd.128` intrinsic; known as `__builtin_ia32_compressdf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.pd.128"]
        pub fn avx512_mask_compress_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.compress.store.ps.512` intrinsic; known as `__builtin_ia32_compressstoresf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.ps.512"]
        pub fn avx512_mask_compress_store_ps_512(a: *mut i8, b: ::simdty::f32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.pd.512` intrinsic; known as `__builtin_ia32_compressstoredf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.pd.512"]
        pub fn avx512_mask_compress_store_pd_512(a: *mut i8, b: ::simdty::f64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.ps.256` intrinsic; known as `__builtin_ia32_compressstoresf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.ps.256"]
        pub fn avx512_mask_compress_store_ps_256(a: *mut i8, b: ::simdty::f32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.pd.256` intrinsic; known as `__builtin_ia32_compressstoredf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.pd.256"]
        pub fn avx512_mask_compress_store_pd_256(a: *mut i8, b: ::simdty::f64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.ps.128` intrinsic; known as `__builtin_ia32_compressstoresf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.ps.128"]
        pub fn avx512_mask_compress_store_ps_128(a: *mut i8, b: ::simdty::f32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.pd.128` intrinsic; known as `__builtin_ia32_compressstoredf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.pd.128"]
        pub fn avx512_mask_compress_store_pd_128(a: *mut i8, b: ::simdty::f64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.d.512` intrinsic; known as `__builtin_ia32_compresssi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.d.512"]
        pub fn avx512_mask_compress_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.compress.q.512` intrinsic; known as `__builtin_ia32_compressdi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.q.512"]
        pub fn avx512_mask_compress_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.compress.d.256` intrinsic; known as `__builtin_ia32_compresssi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.d.256"]
        pub fn avx512_mask_compress_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.compress.q.256` intrinsic; known as `__builtin_ia32_compressdi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.q.256"]
        pub fn avx512_mask_compress_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.compress.d.128` intrinsic; known as `__builtin_ia32_compresssi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.d.128"]
        pub fn avx512_mask_compress_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.compress.q.128` intrinsic; known as `__builtin_ia32_compressdi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.q.128"]
        pub fn avx512_mask_compress_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.compress.store.d.512` intrinsic; known as `__builtin_ia32_compressstoresi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.d.512"]
        pub fn avx512_mask_compress_store_d_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.q.512` intrinsic; known as `__builtin_ia32_compressstoredi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.q.512"]
        pub fn avx512_mask_compress_store_q_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.d.256` intrinsic; known as `__builtin_ia32_compressstoresi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.d.256"]
        pub fn avx512_mask_compress_store_d_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.q.256` intrinsic; known as `__builtin_ia32_compressstoredi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.q.256"]
        pub fn avx512_mask_compress_store_q_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.d.128` intrinsic; known as `__builtin_ia32_compressstoresi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.d.128"]
        pub fn avx512_mask_compress_store_d_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.compress.store.q.128` intrinsic; known as `__builtin_ia32_compressstoredi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.compress.store.q.128"]
        pub fn avx512_mask_compress_store_q_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.expand.ps.512` intrinsic; known as `__builtin_ia32_expandsf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.ps.512"]
        pub fn avx512_mask_expand_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.expand.pd.512` intrinsic; known as `__builtin_ia32_expanddf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.pd.512"]
        pub fn avx512_mask_expand_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.expand.ps.256` intrinsic; known as `__builtin_ia32_expandsf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.ps.256"]
        pub fn avx512_mask_expand_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.expand.pd.256` intrinsic; known as `__builtin_ia32_expanddf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.pd.256"]
        pub fn avx512_mask_expand_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.expand.ps.128` intrinsic; known as `__builtin_ia32_expandsf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.ps.128"]
        pub fn avx512_mask_expand_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.expand.pd.128` intrinsic; known as `__builtin_ia32_expanddf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.pd.128"]
        pub fn avx512_mask_expand_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.expand.load.ps.512` intrinsic; known as `__builtin_ia32_expandloadsf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.ps.512"]
        pub fn avx512_mask_expand_load_ps_512(a: *mut i8, b: ::simdty::f32x16, c: i16) -> ::simdty::f32x16;
        /// The `llvm.x86.avx512.mask.expand.load.pd.512` intrinsic; known as `__builtin_ia32_expandloaddf512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.pd.512"]
        pub fn avx512_mask_expand_load_pd_512(a: *mut i8, b: ::simdty::f64x8, c: i8) -> ::simdty::f64x8;
        /// The `llvm.x86.avx512.mask.expand.load.ps.256` intrinsic; known as `__builtin_ia32_expandloadsf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.ps.256"]
        pub fn avx512_mask_expand_load_ps_256(a: *mut i8, b: ::simdty::f32x8, c: i8) -> ::simdty::f32x8;
        /// The `llvm.x86.avx512.mask.expand.load.pd.256` intrinsic; known as `__builtin_ia32_expandloaddf256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.pd.256"]
        pub fn avx512_mask_expand_load_pd_256(a: *mut i8, b: ::simdty::f64x4, c: i8) -> ::simdty::f64x4;
        /// The `llvm.x86.avx512.mask.expand.load.ps.128` intrinsic; known as `__builtin_ia32_expandloadsf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.ps.128"]
        pub fn avx512_mask_expand_load_ps_128(a: *mut i8, b: ::simdty::f32x4, c: i8) -> ::simdty::f32x4;
        /// The `llvm.x86.avx512.mask.expand.load.pd.128` intrinsic; known as `__builtin_ia32_expandloaddf128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.pd.128"]
        pub fn avx512_mask_expand_load_pd_128(a: *mut i8, b: ::simdty::f64x2, c: i8) -> ::simdty::f64x2;
        /// The `llvm.x86.avx512.mask.expand.d.512` intrinsic; known as `__builtin_ia32_expandsi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.d.512"]
        pub fn avx512_mask_expand_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.expand.q.512` intrinsic; known as `__builtin_ia32_expanddi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.q.512"]
        pub fn avx512_mask_expand_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.expand.d.256` intrinsic; known as `__builtin_ia32_expandsi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.d.256"]
        pub fn avx512_mask_expand_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.expand.q.256` intrinsic; known as `__builtin_ia32_expanddi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.q.256"]
        pub fn avx512_mask_expand_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.expand.d.128` intrinsic; known as `__builtin_ia32_expandsi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.d.128"]
        pub fn avx512_mask_expand_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.expand.q.128` intrinsic; known as `__builtin_ia32_expanddi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.q.128"]
        pub fn avx512_mask_expand_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.expand.load.d.512` intrinsic; known as `__builtin_ia32_expandloadsi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.d.512"]
        pub fn avx512_mask_expand_load_d_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.expand.load.q.512` intrinsic; known as `__builtin_ia32_expandloaddi512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.q.512"]
        pub fn avx512_mask_expand_load_q_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.expand.load.d.256` intrinsic; known as `__builtin_ia32_expandloadsi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.d.256"]
        pub fn avx512_mask_expand_load_d_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.expand.load.q.256` intrinsic; known as `__builtin_ia32_expandloaddi256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.q.256"]
        pub fn avx512_mask_expand_load_q_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.expand.load.d.128` intrinsic; known as `__builtin_ia32_expandloadsi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.d.128"]
        pub fn avx512_mask_expand_load_d_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.expand.load.q.128` intrinsic; known as `__builtin_ia32_expandloaddi128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.expand.load.q.128"]
        pub fn avx512_mask_expand_load_q_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pmov.qb.128` intrinsic; known as `__builtin_ia32_pmovqb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.128"]
        pub fn avx512_mask_pmov_qb_128(a: ::simdty::i64x2, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.qb.mem.128` intrinsic; known as `__builtin_ia32_pmovqb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.mem.128"]
        pub fn avx512_mask_pmov_qb_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qb.128` intrinsic; known as `__builtin_ia32_pmovsqb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.128"]
        pub fn avx512_mask_pmovs_qb_128(a: ::simdty::i64x2, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.qb.mem.128` intrinsic; known as `__builtin_ia32_pmovsqb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.mem.128"]
        pub fn avx512_mask_pmovs_qb_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qb.128` intrinsic; known as `__builtin_ia32_pmovusqb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.128"]
        pub fn avx512_mask_pmovus_qb_128(a: ::simdty::i64x2, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.qb.mem.128` intrinsic; known as `__builtin_ia32_pmovusqb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.mem.128"]
        pub fn avx512_mask_pmovus_qb_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qb.256` intrinsic; known as `__builtin_ia32_pmovqb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.256"]
        pub fn avx512_mask_pmov_qb_256(a: ::simdty::i64x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.qb.mem.256` intrinsic; known as `__builtin_ia32_pmovqb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.mem.256"]
        pub fn avx512_mask_pmov_qb_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qb.256` intrinsic; known as `__builtin_ia32_pmovsqb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.256"]
        pub fn avx512_mask_pmovs_qb_256(a: ::simdty::i64x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.qb.mem.256` intrinsic; known as `__builtin_ia32_pmovsqb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.mem.256"]
        pub fn avx512_mask_pmovs_qb_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qb.256` intrinsic; known as `__builtin_ia32_pmovusqb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.256"]
        pub fn avx512_mask_pmovus_qb_256(a: ::simdty::i64x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.qb.mem.256` intrinsic; known as `__builtin_ia32_pmovusqb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.mem.256"]
        pub fn avx512_mask_pmovus_qb_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qb.512` intrinsic; known as `__builtin_ia32_pmovqb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.512"]
        pub fn avx512_mask_pmov_qb_512(a: ::simdty::i64x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.qb.mem.512` intrinsic; known as `__builtin_ia32_pmovqb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qb.mem.512"]
        pub fn avx512_mask_pmov_qb_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qb.512` intrinsic; known as `__builtin_ia32_pmovsqb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.512"]
        pub fn avx512_mask_pmovs_qb_512(a: ::simdty::i64x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.qb.mem.512` intrinsic; known as `__builtin_ia32_pmovsqb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qb.mem.512"]
        pub fn avx512_mask_pmovs_qb_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qb.512` intrinsic; known as `__builtin_ia32_pmovusqb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.512"]
        pub fn avx512_mask_pmovus_qb_512(a: ::simdty::i64x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.qb.mem.512` intrinsic; known as `__builtin_ia32_pmovusqb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qb.mem.512"]
        pub fn avx512_mask_pmovus_qb_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qw.128` intrinsic; known as `__builtin_ia32_pmovqw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.128"]
        pub fn avx512_mask_pmov_qw_128(a: ::simdty::i64x2, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmov.qw.mem.128` intrinsic; known as `__builtin_ia32_pmovqw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.mem.128"]
        pub fn avx512_mask_pmov_qw_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qw.128` intrinsic; known as `__builtin_ia32_pmovsqw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.128"]
        pub fn avx512_mask_pmovs_qw_128(a: ::simdty::i64x2, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovs.qw.mem.128` intrinsic; known as `__builtin_ia32_pmovsqw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.mem.128"]
        pub fn avx512_mask_pmovs_qw_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qw.128` intrinsic; known as `__builtin_ia32_pmovusqw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.128"]
        pub fn avx512_mask_pmovus_qw_128(a: ::simdty::i64x2, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovus.qw.mem.128` intrinsic; known as `__builtin_ia32_pmovusqw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.mem.128"]
        pub fn avx512_mask_pmovus_qw_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qw.256` intrinsic; known as `__builtin_ia32_pmovqw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.256"]
        pub fn avx512_mask_pmov_qw_256(a: ::simdty::i64x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmov.qw.mem.256` intrinsic; known as `__builtin_ia32_pmovqw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.mem.256"]
        pub fn avx512_mask_pmov_qw_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qw.256` intrinsic; known as `__builtin_ia32_pmovsqw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.256"]
        pub fn avx512_mask_pmovs_qw_256(a: ::simdty::i64x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovs.qw.mem.256` intrinsic; known as `__builtin_ia32_pmovsqw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.mem.256"]
        pub fn avx512_mask_pmovs_qw_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qw.256` intrinsic; known as `__builtin_ia32_pmovusqw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.256"]
        pub fn avx512_mask_pmovus_qw_256(a: ::simdty::i64x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovus.qw.mem.256` intrinsic; known as `__builtin_ia32_pmovusqw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.mem.256"]
        pub fn avx512_mask_pmovus_qw_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qw.512` intrinsic; known as `__builtin_ia32_pmovqw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.512"]
        pub fn avx512_mask_pmov_qw_512(a: ::simdty::i64x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmov.qw.mem.512` intrinsic; known as `__builtin_ia32_pmovqw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qw.mem.512"]
        pub fn avx512_mask_pmov_qw_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qw.512` intrinsic; known as `__builtin_ia32_pmovsqw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.512"]
        pub fn avx512_mask_pmovs_qw_512(a: ::simdty::i64x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovs.qw.mem.512` intrinsic; known as `__builtin_ia32_pmovsqw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qw.mem.512"]
        pub fn avx512_mask_pmovs_qw_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qw.512` intrinsic; known as `__builtin_ia32_pmovusqw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.512"]
        pub fn avx512_mask_pmovus_qw_512(a: ::simdty::i64x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovus.qw.mem.512` intrinsic; known as `__builtin_ia32_pmovusqw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qw.mem.512"]
        pub fn avx512_mask_pmovus_qw_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qd.128` intrinsic; known as `__builtin_ia32_pmovqd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.128"]
        pub fn avx512_mask_pmov_qd_128(a: ::simdty::i64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmov.qd.mem.128` intrinsic; known as `__builtin_ia32_pmovqd128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.mem.128"]
        pub fn avx512_mask_pmov_qd_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qd.128` intrinsic; known as `__builtin_ia32_pmovsqd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.128"]
        pub fn avx512_mask_pmovs_qd_128(a: ::simdty::i64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovs.qd.mem.128` intrinsic; known as `__builtin_ia32_pmovsqd128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.mem.128"]
        pub fn avx512_mask_pmovs_qd_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qd.128` intrinsic; known as `__builtin_ia32_pmovusqd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.128"]
        pub fn avx512_mask_pmovus_qd_128(a: ::simdty::i64x2, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovus.qd.mem.128` intrinsic; known as `__builtin_ia32_pmovusqd128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.mem.128"]
        pub fn avx512_mask_pmovus_qd_mem_128(a: *mut i8, b: ::simdty::i64x2, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qd.256` intrinsic; known as `__builtin_ia32_pmovqd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.256"]
        pub fn avx512_mask_pmov_qd_256(a: ::simdty::i64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmov.qd.mem.256` intrinsic; known as `__builtin_ia32_pmovqd256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.mem.256"]
        pub fn avx512_mask_pmov_qd_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qd.256` intrinsic; known as `__builtin_ia32_pmovsqd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.256"]
        pub fn avx512_mask_pmovs_qd_256(a: ::simdty::i64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovs.qd.mem.256` intrinsic; known as `__builtin_ia32_pmovsqd256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.mem.256"]
        pub fn avx512_mask_pmovs_qd_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qd.256` intrinsic; known as `__builtin_ia32_pmovusqd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.256"]
        pub fn avx512_mask_pmovus_qd_256(a: ::simdty::i64x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pmovus.qd.mem.256` intrinsic; known as `__builtin_ia32_pmovusqd256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.mem.256"]
        pub fn avx512_mask_pmovus_qd_mem_256(a: *mut i8, b: ::simdty::i64x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.qd.512` intrinsic; known as `__builtin_ia32_pmovqd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.512"]
        pub fn avx512_mask_pmov_qd_512(a: ::simdty::i64x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmov.qd.mem.512` intrinsic; known as `__builtin_ia32_pmovqd512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.qd.mem.512"]
        pub fn avx512_mask_pmov_qd_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.qd.512` intrinsic; known as `__builtin_ia32_pmovsqd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.512"]
        pub fn avx512_mask_pmovs_qd_512(a: ::simdty::i64x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovs.qd.mem.512` intrinsic; known as `__builtin_ia32_pmovsqd512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.qd.mem.512"]
        pub fn avx512_mask_pmovs_qd_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.qd.512` intrinsic; known as `__builtin_ia32_pmovusqd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.512"]
        pub fn avx512_mask_pmovus_qd_512(a: ::simdty::i64x8, b: ::simdty::i32x8, c: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pmovus.qd.mem.512` intrinsic; known as `__builtin_ia32_pmovusqd512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.qd.mem.512"]
        pub fn avx512_mask_pmovus_qd_mem_512(a: *mut i8, b: ::simdty::i64x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.db.128` intrinsic; known as `__builtin_ia32_pmovdb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.128"]
        pub fn avx512_mask_pmov_db_128(a: ::simdty::i32x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.db.mem.128` intrinsic; known as `__builtin_ia32_pmovdb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.mem.128"]
        pub fn avx512_mask_pmov_db_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.db.128` intrinsic; known as `__builtin_ia32_pmovsdb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.128"]
        pub fn avx512_mask_pmovs_db_128(a: ::simdty::i32x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.db.mem.128` intrinsic; known as `__builtin_ia32_pmovsdb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.mem.128"]
        pub fn avx512_mask_pmovs_db_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.db.128` intrinsic; known as `__builtin_ia32_pmovusdb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.128"]
        pub fn avx512_mask_pmovus_db_128(a: ::simdty::i32x4, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.db.mem.128` intrinsic; known as `__builtin_ia32_pmovusdb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.mem.128"]
        pub fn avx512_mask_pmovus_db_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.db.256` intrinsic; known as `__builtin_ia32_pmovdb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.256"]
        pub fn avx512_mask_pmov_db_256(a: ::simdty::i32x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.db.mem.256` intrinsic; known as `__builtin_ia32_pmovdb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.mem.256"]
        pub fn avx512_mask_pmov_db_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.db.256` intrinsic; known as `__builtin_ia32_pmovsdb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.256"]
        pub fn avx512_mask_pmovs_db_256(a: ::simdty::i32x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.db.mem.256` intrinsic; known as `__builtin_ia32_pmovsdb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.mem.256"]
        pub fn avx512_mask_pmovs_db_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.db.256` intrinsic; known as `__builtin_ia32_pmovusdb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.256"]
        pub fn avx512_mask_pmovus_db_256(a: ::simdty::i32x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.db.mem.256` intrinsic; known as `__builtin_ia32_pmovusdb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.mem.256"]
        pub fn avx512_mask_pmovus_db_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.db.512` intrinsic; known as `__builtin_ia32_pmovdb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.512"]
        pub fn avx512_mask_pmov_db_512(a: ::simdty::i32x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.db.mem.512` intrinsic; known as `__builtin_ia32_pmovdb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.db.mem.512"]
        pub fn avx512_mask_pmov_db_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.db.512` intrinsic; known as `__builtin_ia32_pmovsdb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.512"]
        pub fn avx512_mask_pmovs_db_512(a: ::simdty::i32x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.db.mem.512` intrinsic; known as `__builtin_ia32_pmovsdb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.db.mem.512"]
        pub fn avx512_mask_pmovs_db_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.db.512` intrinsic; known as `__builtin_ia32_pmovusdb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.512"]
        pub fn avx512_mask_pmovus_db_512(a: ::simdty::i32x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.db.mem.512` intrinsic; known as `__builtin_ia32_pmovusdb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.db.mem.512"]
        pub fn avx512_mask_pmovus_db_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmov.dw.128` intrinsic; known as `__builtin_ia32_pmovdw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.128"]
        pub fn avx512_mask_pmov_dw_128(a: ::simdty::i32x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmov.dw.mem.128` intrinsic; known as `__builtin_ia32_pmovdw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.mem.128"]
        pub fn avx512_mask_pmov_dw_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.dw.128` intrinsic; known as `__builtin_ia32_pmovsdw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.128"]
        pub fn avx512_mask_pmovs_dw_128(a: ::simdty::i32x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovs.dw.mem.128` intrinsic; known as `__builtin_ia32_pmovsdw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.mem.128"]
        pub fn avx512_mask_pmovs_dw_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.dw.128` intrinsic; known as `__builtin_ia32_pmovusdw128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.128"]
        pub fn avx512_mask_pmovus_dw_128(a: ::simdty::i32x4, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovus.dw.mem.128` intrinsic; known as `__builtin_ia32_pmovusdw128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.mem.128"]
        pub fn avx512_mask_pmovus_dw_mem_128(a: *mut i8, b: ::simdty::i32x4, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.dw.256` intrinsic; known as `__builtin_ia32_pmovdw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.256"]
        pub fn avx512_mask_pmov_dw_256(a: ::simdty::i32x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmov.dw.mem.256` intrinsic; known as `__builtin_ia32_pmovdw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.mem.256"]
        pub fn avx512_mask_pmov_dw_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.dw.256` intrinsic; known as `__builtin_ia32_pmovsdw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.256"]
        pub fn avx512_mask_pmovs_dw_256(a: ::simdty::i32x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovs.dw.mem.256` intrinsic; known as `__builtin_ia32_pmovsdw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.mem.256"]
        pub fn avx512_mask_pmovs_dw_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.dw.256` intrinsic; known as `__builtin_ia32_pmovusdw256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.256"]
        pub fn avx512_mask_pmovus_dw_256(a: ::simdty::i32x8, b: ::simdty::i16x8, c: i8) -> ::simdty::i16x8;
        /// The `llvm.x86.avx512.mask.pmovus.dw.mem.256` intrinsic; known as `__builtin_ia32_pmovusdw256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.mem.256"]
        pub fn avx512_mask_pmovus_dw_mem_256(a: *mut i8, b: ::simdty::i32x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.dw.512` intrinsic; known as `__builtin_ia32_pmovdw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.512"]
        pub fn avx512_mask_pmov_dw_512(a: ::simdty::i32x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmov.dw.mem.512` intrinsic; known as `__builtin_ia32_pmovdw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.dw.mem.512"]
        pub fn avx512_mask_pmov_dw_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.dw.512` intrinsic; known as `__builtin_ia32_pmovsdw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.512"]
        pub fn avx512_mask_pmovs_dw_512(a: ::simdty::i32x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmovs.dw.mem.512` intrinsic; known as `__builtin_ia32_pmovsdw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.dw.mem.512"]
        pub fn avx512_mask_pmovs_dw_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.dw.512` intrinsic; known as `__builtin_ia32_pmovusdw512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.512"]
        pub fn avx512_mask_pmovus_dw_512(a: ::simdty::i32x16, b: ::simdty::i16x16, c: i16) -> ::simdty::i16x16;
        /// The `llvm.x86.avx512.mask.pmovus.dw.mem.512` intrinsic; known as `__builtin_ia32_pmovusdw512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.dw.mem.512"]
        pub fn avx512_mask_pmovus_dw_mem_512(a: *mut i8, b: ::simdty::i32x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmov.wb.128` intrinsic; known as `__builtin_ia32_pmovwb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.128"]
        pub fn avx512_mask_pmov_wb_128(a: ::simdty::i16x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.wb.mem.128` intrinsic; known as `__builtin_ia32_pmovwb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.mem.128"]
        pub fn avx512_mask_pmov_wb_mem_128(a: *mut i8, b: ::simdty::i16x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.wb.128` intrinsic; known as `__builtin_ia32_pmovswb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.128"]
        pub fn avx512_mask_pmovs_wb_128(a: ::simdty::i16x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.wb.mem.128` intrinsic; known as `__builtin_ia32_pmovswb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.mem.128"]
        pub fn avx512_mask_pmovs_wb_mem_128(a: *mut i8, b: ::simdty::i16x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.wb.128` intrinsic; known as `__builtin_ia32_pmovuswb128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.128"]
        pub fn avx512_mask_pmovus_wb_128(a: ::simdty::i16x8, b: ::simdty::i8x16, c: i8) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.wb.mem.128` intrinsic; known as `__builtin_ia32_pmovuswb128mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.mem.128"]
        pub fn avx512_mask_pmovus_wb_mem_128(a: *mut i8, b: ::simdty::i16x8, c: i8) -> ();
        /// The `llvm.x86.avx512.mask.pmov.wb.256` intrinsic; known as `__builtin_ia32_pmovwb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.256"]
        pub fn avx512_mask_pmov_wb_256(a: ::simdty::i16x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmov.wb.mem.256` intrinsic; known as `__builtin_ia32_pmovwb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.mem.256"]
        pub fn avx512_mask_pmov_wb_mem_256(a: *mut i8, b: ::simdty::i16x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.wb.256` intrinsic; known as `__builtin_ia32_pmovswb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.256"]
        pub fn avx512_mask_pmovs_wb_256(a: ::simdty::i16x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovs.wb.mem.256` intrinsic; known as `__builtin_ia32_pmovswb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.mem.256"]
        pub fn avx512_mask_pmovs_wb_mem_256(a: *mut i8, b: ::simdty::i16x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.wb.256` intrinsic; known as `__builtin_ia32_pmovuswb256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.256"]
        pub fn avx512_mask_pmovus_wb_256(a: ::simdty::i16x16, b: ::simdty::i8x16, c: i16) -> ::simdty::i8x16;
        /// The `llvm.x86.avx512.mask.pmovus.wb.mem.256` intrinsic; known as `__builtin_ia32_pmovuswb256mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.mem.256"]
        pub fn avx512_mask_pmovus_wb_mem_256(a: *mut i8, b: ::simdty::i16x16, c: i16) -> ();
        /// The `llvm.x86.avx512.mask.pmov.wb.512` intrinsic; known as `__builtin_ia32_pmovwb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.512"]
        pub fn avx512_mask_pmov_wb_512(a: ::simdty::i16x32, b: ::simdty::i8x32, c: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmov.wb.mem.512` intrinsic; known as `__builtin_ia32_pmovwb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmov.wb.mem.512"]
        pub fn avx512_mask_pmov_wb_mem_512(a: *mut i8, b: ::simdty::i16x32, c: i32) -> ();
        /// The `llvm.x86.avx512.mask.pmovs.wb.512` intrinsic; known as `__builtin_ia32_pmovswb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.512"]
        pub fn avx512_mask_pmovs_wb_512(a: ::simdty::i16x32, b: ::simdty::i8x32, c: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmovs.wb.mem.512` intrinsic; known as `__builtin_ia32_pmovswb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovs.wb.mem.512"]
        pub fn avx512_mask_pmovs_wb_mem_512(a: *mut i8, b: ::simdty::i16x32, c: i32) -> ();
        /// The `llvm.x86.avx512.mask.pmovus.wb.512` intrinsic; known as `__builtin_ia32_pmovuswb512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.512"]
        pub fn avx512_mask_pmovus_wb_512(a: ::simdty::i16x32, b: ::simdty::i8x32, c: i32) -> ::simdty::i8x32;
        /// The `llvm.x86.avx512.mask.pmovus.wb.mem.512` intrinsic; known as `__builtin_ia32_pmovuswb512mem_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pmovus.wb.mem.512"]
        pub fn avx512_mask_pmovus_wb_mem_512(a: *mut i8, b: ::simdty::i16x32, c: i32) -> ();
        /// The `llvm.x86.avx512.mask.pternlog.d.128` intrinsic; known as `__builtin_ia32_pternlogd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.d.128"]
        pub fn avx512_mask_pternlog_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i32, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.maskz.pternlog.d.128` intrinsic; known as `__builtin_ia32_pternlogd128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.d.128"]
        pub fn avx512_maskz_pternlog_d_128(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4, d: i32, e: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.avx512.mask.pternlog.d.256` intrinsic; known as `__builtin_ia32_pternlogd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.d.256"]
        pub fn avx512_mask_pternlog_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i32, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.maskz.pternlog.d.256` intrinsic; known as `__builtin_ia32_pternlogd256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.d.256"]
        pub fn avx512_maskz_pternlog_d_256(a: ::simdty::i32x8, b: ::simdty::i32x8, c: ::simdty::i32x8, d: i32, e: i8) -> ::simdty::i32x8;
        /// The `llvm.x86.avx512.mask.pternlog.d.512` intrinsic; known as `__builtin_ia32_pternlogd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.d.512"]
        pub fn avx512_mask_pternlog_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i32, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.maskz.pternlog.d.512` intrinsic; known as `__builtin_ia32_pternlogd512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.d.512"]
        pub fn avx512_maskz_pternlog_d_512(a: ::simdty::i32x16, b: ::simdty::i32x16, c: ::simdty::i32x16, d: i32, e: i16) -> ::simdty::i32x16;
        /// The `llvm.x86.avx512.mask.pternlog.q.128` intrinsic; known as `__builtin_ia32_pternlogq128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.q.128"]
        pub fn avx512_mask_pternlog_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i32, e: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.maskz.pternlog.q.128` intrinsic; known as `__builtin_ia32_pternlogq128_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.q.128"]
        pub fn avx512_maskz_pternlog_q_128(a: ::simdty::i64x2, b: ::simdty::i64x2, c: ::simdty::i64x2, d: i32, e: i8) -> ::simdty::i64x2;
        /// The `llvm.x86.avx512.mask.pternlog.q.256` intrinsic; known as `__builtin_ia32_pternlogq256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.q.256"]
        pub fn avx512_mask_pternlog_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i32, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.maskz.pternlog.q.256` intrinsic; known as `__builtin_ia32_pternlogq256_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.q.256"]
        pub fn avx512_maskz_pternlog_q_256(a: ::simdty::i64x4, b: ::simdty::i64x4, c: ::simdty::i64x4, d: i32, e: i8) -> ::simdty::i64x4;
        /// The `llvm.x86.avx512.mask.pternlog.q.512` intrinsic; known as `__builtin_ia32_pternlogq512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.pternlog.q.512"]
        pub fn avx512_mask_pternlog_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i32, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.maskz.pternlog.q.512` intrinsic; known as `__builtin_ia32_pternlogq512_maskz` in GCC.
        #[link_name = "llvm.x86.avx512.maskz.pternlog.q.512"]
        pub fn avx512_maskz_pternlog_q_512(a: ::simdty::i64x8, b: ::simdty::i64x8, c: ::simdty::i64x8, d: i32, e: i8) -> ::simdty::i64x8;
        /// The `llvm.x86.avx512.mask.cmp.ps.512` intrinsic; known as `__builtin_ia32_cmpps512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.ps.512"]
        pub fn avx512_mask_cmp_ps_512(a: ::simdty::f32x16, b: ::simdty::f32x16, c: i32, d: i16, e: i32) -> i16;
        /// The `llvm.x86.avx512.mask.cmp.pd.512` intrinsic; known as `__builtin_ia32_cmppd512_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.pd.512"]
        pub fn avx512_mask_cmp_pd_512(a: ::simdty::f64x8, b: ::simdty::f64x8, c: i32, d: i8, e: i32) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.ps.256` intrinsic; known as `__builtin_ia32_cmpps256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.ps.256"]
        pub fn avx512_mask_cmp_ps_256(a: ::simdty::f32x8, b: ::simdty::f32x8, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.pd.256` intrinsic; known as `__builtin_ia32_cmppd256_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.pd.256"]
        pub fn avx512_mask_cmp_pd_256(a: ::simdty::f64x4, b: ::simdty::f64x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.ps.128` intrinsic; known as `__builtin_ia32_cmpps128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.ps.128"]
        pub fn avx512_mask_cmp_ps_128(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.pd.128` intrinsic; known as `__builtin_ia32_cmppd128_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.pd.128"]
        pub fn avx512_mask_cmp_pd_128(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: i8) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.ss` intrinsic; known as `__builtin_ia32_cmpss_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.ss"]
        pub fn avx512_mask_cmp_ss(a: ::simdty::f32x4, b: ::simdty::f32x4, c: i32, d: i8, e: i32) -> i8;
        /// The `llvm.x86.avx512.mask.cmp.sd` intrinsic; known as `__builtin_ia32_cmpsd_mask` in GCC.
        #[link_name = "llvm.x86.avx512.mask.cmp.sd"]
        pub fn avx512_mask_cmp_sd(a: ::simdty::f64x2, b: ::simdty::f64x2, c: i32, d: i8, e: i32) -> i8;
        /// The `llvm.x86.avx512.movntdqa` intrinsic; known as `__builtin_ia32_movntdqa512` in GCC.
        #[link_name = "llvm.x86.avx512.movntdqa"]
        pub fn avx512_movntdqa(a: *mut i8) -> ::simdty::i64x8;
        /// The `llvm.x86.sha1rnds4` intrinsic; known as `__builtin_ia32_sha1rnds4` in GCC.
        #[link_name = "llvm.x86.sha1rnds4"]
        pub fn sha1rnds4(a: ::simdty::i32x4, b: ::simdty::i32x4, c: i8) -> ::simdty::i32x4;
        /// The `llvm.x86.sha1nexte` intrinsic; known as `__builtin_ia32_sha1nexte` in GCC.
        #[link_name = "llvm.x86.sha1nexte"]
        pub fn sha1nexte(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sha1msg1` intrinsic; known as `__builtin_ia32_sha1msg1` in GCC.
        #[link_name = "llvm.x86.sha1msg1"]
        pub fn sha1msg1(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sha1msg2` intrinsic; known as `__builtin_ia32_sha1msg2` in GCC.
        #[link_name = "llvm.x86.sha1msg2"]
        pub fn sha1msg2(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sha256rnds2` intrinsic; known as `__builtin_ia32_sha256rnds2` in GCC.
        #[link_name = "llvm.x86.sha256rnds2"]
        pub fn sha256rnds2(a: ::simdty::i32x4, b: ::simdty::i32x4, c: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sha256msg1` intrinsic; known as `__builtin_ia32_sha256msg1` in GCC.
        #[link_name = "llvm.x86.sha256msg1"]
        pub fn sha256msg1(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.sha256msg2` intrinsic; known as `__builtin_ia32_sha256msg2` in GCC.
        #[link_name = "llvm.x86.sha256msg2"]
        pub fn sha256msg2(a: ::simdty::i32x4, b: ::simdty::i32x4) -> ::simdty::i32x4;
        /// The `llvm.x86.monitorx` intrinsic; known as `__builtin_ia32_monitorx` in GCC.
        #[link_name = "llvm.x86.monitorx"]
        pub fn monitorx(a: *mut i8, b: i32, c: i32) -> ();
        /// The `llvm.x86.mwaitx` intrinsic; known as `__builtin_ia32_mwaitx` in GCC.
        #[link_name = "llvm.x86.mwaitx"]
        pub fn mwaitx(a: i32, b: i32, c: i32) -> ();
    }
}
/// LLVM intrinsics for the xcore architecture.
pub mod xcore {
    extern {
        /// The `llvm.xcore.bitrev` intrinsic; known as `__builtin_bitrev` in GCC.
        #[link_name = "llvm.xcore.bitrev"]
        pub fn bitrev(a: i32) -> i32;
        /// The `llvm.xcore.crc32` intrinsic.
        #[link_name = "llvm.xcore.crc32"]
        pub fn crc32(a: i32, b: i32, c: i32) -> i32;
        /// The `llvm.xcore.sext` intrinsic.
        #[link_name = "llvm.xcore.sext"]
        pub fn sext(a: i32, b: i32) -> i32;
        /// The `llvm.xcore.zext` intrinsic.
        #[link_name = "llvm.xcore.zext"]
        pub fn zext(a: i32, b: i32) -> i32;
        /// The `llvm.xcore.getid` intrinsic; known as `__builtin_getid` in GCC.
        #[link_name = "llvm.xcore.getid"]
        pub fn getid() -> i32;
        /// The `llvm.xcore.getps` intrinsic; known as `__builtin_getps` in GCC.
        #[link_name = "llvm.xcore.getps"]
        pub fn getps(a: i32) -> i32;
        /// The `llvm.xcore.setps` intrinsic; known as `__builtin_setps` in GCC.
        #[link_name = "llvm.xcore.setps"]
        pub fn setps(a: i32, b: i32) -> ();
        /// The `llvm.xcore.geted` intrinsic.
        #[link_name = "llvm.xcore.geted"]
        pub fn geted() -> i32;
        /// The `llvm.xcore.getet` intrinsic.
        #[link_name = "llvm.xcore.getet"]
        pub fn getet() -> i32;
        /// The `llvm.xcore.setsr` intrinsic.
        #[link_name = "llvm.xcore.setsr"]
        pub fn setsr(a: i32) -> ();
        /// The `llvm.xcore.clrsr` intrinsic.
        #[link_name = "llvm.xcore.clrsr"]
        pub fn clrsr(a: i32) -> ();
        /// The `llvm.xcore.getr.p0i8` intrinsic.
        #[link_name = "llvm.xcore.getr.p0i8"]
        pub fn getr_p0i8(a: i32) -> *mut i8;
        /// The `llvm.xcore.freer.p0i8` intrinsic.
        #[link_name = "llvm.xcore.freer.p0i8"]
        pub fn freer_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.in.p0i8` intrinsic.
        #[link_name = "llvm.xcore.in.p0i8"]
        pub fn in_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.int.p0i8` intrinsic.
        #[link_name = "llvm.xcore.int.p0i8"]
        pub fn int_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.inct.p0i8` intrinsic.
        #[link_name = "llvm.xcore.inct.p0i8"]
        pub fn inct_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.out.p0i8` intrinsic.
        #[link_name = "llvm.xcore.out.p0i8"]
        pub fn out_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.outt.p0i8` intrinsic.
        #[link_name = "llvm.xcore.outt.p0i8"]
        pub fn outt_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.outct.p0i8` intrinsic.
        #[link_name = "llvm.xcore.outct.p0i8"]
        pub fn outct_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.chkct.p0i8` intrinsic.
        #[link_name = "llvm.xcore.chkct.p0i8"]
        pub fn chkct_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.testct.p0i8` intrinsic.
        #[link_name = "llvm.xcore.testct.p0i8"]
        pub fn testct_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.testwct.p0i8` intrinsic.
        #[link_name = "llvm.xcore.testwct.p0i8"]
        pub fn testwct_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.setd.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setd.p0i8"]
        pub fn setd_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.setc.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setc.p0i8"]
        pub fn setc_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.inshr.p0i8` intrinsic.
        #[link_name = "llvm.xcore.inshr.p0i8"]
        pub fn inshr_p0i8(a: *mut i8, b: i32) -> i32;
        /// The `llvm.xcore.outshr.p0i8` intrinsic.
        #[link_name = "llvm.xcore.outshr.p0i8"]
        pub fn outshr_p0i8(a: *mut i8, b: i32) -> i32;
        /// The `llvm.xcore.setpt.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setpt.p0i8"]
        pub fn setpt_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.clrpt.p0i8` intrinsic.
        #[link_name = "llvm.xcore.clrpt.p0i8"]
        pub fn clrpt_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.getts.p0i8` intrinsic.
        #[link_name = "llvm.xcore.getts.p0i8"]
        pub fn getts_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.syncr.p0i8` intrinsic.
        #[link_name = "llvm.xcore.syncr.p0i8"]
        pub fn syncr_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.settw.p0i8` intrinsic.
        #[link_name = "llvm.xcore.settw.p0i8"]
        pub fn settw_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.setv.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setv.p0i8"]
        pub fn setv_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.setev.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setev.p0i8"]
        pub fn setev_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.eeu.p0i8` intrinsic.
        #[link_name = "llvm.xcore.eeu.p0i8"]
        pub fn eeu_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.edu.p0i8` intrinsic.
        #[link_name = "llvm.xcore.edu.p0i8"]
        pub fn edu_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.setclk.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setclk.p0i8.p0i8"]
        pub fn setclk_p0i8_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.setrdy.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setrdy.p0i8.p0i8"]
        pub fn setrdy_p0i8_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.setpsc.p0i8` intrinsic.
        #[link_name = "llvm.xcore.setpsc.p0i8"]
        pub fn setpsc_p0i8(a: *mut i8, b: i32) -> ();
        /// The `llvm.xcore.peek.p0i8` intrinsic.
        #[link_name = "llvm.xcore.peek.p0i8"]
        pub fn peek_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.endin.p0i8` intrinsic.
        #[link_name = "llvm.xcore.endin.p0i8"]
        pub fn endin_p0i8(a: *mut i8) -> i32;
        /// The `llvm.xcore.waitevent` intrinsic.
        #[link_name = "llvm.xcore.waitevent"]
        pub fn waitevent() -> *mut i8;
        /// The `llvm.xcore.checkevent` intrinsic.
        #[link_name = "llvm.xcore.checkevent"]
        pub fn checkevent(a: *mut i8) -> *mut i8;
        /// The `llvm.xcore.clre` intrinsic.
        #[link_name = "llvm.xcore.clre"]
        pub fn clre() -> ();
        /// The `llvm.xcore.getst.p0i8.p0i8` intrinsic.
        #[link_name = "llvm.xcore.getst.p0i8.p0i8"]
        pub fn getst_p0i8_p0i8(a: *mut i8) -> *mut i8;
        /// The `llvm.xcore.msync.p0i8` intrinsic.
        #[link_name = "llvm.xcore.msync.p0i8"]
        pub fn msync_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.ssync` intrinsic.
        #[link_name = "llvm.xcore.ssync"]
        pub fn ssync() -> ();
        /// The `llvm.xcore.mjoin.p0i8` intrinsic.
        #[link_name = "llvm.xcore.mjoin.p0i8"]
        pub fn mjoin_p0i8(a: *mut i8) -> ();
        /// The `llvm.xcore.initsp.p0i8` intrinsic.
        #[link_name = "llvm.xcore.initsp.p0i8"]
        pub fn initsp_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.initpc.p0i8` intrinsic.
        #[link_name = "llvm.xcore.initpc.p0i8"]
        pub fn initpc_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.initlr.p0i8` intrinsic.
        #[link_name = "llvm.xcore.initlr.p0i8"]
        pub fn initlr_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.initcp.p0i8` intrinsic.
        #[link_name = "llvm.xcore.initcp.p0i8"]
        pub fn initcp_p0i8(a: *mut i8, b: *mut i8) -> ();
        /// The `llvm.xcore.initdp.p0i8` intrinsic.
        #[link_name = "llvm.xcore.initdp.p0i8"]
        pub fn initdp_p0i8(a: *mut i8, b: *mut i8) -> ();
    }
}
/// Listing of the corresponding name(s) of many GCC intrinsics, for reference/search purposes.
///
/// <dl>
/// <dt><strong><code>__builtin_HEXAGON_A2_abs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_abs.html"><code>hexagon::A2_abs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_absp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_absp.html"><code>hexagon::A2_absp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_abssat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_abssat.html"><code>hexagon::A2_abssat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_add</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_add.html"><code>hexagon::A2_add</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_hh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_hh.html"><code>hexagon::A2_addh_h16_hh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_hl.html"><code>hexagon::A2_addh_h16_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_lh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_lh.html"><code>hexagon::A2_addh_h16_lh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_ll.html"><code>hexagon::A2_addh_h16_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_sat_hh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_sat_hh.html"><code>hexagon::A2_addh_h16_sat_hh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_sat_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_sat_hl.html"><code>hexagon::A2_addh_h16_sat_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_sat_lh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_sat_lh.html"><code>hexagon::A2_addh_h16_sat_lh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_h16_sat_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_h16_sat_ll.html"><code>hexagon::A2_addh_h16_sat_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_l16_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_l16_hl.html"><code>hexagon::A2_addh_l16_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_l16_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_l16_ll.html"><code>hexagon::A2_addh_l16_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_l16_sat_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_l16_sat_hl.html"><code>hexagon::A2_addh_l16_sat_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addh_l16_sat_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addh_l16_sat_ll.html"><code>hexagon::A2_addh_l16_sat_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addi.html"><code>hexagon::A2_addi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addp.html"><code>hexagon::A2_addp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addpsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addpsat.html"><code>hexagon::A2_addpsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addsat.html"><code>hexagon::A2_addsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_addsp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_addsp.html"><code>hexagon::A2_addsp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_and.html"><code>hexagon::A2_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_andir</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_andir.html"><code>hexagon::A2_andir</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_andp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_andp.html"><code>hexagon::A2_andp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_aslh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_aslh.html"><code>hexagon::A2_aslh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_asrh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_asrh.html"><code>hexagon::A2_asrh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combine_hh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combine_hh.html"><code>hexagon::A2_combine_hh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combine_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combine_hl.html"><code>hexagon::A2_combine_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combine_lh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combine_lh.html"><code>hexagon::A2_combine_lh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combine_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combine_ll.html"><code>hexagon::A2_combine_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combineii</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combineii.html"><code>hexagon::A2_combineii</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_combinew</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_combinew.html"><code>hexagon::A2_combinew</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_max</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_max.html"><code>hexagon::A2_max</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_maxp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_maxp.html"><code>hexagon::A2_maxp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_maxu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_maxu.html"><code>hexagon::A2_maxu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_maxup</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_maxup.html"><code>hexagon::A2_maxup</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_min</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_min.html"><code>hexagon::A2_min</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_minp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_minp.html"><code>hexagon::A2_minp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_minu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_minu.html"><code>hexagon::A2_minu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_minup</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_minup.html"><code>hexagon::A2_minup</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_neg</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_neg.html"><code>hexagon::A2_neg</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_negp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_negp.html"><code>hexagon::A2_negp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_negsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_negsat.html"><code>hexagon::A2_negsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_not</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_not.html"><code>hexagon::A2_not</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_notp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_notp.html"><code>hexagon::A2_notp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_or.html"><code>hexagon::A2_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_orir</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_orir.html"><code>hexagon::A2_orir</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_orp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_orp.html"><code>hexagon::A2_orp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_roundsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_roundsat.html"><code>hexagon::A2_roundsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sat.html"><code>hexagon::A2_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_satb</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_satb.html"><code>hexagon::A2_satb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sath</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sath.html"><code>hexagon::A2_sath</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_satub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_satub.html"><code>hexagon::A2_satub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_satuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_satuh.html"><code>hexagon::A2_satuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sub.html"><code>hexagon::A2_sub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_hh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_hh.html"><code>hexagon::A2_subh_h16_hh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_hl.html"><code>hexagon::A2_subh_h16_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_lh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_lh.html"><code>hexagon::A2_subh_h16_lh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_ll.html"><code>hexagon::A2_subh_h16_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_sat_hh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_sat_hh.html"><code>hexagon::A2_subh_h16_sat_hh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_sat_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_sat_hl.html"><code>hexagon::A2_subh_h16_sat_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_sat_lh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_sat_lh.html"><code>hexagon::A2_subh_h16_sat_lh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_h16_sat_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_h16_sat_ll.html"><code>hexagon::A2_subh_h16_sat_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_l16_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_l16_hl.html"><code>hexagon::A2_subh_l16_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_l16_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_l16_ll.html"><code>hexagon::A2_subh_l16_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_l16_sat_hl</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_l16_sat_hl.html"><code>hexagon::A2_subh_l16_sat_hl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subh_l16_sat_ll</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subh_l16_sat_ll.html"><code>hexagon::A2_subh_l16_sat_ll</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subp.html"><code>hexagon::A2_subp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subri</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subri.html"><code>hexagon::A2_subri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_subsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_subsat.html"><code>hexagon::A2_subsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svaddh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svaddh.html"><code>hexagon::A2_svaddh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svaddhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svaddhs.html"><code>hexagon::A2_svaddhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svadduhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svadduhs.html"><code>hexagon::A2_svadduhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svavgh.html"><code>hexagon::A2_svavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svavghs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svavghs.html"><code>hexagon::A2_svavghs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svnavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svnavgh.html"><code>hexagon::A2_svnavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svsubh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svsubh.html"><code>hexagon::A2_svsubh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svsubhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svsubhs.html"><code>hexagon::A2_svsubhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_svsubuhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_svsubuhs.html"><code>hexagon::A2_svsubuhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_swiz</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_swiz.html"><code>hexagon::A2_swiz</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sxtb</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sxtb.html"><code>hexagon::A2_sxtb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sxth</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sxth.html"><code>hexagon::A2_sxth</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_sxtw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_sxtw.html"><code>hexagon::A2_sxtw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfr.html"><code>hexagon::A2_tfr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfrih</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfrih.html"><code>hexagon::A2_tfrih</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfril</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfril.html"><code>hexagon::A2_tfril</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfrp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfrp.html"><code>hexagon::A2_tfrp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfrpi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfrpi.html"><code>hexagon::A2_tfrpi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_tfrsi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_tfrsi.html"><code>hexagon::A2_tfrsi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vabsh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vabsh.html"><code>hexagon::A2_vabsh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vabshsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vabshsat.html"><code>hexagon::A2_vabshsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vabsw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vabsw.html"><code>hexagon::A2_vabsw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vabswsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vabswsat.html"><code>hexagon::A2_vabswsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddb_map</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddb_map.html"><code>hexagon::A2_vaddb_map</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddh.html"><code>hexagon::A2_vaddh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddhs.html"><code>hexagon::A2_vaddhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddub.html"><code>hexagon::A2_vaddub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddubs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddubs.html"><code>hexagon::A2_vaddubs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vadduhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vadduhs.html"><code>hexagon::A2_vadduhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddw.html"><code>hexagon::A2_vaddw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vaddws</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vaddws.html"><code>hexagon::A2_vaddws</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgh.html"><code>hexagon::A2_vavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavghcr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavghcr.html"><code>hexagon::A2_vavghcr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavghr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavghr.html"><code>hexagon::A2_vavghr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgub.html"><code>hexagon::A2_vavgub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgubr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgubr.html"><code>hexagon::A2_vavgubr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavguh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavguh.html"><code>hexagon::A2_vavguh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavguhr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavguhr.html"><code>hexagon::A2_vavguhr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavguw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavguw.html"><code>hexagon::A2_vavguw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavguwr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavguwr.html"><code>hexagon::A2_vavguwr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgw.html"><code>hexagon::A2_vavgw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgwcr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgwcr.html"><code>hexagon::A2_vavgwcr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vavgwr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vavgwr.html"><code>hexagon::A2_vavgwr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpbeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpbeq.html"><code>hexagon::A2_vcmpbeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpbgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpbgtu.html"><code>hexagon::A2_vcmpbgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpheq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpheq.html"><code>hexagon::A2_vcmpheq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmphgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmphgt.html"><code>hexagon::A2_vcmphgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmphgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmphgtu.html"><code>hexagon::A2_vcmphgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpweq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpweq.html"><code>hexagon::A2_vcmpweq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpwgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpwgt.html"><code>hexagon::A2_vcmpwgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vcmpwgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vcmpwgtu.html"><code>hexagon::A2_vcmpwgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vconj</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vconj.html"><code>hexagon::A2_vconj</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxb</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxb.html"><code>hexagon::A2_vmaxb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxh.html"><code>hexagon::A2_vmaxh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxub.html"><code>hexagon::A2_vmaxub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxuh.html"><code>hexagon::A2_vmaxuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxuw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxuw.html"><code>hexagon::A2_vmaxuw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vmaxw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vmaxw.html"><code>hexagon::A2_vmaxw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminb</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminb.html"><code>hexagon::A2_vminb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminh.html"><code>hexagon::A2_vminh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminub.html"><code>hexagon::A2_vminub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminuh.html"><code>hexagon::A2_vminuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminuw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminuw.html"><code>hexagon::A2_vminuw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vminw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vminw.html"><code>hexagon::A2_vminw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavgh.html"><code>hexagon::A2_vnavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavghcr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavghcr.html"><code>hexagon::A2_vnavghcr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavghr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavghr.html"><code>hexagon::A2_vnavghr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavgw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavgw.html"><code>hexagon::A2_vnavgw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavgwcr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavgwcr.html"><code>hexagon::A2_vnavgwcr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vnavgwr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vnavgwr.html"><code>hexagon::A2_vnavgwr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vraddub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vraddub.html"><code>hexagon::A2_vraddub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vraddub_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vraddub_acc.html"><code>hexagon::A2_vraddub_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vrsadub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vrsadub.html"><code>hexagon::A2_vrsadub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vrsadub_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vrsadub_acc.html"><code>hexagon::A2_vrsadub_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubb_map</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubb_map.html"><code>hexagon::A2_vsubb_map</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubh.html"><code>hexagon::A2_vsubh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubhs.html"><code>hexagon::A2_vsubhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubub</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubub.html"><code>hexagon::A2_vsubub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsububs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsububs.html"><code>hexagon::A2_vsububs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubuhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubuhs.html"><code>hexagon::A2_vsubuhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubw.html"><code>hexagon::A2_vsubw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_vsubws</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_vsubws.html"><code>hexagon::A2_vsubws</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_xor.html"><code>hexagon::A2_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_xorp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_xorp.html"><code>hexagon::A2_xorp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_zxtb</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_zxtb.html"><code>hexagon::A2_zxtb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A2_zxth</code></strong></dt>
/// <dd><a href="../hexagon/fn.A2_zxth.html"><code>hexagon::A2_zxth</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_andn.html"><code>hexagon::A4_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_andnp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_andnp.html"><code>hexagon::A4_andnp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_bitsplit</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_bitsplit.html"><code>hexagon::A4_bitsplit</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_bitspliti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_bitspliti.html"><code>hexagon::A4_bitspliti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_boundscheck</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_boundscheck.html"><code>hexagon::A4_boundscheck</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbeq.html"><code>hexagon::A4_cmpbeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbeqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbeqi.html"><code>hexagon::A4_cmpbeqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbgt.html"><code>hexagon::A4_cmpbgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbgti.html"><code>hexagon::A4_cmpbgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbgtu.html"><code>hexagon::A4_cmpbgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpbgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpbgtui.html"><code>hexagon::A4_cmpbgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpheq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpheq.html"><code>hexagon::A4_cmpheq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmpheqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmpheqi.html"><code>hexagon::A4_cmpheqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmphgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmphgt.html"><code>hexagon::A4_cmphgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmphgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmphgti.html"><code>hexagon::A4_cmphgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmphgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmphgtu.html"><code>hexagon::A4_cmphgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cmphgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cmphgtui.html"><code>hexagon::A4_cmphgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_combineir</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_combineir.html"><code>hexagon::A4_combineir</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_combineri</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_combineri.html"><code>hexagon::A4_combineri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cround_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cround_ri.html"><code>hexagon::A4_cround_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_cround_rr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_cround_rr.html"><code>hexagon::A4_cround_rr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_modwrapu</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_modwrapu.html"><code>hexagon::A4_modwrapu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_orn</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_orn.html"><code>hexagon::A4_orn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_ornp</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_ornp.html"><code>hexagon::A4_ornp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_rcmpeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_rcmpeq.html"><code>hexagon::A4_rcmpeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_rcmpeqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_rcmpeqi.html"><code>hexagon::A4_rcmpeqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_rcmpneq</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_rcmpneq.html"><code>hexagon::A4_rcmpneq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_rcmpneqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_rcmpneqi.html"><code>hexagon::A4_rcmpneqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_round_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_round_ri.html"><code>hexagon::A4_round_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_round_ri_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_round_ri_sat.html"><code>hexagon::A4_round_ri_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_round_rr</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_round_rr.html"><code>hexagon::A4_round_rr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_round_rr_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_round_rr_sat.html"><code>hexagon::A4_round_rr_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_tlbmatch</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_tlbmatch.html"><code>hexagon::A4_tlbmatch</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpbeq_any</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpbeq_any.html"><code>hexagon::A4_vcmpbeq_any</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpbeqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpbeqi.html"><code>hexagon::A4_vcmpbeqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpbgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpbgt.html"><code>hexagon::A4_vcmpbgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpbgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpbgti.html"><code>hexagon::A4_vcmpbgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpbgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpbgtui.html"><code>hexagon::A4_vcmpbgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpheqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpheqi.html"><code>hexagon::A4_vcmpheqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmphgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmphgti.html"><code>hexagon::A4_vcmphgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmphgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmphgtui.html"><code>hexagon::A4_vcmphgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpweqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpweqi.html"><code>hexagon::A4_vcmpweqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpwgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpwgti.html"><code>hexagon::A4_vcmpwgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vcmpwgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vcmpwgtui.html"><code>hexagon::A4_vcmpwgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrmaxh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrmaxh.html"><code>hexagon::A4_vrmaxh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrmaxuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrmaxuh.html"><code>hexagon::A4_vrmaxuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrmaxuw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrmaxuw.html"><code>hexagon::A4_vrmaxuw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrmaxw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrmaxw.html"><code>hexagon::A4_vrmaxw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrminh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrminh.html"><code>hexagon::A4_vrminh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrminuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrminuh.html"><code>hexagon::A4_vrminuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrminuw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrminuw.html"><code>hexagon::A4_vrminuw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A4_vrminw</code></strong></dt>
/// <dd><a href="../hexagon/fn.A4_vrminw.html"><code>hexagon::A4_vrminw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_A5_vaddhubs</code></strong></dt>
/// <dd><a href="../hexagon/fn.A5_vaddhubs.html"><code>hexagon::A5_vaddhubs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_all8</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_all8.html"><code>hexagon::C2_all8</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_and.html"><code>hexagon::C2_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_andn.html"><code>hexagon::C2_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_any8</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_any8.html"><code>hexagon::C2_any8</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_bitsclr</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_bitsclr.html"><code>hexagon::C2_bitsclr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_bitsclri</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_bitsclri.html"><code>hexagon::C2_bitsclri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_bitsset</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_bitsset.html"><code>hexagon::C2_bitsset</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpeq.html"><code>hexagon::C2_cmpeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpeqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpeqi.html"><code>hexagon::C2_cmpeqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpeqp</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpeqp.html"><code>hexagon::C2_cmpeqp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgei</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgei.html"><code>hexagon::C2_cmpgei</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgeui</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgeui.html"><code>hexagon::C2_cmpgeui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgt.html"><code>hexagon::C2_cmpgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgti</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgti.html"><code>hexagon::C2_cmpgti</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgtp</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgtp.html"><code>hexagon::C2_cmpgtp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgtu</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgtu.html"><code>hexagon::C2_cmpgtu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgtui</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgtui.html"><code>hexagon::C2_cmpgtui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpgtup</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpgtup.html"><code>hexagon::C2_cmpgtup</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmplt</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmplt.html"><code>hexagon::C2_cmplt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_cmpltu</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_cmpltu.html"><code>hexagon::C2_cmpltu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_mask</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_mask.html"><code>hexagon::C2_mask</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_mux</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_mux.html"><code>hexagon::C2_mux</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_muxii</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_muxii.html"><code>hexagon::C2_muxii</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_muxir</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_muxir.html"><code>hexagon::C2_muxir</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_muxri</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_muxri.html"><code>hexagon::C2_muxri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_not</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_not.html"><code>hexagon::C2_not</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_or.html"><code>hexagon::C2_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_orn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_orn.html"><code>hexagon::C2_orn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_pxfer_map</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_pxfer_map.html"><code>hexagon::C2_pxfer_map</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_tfrpr</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_tfrpr.html"><code>hexagon::C2_tfrpr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_tfrrp</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_tfrrp.html"><code>hexagon::C2_tfrrp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_vitpack</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_vitpack.html"><code>hexagon::C2_vitpack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_vmux</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_vmux.html"><code>hexagon::C2_vmux</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C2_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.C2_xor.html"><code>hexagon::C2_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_and_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_and_and.html"><code>hexagon::C4_and_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_and_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_and_andn.html"><code>hexagon::C4_and_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_and_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_and_or.html"><code>hexagon::C4_and_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_and_orn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_and_orn.html"><code>hexagon::C4_and_orn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmplte</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmplte.html"><code>hexagon::C4_cmplte</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmpltei</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmpltei.html"><code>hexagon::C4_cmpltei</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmplteu</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmplteu.html"><code>hexagon::C4_cmplteu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmplteui</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmplteui.html"><code>hexagon::C4_cmplteui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmpneq</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmpneq.html"><code>hexagon::C4_cmpneq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_cmpneqi</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_cmpneqi.html"><code>hexagon::C4_cmpneqi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_fastcorner9</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_fastcorner9.html"><code>hexagon::C4_fastcorner9</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_fastcorner9_not</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_fastcorner9_not.html"><code>hexagon::C4_fastcorner9_not</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_nbitsclr</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_nbitsclr.html"><code>hexagon::C4_nbitsclr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_nbitsclri</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_nbitsclri.html"><code>hexagon::C4_nbitsclri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_nbitsset</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_nbitsset.html"><code>hexagon::C4_nbitsset</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_or_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_or_and.html"><code>hexagon::C4_or_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_or_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_or_andn.html"><code>hexagon::C4_or_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_or_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_or_or.html"><code>hexagon::C4_or_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_C4_or_orn</code></strong></dt>
/// <dd><a href="../hexagon/fn.C4_or_orn.html"><code>hexagon::C4_or_orn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_d2df</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_d2df.html"><code>hexagon::F2_conv_d2df</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_d2sf</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_d2sf.html"><code>hexagon::F2_conv_d2sf</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2d</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2d.html"><code>hexagon::F2_conv_df2d</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2d_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2d_chop.html"><code>hexagon::F2_conv_df2d_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2sf</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2sf.html"><code>hexagon::F2_conv_df2sf</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2ud</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2ud.html"><code>hexagon::F2_conv_df2ud</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2ud_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2ud_chop.html"><code>hexagon::F2_conv_df2ud_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2uw</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2uw.html"><code>hexagon::F2_conv_df2uw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2uw_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2uw_chop.html"><code>hexagon::F2_conv_df2uw_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2w</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2w.html"><code>hexagon::F2_conv_df2w</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_df2w_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_df2w_chop.html"><code>hexagon::F2_conv_df2w_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2d</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2d.html"><code>hexagon::F2_conv_sf2d</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2d_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2d_chop.html"><code>hexagon::F2_conv_sf2d_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2df</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2df.html"><code>hexagon::F2_conv_sf2df</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2ud</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2ud.html"><code>hexagon::F2_conv_sf2ud</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2ud_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2ud_chop.html"><code>hexagon::F2_conv_sf2ud_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2uw</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2uw.html"><code>hexagon::F2_conv_sf2uw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2uw_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2uw_chop.html"><code>hexagon::F2_conv_sf2uw_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2w</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2w.html"><code>hexagon::F2_conv_sf2w</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_sf2w_chop</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_sf2w_chop.html"><code>hexagon::F2_conv_sf2w_chop</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_ud2df</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_ud2df.html"><code>hexagon::F2_conv_ud2df</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_ud2sf</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_ud2sf.html"><code>hexagon::F2_conv_ud2sf</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_uw2df</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_uw2df.html"><code>hexagon::F2_conv_uw2df</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_uw2sf</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_uw2sf.html"><code>hexagon::F2_conv_uw2sf</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_w2df</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_w2df.html"><code>hexagon::F2_conv_w2df</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_conv_w2sf</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_conv_w2sf.html"><code>hexagon::F2_conv_w2sf</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfclass</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfclass.html"><code>hexagon::F2_dfclass</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfcmpeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfcmpeq.html"><code>hexagon::F2_dfcmpeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfcmpge</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfcmpge.html"><code>hexagon::F2_dfcmpge</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfcmpgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfcmpgt.html"><code>hexagon::F2_dfcmpgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfcmpuo</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfcmpuo.html"><code>hexagon::F2_dfcmpuo</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfimm_n</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfimm_n.html"><code>hexagon::F2_dfimm_n</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_dfimm_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_dfimm_p.html"><code>hexagon::F2_dfimm_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfadd</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfadd.html"><code>hexagon::F2_sfadd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfclass</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfclass.html"><code>hexagon::F2_sfclass</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfcmpeq</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfcmpeq.html"><code>hexagon::F2_sfcmpeq</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfcmpge</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfcmpge.html"><code>hexagon::F2_sfcmpge</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfcmpgt</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfcmpgt.html"><code>hexagon::F2_sfcmpgt</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfcmpuo</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfcmpuo.html"><code>hexagon::F2_sfcmpuo</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffixupd</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffixupd.html"><code>hexagon::F2_sffixupd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffixupn</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffixupn.html"><code>hexagon::F2_sffixupn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffixupr</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffixupr.html"><code>hexagon::F2_sffixupr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffma</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffma.html"><code>hexagon::F2_sffma</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffma_lib</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffma_lib.html"><code>hexagon::F2_sffma_lib</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffma_sc</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffma_sc.html"><code>hexagon::F2_sffma_sc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffms</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffms.html"><code>hexagon::F2_sffms</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sffms_lib</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sffms_lib.html"><code>hexagon::F2_sffms_lib</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfimm_n</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfimm_n.html"><code>hexagon::F2_sfimm_n</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfimm_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfimm_p.html"><code>hexagon::F2_sfimm_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfmax</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfmax.html"><code>hexagon::F2_sfmax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfmin</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfmin.html"><code>hexagon::F2_sfmin</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfmpy</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfmpy.html"><code>hexagon::F2_sfmpy</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_F2_sfsub</code></strong></dt>
/// <dd><a href="../hexagon/fn.F2_sfsub.html"><code>hexagon::F2_sfsub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_acci</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_acci.html"><code>hexagon::M2_acci</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_accii</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_accii.html"><code>hexagon::M2_accii</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmaci_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmaci_s0.html"><code>hexagon::M2_cmaci_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmacr_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmacr_s0.html"><code>hexagon::M2_cmacr_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmacs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmacs_s0.html"><code>hexagon::M2_cmacs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmacs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmacs_s1.html"><code>hexagon::M2_cmacs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmacsc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmacsc_s0.html"><code>hexagon::M2_cmacsc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmacsc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmacsc_s1.html"><code>hexagon::M2_cmacsc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyi_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyi_s0.html"><code>hexagon::M2_cmpyi_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyr_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyr_s0.html"><code>hexagon::M2_cmpyr_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyrs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyrs_s0.html"><code>hexagon::M2_cmpyrs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyrs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyrs_s1.html"><code>hexagon::M2_cmpyrs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyrsc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyrsc_s0.html"><code>hexagon::M2_cmpyrsc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpyrsc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpyrsc_s1.html"><code>hexagon::M2_cmpyrsc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpys_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpys_s0.html"><code>hexagon::M2_cmpys_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpys_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpys_s1.html"><code>hexagon::M2_cmpys_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpysc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpysc_s0.html"><code>hexagon::M2_cmpysc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cmpysc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cmpysc_s1.html"><code>hexagon::M2_cmpysc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cnacs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cnacs_s0.html"><code>hexagon::M2_cnacs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cnacs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cnacs_s1.html"><code>hexagon::M2_cnacs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cnacsc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cnacsc_s0.html"><code>hexagon::M2_cnacsc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_cnacsc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_cnacsc_s1.html"><code>hexagon::M2_cnacsc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyss_acc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyss_acc_s0.html"><code>hexagon::M2_dpmpyss_acc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyss_nac_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyss_nac_s0.html"><code>hexagon::M2_dpmpyss_nac_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyss_rnd_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyss_rnd_s0.html"><code>hexagon::M2_dpmpyss_rnd_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyss_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyss_s0.html"><code>hexagon::M2_dpmpyss_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyuu_acc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyuu_acc_s0.html"><code>hexagon::M2_dpmpyuu_acc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyuu_nac_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyuu_nac_s0.html"><code>hexagon::M2_dpmpyuu_nac_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_dpmpyuu_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_dpmpyuu_s0.html"><code>hexagon::M2_dpmpyuu_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_hmmpyh_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_hmmpyh_rs1.html"><code>hexagon::M2_hmmpyh_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_hmmpyh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_hmmpyh_s1.html"><code>hexagon::M2_hmmpyh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_hmmpyl_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_hmmpyl_rs1.html"><code>hexagon::M2_hmmpyl_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_hmmpyl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_hmmpyl_s1.html"><code>hexagon::M2_hmmpyl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_maci</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_maci.html"><code>hexagon::M2_maci</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_macsin</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_macsin.html"><code>hexagon::M2_macsin</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_macsip</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_macsip.html"><code>hexagon::M2_macsip</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmachs_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmachs_rs0.html"><code>hexagon::M2_mmachs_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmachs_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmachs_rs1.html"><code>hexagon::M2_mmachs_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmachs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmachs_s0.html"><code>hexagon::M2_mmachs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmachs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmachs_s1.html"><code>hexagon::M2_mmachs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacls_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacls_rs0.html"><code>hexagon::M2_mmacls_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacls_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacls_rs1.html"><code>hexagon::M2_mmacls_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacls_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacls_s0.html"><code>hexagon::M2_mmacls_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacls_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacls_s1.html"><code>hexagon::M2_mmacls_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacuhs_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacuhs_rs0.html"><code>hexagon::M2_mmacuhs_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacuhs_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacuhs_rs1.html"><code>hexagon::M2_mmacuhs_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacuhs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacuhs_s0.html"><code>hexagon::M2_mmacuhs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmacuhs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmacuhs_s1.html"><code>hexagon::M2_mmacuhs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmaculs_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmaculs_rs0.html"><code>hexagon::M2_mmaculs_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmaculs_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmaculs_rs1.html"><code>hexagon::M2_mmaculs_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmaculs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmaculs_s0.html"><code>hexagon::M2_mmaculs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmaculs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmaculs_s1.html"><code>hexagon::M2_mmaculs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyh_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyh_rs0.html"><code>hexagon::M2_mmpyh_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyh_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyh_rs1.html"><code>hexagon::M2_mmpyh_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyh_s0.html"><code>hexagon::M2_mmpyh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyh_s1.html"><code>hexagon::M2_mmpyh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyl_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyl_rs0.html"><code>hexagon::M2_mmpyl_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyl_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyl_rs1.html"><code>hexagon::M2_mmpyl_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyl_s0.html"><code>hexagon::M2_mmpyl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyl_s1.html"><code>hexagon::M2_mmpyl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyuh_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyuh_rs0.html"><code>hexagon::M2_mmpyuh_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyuh_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyuh_rs1.html"><code>hexagon::M2_mmpyuh_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyuh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyuh_s0.html"><code>hexagon::M2_mmpyuh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyuh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyuh_s1.html"><code>hexagon::M2_mmpyuh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyul_rs0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyul_rs0.html"><code>hexagon::M2_mmpyul_rs0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyul_rs1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyul_rs1.html"><code>hexagon::M2_mmpyul_rs1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyul_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyul_s0.html"><code>hexagon::M2_mmpyul_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mmpyul_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mmpyul_s1.html"><code>hexagon::M2_mmpyul_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_hh_s0.html"><code>hexagon::M2_mpy_acc_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_hh_s1.html"><code>hexagon::M2_mpy_acc_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_hl_s0.html"><code>hexagon::M2_mpy_acc_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_hl_s1.html"><code>hexagon::M2_mpy_acc_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_lh_s0.html"><code>hexagon::M2_mpy_acc_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_lh_s1.html"><code>hexagon::M2_mpy_acc_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_ll_s0.html"><code>hexagon::M2_mpy_acc_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_ll_s1.html"><code>hexagon::M2_mpy_acc_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_hh_s0.html"><code>hexagon::M2_mpy_acc_sat_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_hh_s1.html"><code>hexagon::M2_mpy_acc_sat_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_hl_s0.html"><code>hexagon::M2_mpy_acc_sat_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_hl_s1.html"><code>hexagon::M2_mpy_acc_sat_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_lh_s0.html"><code>hexagon::M2_mpy_acc_sat_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_lh_s1.html"><code>hexagon::M2_mpy_acc_sat_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_ll_s0.html"><code>hexagon::M2_mpy_acc_sat_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_acc_sat_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_acc_sat_ll_s1.html"><code>hexagon::M2_mpy_acc_sat_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_hh_s0.html"><code>hexagon::M2_mpy_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_hh_s1.html"><code>hexagon::M2_mpy_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_hl_s0.html"><code>hexagon::M2_mpy_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_hl_s1.html"><code>hexagon::M2_mpy_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_lh_s0.html"><code>hexagon::M2_mpy_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_lh_s1.html"><code>hexagon::M2_mpy_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_ll_s0.html"><code>hexagon::M2_mpy_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_ll_s1.html"><code>hexagon::M2_mpy_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_hh_s0.html"><code>hexagon::M2_mpy_nac_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_hh_s1.html"><code>hexagon::M2_mpy_nac_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_hl_s0.html"><code>hexagon::M2_mpy_nac_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_hl_s1.html"><code>hexagon::M2_mpy_nac_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_lh_s0.html"><code>hexagon::M2_mpy_nac_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_lh_s1.html"><code>hexagon::M2_mpy_nac_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_ll_s0.html"><code>hexagon::M2_mpy_nac_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_ll_s1.html"><code>hexagon::M2_mpy_nac_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_hh_s0.html"><code>hexagon::M2_mpy_nac_sat_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_hh_s1.html"><code>hexagon::M2_mpy_nac_sat_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_hl_s0.html"><code>hexagon::M2_mpy_nac_sat_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_hl_s1.html"><code>hexagon::M2_mpy_nac_sat_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_lh_s0.html"><code>hexagon::M2_mpy_nac_sat_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_lh_s1.html"><code>hexagon::M2_mpy_nac_sat_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_ll_s0.html"><code>hexagon::M2_mpy_nac_sat_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_nac_sat_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_nac_sat_ll_s1.html"><code>hexagon::M2_mpy_nac_sat_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_hh_s0.html"><code>hexagon::M2_mpy_rnd_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_hh_s1.html"><code>hexagon::M2_mpy_rnd_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_hl_s0.html"><code>hexagon::M2_mpy_rnd_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_hl_s1.html"><code>hexagon::M2_mpy_rnd_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_lh_s0.html"><code>hexagon::M2_mpy_rnd_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_lh_s1.html"><code>hexagon::M2_mpy_rnd_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_ll_s0.html"><code>hexagon::M2_mpy_rnd_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_rnd_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_rnd_ll_s1.html"><code>hexagon::M2_mpy_rnd_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_hh_s0.html"><code>hexagon::M2_mpy_sat_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_hh_s1.html"><code>hexagon::M2_mpy_sat_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_hl_s0.html"><code>hexagon::M2_mpy_sat_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_hl_s1.html"><code>hexagon::M2_mpy_sat_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_lh_s0.html"><code>hexagon::M2_mpy_sat_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_lh_s1.html"><code>hexagon::M2_mpy_sat_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_ll_s0.html"><code>hexagon::M2_mpy_sat_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_ll_s1.html"><code>hexagon::M2_mpy_sat_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_hh_s0.html"><code>hexagon::M2_mpy_sat_rnd_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_hh_s1.html"><code>hexagon::M2_mpy_sat_rnd_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_hl_s0.html"><code>hexagon::M2_mpy_sat_rnd_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_hl_s1.html"><code>hexagon::M2_mpy_sat_rnd_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_lh_s0.html"><code>hexagon::M2_mpy_sat_rnd_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_lh_s1.html"><code>hexagon::M2_mpy_sat_rnd_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_ll_s0.html"><code>hexagon::M2_mpy_sat_rnd_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_sat_rnd_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_sat_rnd_ll_s1.html"><code>hexagon::M2_mpy_sat_rnd_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_up</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_up.html"><code>hexagon::M2_mpy_up</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_up_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_up_s1.html"><code>hexagon::M2_mpy_up_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpy_up_s1_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpy_up_s1_sat.html"><code>hexagon::M2_mpy_up_s1_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_hh_s0.html"><code>hexagon::M2_mpyd_acc_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_hh_s1.html"><code>hexagon::M2_mpyd_acc_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_hl_s0.html"><code>hexagon::M2_mpyd_acc_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_hl_s1.html"><code>hexagon::M2_mpyd_acc_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_lh_s0.html"><code>hexagon::M2_mpyd_acc_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_lh_s1.html"><code>hexagon::M2_mpyd_acc_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_ll_s0.html"><code>hexagon::M2_mpyd_acc_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_acc_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_acc_ll_s1.html"><code>hexagon::M2_mpyd_acc_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_hh_s0.html"><code>hexagon::M2_mpyd_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_hh_s1.html"><code>hexagon::M2_mpyd_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_hl_s0.html"><code>hexagon::M2_mpyd_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_hl_s1.html"><code>hexagon::M2_mpyd_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_lh_s0.html"><code>hexagon::M2_mpyd_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_lh_s1.html"><code>hexagon::M2_mpyd_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_ll_s0.html"><code>hexagon::M2_mpyd_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_ll_s1.html"><code>hexagon::M2_mpyd_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_hh_s0.html"><code>hexagon::M2_mpyd_nac_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_hh_s1.html"><code>hexagon::M2_mpyd_nac_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_hl_s0.html"><code>hexagon::M2_mpyd_nac_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_hl_s1.html"><code>hexagon::M2_mpyd_nac_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_lh_s0.html"><code>hexagon::M2_mpyd_nac_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_lh_s1.html"><code>hexagon::M2_mpyd_nac_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_ll_s0.html"><code>hexagon::M2_mpyd_nac_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_nac_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_nac_ll_s1.html"><code>hexagon::M2_mpyd_nac_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_hh_s0.html"><code>hexagon::M2_mpyd_rnd_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_hh_s1.html"><code>hexagon::M2_mpyd_rnd_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_hl_s0.html"><code>hexagon::M2_mpyd_rnd_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_hl_s1.html"><code>hexagon::M2_mpyd_rnd_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_lh_s0.html"><code>hexagon::M2_mpyd_rnd_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_lh_s1.html"><code>hexagon::M2_mpyd_rnd_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_ll_s0.html"><code>hexagon::M2_mpyd_rnd_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyd_rnd_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyd_rnd_ll_s1.html"><code>hexagon::M2_mpyd_rnd_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyi</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyi.html"><code>hexagon::M2_mpyi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpysmi</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpysmi.html"><code>hexagon::M2_mpysmi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpysu_up</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpysu_up.html"><code>hexagon::M2_mpysu_up</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_hh_s0.html"><code>hexagon::M2_mpyu_acc_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_hh_s1.html"><code>hexagon::M2_mpyu_acc_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_hl_s0.html"><code>hexagon::M2_mpyu_acc_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_hl_s1.html"><code>hexagon::M2_mpyu_acc_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_lh_s0.html"><code>hexagon::M2_mpyu_acc_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_lh_s1.html"><code>hexagon::M2_mpyu_acc_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_ll_s0.html"><code>hexagon::M2_mpyu_acc_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_acc_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_acc_ll_s1.html"><code>hexagon::M2_mpyu_acc_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_hh_s0.html"><code>hexagon::M2_mpyu_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_hh_s1.html"><code>hexagon::M2_mpyu_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_hl_s0.html"><code>hexagon::M2_mpyu_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_hl_s1.html"><code>hexagon::M2_mpyu_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_lh_s0.html"><code>hexagon::M2_mpyu_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_lh_s1.html"><code>hexagon::M2_mpyu_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_ll_s0.html"><code>hexagon::M2_mpyu_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_ll_s1.html"><code>hexagon::M2_mpyu_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_hh_s0.html"><code>hexagon::M2_mpyu_nac_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_hh_s1.html"><code>hexagon::M2_mpyu_nac_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_hl_s0.html"><code>hexagon::M2_mpyu_nac_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_hl_s1.html"><code>hexagon::M2_mpyu_nac_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_lh_s0.html"><code>hexagon::M2_mpyu_nac_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_lh_s1.html"><code>hexagon::M2_mpyu_nac_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_ll_s0.html"><code>hexagon::M2_mpyu_nac_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_nac_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_nac_ll_s1.html"><code>hexagon::M2_mpyu_nac_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyu_up</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyu_up.html"><code>hexagon::M2_mpyu_up</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_hh_s0.html"><code>hexagon::M2_mpyud_acc_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_hh_s1.html"><code>hexagon::M2_mpyud_acc_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_hl_s0.html"><code>hexagon::M2_mpyud_acc_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_hl_s1.html"><code>hexagon::M2_mpyud_acc_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_lh_s0.html"><code>hexagon::M2_mpyud_acc_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_lh_s1.html"><code>hexagon::M2_mpyud_acc_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_ll_s0.html"><code>hexagon::M2_mpyud_acc_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_acc_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_acc_ll_s1.html"><code>hexagon::M2_mpyud_acc_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_hh_s0.html"><code>hexagon::M2_mpyud_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_hh_s1.html"><code>hexagon::M2_mpyud_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_hl_s0.html"><code>hexagon::M2_mpyud_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_hl_s1.html"><code>hexagon::M2_mpyud_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_lh_s0.html"><code>hexagon::M2_mpyud_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_lh_s1.html"><code>hexagon::M2_mpyud_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_ll_s0.html"><code>hexagon::M2_mpyud_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_ll_s1.html"><code>hexagon::M2_mpyud_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_hh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_hh_s0.html"><code>hexagon::M2_mpyud_nac_hh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_hh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_hh_s1.html"><code>hexagon::M2_mpyud_nac_hh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_hl_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_hl_s0.html"><code>hexagon::M2_mpyud_nac_hl_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_hl_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_hl_s1.html"><code>hexagon::M2_mpyud_nac_hl_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_lh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_lh_s0.html"><code>hexagon::M2_mpyud_nac_lh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_lh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_lh_s1.html"><code>hexagon::M2_mpyud_nac_lh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_ll_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_ll_s0.html"><code>hexagon::M2_mpyud_nac_ll_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyud_nac_ll_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyud_nac_ll_s1.html"><code>hexagon::M2_mpyud_nac_ll_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_mpyui</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_mpyui.html"><code>hexagon::M2_mpyui</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_nacci</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_nacci.html"><code>hexagon::M2_nacci</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_naccii</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_naccii.html"><code>hexagon::M2_naccii</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_subacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_subacc.html"><code>hexagon::M2_subacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vabsdiffh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vabsdiffh.html"><code>hexagon::M2_vabsdiffh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vabsdiffw</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vabsdiffw.html"><code>hexagon::M2_vabsdiffw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmac_s0_sat_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmac_s0_sat_i.html"><code>hexagon::M2_vcmac_s0_sat_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmac_s0_sat_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmac_s0_sat_r.html"><code>hexagon::M2_vcmac_s0_sat_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmpy_s0_sat_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmpy_s0_sat_i.html"><code>hexagon::M2_vcmpy_s0_sat_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmpy_s0_sat_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmpy_s0_sat_r.html"><code>hexagon::M2_vcmpy_s0_sat_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmpy_s1_sat_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmpy_s1_sat_i.html"><code>hexagon::M2_vcmpy_s1_sat_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vcmpy_s1_sat_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vcmpy_s1_sat_r.html"><code>hexagon::M2_vcmpy_s1_sat_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmacs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmacs_s0.html"><code>hexagon::M2_vdmacs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmacs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmacs_s1.html"><code>hexagon::M2_vdmacs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmpyrs_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmpyrs_s0.html"><code>hexagon::M2_vdmpyrs_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmpyrs_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmpyrs_s1.html"><code>hexagon::M2_vdmpyrs_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmpys_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmpys_s0.html"><code>hexagon::M2_vdmpys_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vdmpys_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vdmpys_s1.html"><code>hexagon::M2_vdmpys_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2.html"><code>hexagon::M2_vmac2</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2es</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2es.html"><code>hexagon::M2_vmac2es</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2es_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2es_s0.html"><code>hexagon::M2_vmac2es_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2es_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2es_s1.html"><code>hexagon::M2_vmac2es_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2s_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2s_s0.html"><code>hexagon::M2_vmac2s_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2s_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2s_s1.html"><code>hexagon::M2_vmac2s_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2su_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2su_s0.html"><code>hexagon::M2_vmac2su_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmac2su_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmac2su_s1.html"><code>hexagon::M2_vmac2su_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2es_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2es_s0.html"><code>hexagon::M2_vmpy2es_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2es_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2es_s1.html"><code>hexagon::M2_vmpy2es_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2s_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2s_s0.html"><code>hexagon::M2_vmpy2s_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2s_s0pack</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2s_s0pack.html"><code>hexagon::M2_vmpy2s_s0pack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2s_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2s_s1.html"><code>hexagon::M2_vmpy2s_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2s_s1pack</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2s_s1pack.html"><code>hexagon::M2_vmpy2s_s1pack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2su_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2su_s0.html"><code>hexagon::M2_vmpy2su_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vmpy2su_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vmpy2su_s1.html"><code>hexagon::M2_vmpy2su_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vraddh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vraddh.html"><code>hexagon::M2_vraddh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vradduh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vradduh.html"><code>hexagon::M2_vradduh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmaci_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmaci_s0.html"><code>hexagon::M2_vrcmaci_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmaci_s0c</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmaci_s0c.html"><code>hexagon::M2_vrcmaci_s0c</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmacr_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmacr_s0.html"><code>hexagon::M2_vrcmacr_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmacr_s0c</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmacr_s0c.html"><code>hexagon::M2_vrcmacr_s0c</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpyi_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpyi_s0.html"><code>hexagon::M2_vrcmpyi_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpyi_s0c</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpyi_s0c.html"><code>hexagon::M2_vrcmpyi_s0c</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpyr_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpyr_s0.html"><code>hexagon::M2_vrcmpyr_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpyr_s0c</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpyr_s0c.html"><code>hexagon::M2_vrcmpyr_s0c</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpys_acc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpys_acc_s1.html"><code>hexagon::M2_vrcmpys_acc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpys_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpys_s1.html"><code>hexagon::M2_vrcmpys_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrcmpys_s1rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrcmpys_s1rp.html"><code>hexagon::M2_vrcmpys_s1rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrmac_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrmac_s0.html"><code>hexagon::M2_vrmac_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_vrmpy_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_vrmpy_s0.html"><code>hexagon::M2_vrmpy_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M2_xor_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M2_xor_xacc.html"><code>hexagon::M2_xor_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_and_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_and_and.html"><code>hexagon::M4_and_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_and_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_and_andn.html"><code>hexagon::M4_and_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_and_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_and_or.html"><code>hexagon::M4_and_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_and_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_and_xor.html"><code>hexagon::M4_and_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_cmpyi_wh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_cmpyi_wh.html"><code>hexagon::M4_cmpyi_wh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_cmpyi_whc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_cmpyi_whc.html"><code>hexagon::M4_cmpyi_whc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_cmpyr_wh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_cmpyr_wh.html"><code>hexagon::M4_cmpyr_wh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_cmpyr_whc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_cmpyr_whc.html"><code>hexagon::M4_cmpyr_whc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mac_up_s1_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mac_up_s1_sat.html"><code>hexagon::M4_mac_up_s1_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mpyri_addi</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mpyri_addi.html"><code>hexagon::M4_mpyri_addi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mpyri_addr</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mpyri_addr.html"><code>hexagon::M4_mpyri_addr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mpyri_addr_u2</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mpyri_addr_u2.html"><code>hexagon::M4_mpyri_addr_u2</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mpyrr_addi</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mpyrr_addi.html"><code>hexagon::M4_mpyrr_addi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_mpyrr_addr</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_mpyrr_addr.html"><code>hexagon::M4_mpyrr_addr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_nac_up_s1_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_nac_up_s1_sat.html"><code>hexagon::M4_nac_up_s1_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_or_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_or_and.html"><code>hexagon::M4_or_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_or_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_or_andn.html"><code>hexagon::M4_or_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_or_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_or_or.html"><code>hexagon::M4_or_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_or_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_or_xor.html"><code>hexagon::M4_or_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_pmpyw</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_pmpyw.html"><code>hexagon::M4_pmpyw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_pmpyw_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_pmpyw_acc.html"><code>hexagon::M4_pmpyw_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vpmpyh</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vpmpyh.html"><code>hexagon::M4_vpmpyh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vpmpyh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vpmpyh_acc.html"><code>hexagon::M4_vpmpyh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyeh_acc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyeh_acc_s0.html"><code>hexagon::M4_vrmpyeh_acc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyeh_acc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyeh_acc_s1.html"><code>hexagon::M4_vrmpyeh_acc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyeh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyeh_s0.html"><code>hexagon::M4_vrmpyeh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyeh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyeh_s1.html"><code>hexagon::M4_vrmpyeh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyoh_acc_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyoh_acc_s0.html"><code>hexagon::M4_vrmpyoh_acc_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyoh_acc_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyoh_acc_s1.html"><code>hexagon::M4_vrmpyoh_acc_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyoh_s0</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyoh_s0.html"><code>hexagon::M4_vrmpyoh_s0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_vrmpyoh_s1</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_vrmpyoh_s1.html"><code>hexagon::M4_vrmpyoh_s1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_xor_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_xor_and.html"><code>hexagon::M4_xor_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_xor_andn</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_xor_andn.html"><code>hexagon::M4_xor_andn</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_xor_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_xor_or.html"><code>hexagon::M4_xor_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M4_xor_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.M4_xor_xacc.html"><code>hexagon::M4_xor_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vdmacbsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vdmacbsu.html"><code>hexagon::M5_vdmacbsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vdmpybsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vdmpybsu.html"><code>hexagon::M5_vdmpybsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vmacbsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vmacbsu.html"><code>hexagon::M5_vmacbsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vmacbuu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vmacbuu.html"><code>hexagon::M5_vmacbuu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vmpybsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vmpybsu.html"><code>hexagon::M5_vmpybsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vmpybuu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vmpybuu.html"><code>hexagon::M5_vmpybuu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vrmacbsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vrmacbsu.html"><code>hexagon::M5_vrmacbsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vrmacbuu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vrmacbuu.html"><code>hexagon::M5_vrmacbuu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vrmpybsu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vrmpybsu.html"><code>hexagon::M5_vrmpybsu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M5_vrmpybuu</code></strong></dt>
/// <dd><a href="../hexagon/fn.M5_vrmpybuu.html"><code>hexagon::M5_vrmpybuu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M6_vabsdiffb</code></strong></dt>
/// <dd><a href="../hexagon/fn.M6_vabsdiffb.html"><code>hexagon::M6_vabsdiffb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_M6_vabsdiffub</code></strong></dt>
/// <dd><a href="../hexagon/fn.M6_vabsdiffub.html"><code>hexagon::M6_vabsdiffub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_addasl_rrri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_addasl_rrri.html"><code>hexagon::S2_addasl_rrri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p.html"><code>hexagon::S2_asl_i_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p_acc.html"><code>hexagon::S2_asl_i_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p_and.html"><code>hexagon::S2_asl_i_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p_nac.html"><code>hexagon::S2_asl_i_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p_or.html"><code>hexagon::S2_asl_i_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_p_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_p_xacc.html"><code>hexagon::S2_asl_i_p_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r.html"><code>hexagon::S2_asl_i_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_acc.html"><code>hexagon::S2_asl_i_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_and.html"><code>hexagon::S2_asl_i_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_nac.html"><code>hexagon::S2_asl_i_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_or.html"><code>hexagon::S2_asl_i_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_sat.html"><code>hexagon::S2_asl_i_r_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_r_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_r_xacc.html"><code>hexagon::S2_asl_i_r_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_vh.html"><code>hexagon::S2_asl_i_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_i_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_i_vw.html"><code>hexagon::S2_asl_i_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p.html"><code>hexagon::S2_asl_r_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p_acc.html"><code>hexagon::S2_asl_r_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p_and.html"><code>hexagon::S2_asl_r_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p_nac.html"><code>hexagon::S2_asl_r_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p_or.html"><code>hexagon::S2_asl_r_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_p_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_p_xor.html"><code>hexagon::S2_asl_r_p_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r.html"><code>hexagon::S2_asl_r_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r_acc.html"><code>hexagon::S2_asl_r_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r_and.html"><code>hexagon::S2_asl_r_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r_nac.html"><code>hexagon::S2_asl_r_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r_or.html"><code>hexagon::S2_asl_r_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_r_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_r_sat.html"><code>hexagon::S2_asl_r_r_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_vh.html"><code>hexagon::S2_asl_r_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asl_r_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asl_r_vw.html"><code>hexagon::S2_asl_r_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p.html"><code>hexagon::S2_asr_i_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_acc.html"><code>hexagon::S2_asr_i_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_and.html"><code>hexagon::S2_asr_i_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_nac.html"><code>hexagon::S2_asr_i_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_or.html"><code>hexagon::S2_asr_i_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_rnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_rnd.html"><code>hexagon::S2_asr_i_p_rnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_p_rnd_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_p_rnd_goodsyntax.html"><code>hexagon::S2_asr_i_p_rnd_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r.html"><code>hexagon::S2_asr_i_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_acc.html"><code>hexagon::S2_asr_i_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_and.html"><code>hexagon::S2_asr_i_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_nac.html"><code>hexagon::S2_asr_i_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_or.html"><code>hexagon::S2_asr_i_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_rnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_rnd.html"><code>hexagon::S2_asr_i_r_rnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_r_rnd_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_r_rnd_goodsyntax.html"><code>hexagon::S2_asr_i_r_rnd_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_svw_trun</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_svw_trun.html"><code>hexagon::S2_asr_i_svw_trun</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_vh.html"><code>hexagon::S2_asr_i_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_i_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_i_vw.html"><code>hexagon::S2_asr_i_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p.html"><code>hexagon::S2_asr_r_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p_acc.html"><code>hexagon::S2_asr_r_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p_and.html"><code>hexagon::S2_asr_r_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p_nac.html"><code>hexagon::S2_asr_r_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p_or.html"><code>hexagon::S2_asr_r_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_p_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_p_xor.html"><code>hexagon::S2_asr_r_p_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r.html"><code>hexagon::S2_asr_r_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r_acc.html"><code>hexagon::S2_asr_r_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r_and.html"><code>hexagon::S2_asr_r_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r_nac.html"><code>hexagon::S2_asr_r_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r_or.html"><code>hexagon::S2_asr_r_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_r_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_r_sat.html"><code>hexagon::S2_asr_r_r_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_svw_trun</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_svw_trun.html"><code>hexagon::S2_asr_r_svw_trun</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_vh.html"><code>hexagon::S2_asr_r_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_asr_r_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_asr_r_vw.html"><code>hexagon::S2_asr_r_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_brev</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_brev.html"><code>hexagon::S2_brev</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_brevp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_brevp.html"><code>hexagon::S2_brevp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_cabacencbin</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_cabacencbin.html"><code>hexagon::S2_cabacencbin</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_cl0</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_cl0.html"><code>hexagon::S2_cl0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_cl0p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_cl0p.html"><code>hexagon::S2_cl0p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_cl1</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_cl1.html"><code>hexagon::S2_cl1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_cl1p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_cl1p.html"><code>hexagon::S2_cl1p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_clb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_clb.html"><code>hexagon::S2_clb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_clbnorm</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_clbnorm.html"><code>hexagon::S2_clbnorm</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_clbp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_clbp.html"><code>hexagon::S2_clbp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_clrbit_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_clrbit_i.html"><code>hexagon::S2_clrbit_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_clrbit_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_clrbit_r.html"><code>hexagon::S2_clrbit_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_ct0</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_ct0.html"><code>hexagon::S2_ct0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_ct0p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_ct0p.html"><code>hexagon::S2_ct0p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_ct1</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_ct1.html"><code>hexagon::S2_ct1</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_ct1p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_ct1p.html"><code>hexagon::S2_ct1p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_deinterleave</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_deinterleave.html"><code>hexagon::S2_deinterleave</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_extractu</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_extractu.html"><code>hexagon::S2_extractu</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_extractu_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_extractu_rp.html"><code>hexagon::S2_extractu_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_extractup</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_extractup.html"><code>hexagon::S2_extractup</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_extractup_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_extractup_rp.html"><code>hexagon::S2_extractup_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_insert</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_insert.html"><code>hexagon::S2_insert</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_insert_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_insert_rp.html"><code>hexagon::S2_insert_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_insertp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_insertp.html"><code>hexagon::S2_insertp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_insertp_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_insertp_rp.html"><code>hexagon::S2_insertp_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_interleave</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_interleave.html"><code>hexagon::S2_interleave</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lfsp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lfsp.html"><code>hexagon::S2_lfsp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p.html"><code>hexagon::S2_lsl_r_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p_acc.html"><code>hexagon::S2_lsl_r_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p_and.html"><code>hexagon::S2_lsl_r_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p_nac.html"><code>hexagon::S2_lsl_r_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p_or.html"><code>hexagon::S2_lsl_r_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_p_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_p_xor.html"><code>hexagon::S2_lsl_r_p_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_r.html"><code>hexagon::S2_lsl_r_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_r_acc.html"><code>hexagon::S2_lsl_r_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_r_and.html"><code>hexagon::S2_lsl_r_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_r_nac.html"><code>hexagon::S2_lsl_r_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_r_or.html"><code>hexagon::S2_lsl_r_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_vh.html"><code>hexagon::S2_lsl_r_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsl_r_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsl_r_vw.html"><code>hexagon::S2_lsl_r_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p.html"><code>hexagon::S2_lsr_i_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p_acc.html"><code>hexagon::S2_lsr_i_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p_and.html"><code>hexagon::S2_lsr_i_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p_nac.html"><code>hexagon::S2_lsr_i_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p_or.html"><code>hexagon::S2_lsr_i_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_p_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_p_xacc.html"><code>hexagon::S2_lsr_i_p_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r.html"><code>hexagon::S2_lsr_i_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r_acc.html"><code>hexagon::S2_lsr_i_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r_and.html"><code>hexagon::S2_lsr_i_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r_nac.html"><code>hexagon::S2_lsr_i_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r_or.html"><code>hexagon::S2_lsr_i_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_r_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_r_xacc.html"><code>hexagon::S2_lsr_i_r_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_vh.html"><code>hexagon::S2_lsr_i_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_i_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_i_vw.html"><code>hexagon::S2_lsr_i_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p.html"><code>hexagon::S2_lsr_r_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p_acc.html"><code>hexagon::S2_lsr_r_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p_and.html"><code>hexagon::S2_lsr_r_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p_nac.html"><code>hexagon::S2_lsr_r_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p_or.html"><code>hexagon::S2_lsr_r_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_p_xor</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_p_xor.html"><code>hexagon::S2_lsr_r_p_xor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_r.html"><code>hexagon::S2_lsr_r_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_r_acc.html"><code>hexagon::S2_lsr_r_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_r_and.html"><code>hexagon::S2_lsr_r_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_r_nac.html"><code>hexagon::S2_lsr_r_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_r_or.html"><code>hexagon::S2_lsr_r_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_vh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_vh.html"><code>hexagon::S2_lsr_r_vh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_lsr_r_vw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_lsr_r_vw.html"><code>hexagon::S2_lsr_r_vw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_packhl</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_packhl.html"><code>hexagon::S2_packhl</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_parityp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_parityp.html"><code>hexagon::S2_parityp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_setbit_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_setbit_i.html"><code>hexagon::S2_setbit_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_setbit_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_setbit_r.html"><code>hexagon::S2_setbit_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_shuffeb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_shuffeb.html"><code>hexagon::S2_shuffeb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_shuffeh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_shuffeh.html"><code>hexagon::S2_shuffeh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_shuffob</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_shuffob.html"><code>hexagon::S2_shuffob</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_shuffoh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_shuffoh.html"><code>hexagon::S2_shuffoh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_svsathb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_svsathb.html"><code>hexagon::S2_svsathb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_svsathub</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_svsathub.html"><code>hexagon::S2_svsathub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tableidxb_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tableidxb_goodsyntax.html"><code>hexagon::S2_tableidxb_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tableidxd_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tableidxd_goodsyntax.html"><code>hexagon::S2_tableidxd_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tableidxh_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tableidxh_goodsyntax.html"><code>hexagon::S2_tableidxh_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tableidxw_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tableidxw_goodsyntax.html"><code>hexagon::S2_tableidxw_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_togglebit_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_togglebit_i.html"><code>hexagon::S2_togglebit_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_togglebit_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_togglebit_r.html"><code>hexagon::S2_togglebit_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tstbit_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tstbit_i.html"><code>hexagon::S2_tstbit_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_tstbit_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_tstbit_r.html"><code>hexagon::S2_tstbit_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_valignib</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_valignib.html"><code>hexagon::S2_valignib</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_valignrb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_valignrb.html"><code>hexagon::S2_valignrb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vcnegh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vcnegh.html"><code>hexagon::S2_vcnegh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vcrotate</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vcrotate.html"><code>hexagon::S2_vcrotate</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vrcnegh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vrcnegh.html"><code>hexagon::S2_vrcnegh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vrndpackwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vrndpackwh.html"><code>hexagon::S2_vrndpackwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vrndpackwhs</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vrndpackwhs.html"><code>hexagon::S2_vrndpackwhs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsathb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsathb.html"><code>hexagon::S2_vsathb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsathb_nopack</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsathb_nopack.html"><code>hexagon::S2_vsathb_nopack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsathub</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsathub.html"><code>hexagon::S2_vsathub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsathub_nopack</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsathub_nopack.html"><code>hexagon::S2_vsathub_nopack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsatwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsatwh.html"><code>hexagon::S2_vsatwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsatwh_nopack</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsatwh_nopack.html"><code>hexagon::S2_vsatwh_nopack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsatwuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsatwuh.html"><code>hexagon::S2_vsatwuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsatwuh_nopack</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsatwuh_nopack.html"><code>hexagon::S2_vsatwuh_nopack</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsplatrb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsplatrb.html"><code>hexagon::S2_vsplatrb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsplatrh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsplatrh.html"><code>hexagon::S2_vsplatrh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vspliceib</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vspliceib.html"><code>hexagon::S2_vspliceib</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsplicerb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsplicerb.html"><code>hexagon::S2_vsplicerb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsxtbh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsxtbh.html"><code>hexagon::S2_vsxtbh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vsxthw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vsxthw.html"><code>hexagon::S2_vsxthw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vtrunehb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vtrunehb.html"><code>hexagon::S2_vtrunehb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vtrunewh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vtrunewh.html"><code>hexagon::S2_vtrunewh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vtrunohb</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vtrunohb.html"><code>hexagon::S2_vtrunohb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vtrunowh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vtrunowh.html"><code>hexagon::S2_vtrunowh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vzxtbh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vzxtbh.html"><code>hexagon::S2_vzxtbh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S2_vzxthw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S2_vzxthw.html"><code>hexagon::S2_vzxthw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_addaddi</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_addaddi.html"><code>hexagon::S4_addaddi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_addi_asl_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_addi_asl_ri.html"><code>hexagon::S4_addi_asl_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_addi_lsr_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_addi_lsr_ri.html"><code>hexagon::S4_addi_lsr_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_andi_asl_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_andi_asl_ri.html"><code>hexagon::S4_andi_asl_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_andi_lsr_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_andi_lsr_ri.html"><code>hexagon::S4_andi_lsr_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_clbaddi</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_clbaddi.html"><code>hexagon::S4_clbaddi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_clbpaddi</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_clbpaddi.html"><code>hexagon::S4_clbpaddi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_clbpnorm</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_clbpnorm.html"><code>hexagon::S4_clbpnorm</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_extract</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_extract.html"><code>hexagon::S4_extract</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_extract_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_extract_rp.html"><code>hexagon::S4_extract_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_extractp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_extractp.html"><code>hexagon::S4_extractp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_extractp_rp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_extractp_rp.html"><code>hexagon::S4_extractp_rp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_lsli</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_lsli.html"><code>hexagon::S4_lsli</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_ntstbit_i</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_ntstbit_i.html"><code>hexagon::S4_ntstbit_i</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_ntstbit_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_ntstbit_r.html"><code>hexagon::S4_ntstbit_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_or_andi</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_or_andi.html"><code>hexagon::S4_or_andi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_or_andix</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_or_andix.html"><code>hexagon::S4_or_andix</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_or_ori</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_or_ori.html"><code>hexagon::S4_or_ori</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_ori_asl_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_ori_asl_ri.html"><code>hexagon::S4_ori_asl_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_ori_lsr_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_ori_lsr_ri.html"><code>hexagon::S4_ori_lsr_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_parity</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_parity.html"><code>hexagon::S4_parity</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_subaddi</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_subaddi.html"><code>hexagon::S4_subaddi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_subi_asl_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_subi_asl_ri.html"><code>hexagon::S4_subi_asl_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_subi_lsr_ri</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_subi_lsr_ri.html"><code>hexagon::S4_subi_lsr_ri</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vrcrotate</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vrcrotate.html"><code>hexagon::S4_vrcrotate</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vrcrotate_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vrcrotate_acc.html"><code>hexagon::S4_vrcrotate_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxaddsubh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxaddsubh.html"><code>hexagon::S4_vxaddsubh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxaddsubhr</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxaddsubhr.html"><code>hexagon::S4_vxaddsubhr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxaddsubw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxaddsubw.html"><code>hexagon::S4_vxaddsubw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxsubaddh</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxsubaddh.html"><code>hexagon::S4_vxsubaddh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxsubaddhr</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxsubaddhr.html"><code>hexagon::S4_vxsubaddhr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S4_vxsubaddw</code></strong></dt>
/// <dd><a href="../hexagon/fn.S4_vxsubaddw.html"><code>hexagon::S4_vxsubaddw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S5_asrhub_rnd_sat_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S5_asrhub_rnd_sat_goodsyntax.html"><code>hexagon::S5_asrhub_rnd_sat_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S5_asrhub_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.S5_asrhub_sat.html"><code>hexagon::S5_asrhub_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S5_popcountp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S5_popcountp.html"><code>hexagon::S5_popcountp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S5_vasrhrnd_goodsyntax</code></strong></dt>
/// <dd><a href="../hexagon/fn.S5_vasrhrnd_goodsyntax.html"><code>hexagon::S5_vasrhrnd_goodsyntax</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p.html"><code>hexagon::S6_rol_i_p</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p_acc.html"><code>hexagon::S6_rol_i_p_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p_and.html"><code>hexagon::S6_rol_i_p_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p_nac.html"><code>hexagon::S6_rol_i_p_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p_or.html"><code>hexagon::S6_rol_i_p_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_p_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_p_xacc.html"><code>hexagon::S6_rol_i_p_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r.html"><code>hexagon::S6_rol_i_r</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r_acc.html"><code>hexagon::S6_rol_i_r_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r_and</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r_and.html"><code>hexagon::S6_rol_i_r_and</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r_nac</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r_nac.html"><code>hexagon::S6_rol_i_r_nac</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r_or</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r_or.html"><code>hexagon::S6_rol_i_r_or</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_rol_i_r_xacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_rol_i_r_xacc.html"><code>hexagon::S6_rol_i_r_xacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_vsplatrbp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_vsplatrbp.html"><code>hexagon::S6_vsplatrbp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_vtrunehb_ppp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_vtrunehb_ppp.html"><code>hexagon::S6_vtrunehb_ppp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_S6_vtrunohb_ppp</code></strong></dt>
/// <dd><a href="../hexagon/fn.S6_vtrunohb_ppp.html"><code>hexagon::S6_vtrunohb_ppp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_extractw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_extractw.html"><code>hexagon::V6_extractw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_extractw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_extractw_128B.html"><code>hexagon::V6_extractw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_hi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_hi.html"><code>hexagon::V6_hi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_hi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_hi_128B.html"><code>hexagon::V6_hi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_lo</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_lo.html"><code>hexagon::V6_lo</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_lo_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_lo_128B.html"><code>hexagon::V6_lo_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_lvsplatw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_lvsplatw.html"><code>hexagon::V6_lvsplatw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_lvsplatw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_lvsplatw_128B.html"><code>hexagon::V6_lvsplatw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffh.html"><code>hexagon::V6_vabsdiffh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffh_128B.html"><code>hexagon::V6_vabsdiffh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffub.html"><code>hexagon::V6_vabsdiffub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffub_128B.html"><code>hexagon::V6_vabsdiffub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffuh.html"><code>hexagon::V6_vabsdiffuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffuh_128B.html"><code>hexagon::V6_vabsdiffuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffw.html"><code>hexagon::V6_vabsdiffw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsdiffw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsdiffw_128B.html"><code>hexagon::V6_vabsdiffw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsh.html"><code>hexagon::V6_vabsh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsh_128B.html"><code>hexagon::V6_vabsh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsh_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsh_sat.html"><code>hexagon::V6_vabsh_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsh_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsh_sat_128B.html"><code>hexagon::V6_vabsh_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsw.html"><code>hexagon::V6_vabsw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsw_128B.html"><code>hexagon::V6_vabsw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsw_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsw_sat.html"><code>hexagon::V6_vabsw_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vabsw_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vabsw_sat_128B.html"><code>hexagon::V6_vabsw_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddb.html"><code>hexagon::V6_vaddb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddb_128B.html"><code>hexagon::V6_vaddb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddb_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddb_dv.html"><code>hexagon::V6_vaddb_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddb_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddb_dv_128B.html"><code>hexagon::V6_vaddb_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddh.html"><code>hexagon::V6_vaddh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddh_128B.html"><code>hexagon::V6_vaddh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddh_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddh_dv.html"><code>hexagon::V6_vaddh_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddh_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddh_dv_128B.html"><code>hexagon::V6_vaddh_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhsat.html"><code>hexagon::V6_vaddhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhsat_128B.html"><code>hexagon::V6_vaddhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhsat_dv.html"><code>hexagon::V6_vaddhsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhsat_dv_128B.html"><code>hexagon::V6_vaddhsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhw.html"><code>hexagon::V6_vaddhw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddhw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddhw_128B.html"><code>hexagon::V6_vaddhw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubh.html"><code>hexagon::V6_vaddubh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubh_128B.html"><code>hexagon::V6_vaddubh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubsat.html"><code>hexagon::V6_vaddubsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubsat_128B.html"><code>hexagon::V6_vaddubsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubsat_dv.html"><code>hexagon::V6_vaddubsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddubsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddubsat_dv_128B.html"><code>hexagon::V6_vaddubsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhsat.html"><code>hexagon::V6_vadduhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhsat_128B.html"><code>hexagon::V6_vadduhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhsat_dv.html"><code>hexagon::V6_vadduhsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhsat_dv_128B.html"><code>hexagon::V6_vadduhsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhw.html"><code>hexagon::V6_vadduhw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vadduhw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vadduhw_128B.html"><code>hexagon::V6_vadduhw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddw.html"><code>hexagon::V6_vaddw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddw_128B.html"><code>hexagon::V6_vaddw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddw_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddw_dv.html"><code>hexagon::V6_vaddw_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddw_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddw_dv_128B.html"><code>hexagon::V6_vaddw_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddwsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddwsat.html"><code>hexagon::V6_vaddwsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddwsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddwsat_128B.html"><code>hexagon::V6_vaddwsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddwsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddwsat_dv.html"><code>hexagon::V6_vaddwsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaddwsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaddwsat_dv_128B.html"><code>hexagon::V6_vaddwsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_valignb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_valignb.html"><code>hexagon::V6_valignb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_valignb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_valignb_128B.html"><code>hexagon::V6_valignb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_valignbi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_valignbi.html"><code>hexagon::V6_valignbi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_valignbi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_valignbi_128B.html"><code>hexagon::V6_valignbi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vand</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vand.html"><code>hexagon::V6_vand</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vand_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vand_128B.html"><code>hexagon::V6_vand_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslh.html"><code>hexagon::V6_vaslh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslh_128B.html"><code>hexagon::V6_vaslh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslhv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslhv.html"><code>hexagon::V6_vaslhv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslhv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslhv_128B.html"><code>hexagon::V6_vaslhv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslw.html"><code>hexagon::V6_vaslw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslw_128B.html"><code>hexagon::V6_vaslw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslw_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslw_acc.html"><code>hexagon::V6_vaslw_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslw_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslw_acc_128B.html"><code>hexagon::V6_vaslw_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslwv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslwv.html"><code>hexagon::V6_vaslwv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vaslwv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vaslwv_128B.html"><code>hexagon::V6_vaslwv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrh.html"><code>hexagon::V6_vasrh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrh_128B.html"><code>hexagon::V6_vasrh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhbrndsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhbrndsat.html"><code>hexagon::V6_vasrhbrndsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhbrndsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhbrndsat_128B.html"><code>hexagon::V6_vasrhbrndsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhubrndsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhubrndsat.html"><code>hexagon::V6_vasrhubrndsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhubrndsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhubrndsat_128B.html"><code>hexagon::V6_vasrhubrndsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhubsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhubsat.html"><code>hexagon::V6_vasrhubsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhubsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhubsat_128B.html"><code>hexagon::V6_vasrhubsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhv.html"><code>hexagon::V6_vasrhv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrhv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrhv_128B.html"><code>hexagon::V6_vasrhv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrw.html"><code>hexagon::V6_vasrw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrw_128B.html"><code>hexagon::V6_vasrw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrw_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrw_acc.html"><code>hexagon::V6_vasrw_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrw_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrw_acc_128B.html"><code>hexagon::V6_vasrw_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwh.html"><code>hexagon::V6_vasrwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwh_128B.html"><code>hexagon::V6_vasrwh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwhrndsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwhrndsat.html"><code>hexagon::V6_vasrwhrndsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwhrndsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwhrndsat_128B.html"><code>hexagon::V6_vasrwhrndsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwhsat.html"><code>hexagon::V6_vasrwhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwhsat_128B.html"><code>hexagon::V6_vasrwhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwuhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwuhsat.html"><code>hexagon::V6_vasrwuhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwuhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwuhsat_128B.html"><code>hexagon::V6_vasrwuhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwv.html"><code>hexagon::V6_vasrwv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vasrwv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vasrwv_128B.html"><code>hexagon::V6_vasrwv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vassign</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vassign.html"><code>hexagon::V6_vassign</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vassign_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vassign_128B.html"><code>hexagon::V6_vassign_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vassignp</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vassignp.html"><code>hexagon::V6_vassignp</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vassignp_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vassignp_128B.html"><code>hexagon::V6_vassignp_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgh.html"><code>hexagon::V6_vavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgh_128B.html"><code>hexagon::V6_vavgh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavghrnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavghrnd.html"><code>hexagon::V6_vavghrnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavghrnd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavghrnd_128B.html"><code>hexagon::V6_vavghrnd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgub.html"><code>hexagon::V6_vavgub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgub_128B.html"><code>hexagon::V6_vavgub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgubrnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgubrnd.html"><code>hexagon::V6_vavgubrnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgubrnd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgubrnd_128B.html"><code>hexagon::V6_vavgubrnd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavguh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavguh.html"><code>hexagon::V6_vavguh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavguh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavguh_128B.html"><code>hexagon::V6_vavguh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavguhrnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavguhrnd.html"><code>hexagon::V6_vavguhrnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavguhrnd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavguhrnd_128B.html"><code>hexagon::V6_vavguhrnd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgw.html"><code>hexagon::V6_vavgw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgw_128B.html"><code>hexagon::V6_vavgw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgwrnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgwrnd.html"><code>hexagon::V6_vavgwrnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vavgwrnd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vavgwrnd_128B.html"><code>hexagon::V6_vavgwrnd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcl0h</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcl0h.html"><code>hexagon::V6_vcl0h</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcl0h_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcl0h_128B.html"><code>hexagon::V6_vcl0h_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcl0w</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcl0w.html"><code>hexagon::V6_vcl0w</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcl0w_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcl0w_128B.html"><code>hexagon::V6_vcl0w_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcombine</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcombine.html"><code>hexagon::V6_vcombine</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vcombine_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vcombine_128B.html"><code>hexagon::V6_vcombine_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vd0</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vd0.html"><code>hexagon::V6_vd0</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vd0_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vd0_128B.html"><code>hexagon::V6_vd0_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealb.html"><code>hexagon::V6_vdealb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealb4w</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealb4w.html"><code>hexagon::V6_vdealb4w</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealb4w_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealb4w_128B.html"><code>hexagon::V6_vdealb4w_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealb_128B.html"><code>hexagon::V6_vdealb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealh.html"><code>hexagon::V6_vdealh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealh_128B.html"><code>hexagon::V6_vdealh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealvdd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealvdd.html"><code>hexagon::V6_vdealvdd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdealvdd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdealvdd_128B.html"><code>hexagon::V6_vdealvdd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdelta</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdelta.html"><code>hexagon::V6_vdelta</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdelta_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdelta_128B.html"><code>hexagon::V6_vdelta_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus.html"><code>hexagon::V6_vdmpybus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_128B.html"><code>hexagon::V6_vdmpybus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_acc.html"><code>hexagon::V6_vdmpybus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_acc_128B.html"><code>hexagon::V6_vdmpybus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_dv.html"><code>hexagon::V6_vdmpybus_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_dv_128B.html"><code>hexagon::V6_vdmpybus_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_dv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_dv_acc.html"><code>hexagon::V6_vdmpybus_dv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpybus_dv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpybus_dv_acc_128B.html"><code>hexagon::V6_vdmpybus_dv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb.html"><code>hexagon::V6_vdmpyhb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_128B.html"><code>hexagon::V6_vdmpyhb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_acc.html"><code>hexagon::V6_vdmpyhb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_acc_128B.html"><code>hexagon::V6_vdmpyhb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_dv.html"><code>hexagon::V6_vdmpyhb_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_dv_128B.html"><code>hexagon::V6_vdmpyhb_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_dv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_dv_acc.html"><code>hexagon::V6_vdmpyhb_dv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhb_dv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhb_dv_acc_128B.html"><code>hexagon::V6_vdmpyhb_dv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhisat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhisat.html"><code>hexagon::V6_vdmpyhisat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhisat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhisat_128B.html"><code>hexagon::V6_vdmpyhisat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhisat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhisat_acc.html"><code>hexagon::V6_vdmpyhisat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhisat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhisat_acc_128B.html"><code>hexagon::V6_vdmpyhisat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsat.html"><code>hexagon::V6_vdmpyhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsat_128B.html"><code>hexagon::V6_vdmpyhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsat_acc.html"><code>hexagon::V6_vdmpyhsat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsat_acc_128B.html"><code>hexagon::V6_vdmpyhsat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsuisat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsuisat.html"><code>hexagon::V6_vdmpyhsuisat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsuisat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsuisat_128B.html"><code>hexagon::V6_vdmpyhsuisat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsuisat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsuisat_acc.html"><code>hexagon::V6_vdmpyhsuisat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsuisat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsuisat_acc_128B.html"><code>hexagon::V6_vdmpyhsuisat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsusat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsusat.html"><code>hexagon::V6_vdmpyhsusat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsusat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsusat_128B.html"><code>hexagon::V6_vdmpyhsusat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsusat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsusat_acc.html"><code>hexagon::V6_vdmpyhsusat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhsusat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhsusat_acc_128B.html"><code>hexagon::V6_vdmpyhsusat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhvsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhvsat.html"><code>hexagon::V6_vdmpyhvsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhvsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhvsat_128B.html"><code>hexagon::V6_vdmpyhvsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhvsat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhvsat_acc.html"><code>hexagon::V6_vdmpyhvsat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdmpyhvsat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdmpyhvsat_acc_128B.html"><code>hexagon::V6_vdmpyhvsat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdsaduh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdsaduh.html"><code>hexagon::V6_vdsaduh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdsaduh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdsaduh_128B.html"><code>hexagon::V6_vdsaduh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdsaduh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdsaduh_acc.html"><code>hexagon::V6_vdsaduh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vdsaduh_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vdsaduh_acc_128B.html"><code>hexagon::V6_vdsaduh_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vinsertwr</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vinsertwr.html"><code>hexagon::V6_vinsertwr</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vinsertwr_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vinsertwr_128B.html"><code>hexagon::V6_vinsertwr_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlalignb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlalignb.html"><code>hexagon::V6_vlalignb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlalignb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlalignb_128B.html"><code>hexagon::V6_vlalignb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlalignbi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlalignbi.html"><code>hexagon::V6_vlalignbi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlalignbi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlalignbi_128B.html"><code>hexagon::V6_vlalignbi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrh.html"><code>hexagon::V6_vlsrh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrh_128B.html"><code>hexagon::V6_vlsrh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrhv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrhv.html"><code>hexagon::V6_vlsrhv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrhv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrhv_128B.html"><code>hexagon::V6_vlsrhv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrw.html"><code>hexagon::V6_vlsrw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrw_128B.html"><code>hexagon::V6_vlsrw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrwv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrwv.html"><code>hexagon::V6_vlsrwv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlsrwv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlsrwv_128B.html"><code>hexagon::V6_vlsrwv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb.html"><code>hexagon::V6_vlutb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_128B.html"><code>hexagon::V6_vlutb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_acc.html"><code>hexagon::V6_vlutb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_acc_128B.html"><code>hexagon::V6_vlutb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_dv.html"><code>hexagon::V6_vlutb_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_dv_128B.html"><code>hexagon::V6_vlutb_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_dv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_dv_acc.html"><code>hexagon::V6_vlutb_dv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutb_dv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutb_dv_acc_128B.html"><code>hexagon::V6_vlutb_dv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvvb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvvb.html"><code>hexagon::V6_vlutvvb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvvb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvvb_128B.html"><code>hexagon::V6_vlutvvb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvvb_oracc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvvb_oracc.html"><code>hexagon::V6_vlutvvb_oracc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvvb_oracc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvvb_oracc_128B.html"><code>hexagon::V6_vlutvvb_oracc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvwh.html"><code>hexagon::V6_vlutvwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvwh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvwh_128B.html"><code>hexagon::V6_vlutvwh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvwh_oracc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvwh_oracc.html"><code>hexagon::V6_vlutvwh_oracc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vlutvwh_oracc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vlutvwh_oracc_128B.html"><code>hexagon::V6_vlutvwh_oracc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxh.html"><code>hexagon::V6_vmaxh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxh_128B.html"><code>hexagon::V6_vmaxh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxub.html"><code>hexagon::V6_vmaxub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxub_128B.html"><code>hexagon::V6_vmaxub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxuh.html"><code>hexagon::V6_vmaxuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxuh_128B.html"><code>hexagon::V6_vmaxuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxw.html"><code>hexagon::V6_vmaxw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmaxw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmaxw_128B.html"><code>hexagon::V6_vmaxw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminh.html"><code>hexagon::V6_vminh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminh_128B.html"><code>hexagon::V6_vminh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminub.html"><code>hexagon::V6_vminub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminub_128B.html"><code>hexagon::V6_vminub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminuh.html"><code>hexagon::V6_vminuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminuh_128B.html"><code>hexagon::V6_vminuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminw.html"><code>hexagon::V6_vminw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vminw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vminw_128B.html"><code>hexagon::V6_vminw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabus.html"><code>hexagon::V6_vmpabus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabus_128B.html"><code>hexagon::V6_vmpabus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabus_acc.html"><code>hexagon::V6_vmpabus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabus_acc_128B.html"><code>hexagon::V6_vmpabus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabusv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabusv.html"><code>hexagon::V6_vmpabusv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabusv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabusv_128B.html"><code>hexagon::V6_vmpabusv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabuuv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabuuv.html"><code>hexagon::V6_vmpabuuv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpabuuv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpabuuv_128B.html"><code>hexagon::V6_vmpabuuv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpahb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpahb.html"><code>hexagon::V6_vmpahb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpahb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpahb_128B.html"><code>hexagon::V6_vmpahb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpahb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpahb_acc.html"><code>hexagon::V6_vmpahb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpahb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpahb_acc_128B.html"><code>hexagon::V6_vmpahb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybus.html"><code>hexagon::V6_vmpybus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybus_128B.html"><code>hexagon::V6_vmpybus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybus_acc.html"><code>hexagon::V6_vmpybus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybus_acc_128B.html"><code>hexagon::V6_vmpybus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybusv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybusv.html"><code>hexagon::V6_vmpybusv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybusv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybusv_128B.html"><code>hexagon::V6_vmpybusv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybusv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybusv_acc.html"><code>hexagon::V6_vmpybusv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybusv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybusv_acc_128B.html"><code>hexagon::V6_vmpybusv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybv.html"><code>hexagon::V6_vmpybv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybv_128B.html"><code>hexagon::V6_vmpybv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybv_acc.html"><code>hexagon::V6_vmpybv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpybv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpybv_acc_128B.html"><code>hexagon::V6_vmpybv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyewuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyewuh.html"><code>hexagon::V6_vmpyewuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyewuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyewuh_128B.html"><code>hexagon::V6_vmpyewuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyh.html"><code>hexagon::V6_vmpyh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyh_128B.html"><code>hexagon::V6_vmpyh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhsat_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhsat_acc.html"><code>hexagon::V6_vmpyhsat_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhsat_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhsat_acc_128B.html"><code>hexagon::V6_vmpyhsat_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhsrs</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhsrs.html"><code>hexagon::V6_vmpyhsrs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhsrs_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhsrs_128B.html"><code>hexagon::V6_vmpyhsrs_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhss</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhss.html"><code>hexagon::V6_vmpyhss</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhss_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhss_128B.html"><code>hexagon::V6_vmpyhss_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhus.html"><code>hexagon::V6_vmpyhus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhus_128B.html"><code>hexagon::V6_vmpyhus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhus_acc.html"><code>hexagon::V6_vmpyhus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhus_acc_128B.html"><code>hexagon::V6_vmpyhus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhv.html"><code>hexagon::V6_vmpyhv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhv_128B.html"><code>hexagon::V6_vmpyhv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhv_acc.html"><code>hexagon::V6_vmpyhv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhv_acc_128B.html"><code>hexagon::V6_vmpyhv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhvsrs</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhvsrs.html"><code>hexagon::V6_vmpyhvsrs</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyhvsrs_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyhvsrs_128B.html"><code>hexagon::V6_vmpyhvsrs_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyieoh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyieoh.html"><code>hexagon::V6_vmpyieoh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyieoh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyieoh_128B.html"><code>hexagon::V6_vmpyieoh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewh_acc.html"><code>hexagon::V6_vmpyiewh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewh_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewh_acc_128B.html"><code>hexagon::V6_vmpyiewh_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewuh.html"><code>hexagon::V6_vmpyiewuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewuh_128B.html"><code>hexagon::V6_vmpyiewuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewuh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewuh_acc.html"><code>hexagon::V6_vmpyiewuh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiewuh_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiewuh_acc_128B.html"><code>hexagon::V6_vmpyiewuh_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyih</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyih.html"><code>hexagon::V6_vmpyih</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyih_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyih_128B.html"><code>hexagon::V6_vmpyih_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyih_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyih_acc.html"><code>hexagon::V6_vmpyih_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyih_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyih_acc_128B.html"><code>hexagon::V6_vmpyih_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyihb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyihb.html"><code>hexagon::V6_vmpyihb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyihb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyihb_128B.html"><code>hexagon::V6_vmpyihb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyihb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyihb_acc.html"><code>hexagon::V6_vmpyihb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyihb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyihb_acc_128B.html"><code>hexagon::V6_vmpyihb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiowh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiowh.html"><code>hexagon::V6_vmpyiowh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiowh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiowh_128B.html"><code>hexagon::V6_vmpyiowh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwb.html"><code>hexagon::V6_vmpyiwb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwb_128B.html"><code>hexagon::V6_vmpyiwb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwb_acc.html"><code>hexagon::V6_vmpyiwb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwb_acc_128B.html"><code>hexagon::V6_vmpyiwb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwh.html"><code>hexagon::V6_vmpyiwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwh_128B.html"><code>hexagon::V6_vmpyiwh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwh_acc.html"><code>hexagon::V6_vmpyiwh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyiwh_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyiwh_acc_128B.html"><code>hexagon::V6_vmpyiwh_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh.html"><code>hexagon::V6_vmpyowh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_128B.html"><code>hexagon::V6_vmpyowh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_rnd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_rnd.html"><code>hexagon::V6_vmpyowh_rnd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_rnd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_rnd_128B.html"><code>hexagon::V6_vmpyowh_rnd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_rnd_sacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_rnd_sacc.html"><code>hexagon::V6_vmpyowh_rnd_sacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_rnd_sacc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_rnd_sacc_128B.html"><code>hexagon::V6_vmpyowh_rnd_sacc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_sacc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_sacc.html"><code>hexagon::V6_vmpyowh_sacc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyowh_sacc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyowh_sacc_128B.html"><code>hexagon::V6_vmpyowh_sacc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyub.html"><code>hexagon::V6_vmpyub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyub_128B.html"><code>hexagon::V6_vmpyub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyub_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyub_acc.html"><code>hexagon::V6_vmpyub_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyub_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyub_acc_128B.html"><code>hexagon::V6_vmpyub_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyubv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyubv.html"><code>hexagon::V6_vmpyubv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyubv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyubv_128B.html"><code>hexagon::V6_vmpyubv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyubv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyubv_acc.html"><code>hexagon::V6_vmpyubv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyubv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyubv_acc_128B.html"><code>hexagon::V6_vmpyubv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuh.html"><code>hexagon::V6_vmpyuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuh_128B.html"><code>hexagon::V6_vmpyuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuh_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuh_acc.html"><code>hexagon::V6_vmpyuh_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuh_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuh_acc_128B.html"><code>hexagon::V6_vmpyuh_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuhv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuhv.html"><code>hexagon::V6_vmpyuhv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuhv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuhv_128B.html"><code>hexagon::V6_vmpyuhv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuhv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuhv_acc.html"><code>hexagon::V6_vmpyuhv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vmpyuhv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vmpyuhv_acc_128B.html"><code>hexagon::V6_vmpyuhv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgh.html"><code>hexagon::V6_vnavgh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgh_128B.html"><code>hexagon::V6_vnavgh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgub.html"><code>hexagon::V6_vnavgub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgub_128B.html"><code>hexagon::V6_vnavgub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgw.html"><code>hexagon::V6_vnavgw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnavgw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnavgw_128B.html"><code>hexagon::V6_vnavgw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnormamth</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnormamth.html"><code>hexagon::V6_vnormamth</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnormamth_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnormamth_128B.html"><code>hexagon::V6_vnormamth_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnormamtw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnormamtw.html"><code>hexagon::V6_vnormamtw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnormamtw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnormamtw_128B.html"><code>hexagon::V6_vnormamtw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnot</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnot.html"><code>hexagon::V6_vnot</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vnot_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vnot_128B.html"><code>hexagon::V6_vnot_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vor</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vor.html"><code>hexagon::V6_vor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vor_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vor_128B.html"><code>hexagon::V6_vor_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackeb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackeb.html"><code>hexagon::V6_vpackeb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackeb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackeb_128B.html"><code>hexagon::V6_vpackeb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackeh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackeh.html"><code>hexagon::V6_vpackeh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackeh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackeh_128B.html"><code>hexagon::V6_vpackeh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackhb_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackhb_sat.html"><code>hexagon::V6_vpackhb_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackhb_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackhb_sat_128B.html"><code>hexagon::V6_vpackhb_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackhub_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackhub_sat.html"><code>hexagon::V6_vpackhub_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackhub_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackhub_sat_128B.html"><code>hexagon::V6_vpackhub_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackob</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackob.html"><code>hexagon::V6_vpackob</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackob_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackob_128B.html"><code>hexagon::V6_vpackob_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackoh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackoh.html"><code>hexagon::V6_vpackoh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackoh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackoh_128B.html"><code>hexagon::V6_vpackoh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackwh_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackwh_sat.html"><code>hexagon::V6_vpackwh_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackwh_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackwh_sat_128B.html"><code>hexagon::V6_vpackwh_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackwuh_sat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackwuh_sat.html"><code>hexagon::V6_vpackwuh_sat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpackwuh_sat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpackwuh_sat_128B.html"><code>hexagon::V6_vpackwuh_sat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpopcounth</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpopcounth.html"><code>hexagon::V6_vpopcounth</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vpopcounth_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vpopcounth_128B.html"><code>hexagon::V6_vpopcounth_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrdelta</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrdelta.html"><code>hexagon::V6_vrdelta</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrdelta_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrdelta_128B.html"><code>hexagon::V6_vrdelta_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybus.html"><code>hexagon::V6_vrmpybus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybus_128B.html"><code>hexagon::V6_vrmpybus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybus_acc.html"><code>hexagon::V6_vrmpybus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybus_acc_128B.html"><code>hexagon::V6_vrmpybus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusi.html"><code>hexagon::V6_vrmpybusi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusi_128B.html"><code>hexagon::V6_vrmpybusi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusi_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusi_acc.html"><code>hexagon::V6_vrmpybusi_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusi_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusi_acc_128B.html"><code>hexagon::V6_vrmpybusi_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusv.html"><code>hexagon::V6_vrmpybusv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusv_128B.html"><code>hexagon::V6_vrmpybusv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusv_acc.html"><code>hexagon::V6_vrmpybusv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybusv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybusv_acc_128B.html"><code>hexagon::V6_vrmpybusv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybv.html"><code>hexagon::V6_vrmpybv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybv_128B.html"><code>hexagon::V6_vrmpybv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybv_acc.html"><code>hexagon::V6_vrmpybv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpybv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpybv_acc_128B.html"><code>hexagon::V6_vrmpybv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyub.html"><code>hexagon::V6_vrmpyub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyub_128B.html"><code>hexagon::V6_vrmpyub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyub_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyub_acc.html"><code>hexagon::V6_vrmpyub_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyub_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyub_acc_128B.html"><code>hexagon::V6_vrmpyub_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubi.html"><code>hexagon::V6_vrmpyubi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubi_128B.html"><code>hexagon::V6_vrmpyubi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubi_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubi_acc.html"><code>hexagon::V6_vrmpyubi_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubi_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubi_acc_128B.html"><code>hexagon::V6_vrmpyubi_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubv.html"><code>hexagon::V6_vrmpyubv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubv_128B.html"><code>hexagon::V6_vrmpyubv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubv_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubv_acc.html"><code>hexagon::V6_vrmpyubv_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrmpyubv_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrmpyubv_acc_128B.html"><code>hexagon::V6_vrmpyubv_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vror</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vror.html"><code>hexagon::V6_vror</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vror_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vror_128B.html"><code>hexagon::V6_vror_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundhb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundhb.html"><code>hexagon::V6_vroundhb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundhb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundhb_128B.html"><code>hexagon::V6_vroundhb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundhub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundhub.html"><code>hexagon::V6_vroundhub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundhub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundhub_128B.html"><code>hexagon::V6_vroundhub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundwh.html"><code>hexagon::V6_vroundwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundwh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundwh_128B.html"><code>hexagon::V6_vroundwh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundwuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundwuh.html"><code>hexagon::V6_vroundwuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vroundwuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vroundwuh_128B.html"><code>hexagon::V6_vroundwuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrsadubi</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrsadubi.html"><code>hexagon::V6_vrsadubi</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrsadubi_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrsadubi_128B.html"><code>hexagon::V6_vrsadubi_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrsadubi_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrsadubi_acc.html"><code>hexagon::V6_vrsadubi_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vrsadubi_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vrsadubi_acc_128B.html"><code>hexagon::V6_vrsadubi_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsathub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsathub.html"><code>hexagon::V6_vsathub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsathub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsathub_128B.html"><code>hexagon::V6_vsathub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsatwh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsatwh.html"><code>hexagon::V6_vsatwh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsatwh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsatwh_128B.html"><code>hexagon::V6_vsatwh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsb.html"><code>hexagon::V6_vsb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsb_128B.html"><code>hexagon::V6_vsb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsh.html"><code>hexagon::V6_vsh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsh_128B.html"><code>hexagon::V6_vsh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufeh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufeh.html"><code>hexagon::V6_vshufeh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufeh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufeh_128B.html"><code>hexagon::V6_vshufeh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffb.html"><code>hexagon::V6_vshuffb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffb_128B.html"><code>hexagon::V6_vshuffb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffeb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffeb.html"><code>hexagon::V6_vshuffeb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffeb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffeb_128B.html"><code>hexagon::V6_vshuffeb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffh.html"><code>hexagon::V6_vshuffh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffh_128B.html"><code>hexagon::V6_vshuffh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffob</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffob.html"><code>hexagon::V6_vshuffob</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffob_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffob_128B.html"><code>hexagon::V6_vshuffob_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffvdd</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffvdd.html"><code>hexagon::V6_vshuffvdd</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshuffvdd_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshuffvdd_128B.html"><code>hexagon::V6_vshuffvdd_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoeb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoeb.html"><code>hexagon::V6_vshufoeb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoeb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoeb_128B.html"><code>hexagon::V6_vshufoeb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoeh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoeh.html"><code>hexagon::V6_vshufoeh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoeh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoeh_128B.html"><code>hexagon::V6_vshufoeh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoh.html"><code>hexagon::V6_vshufoh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vshufoh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vshufoh_128B.html"><code>hexagon::V6_vshufoh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubb.html"><code>hexagon::V6_vsubb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubb_128B.html"><code>hexagon::V6_vsubb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubb_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubb_dv.html"><code>hexagon::V6_vsubb_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubb_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubb_dv_128B.html"><code>hexagon::V6_vsubb_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubh.html"><code>hexagon::V6_vsubh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubh_128B.html"><code>hexagon::V6_vsubh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubh_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubh_dv.html"><code>hexagon::V6_vsubh_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubh_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubh_dv_128B.html"><code>hexagon::V6_vsubh_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhsat.html"><code>hexagon::V6_vsubhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhsat_128B.html"><code>hexagon::V6_vsubhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhsat_dv.html"><code>hexagon::V6_vsubhsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhsat_dv_128B.html"><code>hexagon::V6_vsubhsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhw.html"><code>hexagon::V6_vsubhw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubhw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubhw_128B.html"><code>hexagon::V6_vsubhw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububh.html"><code>hexagon::V6_vsububh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububh_128B.html"><code>hexagon::V6_vsububh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububsat.html"><code>hexagon::V6_vsububsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububsat_128B.html"><code>hexagon::V6_vsububsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububsat_dv.html"><code>hexagon::V6_vsububsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsububsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsububsat_dv_128B.html"><code>hexagon::V6_vsububsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhsat.html"><code>hexagon::V6_vsubuhsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhsat_128B.html"><code>hexagon::V6_vsubuhsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhsat_dv.html"><code>hexagon::V6_vsubuhsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhsat_dv_128B.html"><code>hexagon::V6_vsubuhsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhw.html"><code>hexagon::V6_vsubuhw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubuhw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubuhw_128B.html"><code>hexagon::V6_vsubuhw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubw</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubw.html"><code>hexagon::V6_vsubw</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubw_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubw_128B.html"><code>hexagon::V6_vsubw_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubw_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubw_dv.html"><code>hexagon::V6_vsubw_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubw_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubw_dv_128B.html"><code>hexagon::V6_vsubw_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubwsat</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubwsat.html"><code>hexagon::V6_vsubwsat</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubwsat_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubwsat_128B.html"><code>hexagon::V6_vsubwsat_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubwsat_dv</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubwsat_dv.html"><code>hexagon::V6_vsubwsat_dv</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vsubwsat_dv_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vsubwsat_dv_128B.html"><code>hexagon::V6_vsubwsat_dv_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyb.html"><code>hexagon::V6_vtmpyb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyb_128B.html"><code>hexagon::V6_vtmpyb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyb_acc.html"><code>hexagon::V6_vtmpyb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyb_acc_128B.html"><code>hexagon::V6_vtmpyb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpybus</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpybus.html"><code>hexagon::V6_vtmpybus</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpybus_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpybus_128B.html"><code>hexagon::V6_vtmpybus_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpybus_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpybus_acc.html"><code>hexagon::V6_vtmpybus_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpybus_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpybus_acc_128B.html"><code>hexagon::V6_vtmpybus_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyhb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyhb.html"><code>hexagon::V6_vtmpyhb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyhb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyhb_128B.html"><code>hexagon::V6_vtmpyhb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyhb_acc</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyhb_acc.html"><code>hexagon::V6_vtmpyhb_acc</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vtmpyhb_acc_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vtmpyhb_acc_128B.html"><code>hexagon::V6_vtmpyhb_acc_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackb.html"><code>hexagon::V6_vunpackb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackb_128B.html"><code>hexagon::V6_vunpackb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackh.html"><code>hexagon::V6_vunpackh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackh_128B.html"><code>hexagon::V6_vunpackh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackob</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackob.html"><code>hexagon::V6_vunpackob</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackob_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackob_128B.html"><code>hexagon::V6_vunpackob_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackoh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackoh.html"><code>hexagon::V6_vunpackoh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackoh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackoh_128B.html"><code>hexagon::V6_vunpackoh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackub</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackub.html"><code>hexagon::V6_vunpackub</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackub_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackub_128B.html"><code>hexagon::V6_vunpackub_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackuh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackuh.html"><code>hexagon::V6_vunpackuh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vunpackuh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vunpackuh_128B.html"><code>hexagon::V6_vunpackuh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vxor</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vxor.html"><code>hexagon::V6_vxor</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vxor_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vxor_128B.html"><code>hexagon::V6_vxor_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vzb</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vzb.html"><code>hexagon::V6_vzb</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vzb_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vzb_128B.html"><code>hexagon::V6_vzb_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vzh</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vzh.html"><code>hexagon::V6_vzh</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_V6_vzh_128B</code></strong></dt>
/// <dd><a href="../hexagon/fn.V6_vzh_128B.html"><code>hexagon::V6_vzh_128B</code></a></dd>
/// <dt><strong><code>__builtin_HEXAGON_prefetch</code></strong></dt>
/// <dd><a href="../hexagon/fn.prefetch.html"><code>hexagon::prefetch</code></a></dd>
/// <dt><strong><code>__builtin_SI_to_SXTHI_asrh</code></strong></dt>
/// <dd><a href="../hexagon/fn.SI_to_SXTHI_asrh.html"><code>hexagon::SI_to_SXTHI_asrh</code></a></dd>
/// <dt><strong><code>__builtin__mm256i_vaddw</code></strong></dt>
/// <dd><a href="../hexagon/fn.mm256i_vaddw.html"><code>hexagon::mm256i_vaddw</code></a></dd>
/// <dt><strong><code>__builtin_adjust_trampoline</code></strong></dt>
/// <dd><a href="../fn.adjust_trampoline.html"><code>adjust_trampoline</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vcipher</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vcipher.html"><code>ppc::altivec_crypto_vcipher</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vcipherlast</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vcipherlast.html"><code>ppc::altivec_crypto_vcipherlast</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vncipher</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vncipher.html"><code>ppc::altivec_crypto_vncipher</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vncipherlast</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vncipherlast.html"><code>ppc::altivec_crypto_vncipherlast</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vpermxor</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vpermxor.html"><code>ppc::altivec_crypto_vpermxor</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vpmsumb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vpmsumb.html"><code>ppc::altivec_crypto_vpmsumb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vpmsumd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vpmsumd.html"><code>ppc::altivec_crypto_vpmsumd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vpmsumh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vpmsumh.html"><code>ppc::altivec_crypto_vpmsumh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vpmsumw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vpmsumw.html"><code>ppc::altivec_crypto_vpmsumw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vsbox</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vsbox.html"><code>ppc::altivec_crypto_vsbox</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vshasigmad</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vshasigmad.html"><code>ppc::altivec_crypto_vshasigmad</code></a></dd>
/// <dt><strong><code>__builtin_altivec_crypto_vshasigmaw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_crypto_vshasigmaw.html"><code>ppc::altivec_crypto_vshasigmaw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dss</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dss.html"><code>ppc::altivec_dss</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dssall</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dssall.html"><code>ppc::altivec_dssall</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dst</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dst.html"><code>ppc::altivec_dst</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dstst</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dstst.html"><code>ppc::altivec_dstst</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dststt</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dststt.html"><code>ppc::altivec_dststt</code></a></dd>
/// <dt><strong><code>__builtin_altivec_dstt</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_dstt.html"><code>ppc::altivec_dstt</code></a></dd>
/// <dt><strong><code>__builtin_altivec_mfvscr</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_mfvscr.html"><code>ppc::altivec_mfvscr</code></a></dd>
/// <dt><strong><code>__builtin_altivec_mtvscr</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_mtvscr.html"><code>ppc::altivec_mtvscr</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vaddcuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vaddcuw.html"><code>ppc::altivec_vaddcuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vaddsbs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vaddsbs.html"><code>ppc::altivec_vaddsbs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vaddshs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vaddshs.html"><code>ppc::altivec_vaddshs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vaddsws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vaddsws.html"><code>ppc::altivec_vaddsws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vaddubs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vaddubs.html"><code>ppc::altivec_vaddubs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vadduhs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vadduhs.html"><code>ppc::altivec_vadduhs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vadduws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vadduws.html"><code>ppc::altivec_vadduws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavgsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavgsb.html"><code>ppc::altivec_vavgsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavgsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavgsh.html"><code>ppc::altivec_vavgsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavgsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavgsw.html"><code>ppc::altivec_vavgsw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavgub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavgub.html"><code>ppc::altivec_vavgub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavguh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavguh.html"><code>ppc::altivec_vavguh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vavguw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vavguw.html"><code>ppc::altivec_vavguw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vbpermq</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vbpermq.html"><code>ppc::altivec_vbpermq</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcfsx</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcfsx.html"><code>ppc::altivec_vcfsx</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcfux</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcfux.html"><code>ppc::altivec_vcfux</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpbfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpbfp.html"><code>ppc::altivec_vcmpbfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpbfp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpbfp_p.html"><code>ppc::altivec_vcmpbfp_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpeqfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpeqfp.html"><code>ppc::altivec_vcmpeqfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpeqfp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpeqfp_p.html"><code>ppc::altivec_vcmpeqfp_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequb.html"><code>ppc::altivec_vcmpequb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequb_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequb_p.html"><code>ppc::altivec_vcmpequb_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequd.html"><code>ppc::altivec_vcmpequd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequd_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequd_p.html"><code>ppc::altivec_vcmpequd_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequh.html"><code>ppc::altivec_vcmpequh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequh_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequh_p.html"><code>ppc::altivec_vcmpequh_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequw.html"><code>ppc::altivec_vcmpequw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpequw_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpequw_p.html"><code>ppc::altivec_vcmpequw_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgefp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgefp.html"><code>ppc::altivec_vcmpgefp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgefp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgefp_p.html"><code>ppc::altivec_vcmpgefp_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtfp.html"><code>ppc::altivec_vcmpgtfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtfp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtfp_p.html"><code>ppc::altivec_vcmpgtfp_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsb.html"><code>ppc::altivec_vcmpgtsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsb_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsb_p.html"><code>ppc::altivec_vcmpgtsb_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsd.html"><code>ppc::altivec_vcmpgtsd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsd_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsd_p.html"><code>ppc::altivec_vcmpgtsd_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsh.html"><code>ppc::altivec_vcmpgtsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsh_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsh_p.html"><code>ppc::altivec_vcmpgtsh_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsw.html"><code>ppc::altivec_vcmpgtsw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtsw_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtsw_p.html"><code>ppc::altivec_vcmpgtsw_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtub.html"><code>ppc::altivec_vcmpgtub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtub_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtub_p.html"><code>ppc::altivec_vcmpgtub_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtud</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtud.html"><code>ppc::altivec_vcmpgtud</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtud_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtud_p.html"><code>ppc::altivec_vcmpgtud_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtuh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtuh.html"><code>ppc::altivec_vcmpgtuh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtuh_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtuh_p.html"><code>ppc::altivec_vcmpgtuh_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtuw.html"><code>ppc::altivec_vcmpgtuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vcmpgtuw_p</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vcmpgtuw_p.html"><code>ppc::altivec_vcmpgtuw_p</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vctsxs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vctsxs.html"><code>ppc::altivec_vctsxs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vctuxs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vctuxs.html"><code>ppc::altivec_vctuxs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vexptefp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vexptefp.html"><code>ppc::altivec_vexptefp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vgbbd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vgbbd.html"><code>ppc::altivec_vgbbd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vlogefp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vlogefp.html"><code>ppc::altivec_vlogefp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaddfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaddfp.html"><code>ppc::altivec_vmaddfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxfp.html"><code>ppc::altivec_vmaxfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxsb.html"><code>ppc::altivec_vmaxsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxsd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxsd.html"><code>ppc::altivec_vmaxsd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxsh.html"><code>ppc::altivec_vmaxsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxsw.html"><code>ppc::altivec_vmaxsw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxub.html"><code>ppc::altivec_vmaxub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxud</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxud.html"><code>ppc::altivec_vmaxud</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxuh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxuh.html"><code>ppc::altivec_vmaxuh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmaxuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmaxuw.html"><code>ppc::altivec_vmaxuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmhaddshs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmhaddshs.html"><code>ppc::altivec_vmhaddshs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmhraddshs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmhraddshs.html"><code>ppc::altivec_vmhraddshs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminfp.html"><code>ppc::altivec_vminfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminsb.html"><code>ppc::altivec_vminsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminsd</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminsd.html"><code>ppc::altivec_vminsd</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminsh.html"><code>ppc::altivec_vminsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminsw.html"><code>ppc::altivec_vminsw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminub.html"><code>ppc::altivec_vminub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminud</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminud.html"><code>ppc::altivec_vminud</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminuh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminuh.html"><code>ppc::altivec_vminuh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vminuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vminuw.html"><code>ppc::altivec_vminuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmladduhm</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmladduhm.html"><code>ppc::altivec_vmladduhm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsummbm</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsummbm.html"><code>ppc::altivec_vmsummbm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsumshm</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsumshm.html"><code>ppc::altivec_vmsumshm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsumshs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsumshs.html"><code>ppc::altivec_vmsumshs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsumubm</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsumubm.html"><code>ppc::altivec_vmsumubm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsumuhm</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsumuhm.html"><code>ppc::altivec_vmsumuhm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmsumuhs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmsumuhs.html"><code>ppc::altivec_vmsumuhs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulesb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulesb.html"><code>ppc::altivec_vmulesb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulesh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulesh.html"><code>ppc::altivec_vmulesh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulesw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulesw.html"><code>ppc::altivec_vmulesw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmuleub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmuleub.html"><code>ppc::altivec_vmuleub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmuleuh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmuleuh.html"><code>ppc::altivec_vmuleuh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmuleuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmuleuw.html"><code>ppc::altivec_vmuleuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulosb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulosb.html"><code>ppc::altivec_vmulosb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulosh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulosh.html"><code>ppc::altivec_vmulosh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulosw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulosw.html"><code>ppc::altivec_vmulosw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmuloub</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmuloub.html"><code>ppc::altivec_vmuloub</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulouh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulouh.html"><code>ppc::altivec_vmulouh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vmulouw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vmulouw.html"><code>ppc::altivec_vmulouw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vnmsubfp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vnmsubfp.html"><code>ppc::altivec_vnmsubfp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vperm_4si</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vperm.html"><code>ppc::altivec_vperm</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkpx</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkpx.html"><code>ppc::altivec_vpkpx</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpksdss</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpksdss.html"><code>ppc::altivec_vpksdss</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpksdus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpksdus.html"><code>ppc::altivec_vpksdus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkshss</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkshss.html"><code>ppc::altivec_vpkshss</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkshus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkshus.html"><code>ppc::altivec_vpkshus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkswss</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkswss.html"><code>ppc::altivec_vpkswss</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkswus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkswus.html"><code>ppc::altivec_vpkswus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkudus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkudus.html"><code>ppc::altivec_vpkudus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkuhus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkuhus.html"><code>ppc::altivec_vpkuhus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vpkuwus</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vpkuwus.html"><code>ppc::altivec_vpkuwus</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrefp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrefp.html"><code>ppc::altivec_vrefp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrfim</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrfim.html"><code>ppc::altivec_vrfim</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrfin</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrfin.html"><code>ppc::altivec_vrfin</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrfip</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrfip.html"><code>ppc::altivec_vrfip</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrfiz</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrfiz.html"><code>ppc::altivec_vrfiz</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrlb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrlb.html"><code>ppc::altivec_vrlb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrld</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrld.html"><code>ppc::altivec_vrld</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrlh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrlh.html"><code>ppc::altivec_vrlh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrlw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrlw.html"><code>ppc::altivec_vrlw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vrsqrtefp</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vrsqrtefp.html"><code>ppc::altivec_vrsqrtefp</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsel_4si</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsel.html"><code>ppc::altivec_vsel</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsl</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsl.html"><code>ppc::altivec_vsl</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vslb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vslb.html"><code>ppc::altivec_vslb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vslh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vslh.html"><code>ppc::altivec_vslh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vslo</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vslo.html"><code>ppc::altivec_vslo</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vslw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vslw.html"><code>ppc::altivec_vslw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsr</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsr.html"><code>ppc::altivec_vsr</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsrab</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsrab.html"><code>ppc::altivec_vsrab</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsrah</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsrah.html"><code>ppc::altivec_vsrah</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsraw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsraw.html"><code>ppc::altivec_vsraw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsrb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsrb.html"><code>ppc::altivec_vsrb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsrh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsrh.html"><code>ppc::altivec_vsrh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsro</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsro.html"><code>ppc::altivec_vsro</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsrw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsrw.html"><code>ppc::altivec_vsrw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubcuw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubcuw.html"><code>ppc::altivec_vsubcuw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubsbs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubsbs.html"><code>ppc::altivec_vsubsbs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubshs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubshs.html"><code>ppc::altivec_vsubshs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubsws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubsws.html"><code>ppc::altivec_vsubsws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsububs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsububs.html"><code>ppc::altivec_vsububs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubuhs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubuhs.html"><code>ppc::altivec_vsubuhs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsubuws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsubuws.html"><code>ppc::altivec_vsubuws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsum2sws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsum2sws.html"><code>ppc::altivec_vsum2sws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsum4sbs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsum4sbs.html"><code>ppc::altivec_vsum4sbs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsum4shs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsum4shs.html"><code>ppc::altivec_vsum4shs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsum4ubs</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsum4ubs.html"><code>ppc::altivec_vsum4ubs</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vsumsws</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vsumsws.html"><code>ppc::altivec_vsumsws</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupkhpx</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupkhpx.html"><code>ppc::altivec_vupkhpx</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupkhsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupkhsb.html"><code>ppc::altivec_vupkhsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupkhsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupkhsh.html"><code>ppc::altivec_vupkhsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupkhsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupkhsw.html"><code>ppc::altivec_vupkhsw</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupklpx</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupklpx.html"><code>ppc::altivec_vupklpx</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupklsb</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupklsb.html"><code>ppc::altivec_vupklsb</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupklsh</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupklsh.html"><code>ppc::altivec_vupklsh</code></a></dd>
/// <dt><strong><code>__builtin_altivec_vupklsw</code></strong></dt>
/// <dd><a href="../ppc/fn.altivec_vupklsw.html"><code>ppc::altivec_vupklsw</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_buffer_wbinvl1</code></strong></dt>
/// <dd><a href="../fn.amdgcn_buffer_wbinvl1.html"><code>amdgcn_buffer_wbinvl1</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_buffer_wbinvl1_sc</code></strong></dt>
/// <dd><a href="../fn.amdgcn_buffer_wbinvl1_sc.html"><code>amdgcn_buffer_wbinvl1_sc</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_buffer_wbinvl1_vol</code></strong></dt>
/// <dd><a href="../fn.amdgcn_buffer_wbinvl1_vol.html"><code>amdgcn_buffer_wbinvl1_vol</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_cubeid</code></strong></dt>
/// <dd><a href="../fn.amdgcn_cubeid.html"><code>amdgcn_cubeid</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_cubema</code></strong></dt>
/// <dd><a href="../fn.amdgcn_cubema.html"><code>amdgcn_cubema</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_cubesc</code></strong></dt>
/// <dd><a href="../fn.amdgcn_cubesc.html"><code>amdgcn_cubesc</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_cubetc</code></strong></dt>
/// <dd><a href="../fn.amdgcn_cubetc.html"><code>amdgcn_cubetc</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_ds_swizzle</code></strong></dt>
/// <dd><a href="../fn.amdgcn_ds_swizzle.html"><code>amdgcn_ds_swizzle</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_groupstaticsize</code></strong></dt>
/// <dd><a href="../fn.amdgcn_groupstaticsize.html"><code>amdgcn_groupstaticsize</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_interp_p1</code></strong></dt>
/// <dd><a href="../fn.amdgcn_interp_p1.html"><code>amdgcn_interp_p1</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_interp_p2</code></strong></dt>
/// <dd><a href="../fn.amdgcn_interp_p2.html"><code>amdgcn_interp_p2</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_lerp</code></strong></dt>
/// <dd><a href="../fn.amdgcn_lerp.html"><code>amdgcn_lerp</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_mbcnt_hi</code></strong></dt>
/// <dd><a href="../fn.amdgcn_mbcnt_hi.html"><code>amdgcn_mbcnt_hi</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_mbcnt_lo</code></strong></dt>
/// <dd><a href="../fn.amdgcn_mbcnt_lo.html"><code>amdgcn_mbcnt_lo</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_rsq_legacy</code></strong></dt>
/// <dd><a href="../fn.amdgcn_rsq_legacy.html"><code>amdgcn_rsq_legacy</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_barrier</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_barrier.html"><code>amdgcn_s_barrier</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_dcache_inv</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_dcache_inv.html"><code>amdgcn_s_dcache_inv</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_dcache_inv_vol</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_dcache_inv_vol.html"><code>amdgcn_s_dcache_inv_vol</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_dcache_wb</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_dcache_wb.html"><code>amdgcn_s_dcache_wb</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_dcache_wb_vol</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_dcache_wb_vol.html"><code>amdgcn_s_dcache_wb_vol</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_getreg</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_getreg.html"><code>amdgcn_s_getreg</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_memrealtime</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_memrealtime.html"><code>amdgcn_s_memrealtime</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_memtime</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_memtime.html"><code>amdgcn_s_memtime</code></a></dd>
/// <dt><strong><code>__builtin_amdgcn_s_sleep</code></strong></dt>
/// <dd><a href="../fn.amdgcn_s_sleep.html"><code>amdgcn_s_sleep</code></a></dd>
/// <dt><strong><code>__builtin_arm_cdp</code></strong></dt>
/// <dd><a href="../arm/fn.cdp.html"><code>arm::cdp</code></a></dd>
/// <dt><strong><code>__builtin_arm_cdp2</code></strong></dt>
/// <dd><a href="../arm/fn.cdp2.html"><code>arm::cdp2</code></a></dd>
/// <dt><strong><code>__builtin_arm_dmb</code></strong></dt>
/// <dd><a href="../aarch64/fn.dmb.html"><code>aarch64::dmb</code></a></dd>
/// <dd><a href="../arm/fn.dmb.html"><code>arm::dmb</code></a></dd>
/// <dt><strong><code>__builtin_arm_dsb</code></strong></dt>
/// <dd><a href="../aarch64/fn.dsb.html"><code>aarch64::dsb</code></a></dd>
/// <dd><a href="../arm/fn.dsb.html"><code>arm::dsb</code></a></dd>
/// <dt><strong><code>__builtin_arm_get_fpscr</code></strong></dt>
/// <dd><a href="../arm/fn.get_fpscr.html"><code>arm::get_fpscr</code></a></dd>
/// <dt><strong><code>__builtin_arm_isb</code></strong></dt>
/// <dd><a href="../aarch64/fn.isb.html"><code>aarch64::isb</code></a></dd>
/// <dd><a href="../arm/fn.isb.html"><code>arm::isb</code></a></dd>
/// <dt><strong><code>__builtin_arm_ldc</code></strong></dt>
/// <dd><a href="../arm/fn.ldc.html"><code>arm::ldc</code></a></dd>
/// <dt><strong><code>__builtin_arm_ldc2</code></strong></dt>
/// <dd><a href="../arm/fn.ldc2.html"><code>arm::ldc2</code></a></dd>
/// <dt><strong><code>__builtin_arm_ldc2l</code></strong></dt>
/// <dd><a href="../arm/fn.ldc2l.html"><code>arm::ldc2l</code></a></dd>
/// <dt><strong><code>__builtin_arm_ldcl</code></strong></dt>
/// <dd><a href="../arm/fn.ldcl.html"><code>arm::ldcl</code></a></dd>
/// <dt><strong><code>__builtin_arm_mcr</code></strong></dt>
/// <dd><a href="../arm/fn.mcr.html"><code>arm::mcr</code></a></dd>
/// <dt><strong><code>__builtin_arm_mcr2</code></strong></dt>
/// <dd><a href="../arm/fn.mcr2.html"><code>arm::mcr2</code></a></dd>
/// <dt><strong><code>__builtin_arm_mrc</code></strong></dt>
/// <dd><a href="../arm/fn.mrc.html"><code>arm::mrc</code></a></dd>
/// <dt><strong><code>__builtin_arm_mrc2</code></strong></dt>
/// <dd><a href="../arm/fn.mrc2.html"><code>arm::mrc2</code></a></dd>
/// <dt><strong><code>__builtin_arm_qadd</code></strong></dt>
/// <dd><a href="../arm/fn.qadd.html"><code>arm::qadd</code></a></dd>
/// <dt><strong><code>__builtin_arm_qsub</code></strong></dt>
/// <dd><a href="../arm/fn.qsub.html"><code>arm::qsub</code></a></dd>
/// <dt><strong><code>__builtin_arm_set_fpscr</code></strong></dt>
/// <dd><a href="../arm/fn.set_fpscr.html"><code>arm::set_fpscr</code></a></dd>
/// <dt><strong><code>__builtin_arm_ssat</code></strong></dt>
/// <dd><a href="../arm/fn.ssat.html"><code>arm::ssat</code></a></dd>
/// <dt><strong><code>__builtin_arm_stc</code></strong></dt>
/// <dd><a href="../arm/fn.stc.html"><code>arm::stc</code></a></dd>
/// <dt><strong><code>__builtin_arm_stc2</code></strong></dt>
/// <dd><a href="../arm/fn.stc2.html"><code>arm::stc2</code></a></dd>
/// <dt><strong><code>__builtin_arm_stc2l</code></strong></dt>
/// <dd><a href="../arm/fn.stc2l.html"><code>arm::stc2l</code></a></dd>
/// <dt><strong><code>__builtin_arm_stcl</code></strong></dt>
/// <dd><a href="../arm/fn.stcl.html"><code>arm::stcl</code></a></dd>
/// <dt><strong><code>__builtin_arm_usat</code></strong></dt>
/// <dd><a href="../arm/fn.usat.html"><code>arm::usat</code></a></dd>
/// <dt><strong><code>__builtin_bitrev</code></strong></dt>
/// <dd><a href="../xcore/fn.bitrev.html"><code>xcore::bitrev</code></a></dd>
/// <dt><strong><code>__builtin_bpermd</code></strong></dt>
/// <dd><a href="../ppc/fn.bpermd.html"><code>ppc::bpermd</code></a></dd>
/// <dt><strong><code>__builtin_bpf_load_byte</code></strong></dt>
/// <dd><a href="../fn.bpf_load_byte.html"><code>bpf_load_byte</code></a></dd>
/// <dt><strong><code>__builtin_bpf_load_half</code></strong></dt>
/// <dd><a href="../fn.bpf_load_half.html"><code>bpf_load_half</code></a></dd>
/// <dt><strong><code>__builtin_bpf_load_word</code></strong></dt>
/// <dd><a href="../fn.bpf_load_word.html"><code>bpf_load_word</code></a></dd>
/// <dt><strong><code>__builtin_bpf_pseudo</code></strong></dt>
/// <dd><a href="../fn.bpf_pseudo.html"><code>bpf_pseudo</code></a></dd>
/// <dt><strong><code>__builtin_brev_ldb</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_ldb.html"><code>hexagon::brev_ldb</code></a></dd>
/// <dt><strong><code>__builtin_brev_ldd</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_ldd.html"><code>hexagon::brev_ldd</code></a></dd>
/// <dt><strong><code>__builtin_brev_ldh</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_ldh.html"><code>hexagon::brev_ldh</code></a></dd>
/// <dt><strong><code>__builtin_brev_ldub</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_ldub.html"><code>hexagon::brev_ldub</code></a></dd>
/// <dt><strong><code>__builtin_brev_lduh</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_lduh.html"><code>hexagon::brev_lduh</code></a></dd>
/// <dt><strong><code>__builtin_brev_ldw</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_ldw.html"><code>hexagon::brev_ldw</code></a></dd>
/// <dt><strong><code>__builtin_brev_stb</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_stb.html"><code>hexagon::brev_stb</code></a></dd>
/// <dt><strong><code>__builtin_brev_std</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_std.html"><code>hexagon::brev_std</code></a></dd>
/// <dt><strong><code>__builtin_brev_sth</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_sth.html"><code>hexagon::brev_sth</code></a></dd>
/// <dt><strong><code>__builtin_brev_sthhi</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_sthhi.html"><code>hexagon::brev_sthhi</code></a></dd>
/// <dt><strong><code>__builtin_brev_stw</code></strong></dt>
/// <dd><a href="../hexagon/fn.brev_stw.html"><code>hexagon::brev_stw</code></a></dd>
/// <dt><strong><code>__builtin_circ_ldb</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_ldb.html"><code>hexagon::circ_ldb</code></a></dd>
/// <dt><strong><code>__builtin_circ_ldd</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_ldd.html"><code>hexagon::circ_ldd</code></a></dd>
/// <dt><strong><code>__builtin_circ_ldh</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_ldh.html"><code>hexagon::circ_ldh</code></a></dd>
/// <dt><strong><code>__builtin_circ_ldub</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_ldub.html"><code>hexagon::circ_ldub</code></a></dd>
/// <dt><strong><code>__builtin_circ_lduh</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_lduh.html"><code>hexagon::circ_lduh</code></a></dd>
/// <dt><strong><code>__builtin_circ_ldw</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_ldw.html"><code>hexagon::circ_ldw</code></a></dd>
/// <dt><strong><code>__builtin_circ_stb</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_stb.html"><code>hexagon::circ_stb</code></a></dd>
/// <dt><strong><code>__builtin_circ_std</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_std.html"><code>hexagon::circ_std</code></a></dd>
/// <dt><strong><code>__builtin_circ_sth</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_sth.html"><code>hexagon::circ_sth</code></a></dd>
/// <dt><strong><code>__builtin_circ_sthhi</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_sthhi.html"><code>hexagon::circ_sthhi</code></a></dd>
/// <dt><strong><code>__builtin_circ_stw</code></strong></dt>
/// <dd><a href="../hexagon/fn.circ_stw.html"><code>hexagon::circ_stw</code></a></dd>
/// <dt><strong><code>__builtin_debugtrap</code></strong></dt>
/// <dd><a href="../fn.debugtrap.html"><code>debugtrap</code></a></dd>
/// <dt><strong><code>__builtin_divde</code></strong></dt>
/// <dd><a href="../ppc/fn.divde.html"><code>ppc::divde</code></a></dd>
/// <dt><strong><code>__builtin_divdeu</code></strong></dt>
/// <dd><a href="../ppc/fn.divdeu.html"><code>ppc::divdeu</code></a></dd>
/// <dt><strong><code>__builtin_divwe</code></strong></dt>
/// <dd><a href="../ppc/fn.divwe.html"><code>ppc::divwe</code></a></dd>
/// <dt><strong><code>__builtin_divweu</code></strong></dt>
/// <dd><a href="../ppc/fn.divweu.html"><code>ppc::divweu</code></a></dd>
/// <dt><strong><code>__builtin_flt_rounds</code></strong></dt>
/// <dd><a href="../fn.flt_rounds.html"><code>flt_rounds</code></a></dd>
/// <dt><strong><code>__builtin_get_texasr</code></strong></dt>
/// <dd><a href="../ppc/fn.get_texasr.html"><code>ppc::get_texasr</code></a></dd>
/// <dt><strong><code>__builtin_get_texasru</code></strong></dt>
/// <dd><a href="../ppc/fn.get_texasru.html"><code>ppc::get_texasru</code></a></dd>
/// <dt><strong><code>__builtin_get_tfhar</code></strong></dt>
/// <dd><a href="../ppc/fn.get_tfhar.html"><code>ppc::get_tfhar</code></a></dd>
/// <dt><strong><code>__builtin_get_tfiar</code></strong></dt>
/// <dd><a href="../ppc/fn.get_tfiar.html"><code>ppc::get_tfiar</code></a></dd>
/// <dt><strong><code>__builtin_getid</code></strong></dt>
/// <dd><a href="../xcore/fn.getid.html"><code>xcore::getid</code></a></dd>
/// <dt><strong><code>__builtin_getps</code></strong></dt>
/// <dd><a href="../xcore/fn.getps.html"><code>xcore::getps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addcarry_u32</code></strong></dt>
/// <dd><a href="../x86/fn.addcarry_u32.html"><code>x86::addcarry_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addcarry_u64</code></strong></dt>
/// <dd><a href="../x86/fn.addcarry_u64.html"><code>x86::addcarry_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addcarryx_u32</code></strong></dt>
/// <dd><a href="../x86/fn.addcarryx_u32.html"><code>x86::addcarryx_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addcarryx_u64</code></strong></dt>
/// <dd><a href="../x86/fn.addcarryx_u64.html"><code>x86::addcarryx_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_pd_128.html"><code>x86::avx512_mask_add_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_pd_256.html"><code>x86::avx512_mask_add_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_pd_512.html"><code>x86::avx512_mask_add_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_ps_128.html"><code>x86::avx512_mask_add_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_ps_256.html"><code>x86::avx512_mask_add_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_ps_512.html"><code>x86::avx512_mask_add_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_sd_round.html"><code>x86::avx512_mask_add_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_add_ss_round.html"><code>x86::avx512_mask_add_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addsubpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_addsub_pd.html"><code>x86::sse3_addsub_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addsubpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_addsub_pd_256.html"><code>x86::avx_addsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addsubps</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_addsub_ps.html"><code>x86::sse3_addsub_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_addsubps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_addsub_ps_256.html"><code>x86::avx_addsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aesdec128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aesdec.html"><code>x86::aesni_aesdec</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aesdeclast128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aesdeclast.html"><code>x86::aesni_aesdeclast</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aesenc128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aesenc.html"><code>x86::aesni_aesenc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aesenclast128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aesenclast.html"><code>x86::aesni_aesenclast</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aesimc128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aesimc.html"><code>x86::aesni_aesimc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_aeskeygenassist128</code></strong></dt>
/// <dd><a href="../x86/fn.aesni_aeskeygenassist.html"><code>x86::aesni_aeskeygenassist</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_d_128.html"><code>x86::avx512_mask_valign_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_d_256.html"><code>x86::avx512_mask_valign_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_d_512.html"><code>x86::avx512_mask_valign_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_q_128.html"><code>x86::avx512_mask_valign_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_q_256.html"><code>x86::avx512_mask_valign_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_alignq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_valign_q_512.html"><code>x86::avx512_mask_valign_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_pd_128.html"><code>x86::avx512_mask_andn_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_pd_256.html"><code>x86::avx512_mask_andn_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_pd_512.html"><code>x86::avx512_mask_andn_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_ps_128.html"><code>x86::avx512_mask_andn_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_ps_256.html"><code>x86::avx512_mask_andn_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andnps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_andn_ps_512.html"><code>x86::avx512_mask_andn_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_pd_128.html"><code>x86::avx512_mask_and_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_pd_256.html"><code>x86::avx512_mask_and_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_pd_512.html"><code>x86::avx512_mask_and_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_ps_128.html"><code>x86::avx512_mask_and_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_ps_256.html"><code>x86::avx512_mask_and_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_andps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_and_ps_512.html"><code>x86::avx512_mask_and_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bextr_u32</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_bextr_32.html"><code>x86::bmi_bextr_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bextr_u64</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_bextr_64.html"><code>x86::bmi_bextr_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bextri_u32</code></strong></dt>
/// <dd><a href="../x86/fn.tbm_bextri_u32.html"><code>x86::tbm_bextri_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bextri_u64</code></strong></dt>
/// <dd><a href="../x86/fn.tbm_bextri_u64.html"><code>x86::tbm_bextri_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_blendvpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_blendvpd.html"><code>x86::sse41_blendvpd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_blendvpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_blendv_pd_256.html"><code>x86::avx_blendv_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_blendvps</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_blendvps.html"><code>x86::sse41_blendvps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_blendvps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_blendv_ps_256.html"><code>x86::avx_blendv_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf32x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf32x2_256.html"><code>x86::avx512_mask_broadcastf32x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf32x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf32x2_512.html"><code>x86::avx512_mask_broadcastf32x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf32x4_256.html"><code>x86::avx512_mask_broadcastf32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf32x4_512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf32x4_512.html"><code>x86::avx512_mask_broadcastf32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf32x8_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf32x8_512.html"><code>x86::avx512_mask_broadcastf32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf64x2_256.html"><code>x86::avx512_mask_broadcastf64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf64x2_512.html"><code>x86::avx512_mask_broadcastf64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastf64x4_512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcastf64x4_512.html"><code>x86::avx512_mask_broadcastf64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x2_128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x2_128.html"><code>x86::avx512_mask_broadcasti32x2_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x2_256.html"><code>x86::avx512_mask_broadcasti32x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x2_512.html"><code>x86::avx512_mask_broadcasti32x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x4_256.html"><code>x86::avx512_mask_broadcasti32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x4_512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x4_512.html"><code>x86::avx512_mask_broadcasti32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti32x8_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti32x8_512.html"><code>x86::avx512_mask_broadcasti32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti64x2_256.html"><code>x86::avx512_mask_broadcasti64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti64x2_512.html"><code>x86::avx512_mask_broadcasti64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcasti64x4_512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_broadcasti64x4_512.html"><code>x86::avx512_mask_broadcasti64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmb128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmb_128.html"><code>x86::avx512_broadcastmb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmb_256.html"><code>x86::avx512_broadcastmb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmb512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmb_512.html"><code>x86::avx512_broadcastmb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmw128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmw_128.html"><code>x86::avx512_broadcastmw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmw_256.html"><code>x86::avx512_broadcastmw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_broadcastmw512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_broadcastmw_512.html"><code>x86::avx512_broadcastmw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bzhi_di</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_bzhi_64.html"><code>x86::bmi_bzhi_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_bzhi_si</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_bzhi_32.html"><code>x86::bmi_bzhi_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_clflush</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_clflush.html"><code>x86::sse2_clflush</code></a></dd>
/// <dt><strong><code>__builtin_ia32_clflushopt</code></strong></dt>
/// <dd><a href="../x86/fn.clflushopt.html"><code>x86::clflushopt</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmppd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_pd_128.html"><code>x86::avx512_mask_cmp_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmppd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_pd_256.html"><code>x86::avx512_mask_cmp_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmppd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_pd_512.html"><code>x86::avx512_mask_cmp_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_ps_128.html"><code>x86::avx512_mask_cmp_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_ps_256.html"><code>x86::avx512_mask_cmp_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_ps_512.html"><code>x86::avx512_mask_cmp_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpsd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cmp_sd.html"><code>x86::sse2_cmp_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpsd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_sd.html"><code>x86::avx512_mask_cmp_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cmp_ss.html"><code>x86::sse_cmp_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cmpss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cmp_ss.html"><code>x86::avx512_mask_cmp_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comieq</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comieq_ss.html"><code>x86::sse_comieq_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comige</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comige_ss.html"><code>x86::sse_comige_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comigt</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comigt_ss.html"><code>x86::sse_comigt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comile</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comile_ss.html"><code>x86::sse_comile_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comilt</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comilt_ss.html"><code>x86::sse_comilt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comineq</code></strong></dt>
/// <dd><a href="../x86/fn.sse_comineq_ss.html"><code>x86::sse_comineq_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdeq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comieq_sd.html"><code>x86::sse2_comieq_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdge</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comige_sd.html"><code>x86::sse2_comige_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdgt</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comigt_sd.html"><code>x86::sse2_comigt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdle</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comile_sd.html"><code>x86::sse2_comile_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdlt</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comilt_sd.html"><code>x86::sse2_comilt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_comisdneq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_comineq_sd.html"><code>x86::sse2_comineq_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_pd_128.html"><code>x86::avx512_mask_compress_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_pd_256.html"><code>x86::avx512_mask_compress_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_pd_512.html"><code>x86::avx512_mask_compress_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_q_128.html"><code>x86::avx512_mask_compress_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_q_256.html"><code>x86::avx512_mask_compress_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressdi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_q_512.html"><code>x86::avx512_mask_compress_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_ps_128.html"><code>x86::avx512_mask_compress_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_ps_256.html"><code>x86::avx512_mask_compress_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_ps_512.html"><code>x86::avx512_mask_compress_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_d_128.html"><code>x86::avx512_mask_compress_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_d_256.html"><code>x86::avx512_mask_compress_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compresssi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_d_512.html"><code>x86::avx512_mask_compress_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_pd_128.html"><code>x86::avx512_mask_compress_store_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_pd_256.html"><code>x86::avx512_mask_compress_store_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_pd_512.html"><code>x86::avx512_mask_compress_store_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_q_128.html"><code>x86::avx512_mask_compress_store_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_q_256.html"><code>x86::avx512_mask_compress_store_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoredi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_q_512.html"><code>x86::avx512_mask_compress_store_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_ps_128.html"><code>x86::avx512_mask_compress_store_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_ps_256.html"><code>x86::avx512_mask_compress_store_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_ps_512.html"><code>x86::avx512_mask_compress_store_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_d_128.html"><code>x86::avx512_mask_compress_store_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_d_256.html"><code>x86::avx512_mask_compress_store_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_compressstoresi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_compress_store_d_512.html"><code>x86::avx512_mask_compress_store_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_crc32di</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_crc32_64_64.html"><code>x86::sse42_crc32_64_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_crc32hi</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_crc32_32_16.html"><code>x86::sse42_crc32_32_16</code></a></dd>
/// <dt><strong><code>__builtin_ia32_crc32qi</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_crc32_32_8.html"><code>x86::sse42_crc32_32_8</code></a></dd>
/// <dt><strong><code>__builtin_ia32_crc32si</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_crc32_32_32.html"><code>x86::sse42_crc32_32_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtb2mask128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtb2mask_128.html"><code>x86::avx512_cvtb2mask_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtb2mask256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtb2mask_256.html"><code>x86::avx512_cvtb2mask_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtb2mask512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtb2mask_512.html"><code>x86::avx512_cvtb2mask_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtd2mask128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtd2mask_128.html"><code>x86::avx512_cvtd2mask_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtd2mask256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtd2mask_256.html"><code>x86::avx512_cvtd2mask_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtd2mask512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtd2mask_512.html"><code>x86::avx512_cvtd2mask_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2pd_128.html"><code>x86::avx512_mask_cvtdq2pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2pd_256.html"><code>x86::avx512_mask_cvtdq2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2pd_512.html"><code>x86::avx512_mask_cvtdq2pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2ps</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtdq2ps.html"><code>x86::sse2_cvtdq2ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2ps_128.html"><code>x86::avx512_mask_cvtdq2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvtdq2_ps_256.html"><code>x86::avx_cvtdq2_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2ps_256.html"><code>x86::avx512_mask_cvtdq2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtdq2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtdq2ps_512.html"><code>x86::avx512_mask_cvtdq2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2b128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2b_128.html"><code>x86::avx512_cvtmask2b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2b256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2b_256.html"><code>x86::avx512_cvtmask2b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2b512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2b_512.html"><code>x86::avx512_cvtmask2b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2d128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2d_128.html"><code>x86::avx512_cvtmask2d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2d256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2d_256.html"><code>x86::avx512_cvtmask2d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2d512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2d_512.html"><code>x86::avx512_cvtmask2d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2q128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2q_128.html"><code>x86::avx512_cvtmask2q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2q256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2q_256.html"><code>x86::avx512_cvtmask2q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2q512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2q_512.html"><code>x86::avx512_cvtmask2q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2w128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2w_128.html"><code>x86::avx512_cvtmask2w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2w256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2w_256.html"><code>x86::avx512_cvtmask2w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtmask2w512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtmask2w_512.html"><code>x86::avx512_cvtmask2w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2dq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtpd2dq.html"><code>x86::sse2_cvtpd2dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2dq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2dq_128.html"><code>x86::avx512_mask_cvtpd2dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2dq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvt_pd2dq_256.html"><code>x86::avx_cvt_pd2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2dq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2dq_256.html"><code>x86::avx512_mask_cvtpd2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2dq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2dq_512.html"><code>x86::avx512_mask_cvtpd2dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2ps</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtpd2ps.html"><code>x86::sse2_cvtpd2ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvt_pd2_ps_256.html"><code>x86::avx_cvt_pd2_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2ps_256.html"><code>x86::avx512_mask_cvtpd2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2ps_512.html"><code>x86::avx512_mask_cvtpd2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2ps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2ps.html"><code>x86::avx512_mask_cvtpd2ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2qq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2qq_128.html"><code>x86::avx512_mask_cvtpd2qq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2qq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2qq_256.html"><code>x86::avx512_mask_cvtpd2qq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2qq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2qq_512.html"><code>x86::avx512_mask_cvtpd2qq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2udq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2udq_128.html"><code>x86::avx512_mask_cvtpd2udq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2udq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2udq_256.html"><code>x86::avx512_mask_cvtpd2udq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2udq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2udq_512.html"><code>x86::avx512_mask_cvtpd2udq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2uqq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2uqq_128.html"><code>x86::avx512_mask_cvtpd2uqq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2uqq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2uqq_256.html"><code>x86::avx512_mask_cvtpd2uqq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtpd2uqq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtpd2uqq_512.html"><code>x86::avx512_mask_cvtpd2uqq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2dq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtps2dq.html"><code>x86::sse2_cvtps2dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2dq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2dq_128.html"><code>x86::avx512_mask_cvtps2dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2dq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvt_ps2dq_256.html"><code>x86::avx_cvt_ps2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2dq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2dq_256.html"><code>x86::avx512_mask_cvtps2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2dq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2dq_512.html"><code>x86::avx512_mask_cvtps2dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2pd_128.html"><code>x86::avx512_mask_cvtps2pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2pd_256.html"><code>x86::avx512_mask_cvtps2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2pd_512.html"><code>x86::avx512_mask_cvtps2pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2qq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2qq_128.html"><code>x86::avx512_mask_cvtps2qq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2qq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2qq_256.html"><code>x86::avx512_mask_cvtps2qq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2qq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2qq_512.html"><code>x86::avx512_mask_cvtps2qq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2udq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2udq_128.html"><code>x86::avx512_mask_cvtps2udq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2udq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2udq_256.html"><code>x86::avx512_mask_cvtps2udq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2udq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2udq_512.html"><code>x86::avx512_mask_cvtps2udq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2uqq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2uqq_128.html"><code>x86::avx512_mask_cvtps2uqq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2uqq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2uqq_256.html"><code>x86::avx512_mask_cvtps2uqq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtps2uqq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtps2uqq_512.html"><code>x86::avx512_mask_cvtps2uqq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtq2mask128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtq2mask_128.html"><code>x86::avx512_cvtq2mask_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtq2mask256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtq2mask_256.html"><code>x86::avx512_cvtq2mask_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtq2mask512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtq2mask_512.html"><code>x86::avx512_cvtq2mask_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2pd_128.html"><code>x86::avx512_mask_cvtqq2pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2pd_256.html"><code>x86::avx512_mask_cvtqq2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2pd_512.html"><code>x86::avx512_mask_cvtqq2pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2ps_128.html"><code>x86::avx512_mask_cvtqq2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2ps_256.html"><code>x86::avx512_mask_cvtqq2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtqq2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtqq2ps_512.html"><code>x86::avx512_mask_cvtqq2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsd2si</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtsd2si.html"><code>x86::sse2_cvtsd2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsd2si64</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtsd2si64.html"><code>x86::sse2_cvtsd2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsd2ss</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtsd2ss.html"><code>x86::sse2_cvtsd2ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsd2ss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtsd2ss_round.html"><code>x86::avx512_mask_cvtsd2ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2sd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtsi2sd.html"><code>x86::sse2_cvtsi2sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2sd32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtsi2sd32.html"><code>x86::avx512_cvtsi2sd32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2sd64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtsi2sd64.html"><code>x86::avx512_cvtsi2sd64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2ss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvtsi2ss.html"><code>x86::sse_cvtsi2ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2ss32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtsi2ss32.html"><code>x86::avx512_cvtsi2ss32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi2ss64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtsi2ss64.html"><code>x86::avx512_cvtsi2ss64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi642sd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtsi642sd.html"><code>x86::sse2_cvtsi642sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtsi642ss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvtsi642ss.html"><code>x86::sse_cvtsi642ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtss2sd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvtss2sd.html"><code>x86::sse2_cvtss2sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtss2sd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtss2sd_round.html"><code>x86::avx512_mask_cvtss2sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtss2si</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvtss2si.html"><code>x86::sse_cvtss2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtss2si64</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvtss2si64.html"><code>x86::sse_cvtss2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2dq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvttpd2dq.html"><code>x86::sse2_cvttpd2dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2dq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2dq_128.html"><code>x86::avx512_mask_cvttpd2dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2dq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvtt_pd2dq_256.html"><code>x86::avx_cvtt_pd2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2dq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2dq_256.html"><code>x86::avx512_mask_cvttpd2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2dq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2dq_512.html"><code>x86::avx512_mask_cvttpd2dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2qq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2qq_128.html"><code>x86::avx512_mask_cvttpd2qq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2qq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2qq_256.html"><code>x86::avx512_mask_cvttpd2qq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2qq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2qq_512.html"><code>x86::avx512_mask_cvttpd2qq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2udq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2udq_128.html"><code>x86::avx512_mask_cvttpd2udq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2udq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2udq_256.html"><code>x86::avx512_mask_cvttpd2udq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2udq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2udq_512.html"><code>x86::avx512_mask_cvttpd2udq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2uqq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2uqq_128.html"><code>x86::avx512_mask_cvttpd2uqq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2uqq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2uqq_256.html"><code>x86::avx512_mask_cvttpd2uqq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttpd2uqq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttpd2uqq_512.html"><code>x86::avx512_mask_cvttpd2uqq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2dq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvttps2dq.html"><code>x86::sse2_cvttps2dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2dq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2dq_128.html"><code>x86::avx512_mask_cvttps2dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2dq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_cvtt_ps2dq_256.html"><code>x86::avx_cvtt_ps2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2dq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2dq_256.html"><code>x86::avx512_mask_cvttps2dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2dq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2dq_512.html"><code>x86::avx512_mask_cvttps2dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2qq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2qq_128.html"><code>x86::avx512_mask_cvttps2qq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2qq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2qq_256.html"><code>x86::avx512_mask_cvttps2qq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2qq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2qq_512.html"><code>x86::avx512_mask_cvttps2qq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2udq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2udq_128.html"><code>x86::avx512_mask_cvttps2udq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2udq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2udq_256.html"><code>x86::avx512_mask_cvttps2udq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2udq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2udq_512.html"><code>x86::avx512_mask_cvttps2udq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2uqq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2uqq_128.html"><code>x86::avx512_mask_cvttps2uqq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2uqq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2uqq_256.html"><code>x86::avx512_mask_cvttps2uqq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttps2uqq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvttps2uqq_512.html"><code>x86::avx512_mask_cvttps2uqq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttsd2si</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvttsd2si.html"><code>x86::sse2_cvttsd2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttsd2si64</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_cvttsd2si64.html"><code>x86::sse2_cvttsd2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttss2si</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvttss2si.html"><code>x86::sse_cvttss2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvttss2si64</code></strong></dt>
/// <dd><a href="../x86/fn.sse_cvttss2si64.html"><code>x86::sse_cvttss2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2pd_128.html"><code>x86::avx512_mask_cvtudq2pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2pd_256.html"><code>x86::avx512_mask_cvtudq2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2pd_512.html"><code>x86::avx512_mask_cvtudq2pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2ps_128.html"><code>x86::avx512_mask_cvtudq2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2ps_256.html"><code>x86::avx512_mask_cvtudq2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtudq2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtudq2ps_512.html"><code>x86::avx512_mask_cvtudq2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2pd_128.html"><code>x86::avx512_mask_cvtuqq2pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2pd_256.html"><code>x86::avx512_mask_cvtuqq2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2pd_512.html"><code>x86::avx512_mask_cvtuqq2pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2ps_128.html"><code>x86::avx512_mask_cvtuqq2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2ps_256.html"><code>x86::avx512_mask_cvtuqq2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtuqq2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_cvtuqq2ps_512.html"><code>x86::avx512_mask_cvtuqq2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtusi2sd32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtusi2sd.html"><code>x86::avx512_cvtusi2sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtusi2sd64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtusi642sd.html"><code>x86::avx512_cvtusi642sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtusi2ss32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtusi2ss.html"><code>x86::avx512_cvtusi2ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtusi2ss64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtusi642ss.html"><code>x86::avx512_cvtusi642ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtw2mask128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtw2mask_128.html"><code>x86::avx512_cvtw2mask_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtw2mask256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtw2mask_256.html"><code>x86::avx512_cvtw2mask_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_cvtw2mask512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvtw2mask_512.html"><code>x86::avx512_cvtw2mask_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dbpsadbw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_dbpsadbw_128.html"><code>x86::avx512_mask_dbpsadbw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dbpsadbw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_dbpsadbw_256.html"><code>x86::avx512_mask_dbpsadbw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dbpsadbw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_dbpsadbw_512.html"><code>x86::avx512_mask_dbpsadbw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_pd_256.html"><code>x86::avx512_mask_div_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_pd_512.html"><code>x86::avx512_mask_div_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divpd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_pd_128.html"><code>x86::avx512_mask_div_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_ps_256.html"><code>x86::avx512_mask_div_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_ps_512.html"><code>x86::avx512_mask_div_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_ps_128.html"><code>x86::avx512_mask_div_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_sd_round.html"><code>x86::avx512_mask_div_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_divss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_div_ss_round.html"><code>x86::avx512_mask_div_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dppd</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_dppd.html"><code>x86::sse41_dppd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dpps</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_dpps.html"><code>x86::sse41_dpps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_dpps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_dp_ps_256.html"><code>x86::avx_dp_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_emms</code></strong></dt>
/// <dd><a href="../x86/fn.mmx_emms.html"><code>x86::mmx_emms</code></a></dd>
/// <dt><strong><code>__builtin_ia32_exp2pd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_exp2_pd.html"><code>x86::avx512_exp2_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_exp2ps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_exp2_ps.html"><code>x86::avx512_exp2_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_pd_128.html"><code>x86::avx512_mask_expand_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_pd_256.html"><code>x86::avx512_mask_expand_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_pd_512.html"><code>x86::avx512_mask_expand_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_q_128.html"><code>x86::avx512_mask_expand_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_q_256.html"><code>x86::avx512_mask_expand_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expanddi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_q_512.html"><code>x86::avx512_mask_expand_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_pd_128.html"><code>x86::avx512_mask_expand_load_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_pd_256.html"><code>x86::avx512_mask_expand_load_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_pd_512.html"><code>x86::avx512_mask_expand_load_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_q_128.html"><code>x86::avx512_mask_expand_load_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_q_256.html"><code>x86::avx512_mask_expand_load_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloaddi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_q_512.html"><code>x86::avx512_mask_expand_load_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_ps_128.html"><code>x86::avx512_mask_expand_load_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_ps_256.html"><code>x86::avx512_mask_expand_load_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_ps_512.html"><code>x86::avx512_mask_expand_load_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_d_128.html"><code>x86::avx512_mask_expand_load_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_d_256.html"><code>x86::avx512_mask_expand_load_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandloadsi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_load_d_512.html"><code>x86::avx512_mask_expand_load_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsf128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_ps_128.html"><code>x86::avx512_mask_expand_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_ps_256.html"><code>x86::avx512_mask_expand_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_ps_512.html"><code>x86::avx512_mask_expand_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_d_128.html"><code>x86::avx512_mask_expand_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_d_256.html"><code>x86::avx512_mask_expand_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_expandsi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_expand_d_512.html"><code>x86::avx512_mask_expand_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf32x4_256.html"><code>x86::avx512_mask_vextractf32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf32x4_512.html"><code>x86::avx512_mask_vextractf32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf32x8_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf32x8_512.html"><code>x86::avx512_mask_vextractf32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf64x2_256.html"><code>x86::avx512_mask_vextractf64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf64x2_512.html"><code>x86::avx512_mask_vextractf64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extractf64x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextractf64x4_512.html"><code>x86::avx512_mask_vextractf64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti32x4_256.html"><code>x86::avx512_mask_vextracti32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti32x4_512.html"><code>x86::avx512_mask_vextracti32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti32x8_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti32x8_512.html"><code>x86::avx512_mask_vextracti32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti64x2_256.html"><code>x86::avx512_mask_vextracti64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti64x2_512.html"><code>x86::avx512_mask_vextracti64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extracti64x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vextracti64x4_512.html"><code>x86::avx512_mask_vextracti64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extrq</code></strong></dt>
/// <dd><a href="../x86/fn.sse4a_extrq.html"><code>x86::sse4a_extrq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_extrqi</code></strong></dt>
/// <dd><a href="../x86/fn.sse4a_extrqi.html"><code>x86::sse4a_extrqi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_femms</code></strong></dt>
/// <dd><a href="../x86/fn.mmx_femms.html"><code>x86::mmx_femms</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_pd_128.html"><code>x86::avx512_mask_fixupimm_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_pd_128.html"><code>x86::avx512_maskz_fixupimm_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_pd_256.html"><code>x86::avx512_mask_fixupimm_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_pd_256.html"><code>x86::avx512_maskz_fixupimm_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_pd_512.html"><code>x86::avx512_mask_fixupimm_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmpd512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_pd_512.html"><code>x86::avx512_maskz_fixupimm_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_ps_128.html"><code>x86::avx512_mask_fixupimm_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_ps_128.html"><code>x86::avx512_maskz_fixupimm_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_ps_256.html"><code>x86::avx512_mask_fixupimm_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_ps_256.html"><code>x86::avx512_maskz_fixupimm_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_ps_512.html"><code>x86::avx512_mask_fixupimm_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmps512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_ps_512.html"><code>x86::avx512_maskz_fixupimm_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmsd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_sd.html"><code>x86::avx512_mask_fixupimm_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmsd_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_sd.html"><code>x86::avx512_maskz_fixupimm_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fixupimm_ss.html"><code>x86::avx512_mask_fixupimm_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fixupimmss_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_fixupimm_ss.html"><code>x86::avx512_maskz_fixupimm_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclasspd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_pd_128.html"><code>x86::avx512_mask_fpclass_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclasspd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_pd_256.html"><code>x86::avx512_mask_fpclass_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclasspd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_pd_512.html"><code>x86::avx512_mask_fpclass_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclassps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_ps_128.html"><code>x86::avx512_mask_fpclass_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclassps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_ps_256.html"><code>x86::avx512_mask_fpclass_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclassps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_ps_512.html"><code>x86::avx512_mask_fpclass_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclasssd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_sd.html"><code>x86::avx512_mask_fpclass_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fpclassss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_fpclass_ss.html"><code>x86::avx512_mask_fpclass_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fxrstor</code></strong></dt>
/// <dd><a href="../x86/fn.fxrstor.html"><code>x86::fxrstor</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fxrstor64</code></strong></dt>
/// <dd><a href="../x86/fn.fxrstor64.html"><code>x86::fxrstor64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fxsave</code></strong></dt>
/// <dd><a href="../x86/fn.fxsave.html"><code>x86::fxsave</code></a></dd>
/// <dt><strong><code>__builtin_ia32_fxsave64</code></strong></dt>
/// <dd><a href="../x86/fn.fxsave64.html"><code>x86::fxsave64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div2df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div2_df.html"><code>x86::avx512_gather3div2_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div2_di.html"><code>x86::avx512_gather3div2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div4df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div4_df.html"><code>x86::avx512_gather3div4_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div4_di.html"><code>x86::avx512_gather3div4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div4sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div4_sf.html"><code>x86::avx512_gather3div4_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div4_si.html"><code>x86::avx512_gather3div4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div8sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div8_sf.html"><code>x86::avx512_gather3div8_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3div8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3div8_si.html"><code>x86::avx512_gather3div8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv2df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv2_df.html"><code>x86::avx512_gather3siv2_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv2_di.html"><code>x86::avx512_gather3siv2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv4df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv4_df.html"><code>x86::avx512_gather3siv4_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv4_di.html"><code>x86::avx512_gather3siv4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv4sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv4_sf.html"><code>x86::avx512_gather3siv4_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv4_si.html"><code>x86::avx512_gather3siv4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv8sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv8_sf.html"><code>x86::avx512_gather3siv8_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gather3siv8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather3siv8_si.html"><code>x86::avx512_gather3siv8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_d</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_d.html"><code>x86::avx2_gather_d_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_d256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_d_256.html"><code>x86::avx2_gather_d_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_pd</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_pd.html"><code>x86::avx2_gather_d_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_pd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_pd_256.html"><code>x86::avx2_gather_d_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_ps</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_ps.html"><code>x86::avx2_gather_d_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_ps_256.html"><code>x86::avx2_gather_d_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_q</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_q.html"><code>x86::avx2_gather_d_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherd_q256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_d_q_256.html"><code>x86::avx2_gather_d_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherdiv16sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_qps_512.html"><code>x86::avx512_gather_qps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherdiv16si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_qpi_512.html"><code>x86::avx512_gather_qpi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherdiv8df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_qpd_512.html"><code>x86::avx512_gather_qpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherdiv8di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_qpq_512.html"><code>x86::avx512_gather_qpq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherpfdpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gatherpf_dpd_512.html"><code>x86::avx512_gatherpf_dpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherpfdps</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gatherpf_dps_512.html"><code>x86::avx512_gatherpf_dps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherpfqpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gatherpf_qpd_512.html"><code>x86::avx512_gatherpf_qpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherpfqps</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gatherpf_qps_512.html"><code>x86::avx512_gatherpf_qps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_d</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_d.html"><code>x86::avx2_gather_q_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_d256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_d_256.html"><code>x86::avx2_gather_q_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_pd</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_pd.html"><code>x86::avx2_gather_q_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_pd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_pd_256.html"><code>x86::avx2_gather_q_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_ps</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_ps.html"><code>x86::avx2_gather_q_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_ps_256.html"><code>x86::avx2_gather_q_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_q</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_q.html"><code>x86::avx2_gather_q_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gatherq_q256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_gather_q_q_256.html"><code>x86::avx2_gather_q_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gathersiv16sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_dps_512.html"><code>x86::avx512_gather_dps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gathersiv16si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_dpi_512.html"><code>x86::avx512_gather_dpi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gathersiv8df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_dpd_512.html"><code>x86::avx512_gather_dpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_gathersiv8di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_gather_dpq_512.html"><code>x86::avx512_gather_dpq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexppd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_pd_128.html"><code>x86::avx512_mask_getexp_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexppd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_pd_256.html"><code>x86::avx512_mask_getexp_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexppd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_pd_512.html"><code>x86::avx512_mask_getexp_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexpps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_ps_128.html"><code>x86::avx512_mask_getexp_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexpps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_ps_256.html"><code>x86::avx512_mask_getexp_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexpps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_ps_512.html"><code>x86::avx512_mask_getexp_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexpsd128_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_sd.html"><code>x86::avx512_mask_getexp_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getexpss128_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getexp_ss.html"><code>x86::avx512_mask_getexp_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_pd_128.html"><code>x86::avx512_mask_getmant_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_pd_256.html"><code>x86::avx512_mask_getmant_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_pd_512.html"><code>x86::avx512_mask_getmant_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_ps_128.html"><code>x86::avx512_mask_getmant_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_ps_256.html"><code>x86::avx512_mask_getmant_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_ps_512.html"><code>x86::avx512_mask_getmant_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_sd.html"><code>x86::avx512_mask_getmant_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_getmantss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_getmant_ss.html"><code>x86::avx512_mask_getmant_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_haddpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_hadd_pd.html"><code>x86::sse3_hadd_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_haddpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_hadd_pd_256.html"><code>x86::avx_hadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_haddps</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_hadd_ps.html"><code>x86::sse3_hadd_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_haddps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_hadd_ps_256.html"><code>x86::avx_hadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_hsubpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_hsub_pd.html"><code>x86::sse3_hsub_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_hsubpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_hsub_pd_256.html"><code>x86::avx_hsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_hsubps</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_hsub_ps.html"><code>x86::sse3_hsub_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_hsubps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_hsub_ps_256.html"><code>x86::avx_hsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf32x4_256.html"><code>x86::avx512_mask_insertf32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf32x4_512.html"><code>x86::avx512_mask_insertf32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf32x8_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf32x8_512.html"><code>x86::avx512_mask_insertf32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf64x2_256.html"><code>x86::avx512_mask_insertf64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf64x2_512.html"><code>x86::avx512_mask_insertf64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertf64x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_insertf64x4_512.html"><code>x86::avx512_mask_insertf64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti32x4_256.html"><code>x86::avx512_mask_inserti32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti32x4_512.html"><code>x86::avx512_mask_inserti32x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti32x8_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti32x8_512.html"><code>x86::avx512_mask_inserti32x8_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti64x2_256.html"><code>x86::avx512_mask_inserti64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti64x2_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti64x2_512.html"><code>x86::avx512_mask_inserti64x2_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_inserti64x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_inserti64x4_512.html"><code>x86::avx512_mask_inserti64x4_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertps128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_insertps.html"><code>x86::sse41_insertps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertq</code></strong></dt>
/// <dd><a href="../x86/fn.sse4a_insertq.html"><code>x86::sse4a_insertq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_insertqi</code></strong></dt>
/// <dd><a href="../x86/fn.sse4a_insertqi.html"><code>x86::sse4a_insertqi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kandhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kand_w.html"><code>x86::avx512_kand_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kandnhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kandn_w.html"><code>x86::avx512_kandn_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_knothi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_knot_w.html"><code>x86::avx512_knot_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_korhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kor_w.html"><code>x86::avx512_kor_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kortestchi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kortestc_w.html"><code>x86::avx512_kortestc_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kortestzhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kortestz_w.html"><code>x86::avx512_kortestz_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kunpckdi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kunpck_dq.html"><code>x86::avx512_kunpck_dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kunpckhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kunpck_bw.html"><code>x86::avx512_kunpck_bw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kunpcksi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kunpck_wd.html"><code>x86::avx512_kunpck_wd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kxnorhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kxnor_w.html"><code>x86::avx512_kxnor_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_kxorhi</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_kxor_w.html"><code>x86::avx512_kxor_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_lddqu</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_ldu_dq.html"><code>x86::sse3_ldu_dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_lddqu256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_ldu_dq_256.html"><code>x86::avx_ldu_dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_lfence</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_lfence.html"><code>x86::sse2_lfence</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadd</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskload_d.html"><code>x86::avx2_maskload_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskload_d_256.html"><code>x86::avx2_maskload_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskload_pd.html"><code>x86::avx_maskload_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskload_pd_256.html"><code>x86::avx_maskload_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskload_ps.html"><code>x86::avx_maskload_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskload_ps_256.html"><code>x86::avx_maskload_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadq</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskload_q.html"><code>x86::avx2_maskload_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskloadq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskload_q_256.html"><code>x86::avx2_maskload_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskmovdqu</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_maskmov_dqu.html"><code>x86::sse2_maskmov_dqu</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstored</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskstore_d.html"><code>x86::avx2_maskstore_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstored256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskstore_d_256.html"><code>x86::avx2_maskstore_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstorepd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskstore_pd.html"><code>x86::avx_maskstore_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstorepd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskstore_pd_256.html"><code>x86::avx_maskstore_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstoreps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskstore_ps.html"><code>x86::avx_maskstore_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstoreps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_maskstore_ps_256.html"><code>x86::avx_maskstore_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstoreq</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskstore_q.html"><code>x86::avx2_maskstore_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maskstoreq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_maskstore_q_256.html"><code>x86::avx2_maskstore_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_max_pd.html"><code>x86::sse2_max_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_max_pd_256.html"><code>x86::avx_max_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_pd_256.html"><code>x86::avx512_mask_max_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_pd_512.html"><code>x86::avx512_mask_max_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxpd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_pd_128.html"><code>x86::avx512_mask_max_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_max_ps.html"><code>x86::sse_max_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_max_ps_256.html"><code>x86::avx_max_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_ps_256.html"><code>x86::avx512_mask_max_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_ps_512.html"><code>x86::avx512_mask_max_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_ps_128.html"><code>x86::avx512_mask_max_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxsd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_max_sd.html"><code>x86::sse2_max_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_sd_round.html"><code>x86::avx512_mask_max_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_max_ss.html"><code>x86::sse_max_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_maxss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_max_ss_round.html"><code>x86::avx512_mask_max_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mfence</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_mfence.html"><code>x86::sse2_mfence</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_min_pd.html"><code>x86::sse2_min_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_min_pd_256.html"><code>x86::avx_min_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_pd_256.html"><code>x86::avx512_mask_min_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_pd_512.html"><code>x86::avx512_mask_min_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minpd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_pd_128.html"><code>x86::avx512_mask_min_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_min_ps.html"><code>x86::sse_min_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_min_ps_256.html"><code>x86::avx_min_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_ps_256.html"><code>x86::avx512_mask_min_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_ps_512.html"><code>x86::avx512_mask_min_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_ps_128.html"><code>x86::avx512_mask_min_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minsd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_min_sd.html"><code>x86::sse2_min_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_sd_round.html"><code>x86::avx512_mask_min_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_min_ss.html"><code>x86::sse_min_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_minss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_min_ss_round.html"><code>x86::avx512_mask_min_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_monitor</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_monitor.html"><code>x86::sse3_monitor</code></a></dd>
/// <dt><strong><code>__builtin_ia32_monitorx</code></strong></dt>
/// <dd><a href="../x86/fn.monitorx.html"><code>x86::monitorx</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movmskpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_movmsk_pd.html"><code>x86::sse2_movmsk_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movmskpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_movmsk_pd_256.html"><code>x86::avx_movmsk_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movmskps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_movmsk_ps.html"><code>x86::sse_movmsk_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movmskps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_movmsk_ps_256.html"><code>x86::avx_movmsk_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movntdqa</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_movntdqa.html"><code>x86::sse41_movntdqa</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movntdqa256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_movntdqa.html"><code>x86::avx2_movntdqa</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movntdqa512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_movntdqa.html"><code>x86::avx512_movntdqa</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movsd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_move_sd.html"><code>x86::avx512_mask_move_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_movss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_move_ss.html"><code>x86::avx512_mask_move_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mpsadbw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_mpsadbw.html"><code>x86::sse41_mpsadbw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mpsadbw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_mpsadbw.html"><code>x86::avx2_mpsadbw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_pd_256.html"><code>x86::avx512_mask_mul_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_pd_512.html"><code>x86::avx512_mask_mul_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulpd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_pd_128.html"><code>x86::avx512_mask_mul_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_ps_256.html"><code>x86::avx512_mask_mul_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_ps_512.html"><code>x86::avx512_mask_mul_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_ps_128.html"><code>x86::avx512_mask_mul_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_sd_round.html"><code>x86::avx512_mask_mul_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mulss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_mul_ss_round.html"><code>x86::avx512_mask_mul_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mwait</code></strong></dt>
/// <dd><a href="../x86/fn.sse3_mwait.html"><code>x86::sse3_mwait</code></a></dd>
/// <dt><strong><code>__builtin_ia32_mwaitx</code></strong></dt>
/// <dd><a href="../x86/fn.mwaitx.html"><code>x86::mwaitx</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_pd_128.html"><code>x86::avx512_mask_or_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_pd_256.html"><code>x86::avx512_mask_or_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_pd_512.html"><code>x86::avx512_mask_or_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_ps_128.html"><code>x86::avx512_mask_or_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_ps_256.html"><code>x86::avx512_mask_or_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_orps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_or_ps_512.html"><code>x86::avx512_mask_or_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsb128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pabs_b_128.html"><code>x86::ssse3_pabs_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_b_128.html"><code>x86::avx512_mask_pabs_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pabs_b.html"><code>x86::avx2_pabs_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_b_256.html"><code>x86::avx512_mask_pabs_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_b_512.html"><code>x86::avx512_mask_pabs_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsd128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pabs_d_128.html"><code>x86::ssse3_pabs_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_d_128.html"><code>x86::avx512_mask_pabs_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pabs_d.html"><code>x86::avx2_pabs_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_d_256.html"><code>x86::avx512_mask_pabs_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_d_512.html"><code>x86::avx512_mask_pabs_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_q_128.html"><code>x86::avx512_mask_pabs_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_q_256.html"><code>x86::avx512_mask_pabs_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_q_512.html"><code>x86::avx512_mask_pabs_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pabs_w_128.html"><code>x86::ssse3_pabs_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_w_128.html"><code>x86::avx512_mask_pabs_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pabs_w.html"><code>x86::avx2_pabs_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_w_256.html"><code>x86::avx512_mask_pabs_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pabsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pabs_w_512.html"><code>x86::avx512_mask_pabs_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packssdw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_packssdw_128.html"><code>x86::sse2_packssdw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packssdw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packssdw_128.html"><code>x86::avx512_mask_packssdw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packssdw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_packssdw.html"><code>x86::avx2_packssdw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packssdw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packssdw_256.html"><code>x86::avx512_mask_packssdw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packssdw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packssdw_512.html"><code>x86::avx512_mask_packssdw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packsswb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_packsswb_128.html"><code>x86::sse2_packsswb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packsswb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packsswb_128.html"><code>x86::avx512_mask_packsswb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packsswb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_packsswb.html"><code>x86::avx2_packsswb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packsswb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packsswb_256.html"><code>x86::avx512_mask_packsswb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packsswb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packsswb_512.html"><code>x86::avx512_mask_packsswb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packusdw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_packusdw.html"><code>x86::sse41_packusdw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packusdw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packusdw_128.html"><code>x86::avx512_mask_packusdw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packusdw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_packusdw.html"><code>x86::avx2_packusdw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packusdw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packusdw_256.html"><code>x86::avx512_mask_packusdw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packusdw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packusdw_512.html"><code>x86::avx512_mask_packusdw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packuswb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_packuswb_128.html"><code>x86::sse2_packuswb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packuswb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packuswb_128.html"><code>x86::avx512_mask_packuswb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packuswb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_packuswb.html"><code>x86::avx2_packuswb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packuswb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packuswb_256.html"><code>x86::avx512_mask_packuswb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_packuswb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_packuswb_512.html"><code>x86::avx512_mask_packuswb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_b_128.html"><code>x86::avx512_mask_padd_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_b_256.html"><code>x86::avx512_mask_padd_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_b_512.html"><code>x86::avx512_mask_padd_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_d_128.html"><code>x86::avx512_mask_padd_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_d_256.html"><code>x86::avx512_mask_padd_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_d_512.html"><code>x86::avx512_mask_padd_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_q_128.html"><code>x86::avx512_mask_padd_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_q_256.html"><code>x86::avx512_mask_padd_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_q_512.html"><code>x86::avx512_mask_padd_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_padds_b.html"><code>x86::sse2_padds_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_b_128.html"><code>x86::avx512_mask_padds_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_padds_b.html"><code>x86::avx2_padds_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_b_256.html"><code>x86::avx512_mask_padds_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_b_512.html"><code>x86::avx512_mask_padds_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_padds_w.html"><code>x86::sse2_padds_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_w_128.html"><code>x86::avx512_mask_padds_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_padds_w.html"><code>x86::avx2_padds_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_w_256.html"><code>x86::avx512_mask_padds_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padds_w_512.html"><code>x86::avx512_mask_padds_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_paddus_b.html"><code>x86::sse2_paddus_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_b_128.html"><code>x86::avx512_mask_paddus_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_paddus_b.html"><code>x86::avx2_paddus_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_b_256.html"><code>x86::avx512_mask_paddus_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_b_512.html"><code>x86::avx512_mask_paddus_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_paddus_w.html"><code>x86::sse2_paddus_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_w_128.html"><code>x86::avx512_mask_paddus_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_paddus_w.html"><code>x86::avx2_paddus_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_w_256.html"><code>x86::avx512_mask_paddus_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddusw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_paddus_w_512.html"><code>x86::avx512_mask_paddus_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_w_128.html"><code>x86::avx512_mask_padd_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_w_256.html"><code>x86::avx512_mask_padd_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_paddw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_padd_w_512.html"><code>x86::avx512_mask_padd_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pause</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pause.html"><code>x86::sse2_pause</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pavg_b.html"><code>x86::sse2_pavg_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_b_128.html"><code>x86::avx512_mask_pavg_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pavg_b.html"><code>x86::avx2_pavg_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_b_256.html"><code>x86::avx512_mask_pavg_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_b_512.html"><code>x86::avx512_mask_pavg_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pavg_w.html"><code>x86::sse2_pavg_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_w_128.html"><code>x86::avx512_mask_pavg_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pavg_w.html"><code>x86::avx2_pavg_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_w_256.html"><code>x86::avx512_mask_pavg_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pavgw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pavg_w_512.html"><code>x86::avx512_mask_pavg_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pblendvb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_pblendvb.html"><code>x86::sse41_pblendvb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pblendvb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pblendvb.html"><code>x86::avx2_pblendvb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastb128_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_b_gpr_128.html"><code>x86::avx512_mask_pbroadcast_b_gpr_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastb256_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_b_gpr_256.html"><code>x86::avx512_mask_pbroadcast_b_gpr_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastb512_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_b_gpr_512.html"><code>x86::avx512_mask_pbroadcast_b_gpr_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastd128_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_d_gpr_128.html"><code>x86::avx512_mask_pbroadcast_d_gpr_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastd256_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_d_gpr_256.html"><code>x86::avx512_mask_pbroadcast_d_gpr_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastd512_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_d_gpr_512.html"><code>x86::avx512_mask_pbroadcast_d_gpr_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastq128_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_q_gpr_128.html"><code>x86::avx512_mask_pbroadcast_q_gpr_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastq256_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_q_gpr_256.html"><code>x86::avx512_mask_pbroadcast_q_gpr_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastq512_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_q_gpr_512.html"><code>x86::avx512_mask_pbroadcast_q_gpr_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastq512_mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_q_mem_512.html"><code>x86::avx512_mask_pbroadcast_q_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastw128_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_w_gpr_128.html"><code>x86::avx512_mask_pbroadcast_w_gpr_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastw256_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_w_gpr_256.html"><code>x86::avx512_mask_pbroadcast_w_gpr_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pbroadcastw512_gpr_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pbroadcast_w_gpr_512.html"><code>x86::avx512_mask_pbroadcast_w_gpr_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pclmulqdq128</code></strong></dt>
/// <dd><a href="../x86/fn.pclmulqdq.html"><code>x86::pclmulqdq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestri128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestri128.html"><code>x86::sse42_pcmpestri128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestria128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestria128.html"><code>x86::sse42_pcmpestria128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestric128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestric128.html"><code>x86::sse42_pcmpestric128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestrio128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestrio128.html"><code>x86::sse42_pcmpestrio128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestris128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestris128.html"><code>x86::sse42_pcmpestris128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestriz128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestriz128.html"><code>x86::sse42_pcmpestriz128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpestrm128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpestrm128.html"><code>x86::sse42_pcmpestrm128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistri128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistri128.html"><code>x86::sse42_pcmpistri128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistria128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistria128.html"><code>x86::sse42_pcmpistria128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistric128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistric128.html"><code>x86::sse42_pcmpistric128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistrio128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistrio128.html"><code>x86::sse42_pcmpistrio128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistris128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistris128.html"><code>x86::sse42_pcmpistris128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistriz128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistriz128.html"><code>x86::sse42_pcmpistriz128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pcmpistrm128</code></strong></dt>
/// <dd><a href="../x86/fn.sse42_pcmpistrm128.html"><code>x86::sse42_pcmpistrm128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pdep_di</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_pdep_64.html"><code>x86::bmi_pdep_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pdep_si</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_pdep_32.html"><code>x86::bmi_pdep_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permti256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_vperm2i128.html"><code>x86::avx2_vperm2i128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvardf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_df_256.html"><code>x86::avx512_mask_permvar_df_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvardf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_df_512.html"><code>x86::avx512_mask_permvar_df_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvardi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_di_256.html"><code>x86::avx512_mask_permvar_di_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvardi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_di_512.html"><code>x86::avx512_mask_permvar_di_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarhi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_hi_128.html"><code>x86::avx512_mask_permvar_hi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarhi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_hi_256.html"><code>x86::avx512_mask_permvar_hi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarhi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_hi_512.html"><code>x86::avx512_mask_permvar_hi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_qi_128.html"><code>x86::avx512_mask_permvar_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_qi_256.html"><code>x86::avx512_mask_permvar_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_qi_512.html"><code>x86::avx512_mask_permvar_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsf256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_permps.html"><code>x86::avx2_permps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsf256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_sf_256.html"><code>x86::avx512_mask_permvar_sf_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsf512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_sf_512.html"><code>x86::avx512_mask_permvar_sf_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_permd.html"><code>x86::avx2_permd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_si_256.html"><code>x86::avx512_mask_permvar_si_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_permvarsi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_permvar_si_512.html"><code>x86::avx512_mask_permvar_si_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pext_di</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_pext_64.html"><code>x86::bmi_pext_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pext_si</code></strong></dt>
/// <dd><a href="../x86/fn.bmi_pext_32.html"><code>x86::bmi_pext_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddd128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phadd_d_128.html"><code>x86::ssse3_phadd_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phadd_d.html"><code>x86::avx2_phadd_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddsw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phadd_sw_128.html"><code>x86::ssse3_phadd_sw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phadd_sw.html"><code>x86::avx2_phadd_sw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phadd_w_128.html"><code>x86::ssse3_phadd_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phaddw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phadd_w.html"><code>x86::avx2_phadd_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phminposuw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_phminposuw.html"><code>x86::sse41_phminposuw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubd128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phsub_d_128.html"><code>x86::ssse3_phsub_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phsub_d.html"><code>x86::avx2_phsub_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubsw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phsub_sw_128.html"><code>x86::ssse3_phsub_sw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phsub_sw.html"><code>x86::avx2_phsub_sw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_phsub_w_128.html"><code>x86::ssse3_phsub_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_phsubw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_phsub_w.html"><code>x86::avx2_phsub_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddubsw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pmadd_ub_sw_128.html"><code>x86::ssse3_pmadd_ub_sw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddubsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddubs_w_128.html"><code>x86::avx512_mask_pmaddubs_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddubsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmadd_ub_sw.html"><code>x86::avx2_pmadd_ub_sw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddubsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddubs_w_256.html"><code>x86::avx512_mask_pmaddubs_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddubsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddubs_w_512.html"><code>x86::avx512_mask_pmaddubs_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddwd128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pmadd_wd.html"><code>x86::sse2_pmadd_wd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddwd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddw_d_128.html"><code>x86::avx512_mask_pmaddw_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddwd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmadd_wd.html"><code>x86::avx2_pmadd_wd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddwd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddw_d_256.html"><code>x86::avx512_mask_pmaddw_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaddwd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaddw_d_512.html"><code>x86::avx512_mask_pmaddw_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_b_128.html"><code>x86::avx512_mask_pmaxs_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_b_256.html"><code>x86::avx512_mask_pmaxs_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_b_512.html"><code>x86::avx512_mask_pmaxs_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_d_128.html"><code>x86::avx512_mask_pmaxs_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_d_256.html"><code>x86::avx512_mask_pmaxs_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_d_512.html"><code>x86::avx512_mask_pmaxs_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_q_128.html"><code>x86::avx512_mask_pmaxs_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_q_256.html"><code>x86::avx512_mask_pmaxs_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_q_512.html"><code>x86::avx512_mask_pmaxs_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_w_128.html"><code>x86::avx512_mask_pmaxs_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_w_256.html"><code>x86::avx512_mask_pmaxs_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxs_w_512.html"><code>x86::avx512_mask_pmaxs_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxub128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_b_128.html"><code>x86::avx512_mask_pmaxu_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxub256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_b_256.html"><code>x86::avx512_mask_pmaxu_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxub512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_b_512.html"><code>x86::avx512_mask_pmaxu_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxud128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_d_128.html"><code>x86::avx512_mask_pmaxu_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxud256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_d_256.html"><code>x86::avx512_mask_pmaxu_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxud512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_d_512.html"><code>x86::avx512_mask_pmaxu_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_q_128.html"><code>x86::avx512_mask_pmaxu_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_q_256.html"><code>x86::avx512_mask_pmaxu_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_q_512.html"><code>x86::avx512_mask_pmaxu_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_w_128.html"><code>x86::avx512_mask_pmaxu_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_w_256.html"><code>x86::avx512_mask_pmaxu_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmaxuw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmaxu_w_512.html"><code>x86::avx512_mask_pmaxu_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_b_128.html"><code>x86::avx512_mask_pmins_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_b_256.html"><code>x86::avx512_mask_pmins_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_b_512.html"><code>x86::avx512_mask_pmins_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_d_128.html"><code>x86::avx512_mask_pmins_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_d_256.html"><code>x86::avx512_mask_pmins_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_d_512.html"><code>x86::avx512_mask_pmins_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_q_128.html"><code>x86::avx512_mask_pmins_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_q_256.html"><code>x86::avx512_mask_pmins_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_q_512.html"><code>x86::avx512_mask_pmins_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_w_128.html"><code>x86::avx512_mask_pmins_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_w_256.html"><code>x86::avx512_mask_pmins_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmins_w_512.html"><code>x86::avx512_mask_pmins_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminub128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_b_128.html"><code>x86::avx512_mask_pminu_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminub256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_b_256.html"><code>x86::avx512_mask_pminu_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminub512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_b_512.html"><code>x86::avx512_mask_pminu_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminud128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_d_128.html"><code>x86::avx512_mask_pminu_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminud256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_d_256.html"><code>x86::avx512_mask_pminu_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminud512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_d_512.html"><code>x86::avx512_mask_pminu_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_q_128.html"><code>x86::avx512_mask_pminu_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_q_256.html"><code>x86::avx512_mask_pminu_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_q_512.html"><code>x86::avx512_mask_pminu_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_w_128.html"><code>x86::avx512_mask_pminu_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_w_256.html"><code>x86::avx512_mask_pminu_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pminuw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pminu_w_512.html"><code>x86::avx512_mask_pminu_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_128.html"><code>x86::avx512_mask_pmov_db_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_mem_128.html"><code>x86::avx512_mask_pmov_db_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_256.html"><code>x86::avx512_mask_pmov_db_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_mem_256.html"><code>x86::avx512_mask_pmov_db_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_512.html"><code>x86::avx512_mask_pmov_db_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_db_mem_512.html"><code>x86::avx512_mask_pmov_db_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_128.html"><code>x86::avx512_mask_pmov_dw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_mem_128.html"><code>x86::avx512_mask_pmov_dw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_256.html"><code>x86::avx512_mask_pmov_dw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_mem_256.html"><code>x86::avx512_mask_pmov_dw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_512.html"><code>x86::avx512_mask_pmov_dw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovdw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_dw_mem_512.html"><code>x86::avx512_mask_pmov_dw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovmskb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pmovmskb_128.html"><code>x86::sse2_pmovmskb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovmskb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmovmskb.html"><code>x86::avx2_pmovmskb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_128.html"><code>x86::avx512_mask_pmov_qb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_mem_128.html"><code>x86::avx512_mask_pmov_qb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_256.html"><code>x86::avx512_mask_pmov_qb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_mem_256.html"><code>x86::avx512_mask_pmov_qb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_512.html"><code>x86::avx512_mask_pmov_qb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qb_mem_512.html"><code>x86::avx512_mask_pmov_qb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_128.html"><code>x86::avx512_mask_pmov_qd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_mem_128.html"><code>x86::avx512_mask_pmov_qd_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_256.html"><code>x86::avx512_mask_pmov_qd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_mem_256.html"><code>x86::avx512_mask_pmov_qd_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_512.html"><code>x86::avx512_mask_pmov_qd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqd512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qd_mem_512.html"><code>x86::avx512_mask_pmov_qd_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_128.html"><code>x86::avx512_mask_pmov_qw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_mem_128.html"><code>x86::avx512_mask_pmov_qw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_256.html"><code>x86::avx512_mask_pmov_qw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_mem_256.html"><code>x86::avx512_mask_pmov_qw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_512.html"><code>x86::avx512_mask_pmov_qw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovqw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_qw_mem_512.html"><code>x86::avx512_mask_pmov_qw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_128.html"><code>x86::avx512_mask_pmovs_db_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_mem_128.html"><code>x86::avx512_mask_pmovs_db_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_256.html"><code>x86::avx512_mask_pmovs_db_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_mem_256.html"><code>x86::avx512_mask_pmovs_db_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_512.html"><code>x86::avx512_mask_pmovs_db_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_db_mem_512.html"><code>x86::avx512_mask_pmovs_db_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_128.html"><code>x86::avx512_mask_pmovs_dw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_mem_128.html"><code>x86::avx512_mask_pmovs_dw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_256.html"><code>x86::avx512_mask_pmovs_dw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_mem_256.html"><code>x86::avx512_mask_pmovs_dw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_512.html"><code>x86::avx512_mask_pmovs_dw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsdw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_dw_mem_512.html"><code>x86::avx512_mask_pmovs_dw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_128.html"><code>x86::avx512_mask_pmovs_qb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_mem_128.html"><code>x86::avx512_mask_pmovs_qb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_256.html"><code>x86::avx512_mask_pmovs_qb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_mem_256.html"><code>x86::avx512_mask_pmovs_qb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_512.html"><code>x86::avx512_mask_pmovs_qb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qb_mem_512.html"><code>x86::avx512_mask_pmovs_qb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_128.html"><code>x86::avx512_mask_pmovs_qd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_mem_128.html"><code>x86::avx512_mask_pmovs_qd_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_256.html"><code>x86::avx512_mask_pmovs_qd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_mem_256.html"><code>x86::avx512_mask_pmovs_qd_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_512.html"><code>x86::avx512_mask_pmovs_qd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqd512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qd_mem_512.html"><code>x86::avx512_mask_pmovs_qd_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_128.html"><code>x86::avx512_mask_pmovs_qw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_mem_128.html"><code>x86::avx512_mask_pmovs_qw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_256.html"><code>x86::avx512_mask_pmovs_qw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_mem_256.html"><code>x86::avx512_mask_pmovs_qw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_512.html"><code>x86::avx512_mask_pmovs_qw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsqw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_qw_mem_512.html"><code>x86::avx512_mask_pmovs_qw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_128.html"><code>x86::avx512_mask_pmovs_wb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_mem_128.html"><code>x86::avx512_mask_pmovs_wb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_256.html"><code>x86::avx512_mask_pmovs_wb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_mem_256.html"><code>x86::avx512_mask_pmovs_wb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_512.html"><code>x86::avx512_mask_pmovs_wb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovswb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovs_wb_mem_512.html"><code>x86::avx512_mask_pmovs_wb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_d_128.html"><code>x86::avx512_mask_pmovsxb_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_d_256.html"><code>x86::avx512_mask_pmovsxb_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_d_512.html"><code>x86::avx512_mask_pmovsxb_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_q_128.html"><code>x86::avx512_mask_pmovsxb_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_q_256.html"><code>x86::avx512_mask_pmovsxb_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_q_512.html"><code>x86::avx512_mask_pmovsxb_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_w_128.html"><code>x86::avx512_mask_pmovsxb_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_w_256.html"><code>x86::avx512_mask_pmovsxb_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxbw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxb_w_512.html"><code>x86::avx512_mask_pmovsxb_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxdq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxd_q_128.html"><code>x86::avx512_mask_pmovsxd_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxdq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxd_q_256.html"><code>x86::avx512_mask_pmovsxd_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxdq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxd_q_512.html"><code>x86::avx512_mask_pmovsxd_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_d_128.html"><code>x86::avx512_mask_pmovsxw_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_d_256.html"><code>x86::avx512_mask_pmovsxw_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_d_512.html"><code>x86::avx512_mask_pmovsxw_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_q_128.html"><code>x86::avx512_mask_pmovsxw_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_q_256.html"><code>x86::avx512_mask_pmovsxw_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovsxwq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovsxw_q_512.html"><code>x86::avx512_mask_pmovsxw_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_128.html"><code>x86::avx512_mask_pmovus_db_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_mem_128.html"><code>x86::avx512_mask_pmovus_db_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_256.html"><code>x86::avx512_mask_pmovus_db_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_mem_256.html"><code>x86::avx512_mask_pmovus_db_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_512.html"><code>x86::avx512_mask_pmovus_db_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_db_mem_512.html"><code>x86::avx512_mask_pmovus_db_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_128.html"><code>x86::avx512_mask_pmovus_dw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_mem_128.html"><code>x86::avx512_mask_pmovus_dw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_256.html"><code>x86::avx512_mask_pmovus_dw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_mem_256.html"><code>x86::avx512_mask_pmovus_dw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_512.html"><code>x86::avx512_mask_pmovus_dw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusdw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_dw_mem_512.html"><code>x86::avx512_mask_pmovus_dw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_128.html"><code>x86::avx512_mask_pmovus_qb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_mem_128.html"><code>x86::avx512_mask_pmovus_qb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_256.html"><code>x86::avx512_mask_pmovus_qb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_mem_256.html"><code>x86::avx512_mask_pmovus_qb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_512.html"><code>x86::avx512_mask_pmovus_qb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qb_mem_512.html"><code>x86::avx512_mask_pmovus_qb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_128.html"><code>x86::avx512_mask_pmovus_qd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_mem_128.html"><code>x86::avx512_mask_pmovus_qd_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_256.html"><code>x86::avx512_mask_pmovus_qd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_mem_256.html"><code>x86::avx512_mask_pmovus_qd_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_512.html"><code>x86::avx512_mask_pmovus_qd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqd512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qd_mem_512.html"><code>x86::avx512_mask_pmovus_qd_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_128.html"><code>x86::avx512_mask_pmovus_qw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_mem_128.html"><code>x86::avx512_mask_pmovus_qw_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_256.html"><code>x86::avx512_mask_pmovus_qw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_mem_256.html"><code>x86::avx512_mask_pmovus_qw_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_512.html"><code>x86::avx512_mask_pmovus_qw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovusqw512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_qw_mem_512.html"><code>x86::avx512_mask_pmovus_qw_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_128.html"><code>x86::avx512_mask_pmovus_wb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_mem_128.html"><code>x86::avx512_mask_pmovus_wb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_256.html"><code>x86::avx512_mask_pmovus_wb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_mem_256.html"><code>x86::avx512_mask_pmovus_wb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_512.html"><code>x86::avx512_mask_pmovus_wb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovuswb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovus_wb_mem_512.html"><code>x86::avx512_mask_pmovus_wb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_128.html"><code>x86::avx512_mask_pmov_wb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb128mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_mem_128.html"><code>x86::avx512_mask_pmov_wb_mem_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_256.html"><code>x86::avx512_mask_pmov_wb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb256mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_mem_256.html"><code>x86::avx512_mask_pmov_wb_mem_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_512.html"><code>x86::avx512_mask_pmov_wb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovwb512mem_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmov_wb_mem_512.html"><code>x86::avx512_mask_pmov_wb_mem_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_d_128.html"><code>x86::avx512_mask_pmovzxb_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_d_256.html"><code>x86::avx512_mask_pmovzxb_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbd512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_pmovzxbd.html"><code>x86::avx512_pmovzxbd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_d_512.html"><code>x86::avx512_mask_pmovzxb_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_q_128.html"><code>x86::avx512_mask_pmovzxb_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_q_256.html"><code>x86::avx512_mask_pmovzxb_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbq512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_pmovzxbq.html"><code>x86::avx512_pmovzxbq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_q_512.html"><code>x86::avx512_mask_pmovzxb_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_w_128.html"><code>x86::avx512_mask_pmovzxb_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_w_256.html"><code>x86::avx512_mask_pmovzxb_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxbw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxb_w_512.html"><code>x86::avx512_mask_pmovzxb_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxdq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxd_q_128.html"><code>x86::avx512_mask_pmovzxd_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxdq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxd_q_256.html"><code>x86::avx512_mask_pmovzxd_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxdq512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_pmovzxdq.html"><code>x86::avx512_pmovzxdq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxdq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxd_q_512.html"><code>x86::avx512_mask_pmovzxd_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_d_128.html"><code>x86::avx512_mask_pmovzxw_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_d_256.html"><code>x86::avx512_mask_pmovzxw_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwd512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_pmovzxwd.html"><code>x86::avx512_pmovzxwd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_d_512.html"><code>x86::avx512_mask_pmovzxw_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_q_128.html"><code>x86::avx512_mask_pmovzxw_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_q_256.html"><code>x86::avx512_mask_pmovzxw_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwq512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_pmovzxwq.html"><code>x86::avx512_pmovzxwq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmovzxwq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmovzxw_q_512.html"><code>x86::avx512_mask_pmovzxw_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuldq128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_pmuldq.html"><code>x86::sse41_pmuldq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuldq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_dq_128.html"><code>x86::avx512_mask_pmul_dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuldq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmul_dq.html"><code>x86::avx2_pmul_dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuldq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_dq_256.html"><code>x86::avx512_mask_pmul_dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuldq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_dq_512.html"><code>x86::avx512_mask_pmul_dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhrsw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pmul_hr_sw_128.html"><code>x86::ssse3_pmul_hr_sw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhrsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_hr_sw_128.html"><code>x86::avx512_mask_pmul_hr_sw_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhrsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmul_hr_sw.html"><code>x86::avx2_pmul_hr_sw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhrsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_hr_sw_256.html"><code>x86::avx512_mask_pmul_hr_sw_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhrsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmul_hr_sw_512.html"><code>x86::avx512_mask_pmul_hr_sw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhuw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pmulhu_w.html"><code>x86::sse2_pmulhu_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhuw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulhu_w_128.html"><code>x86::avx512_mask_pmulhu_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhuw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmulhu_w.html"><code>x86::avx2_pmulhu_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhuw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulhu_w_256.html"><code>x86::avx512_mask_pmulhu_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhuw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulhu_w_512.html"><code>x86::avx512_mask_pmulhu_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pmulh_w.html"><code>x86::sse2_pmulh_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulh_w_128.html"><code>x86::avx512_mask_pmulh_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmulh_w.html"><code>x86::avx2_pmulh_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulh_w_256.html"><code>x86::avx512_mask_pmulh_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulhw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulh_w_512.html"><code>x86::avx512_mask_pmulh_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulld128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_d_128.html"><code>x86::avx512_mask_pmull_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulld256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_d_256.html"><code>x86::avx512_mask_pmull_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmulld512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_d_512.html"><code>x86::avx512_mask_pmull_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_q_128.html"><code>x86::avx512_mask_pmull_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_q_256.html"><code>x86::avx512_mask_pmull_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_q_512.html"><code>x86::avx512_mask_pmull_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_w_128.html"><code>x86::avx512_mask_pmull_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_w_256.html"><code>x86::avx512_mask_pmull_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmullw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmull_w_512.html"><code>x86::avx512_mask_pmull_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuludq128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pmulu_dq.html"><code>x86::sse2_pmulu_dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuludq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulu_dq_128.html"><code>x86::avx512_mask_pmulu_dq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuludq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pmulu_dq.html"><code>x86::avx2_pmulu_dq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuludq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulu_dq_256.html"><code>x86::avx512_mask_pmulu_dq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pmuludq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmulu_dq_512.html"><code>x86::avx512_mask_pmulu_dq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prold128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_d_128.html"><code>x86::avx512_mask_prol_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prold256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_d_256.html"><code>x86::avx512_mask_prol_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prold512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_d_512.html"><code>x86::avx512_mask_prol_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_q_128.html"><code>x86::avx512_mask_prol_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_q_256.html"><code>x86::avx512_mask_prol_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prol_q_512.html"><code>x86::avx512_mask_prol_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_d_128.html"><code>x86::avx512_mask_prolv_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_d_256.html"><code>x86::avx512_mask_prolv_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_d_512.html"><code>x86::avx512_mask_prolv_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_q_128.html"><code>x86::avx512_mask_prolv_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_q_256.html"><code>x86::avx512_mask_prolv_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prolvq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prolv_q_512.html"><code>x86::avx512_mask_prolv_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prord128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_d_128.html"><code>x86::avx512_mask_pror_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prord256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_d_256.html"><code>x86::avx512_mask_pror_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prord512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_d_512.html"><code>x86::avx512_mask_pror_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_q_128.html"><code>x86::avx512_mask_pror_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_q_256.html"><code>x86::avx512_mask_pror_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pror_q_512.html"><code>x86::avx512_mask_pror_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_d_128.html"><code>x86::avx512_mask_prorv_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_d_256.html"><code>x86::avx512_mask_prorv_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_d_512.html"><code>x86::avx512_mask_prorv_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_q_128.html"><code>x86::avx512_mask_prorv_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_q_256.html"><code>x86::avx512_mask_prorv_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_prorvq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_prorv_q_512.html"><code>x86::avx512_mask_prorv_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psadbw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psad_bw.html"><code>x86::sse2_psad_bw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psadbw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psad_bw.html"><code>x86::avx2_psad_bw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psadbw512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_psad_bw_512.html"><code>x86::avx512_psad_bw_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pshufb128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_pshuf_b_128.html"><code>x86::ssse3_pshuf_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pshufb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pshuf_b_128.html"><code>x86::avx512_mask_pshuf_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pshufb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pshuf_b.html"><code>x86::avx2_pshuf_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pshufb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pshuf_b_256.html"><code>x86::avx512_mask_pshuf_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pshufb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pshuf_b_512.html"><code>x86::avx512_mask_pshuf_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignb128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_psign_b_128.html"><code>x86::ssse3_psign_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psign_b.html"><code>x86::avx2_psign_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignd128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_psign_d_128.html"><code>x86::ssse3_psign_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psign_d.html"><code>x86::avx2_psign_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignw128</code></strong></dt>
/// <dd><a href="../x86/fn.ssse3_psign_w_128.html"><code>x86::ssse3_psign_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psignw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psign_w.html"><code>x86::avx2_psign_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslld128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psll_d.html"><code>x86::sse2_psll_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslld128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_d_128.html"><code>x86::avx512_mask_psll_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslld256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psll_d.html"><code>x86::avx2_psll_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslld256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_d_256.html"><code>x86::avx512_mask_psll_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslld512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_d.html"><code>x86::avx512_mask_psll_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslldi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pslli_d.html"><code>x86::sse2_pslli_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslldi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_di_128.html"><code>x86::avx512_mask_psll_di_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslldi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pslli_d.html"><code>x86::avx2_pslli_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslldi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_di_256.html"><code>x86::avx512_mask_psll_di_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pslldi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_di_512.html"><code>x86::avx512_mask_psll_di_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllq128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psll_q.html"><code>x86::sse2_psll_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_q_128.html"><code>x86::avx512_mask_psll_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psll_q.html"><code>x86::avx2_psll_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_q_256.html"><code>x86::avx512_mask_psll_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_q.html"><code>x86::avx512_mask_psll_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllqi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pslli_q.html"><code>x86::sse2_pslli_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_qi_128.html"><code>x86::avx512_mask_psll_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllqi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pslli_q.html"><code>x86::avx2_pslli_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_qi_256.html"><code>x86::avx512_mask_psll_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_qi_512.html"><code>x86::avx512_mask_psll_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv16hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv16_hi.html"><code>x86::avx512_mask_psllv16_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv16si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv_d.html"><code>x86::avx512_mask_psllv_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psllv_q.html"><code>x86::avx2_psllv_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv2di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv2_di.html"><code>x86::avx512_mask_psllv2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv32hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv32hi.html"><code>x86::avx512_mask_psllv32hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psllv_q_256.html"><code>x86::avx2_psllv_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv4di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv4_di.html"><code>x86::avx512_mask_psllv4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psllv_d.html"><code>x86::avx2_psllv_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv4si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv4_si.html"><code>x86::avx512_mask_psllv4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv8di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv_q.html"><code>x86::avx512_mask_psllv_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv8hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv8_hi.html"><code>x86::avx512_mask_psllv8_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psllv_d_256.html"><code>x86::avx2_psllv_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllv8si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psllv8_si.html"><code>x86::avx512_mask_psllv8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psll_w.html"><code>x86::sse2_psll_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_w_128.html"><code>x86::avx512_mask_psll_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psll_w.html"><code>x86::avx2_psll_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_w_256.html"><code>x86::avx512_mask_psll_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_w_512.html"><code>x86::avx512_mask_psll_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllwi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_pslli_w.html"><code>x86::sse2_pslli_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllwi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_wi_128.html"><code>x86::avx512_mask_psll_wi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllwi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_pslli_w.html"><code>x86::avx2_pslli_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllwi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_wi_256.html"><code>x86::avx512_mask_psll_wi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psllwi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psll_wi_512.html"><code>x86::avx512_mask_psll_wi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrad128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psra_d.html"><code>x86::sse2_psra_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrad128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_d_128.html"><code>x86::avx512_mask_psra_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrad256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psra_d.html"><code>x86::avx2_psra_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrad256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_d_256.html"><code>x86::avx512_mask_psra_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrad512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_d.html"><code>x86::avx512_mask_psra_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psradi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrai_d.html"><code>x86::sse2_psrai_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psradi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_di_128.html"><code>x86::avx512_mask_psra_di_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psradi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrai_d.html"><code>x86::avx2_psrai_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psradi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_di_256.html"><code>x86::avx512_mask_psra_di_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psradi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_di_512.html"><code>x86::avx512_mask_psra_di_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_q_128.html"><code>x86::avx512_mask_psra_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_q_256.html"><code>x86::avx512_mask_psra_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_q.html"><code>x86::avx512_mask_psra_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_qi_128.html"><code>x86::avx512_mask_psra_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_qi_256.html"><code>x86::avx512_mask_psra_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_qi_512.html"><code>x86::avx512_mask_psra_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav16hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav16_hi.html"><code>x86::avx512_mask_psrav16_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav16si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav_d.html"><code>x86::avx512_mask_psrav_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav32hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav32_hi.html"><code>x86::avx512_mask_psrav32_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrav_d.html"><code>x86::avx2_psrav_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav4si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav4_si.html"><code>x86::avx512_mask_psrav4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav8di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav_q.html"><code>x86::avx512_mask_psrav_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav8hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav8_hi.html"><code>x86::avx512_mask_psrav8_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrav_d_256.html"><code>x86::avx2_psrav_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrav8si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav8_si.html"><code>x86::avx512_mask_psrav8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psravq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav_q_128.html"><code>x86::avx512_mask_psrav_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psravq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrav_q_256.html"><code>x86::avx512_mask_psrav_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psra_w.html"><code>x86::sse2_psra_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_w_128.html"><code>x86::avx512_mask_psra_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psra_w.html"><code>x86::avx2_psra_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_w_256.html"><code>x86::avx512_mask_psra_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psraw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_w_512.html"><code>x86::avx512_mask_psra_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrawi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrai_w.html"><code>x86::sse2_psrai_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrawi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_wi_128.html"><code>x86::avx512_mask_psra_wi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrawi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrai_w.html"><code>x86::avx2_psrai_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrawi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_wi_256.html"><code>x86::avx512_mask_psra_wi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrawi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psra_wi_512.html"><code>x86::avx512_mask_psra_wi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrld128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrl_d.html"><code>x86::sse2_psrl_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrld128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_d_128.html"><code>x86::avx512_mask_psrl_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrld256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrl_d.html"><code>x86::avx2_psrl_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrld256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_d_256.html"><code>x86::avx512_mask_psrl_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrld512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_d.html"><code>x86::avx512_mask_psrl_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrldi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrli_d.html"><code>x86::sse2_psrli_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrldi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_di_128.html"><code>x86::avx512_mask_psrl_di_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrldi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrli_d.html"><code>x86::avx2_psrli_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrldi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_di_256.html"><code>x86::avx512_mask_psrl_di_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrldi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_di_512.html"><code>x86::avx512_mask_psrl_di_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlq128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrl_q.html"><code>x86::sse2_psrl_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_q_128.html"><code>x86::avx512_mask_psrl_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrl_q.html"><code>x86::avx2_psrl_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_q_256.html"><code>x86::avx512_mask_psrl_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_q.html"><code>x86::avx512_mask_psrl_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlqi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrli_q.html"><code>x86::sse2_psrli_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_qi_128.html"><code>x86::avx512_mask_psrl_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlqi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrli_q.html"><code>x86::avx2_psrli_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_qi_256.html"><code>x86::avx512_mask_psrl_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_qi_512.html"><code>x86::avx512_mask_psrl_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv16hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv16_hi.html"><code>x86::avx512_mask_psrlv16_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv16si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv_d.html"><code>x86::avx512_mask_psrlv_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrlv_q.html"><code>x86::avx2_psrlv_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv2di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv2_di.html"><code>x86::avx512_mask_psrlv2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv32hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv32hi.html"><code>x86::avx512_mask_psrlv32hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrlv_q_256.html"><code>x86::avx2_psrlv_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv4di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv4_di.html"><code>x86::avx512_mask_psrlv4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrlv_d.html"><code>x86::avx2_psrlv_d</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv4si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv4_si.html"><code>x86::avx512_mask_psrlv4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv8di_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv_q.html"><code>x86::avx512_mask_psrlv_q</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv8hi_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv8_hi.html"><code>x86::avx512_mask_psrlv8_hi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrlv_d_256.html"><code>x86::avx2_psrlv_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlv8si_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrlv8_si.html"><code>x86::avx512_mask_psrlv8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrl_w.html"><code>x86::sse2_psrl_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_w_128.html"><code>x86::avx512_mask_psrl_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrl_w.html"><code>x86::avx2_psrl_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_w_256.html"><code>x86::avx512_mask_psrl_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_w_512.html"><code>x86::avx512_mask_psrl_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlwi128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psrli_w.html"><code>x86::sse2_psrli_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlwi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_wi_128.html"><code>x86::avx512_mask_psrl_wi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlwi256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psrli_w.html"><code>x86::avx2_psrli_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlwi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_wi_256.html"><code>x86::avx512_mask_psrl_wi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psrlwi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psrl_wi_512.html"><code>x86::avx512_mask_psrl_wi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_b_128.html"><code>x86::avx512_mask_psub_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_b_256.html"><code>x86::avx512_mask_psub_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_b_512.html"><code>x86::avx512_mask_psub_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_d_128.html"><code>x86::avx512_mask_psub_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_d_256.html"><code>x86::avx512_mask_psub_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_d_512.html"><code>x86::avx512_mask_psub_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_q_128.html"><code>x86::avx512_mask_psub_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_q_256.html"><code>x86::avx512_mask_psub_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_q_512.html"><code>x86::avx512_mask_psub_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psubs_b.html"><code>x86::sse2_psubs_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_b_128.html"><code>x86::avx512_mask_psubs_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psubs_b.html"><code>x86::avx2_psubs_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_b_256.html"><code>x86::avx512_mask_psubs_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_b_512.html"><code>x86::avx512_mask_psubs_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psubs_w.html"><code>x86::sse2_psubs_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_w_128.html"><code>x86::avx512_mask_psubs_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psubs_w.html"><code>x86::avx2_psubs_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_w_256.html"><code>x86::avx512_mask_psubs_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubsw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubs_w_512.html"><code>x86::avx512_mask_psubs_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusb128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psubus_b.html"><code>x86::sse2_psubus_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_b_128.html"><code>x86::avx512_mask_psubus_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psubus_b.html"><code>x86::avx2_psubus_b</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_b_256.html"><code>x86::avx512_mask_psubus_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_b_512.html"><code>x86::avx512_mask_psubus_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusw128</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_psubus_w.html"><code>x86::sse2_psubus_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_w_128.html"><code>x86::avx512_mask_psubus_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx2_psubus_w.html"><code>x86::avx2_psubus_w</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_w_256.html"><code>x86::avx512_mask_psubus_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubusw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psubus_w_512.html"><code>x86::avx512_mask_psubus_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubw128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_w_128.html"><code>x86::avx512_mask_psub_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubw256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_w_256.html"><code>x86::avx512_mask_psub_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_psubw512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_psub_w_512.html"><code>x86::avx512_mask_psub_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_d_128.html"><code>x86::avx512_mask_pternlog_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_d_128.html"><code>x86::avx512_maskz_pternlog_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_d_256.html"><code>x86::avx512_mask_pternlog_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_d_256.html"><code>x86::avx512_maskz_pternlog_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_d_512.html"><code>x86::avx512_mask_pternlog_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogd512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_d_512.html"><code>x86::avx512_maskz_pternlog_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_q_128.html"><code>x86::avx512_mask_pternlog_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_q_128.html"><code>x86::avx512_maskz_pternlog_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_q_256.html"><code>x86::avx512_mask_pternlog_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_q_256.html"><code>x86::avx512_maskz_pternlog_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pternlog_q_512.html"><code>x86::avx512_mask_pternlog_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_pternlogq512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_pternlog_q_512.html"><code>x86::avx512_maskz_pternlog_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestc128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_ptestc.html"><code>x86::sse41_ptestc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestc256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_ptestc_256.html"><code>x86::avx_ptestc_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmb128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_b_128.html"><code>x86::avx512_ptestm_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_b_256.html"><code>x86::avx512_ptestm_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmb512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_b_512.html"><code>x86::avx512_ptestm_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmd128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_d_128.html"><code>x86::avx512_ptestm_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_d_256.html"><code>x86::avx512_ptestm_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmd512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_d_512.html"><code>x86::avx512_ptestm_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmq128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_q_128.html"><code>x86::avx512_ptestm_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_q_256.html"><code>x86::avx512_ptestm_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmq512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_q_512.html"><code>x86::avx512_ptestm_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmw128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_w_128.html"><code>x86::avx512_ptestm_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_w_256.html"><code>x86::avx512_ptestm_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestmw512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestm_w_512.html"><code>x86::avx512_ptestm_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmb128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_b_128.html"><code>x86::avx512_ptestnm_b_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmb256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_b_256.html"><code>x86::avx512_ptestnm_b_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmb512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_b_512.html"><code>x86::avx512_ptestnm_b_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmd128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_d_128.html"><code>x86::avx512_ptestnm_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_d_256.html"><code>x86::avx512_ptestnm_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmd512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_d_512.html"><code>x86::avx512_ptestnm_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmq128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_q_128.html"><code>x86::avx512_ptestnm_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmq256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_q_256.html"><code>x86::avx512_ptestnm_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmq512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_q_512.html"><code>x86::avx512_ptestnm_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmw128</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_w_128.html"><code>x86::avx512_ptestnm_w_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmw256</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_w_256.html"><code>x86::avx512_ptestnm_w_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnmw512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_ptestnm_w_512.html"><code>x86::avx512_ptestnm_w_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnzc128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_ptestnzc.html"><code>x86::sse41_ptestnzc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestnzc256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_ptestnzc_256.html"><code>x86::avx_ptestnzc_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestz128</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_ptestz.html"><code>x86::sse41_ptestz</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ptestz256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_ptestz_256.html"><code>x86::avx_ptestz_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangepd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_pd_128.html"><code>x86::avx512_mask_range_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangepd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_pd_256.html"><code>x86::avx512_mask_range_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangepd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_pd_512.html"><code>x86::avx512_mask_range_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangeps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_ps_128.html"><code>x86::avx512_mask_range_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangeps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_ps_256.html"><code>x86::avx512_mask_range_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangeps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_ps_512.html"><code>x86::avx512_mask_range_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangesd128_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_sd.html"><code>x86::avx512_mask_range_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rangess128_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_range_ss.html"><code>x86::avx512_mask_range_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_pd_128.html"><code>x86::avx512_rcp14_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_pd_256.html"><code>x86::avx512_rcp14_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_pd_512.html"><code>x86::avx512_rcp14_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_ps_128.html"><code>x86::avx512_rcp14_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_ps_256.html"><code>x86::avx512_rcp14_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_ps_512.html"><code>x86::avx512_rcp14_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14sd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_sd.html"><code>x86::avx512_rcp14_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp14ss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp14_ss.html"><code>x86::avx512_rcp14_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp28pd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp28_pd.html"><code>x86::avx512_rcp28_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp28ps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp28_ps.html"><code>x86::avx512_rcp28_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp28sd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp28_sd.html"><code>x86::avx512_rcp28_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcp28ss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rcp28_ss.html"><code>x86::avx512_rcp28_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcpps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_rcp_ps.html"><code>x86::sse_rcp_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcpps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_rcp_ps_256.html"><code>x86::avx_rcp_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rcpss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_rcp_ss.html"><code>x86::sse_rcp_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdfsbase32</code></strong></dt>
/// <dd><a href="../x86/fn.rdfsbase_32.html"><code>x86::rdfsbase_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdfsbase64</code></strong></dt>
/// <dd><a href="../x86/fn.rdfsbase_64.html"><code>x86::rdfsbase_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdgsbase32</code></strong></dt>
/// <dd><a href="../x86/fn.rdgsbase_32.html"><code>x86::rdgsbase_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdgsbase64</code></strong></dt>
/// <dd><a href="../x86/fn.rdgsbase_64.html"><code>x86::rdgsbase_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdpkru</code></strong></dt>
/// <dd><a href="../x86/fn.rdpkru.html"><code>x86::rdpkru</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdpmc</code></strong></dt>
/// <dd><a href="../x86/fn.rdpmc.html"><code>x86::rdpmc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdtsc</code></strong></dt>
/// <dd><a href="../x86/fn.rdtsc.html"><code>x86::rdtsc</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rdtscp</code></strong></dt>
/// <dd><a href="../x86/fn.rdtscp.html"><code>x86::rdtscp</code></a></dd>
/// <dt><strong><code>__builtin_ia32_readeflags_u32</code></strong></dt>
/// <dd><a href="../x86/fn.flags_read_u32.html"><code>x86::flags_read_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_readeflags_u64</code></strong></dt>
/// <dd><a href="../x86/fn.flags_read_u64.html"><code>x86::flags_read_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reducepd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_pd_128.html"><code>x86::avx512_mask_reduce_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reducepd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_pd_256.html"><code>x86::avx512_mask_reduce_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reducepd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_pd_512.html"><code>x86::avx512_mask_reduce_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reduceps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_ps_128.html"><code>x86::avx512_mask_reduce_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reduceps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_ps_256.html"><code>x86::avx512_mask_reduce_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reduceps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_ps_512.html"><code>x86::avx512_mask_reduce_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reducesd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_sd.html"><code>x86::avx512_mask_reduce_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_reducess_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_reduce_ss.html"><code>x86::avx512_mask_reduce_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscalepd_128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_pd_128.html"><code>x86::avx512_mask_rndscale_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscalepd_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_pd_256.html"><code>x86::avx512_mask_rndscale_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscalepd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_pd_512.html"><code>x86::avx512_mask_rndscale_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscaleps_128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_ps_128.html"><code>x86::avx512_mask_rndscale_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscaleps_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_ps_256.html"><code>x86::avx512_mask_rndscale_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscaleps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_ps_512.html"><code>x86::avx512_mask_rndscale_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscalesd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_sd.html"><code>x86::avx512_mask_rndscale_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rndscaless_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_rndscale_ss.html"><code>x86::avx512_mask_rndscale_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_round_pd.html"><code>x86::sse41_round_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_round_pd_256.html"><code>x86::avx_round_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundps</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_round_ps.html"><code>x86::sse41_round_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_round_ps_256.html"><code>x86::avx_round_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundsd</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_round_sd.html"><code>x86::sse41_round_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_roundss</code></strong></dt>
/// <dd><a href="../x86/fn.sse41_round_ss.html"><code>x86::sse41_round_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14pd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_pd_128.html"><code>x86::avx512_rsqrt14_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14pd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_pd_256.html"><code>x86::avx512_rsqrt14_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14pd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_pd_512.html"><code>x86::avx512_rsqrt14_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14ps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_ps_128.html"><code>x86::avx512_rsqrt14_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_ps_256.html"><code>x86::avx512_rsqrt14_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_ps_512.html"><code>x86::avx512_rsqrt14_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14sd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_sd.html"><code>x86::avx512_rsqrt14_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt14ss_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt14_ss.html"><code>x86::avx512_rsqrt14_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt28pd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt28_pd.html"><code>x86::avx512_rsqrt28_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt28ps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt28_ps.html"><code>x86::avx512_rsqrt28_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt28sd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt28_sd.html"><code>x86::avx512_rsqrt28_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrt28ss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_rsqrt28_ss.html"><code>x86::avx512_rsqrt28_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrtps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_rsqrt_ps.html"><code>x86::sse_rsqrt_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrtps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_rsqrt_ps_256.html"><code>x86::avx_rsqrt_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_rsqrtss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_rsqrt_ss.html"><code>x86::sse_rsqrt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_pd_128.html"><code>x86::avx512_mask_scalef_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_pd_256.html"><code>x86::avx512_mask_scalef_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_pd_512.html"><code>x86::avx512_mask_scalef_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_ps_128.html"><code>x86::avx512_mask_scalef_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_ps_256.html"><code>x86::avx512_mask_scalef_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_ps_512.html"><code>x86::avx512_mask_scalef_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_sd.html"><code>x86::avx512_mask_scalef_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scalefss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_scalef_ss.html"><code>x86::avx512_mask_scalef_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv16sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_qps_512.html"><code>x86::avx512_scatter_qps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv16si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_qpi_512.html"><code>x86::avx512_scatter_qpi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv2df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv2_df.html"><code>x86::avx512_scatterdiv2_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv2_di.html"><code>x86::avx512_scatterdiv2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv4df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv4_df.html"><code>x86::avx512_scatterdiv4_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv4_di.html"><code>x86::avx512_scatterdiv4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv4sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv4_sf.html"><code>x86::avx512_scatterdiv4_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv4_si.html"><code>x86::avx512_scatterdiv4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv8df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_qpd_512.html"><code>x86::avx512_scatter_qpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv8di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_qpq_512.html"><code>x86::avx512_scatter_qpq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv8sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv8_sf.html"><code>x86::avx512_scatterdiv8_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterdiv8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterdiv8_si.html"><code>x86::avx512_scatterdiv8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterpfdpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterpf_dpd_512.html"><code>x86::avx512_scatterpf_dpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterpfdps</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterpf_dps_512.html"><code>x86::avx512_scatterpf_dps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterpfqpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterpf_qpd_512.html"><code>x86::avx512_scatterpf_qpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scatterpfqps</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatterpf_qps_512.html"><code>x86::avx512_scatterpf_qps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv16sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_dps_512.html"><code>x86::avx512_scatter_dps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv16si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_dpi_512.html"><code>x86::avx512_scatter_dpi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv2df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv2_df.html"><code>x86::avx512_scattersiv2_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv2di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv2_di.html"><code>x86::avx512_scattersiv2_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv4df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv4_df.html"><code>x86::avx512_scattersiv4_df</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv4di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv4_di.html"><code>x86::avx512_scattersiv4_di</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv4sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv4_sf.html"><code>x86::avx512_scattersiv4_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv4si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv4_si.html"><code>x86::avx512_scattersiv4_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv8df</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_dpd_512.html"><code>x86::avx512_scatter_dpd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv8di</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scatter_dpq_512.html"><code>x86::avx512_scatter_dpq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv8sf</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv8_sf.html"><code>x86::avx512_scattersiv8_sf</code></a></dd>
/// <dt><strong><code>__builtin_ia32_scattersiv8si</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_scattersiv8_si.html"><code>x86::avx512_scattersiv8_si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sfence</code></strong></dt>
/// <dd><a href="../x86/fn.sse_sfence.html"><code>x86::sse_sfence</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha1msg1</code></strong></dt>
/// <dd><a href="../x86/fn.sha1msg1.html"><code>x86::sha1msg1</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha1msg2</code></strong></dt>
/// <dd><a href="../x86/fn.sha1msg2.html"><code>x86::sha1msg2</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha1nexte</code></strong></dt>
/// <dd><a href="../x86/fn.sha1nexte.html"><code>x86::sha1nexte</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha1rnds4</code></strong></dt>
/// <dd><a href="../x86/fn.sha1rnds4.html"><code>x86::sha1rnds4</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha256msg1</code></strong></dt>
/// <dd><a href="../x86/fn.sha256msg1.html"><code>x86::sha256msg1</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha256msg2</code></strong></dt>
/// <dd><a href="../x86/fn.sha256msg2.html"><code>x86::sha256msg2</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sha256rnds2</code></strong></dt>
/// <dd><a href="../x86/fn.sha256rnds2.html"><code>x86::sha256rnds2</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_f32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_f32x4_256.html"><code>x86::avx512_mask_shuf_f32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_f32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_f32x4.html"><code>x86::avx512_mask_shuf_f32x4</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_f64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_f64x2_256.html"><code>x86::avx512_mask_shuf_f64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_f64x2_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_f64x2.html"><code>x86::avx512_mask_shuf_f64x2</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_i32x4_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_i32x4_256.html"><code>x86::avx512_mask_shuf_i32x4_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_i32x4_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_i32x4.html"><code>x86::avx512_mask_shuf_i32x4</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_i64x2_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_i64x2_256.html"><code>x86::avx512_mask_shuf_i64x2_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shuf_i64x2_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_i64x2.html"><code>x86::avx512_mask_shuf_i64x2</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_pd_128.html"><code>x86::avx512_mask_shuf_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_pd_256.html"><code>x86::avx512_mask_shuf_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_pd_512.html"><code>x86::avx512_mask_shuf_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_ps_128.html"><code>x86::avx512_mask_shuf_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_ps_256.html"><code>x86::avx512_mask_shuf_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_shufps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_shuf_ps_512.html"><code>x86::avx512_mask_shuf_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtpd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_sqrt_pd.html"><code>x86::sse2_sqrt_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_pd_128.html"><code>x86::avx512_mask_sqrt_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_sqrt_pd_256.html"><code>x86::avx_sqrt_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_pd_256.html"><code>x86::avx512_mask_sqrt_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_pd_512.html"><code>x86::avx512_mask_sqrt_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtps</code></strong></dt>
/// <dd><a href="../x86/fn.sse_sqrt_ps.html"><code>x86::sse_sqrt_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_ps_128.html"><code>x86::avx512_mask_sqrt_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_sqrt_ps_256.html"><code>x86::avx_sqrt_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_ps_256.html"><code>x86::avx512_mask_sqrt_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_ps_512.html"><code>x86::avx512_mask_sqrt_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtsd</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_sqrt_sd.html"><code>x86::sse2_sqrt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_sd.html"><code>x86::avx512_mask_sqrt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtss</code></strong></dt>
/// <dd><a href="../x86/fn.sse_sqrt_ss.html"><code>x86::sse_sqrt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_sqrtss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sqrt_ss.html"><code>x86::avx512_mask_sqrt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_storess_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_store_ss.html"><code>x86::avx512_mask_store_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subborrow_u32</code></strong></dt>
/// <dd><a href="../x86/fn.subborrow_u32.html"><code>x86::subborrow_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subborrow_u64</code></strong></dt>
/// <dd><a href="../x86/fn.subborrow_u64.html"><code>x86::subborrow_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_pd_128.html"><code>x86::avx512_mask_sub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_pd_256.html"><code>x86::avx512_mask_sub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_pd_512.html"><code>x86::avx512_mask_sub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_ps_128.html"><code>x86::avx512_mask_sub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_ps_256.html"><code>x86::avx512_mask_sub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_ps_512.html"><code>x86::avx512_mask_sub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subsd_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_sd_round.html"><code>x86::avx512_mask_sub_sd_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_subss_round_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_sub_ss_round.html"><code>x86::avx512_mask_sub_ss_round</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomieq</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomieq_ss.html"><code>x86::sse_ucomieq_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomige</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomige_ss.html"><code>x86::sse_ucomige_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomigt</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomigt_ss.html"><code>x86::sse_ucomigt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomile</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomile_ss.html"><code>x86::sse_ucomile_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomilt</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomilt_ss.html"><code>x86::sse_ucomilt_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomineq</code></strong></dt>
/// <dd><a href="../x86/fn.sse_ucomineq_ss.html"><code>x86::sse_ucomineq_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdeq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomieq_sd.html"><code>x86::sse2_ucomieq_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdge</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomige_sd.html"><code>x86::sse2_ucomige_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdgt</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomigt_sd.html"><code>x86::sse2_ucomigt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdle</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomile_sd.html"><code>x86::sse2_ucomile_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdlt</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomilt_sd.html"><code>x86::sse2_ucomilt_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_ucomisdneq</code></strong></dt>
/// <dd><a href="../x86/fn.sse2_ucomineq_sd.html"><code>x86::sse2_ucomineq_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vbroadcastf128_pd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vbroadcastf128_pd_256.html"><code>x86::avx_vbroadcastf128_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vbroadcastf128_ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vbroadcastf128_ps_256.html"><code>x86::avx_vbroadcastf128_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vbroadcastsd512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vbroadcast_sd_512.html"><code>x86::avx512_vbroadcast_sd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vbroadcastss512</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vbroadcast_ss_512.html"><code>x86::avx512_vbroadcast_ss_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcomisd</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcomi_sd.html"><code>x86::avx512_vcomi_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcomiss</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcomi_ss.html"><code>x86::avx512_vcomi_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtph2ps</code></strong></dt>
/// <dd><a href="../x86/fn.vcvtph2ps_128.html"><code>x86::vcvtph2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtph2ps256</code></strong></dt>
/// <dd><a href="../x86/fn.vcvtph2ps_256.html"><code>x86::vcvtph2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtph2ps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtph2ps_256.html"><code>x86::avx512_mask_vcvtph2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtph2ps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtph2ps_512.html"><code>x86::avx512_mask_vcvtph2ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtph2ps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtph2ps_128.html"><code>x86::avx512_mask_vcvtph2ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtps2ph</code></strong></dt>
/// <dd><a href="../x86/fn.vcvtps2ph_128.html"><code>x86::vcvtps2ph_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtps2ph256</code></strong></dt>
/// <dd><a href="../x86/fn.vcvtps2ph_256.html"><code>x86::vcvtps2ph_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtps2ph256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtps2ph_256.html"><code>x86::avx512_mask_vcvtps2ph_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtps2ph512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtps2ph_512.html"><code>x86::avx512_mask_vcvtps2ph_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtps2ph_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vcvtps2ph_128.html"><code>x86::avx512_mask_vcvtps2ph_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtsd2si32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtsd2si32.html"><code>x86::avx512_vcvtsd2si32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtsd2si64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtsd2si64.html"><code>x86::avx512_vcvtsd2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtsd2usi32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtsd2usi32.html"><code>x86::avx512_vcvtsd2usi32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtsd2usi64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtsd2usi64.html"><code>x86::avx512_vcvtsd2usi64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtss2si32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtss2si32.html"><code>x86::avx512_vcvtss2si32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtss2si64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtss2si64.html"><code>x86::avx512_vcvtss2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtss2usi32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtss2usi32.html"><code>x86::avx512_vcvtss2usi32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvtss2usi64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_vcvtss2usi64.html"><code>x86::avx512_vcvtss2usi64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttsd2si32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttsd2si.html"><code>x86::avx512_cvttsd2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttsd2si64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttsd2si64.html"><code>x86::avx512_cvttsd2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttsd2usi32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttsd2usi.html"><code>x86::avx512_cvttsd2usi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttsd2usi64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttsd2usi64.html"><code>x86::avx512_cvttsd2usi64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttss2si32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttss2si.html"><code>x86::avx512_cvttss2si</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttss2si64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttss2si64.html"><code>x86::avx512_cvttss2si64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttss2usi32</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttss2usi.html"><code>x86::avx512_cvttss2usi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vcvttss2usi64</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_cvttss2usi64.html"><code>x86::avx512_cvttss2usi64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_pd.html"><code>x86::fma_vfmadd_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_pd_128.html"><code>x86::avx512_mask_vfmadd_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_pd_128.html"><code>x86::avx512_mask3_vfmadd_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_pd_128.html"><code>x86::avx512_maskz_vfmadd_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_pd_256.html"><code>x86::fma_vfmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_pd_256.html"><code>x86::avx512_mask_vfmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_pd_256.html"><code>x86::avx512_mask3_vfmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_pd_256.html"><code>x86::avx512_maskz_vfmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_pd_512.html"><code>x86::avx512_mask_vfmadd_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_pd_512.html"><code>x86::avx512_mask3_vfmadd_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddpd512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_pd_512.html"><code>x86::avx512_maskz_vfmadd_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_ps.html"><code>x86::fma_vfmadd_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_ps_128.html"><code>x86::avx512_mask_vfmadd_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_ps_128.html"><code>x86::avx512_mask3_vfmadd_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_ps_128.html"><code>x86::avx512_maskz_vfmadd_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_ps_256.html"><code>x86::fma_vfmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_ps_256.html"><code>x86::avx512_mask_vfmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_ps_256.html"><code>x86::avx512_mask3_vfmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_ps_256.html"><code>x86::avx512_maskz_vfmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_ps_512.html"><code>x86::avx512_mask_vfmadd_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_ps_512.html"><code>x86::avx512_mask3_vfmadd_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddps512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_ps_512.html"><code>x86::avx512_maskz_vfmadd_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_sd.html"><code>x86::fma_vfmadd_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsd3_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_sd.html"><code>x86::avx512_mask_vfmadd_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsd3_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_sd.html"><code>x86::avx512_mask3_vfmadd_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsd3_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_sd.html"><code>x86::avx512_maskz_vfmadd_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddss</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmadd_ss.html"><code>x86::fma_vfmadd_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddss3_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmadd_ss.html"><code>x86::avx512_mask_vfmadd_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddss3_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmadd_ss.html"><code>x86::avx512_mask3_vfmadd_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddss3_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmadd_ss.html"><code>x86::avx512_maskz_vfmadd_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmaddsub_pd.html"><code>x86::fma_vfmaddsub_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_pd_128.html"><code>x86::avx512_mask_vfmaddsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_pd_128.html"><code>x86::avx512_mask3_vfmaddsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_pd_128.html"><code>x86::avx512_maskz_vfmaddsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmaddsub_pd_256.html"><code>x86::fma_vfmaddsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_pd_256.html"><code>x86::avx512_mask_vfmaddsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_pd_256.html"><code>x86::avx512_mask3_vfmaddsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_pd_256.html"><code>x86::avx512_maskz_vfmaddsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_pd_512.html"><code>x86::avx512_mask_vfmaddsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_pd_512.html"><code>x86::avx512_mask3_vfmaddsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubpd512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_pd_512.html"><code>x86::avx512_maskz_vfmaddsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmaddsub_ps.html"><code>x86::fma_vfmaddsub_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_ps_128.html"><code>x86::avx512_mask_vfmaddsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_ps_128.html"><code>x86::avx512_mask3_vfmaddsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_ps_128.html"><code>x86::avx512_maskz_vfmaddsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmaddsub_ps_256.html"><code>x86::fma_vfmaddsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_ps_256.html"><code>x86::avx512_mask_vfmaddsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_ps_256.html"><code>x86::avx512_mask3_vfmaddsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_ps_256.html"><code>x86::avx512_maskz_vfmaddsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfmaddsub_ps_512.html"><code>x86::avx512_mask_vfmaddsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmaddsub_ps_512.html"><code>x86::avx512_mask3_vfmaddsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmaddsubps512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vfmaddsub_ps_512.html"><code>x86::avx512_maskz_vfmaddsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsubadd_pd.html"><code>x86::fma_vfmsubadd_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddpd128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_pd_128.html"><code>x86::avx512_mask3_vfmsubadd_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsubadd_pd_256.html"><code>x86::fma_vfmsubadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddpd256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_pd_256.html"><code>x86::avx512_mask3_vfmsubadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddpd512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_pd_512.html"><code>x86::avx512_mask3_vfmsubadd_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsubadd_ps.html"><code>x86::fma_vfmsubadd_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddps128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_ps_128.html"><code>x86::avx512_mask3_vfmsubadd_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsubadd_ps_256.html"><code>x86::fma_vfmsubadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddps256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_ps_256.html"><code>x86::avx512_mask3_vfmsubadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubaddps512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsubadd_ps_512.html"><code>x86::avx512_mask3_vfmsubadd_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_pd.html"><code>x86::fma_vfmsub_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubpd128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_pd_128.html"><code>x86::avx512_mask3_vfmsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_pd_256.html"><code>x86::fma_vfmsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubpd256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_pd_256.html"><code>x86::avx512_mask3_vfmsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubpd512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_pd_512.html"><code>x86::avx512_mask3_vfmsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_ps.html"><code>x86::fma_vfmsub_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubps128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_ps_128.html"><code>x86::avx512_mask3_vfmsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_ps_256.html"><code>x86::fma_vfmsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubps256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_ps_256.html"><code>x86::avx512_mask3_vfmsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubps512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfmsub_ps_512.html"><code>x86::avx512_mask3_vfmsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubsd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_sd.html"><code>x86::fma_vfmsub_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfmsubss</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfmsub_ss.html"><code>x86::fma_vfmsub_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_pd.html"><code>x86::fma_vfnmadd_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_pd_128.html"><code>x86::avx512_mask_vfnmadd_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_pd_256.html"><code>x86::fma_vfnmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_pd_256.html"><code>x86::avx512_mask_vfnmadd_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_pd_512.html"><code>x86::avx512_mask_vfnmadd_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_ps.html"><code>x86::fma_vfnmadd_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_ps_128.html"><code>x86::avx512_mask_vfnmadd_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_ps_256.html"><code>x86::fma_vfnmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_ps_256.html"><code>x86::avx512_mask_vfnmadd_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmadd_ps_512.html"><code>x86::avx512_mask_vfnmadd_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddsd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_sd.html"><code>x86::fma_vfnmadd_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmaddss</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmadd_ss.html"><code>x86::fma_vfnmadd_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_pd.html"><code>x86::fma_vfnmsub_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_pd_128.html"><code>x86::avx512_mask_vfnmsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_pd_128.html"><code>x86::avx512_mask3_vfnmsub_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_pd_256.html"><code>x86::fma_vfnmsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_pd_256.html"><code>x86::avx512_mask_vfnmsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_pd_256.html"><code>x86::avx512_mask3_vfnmsub_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_pd_512.html"><code>x86::avx512_mask_vfnmsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubpd512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_pd_512.html"><code>x86::avx512_mask3_vfnmsub_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_ps.html"><code>x86::fma_vfnmsub_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_ps_128.html"><code>x86::avx512_mask_vfnmsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps128_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_ps_128.html"><code>x86::avx512_mask3_vfnmsub_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps256</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_ps_256.html"><code>x86::fma_vfnmsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_ps_256.html"><code>x86::avx512_mask_vfnmsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps256_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_ps_256.html"><code>x86::avx512_mask3_vfnmsub_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vfnmsub_ps_512.html"><code>x86::avx512_mask_vfnmsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubps512_mask3</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask3_vfnmsub_ps_512.html"><code>x86::avx512_mask3_vfnmsub_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubsd</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_sd.html"><code>x86::fma_vfnmsub_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfnmsubss</code></strong></dt>
/// <dd><a href="../x86/fn.fma_vfnmsub_ss.html"><code>x86::fma_vfnmsub_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczpd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_pd.html"><code>x86::xop_vfrcz_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczpd256</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_pd_256.html"><code>x86::xop_vfrcz_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczps</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_ps.html"><code>x86::xop_vfrcz_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczps256</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_ps_256.html"><code>x86::xop_vfrcz_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczsd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_sd.html"><code>x86::xop_vfrcz_sd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vfrczss</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vfrcz_ss.html"><code>x86::xop_vfrcz_ss</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcmov</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcmov.html"><code>x86::xop_vpcmov</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcmov_256</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcmov_256.html"><code>x86::xop_vpcmov_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomb</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomb.html"><code>x86::xop_vpcomb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomd.html"><code>x86::xop_vpcomd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomq.html"><code>x86::xop_vpcomq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomub</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomub.html"><code>x86::xop_vpcomub</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomud</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomud.html"><code>x86::xop_vpcomud</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomuq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomuq.html"><code>x86::xop_vpcomuq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomuw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomuw.html"><code>x86::xop_vpcomuw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpcomw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpcomw.html"><code>x86::xop_vpcomw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictdi_128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_q_128.html"><code>x86::avx512_mask_conflict_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictdi_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_q_256.html"><code>x86::avx512_mask_conflict_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictdi_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_q_512.html"><code>x86::avx512_mask_conflict_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictsi_128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_d_128.html"><code>x86::avx512_mask_conflict_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictsi_256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_d_256.html"><code>x86::avx512_mask_conflict_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpconflictsi_512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_conflict_d_512.html"><code>x86::avx512_mask_conflict_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vperm2f128_pd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vperm2f128_pd_256.html"><code>x86::avx_vperm2f128_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vperm2f128_ps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vperm2f128_ps_256.html"><code>x86::avx_vperm2f128_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vperm2f128_si256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vperm2f128_si_256.html"><code>x86::avx_vperm2f128_si_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2vard128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_d_128.html"><code>x86::avx512_mask_vpermi2var_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2vard256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_d_256.html"><code>x86::avx512_mask_vpermi2var_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2vard512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_d_512.html"><code>x86::avx512_mask_vpermi2var_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varhi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_hi_128.html"><code>x86::avx512_mask_vpermi2var_hi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varhi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_hi_256.html"><code>x86::avx512_mask_vpermi2var_hi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varhi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_hi_512.html"><code>x86::avx512_mask_vpermi2var_hi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_pd_128.html"><code>x86::avx512_mask_vpermi2var_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_pd_256.html"><code>x86::avx512_mask_vpermi2var_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_pd_512.html"><code>x86::avx512_mask_vpermi2var_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_ps_128.html"><code>x86::avx512_mask_vpermi2var_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_ps_256.html"><code>x86::avx512_mask_vpermi2var_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_ps_512.html"><code>x86::avx512_mask_vpermi2var_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_q_128.html"><code>x86::avx512_mask_vpermi2var_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_q_256.html"><code>x86::avx512_mask_vpermi2var_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_q_512.html"><code>x86::avx512_mask_vpermi2var_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_qi_128.html"><code>x86::avx512_mask_vpermi2var_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_qi_256.html"><code>x86::avx512_mask_vpermi2var_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermi2varqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermi2var_qi_512.html"><code>x86::avx512_mask_vpermi2var_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermil2pd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpermil2pd.html"><code>x86::xop_vpermil2pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermil2pd256</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpermil2pd_256.html"><code>x86::xop_vpermil2pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermil2ps</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpermil2ps.html"><code>x86::xop_vpermil2ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermil2ps256</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpermil2ps_256.html"><code>x86::xop_vpermil2ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vpermilvar_pd.html"><code>x86::avx_vpermilvar_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vpermilvar_pd_256.html"><code>x86::avx_vpermilvar_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_pd_256.html"><code>x86::avx512_mask_vpermilvar_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_pd_512.html"><code>x86::avx512_mask_vpermilvar_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarpd_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_pd_128.html"><code>x86::avx512_mask_vpermilvar_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vpermilvar_ps.html"><code>x86::avx_vpermilvar_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vpermilvar_ps_256.html"><code>x86::avx_vpermilvar_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_ps_256.html"><code>x86::avx512_mask_vpermilvar_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_ps_512.html"><code>x86::avx512_mask_vpermilvar_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermilvarps_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermilvar_ps_128.html"><code>x86::avx512_mask_vpermilvar_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_d_128.html"><code>x86::avx512_mask_vpermt2var_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_d_128.html"><code>x86::avx512_maskz_vpermt2var_d_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_d_256.html"><code>x86::avx512_mask_vpermt2var_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_d_256.html"><code>x86::avx512_maskz_vpermt2var_d_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_d_512.html"><code>x86::avx512_mask_vpermt2var_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2vard512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_d_512.html"><code>x86::avx512_maskz_vpermt2var_d_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_hi_128.html"><code>x86::avx512_mask_vpermt2var_hi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_hi_128.html"><code>x86::avx512_maskz_vpermt2var_hi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_hi_256.html"><code>x86::avx512_mask_vpermt2var_hi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_hi_256.html"><code>x86::avx512_maskz_vpermt2var_hi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_hi_512.html"><code>x86::avx512_mask_vpermt2var_hi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varhi512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_hi_512.html"><code>x86::avx512_maskz_vpermt2var_hi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_pd_128.html"><code>x86::avx512_mask_vpermt2var_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_pd_128.html"><code>x86::avx512_maskz_vpermt2var_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_pd_256.html"><code>x86::avx512_mask_vpermt2var_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_pd_256.html"><code>x86::avx512_maskz_vpermt2var_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_pd_512.html"><code>x86::avx512_mask_vpermt2var_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varpd512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_pd_512.html"><code>x86::avx512_maskz_vpermt2var_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_ps_128.html"><code>x86::avx512_mask_vpermt2var_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_ps_128.html"><code>x86::avx512_maskz_vpermt2var_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_ps_256.html"><code>x86::avx512_mask_vpermt2var_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_ps_256.html"><code>x86::avx512_maskz_vpermt2var_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_ps_512.html"><code>x86::avx512_mask_vpermt2var_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varps512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_ps_512.html"><code>x86::avx512_maskz_vpermt2var_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_q_128.html"><code>x86::avx512_mask_vpermt2var_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_q_128.html"><code>x86::avx512_maskz_vpermt2var_q_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_q_256.html"><code>x86::avx512_mask_vpermt2var_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_q_256.html"><code>x86::avx512_maskz_vpermt2var_q_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_q_512.html"><code>x86::avx512_mask_vpermt2var_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varq512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_q_512.html"><code>x86::avx512_maskz_vpermt2var_q_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_qi_128.html"><code>x86::avx512_mask_vpermt2var_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_qi_128.html"><code>x86::avx512_maskz_vpermt2var_qi_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_qi_256.html"><code>x86::avx512_mask_vpermt2var_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_qi_256.html"><code>x86::avx512_maskz_vpermt2var_qi_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpermt2var_qi_512.html"><code>x86::avx512_mask_vpermt2var_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpermt2varqi512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpermt2var_qi_512.html"><code>x86::avx512_maskz_vpermt2var_qi_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddbd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddbd.html"><code>x86::xop_vphaddbd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddbq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddbq.html"><code>x86::xop_vphaddbq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddbw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddbw.html"><code>x86::xop_vphaddbw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphadddq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphadddq.html"><code>x86::xop_vphadddq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddubd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddubd.html"><code>x86::xop_vphaddubd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddubq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddubq.html"><code>x86::xop_vphaddubq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddubw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddubw.html"><code>x86::xop_vphaddubw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddudq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddudq.html"><code>x86::xop_vphaddudq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphadduwd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphadduwd.html"><code>x86::xop_vphadduwd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphadduwq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphadduwq.html"><code>x86::xop_vphadduwq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddwd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddwd.html"><code>x86::xop_vphaddwd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphaddwq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphaddwq.html"><code>x86::xop_vphaddwq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphsubbw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphsubbw.html"><code>x86::xop_vphsubbw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphsubdq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphsubdq.html"><code>x86::xop_vphsubdq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vphsubwd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vphsubwd.html"><code>x86::xop_vphsubwd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacsdd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacsdd.html"><code>x86::xop_vpmacsdd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacsdqh</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacsdqh.html"><code>x86::xop_vpmacsdqh</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacsdql</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacsdql.html"><code>x86::xop_vpmacsdql</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacssdd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacssdd.html"><code>x86::xop_vpmacssdd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacssdqh</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacssdqh.html"><code>x86::xop_vpmacssdqh</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacssdql</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacssdql.html"><code>x86::xop_vpmacssdql</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacsswd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacsswd.html"><code>x86::xop_vpmacsswd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacssww</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacssww.html"><code>x86::xop_vpmacssww</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacswd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacswd.html"><code>x86::xop_vpmacswd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmacsww</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmacsww.html"><code>x86::xop_vpmacsww</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadcsswd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmadcsswd.html"><code>x86::xop_vpmadcsswd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadcswd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpmadcswd.html"><code>x86::xop_vpmadcswd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52h_uq_128.html"><code>x86::avx512_mask_vpmadd52h_uq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52h_uq_128.html"><code>x86::avx512_maskz_vpmadd52h_uq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52h_uq_256.html"><code>x86::avx512_mask_vpmadd52h_uq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52h_uq_256.html"><code>x86::avx512_maskz_vpmadd52h_uq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52h_uq_512.html"><code>x86::avx512_mask_vpmadd52h_uq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52huq512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52h_uq_512.html"><code>x86::avx512_maskz_vpmadd52h_uq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52l_uq_128.html"><code>x86::avx512_mask_vpmadd52l_uq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq128_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52l_uq_128.html"><code>x86::avx512_maskz_vpmadd52l_uq_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52l_uq_256.html"><code>x86::avx512_mask_vpmadd52l_uq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq256_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52l_uq_256.html"><code>x86::avx512_maskz_vpmadd52l_uq_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_vpmadd52l_uq_512.html"><code>x86::avx512_mask_vpmadd52l_uq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmadd52luq512_maskz</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_maskz_vpmadd52l_uq_512.html"><code>x86::avx512_maskz_vpmadd52l_uq_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmultishiftqb128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmultishift_qb_128.html"><code>x86::avx512_mask_pmultishift_qb_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmultishiftqb256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmultishift_qb_256.html"><code>x86::avx512_mask_pmultishift_qb_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpmultishiftqb512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_pmultishift_qb_512.html"><code>x86::avx512_mask_pmultishift_qb_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpperm</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpperm.html"><code>x86::xop_vpperm</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotb</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotb.html"><code>x86::xop_vprotb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotbi</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotbi.html"><code>x86::xop_vprotbi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotd</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotd.html"><code>x86::xop_vprotd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotdi</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotdi.html"><code>x86::xop_vprotdi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotq.html"><code>x86::xop_vprotq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotqi</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotqi.html"><code>x86::xop_vprotqi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotw.html"><code>x86::xop_vprotw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vprotwi</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vprotwi.html"><code>x86::xop_vprotwi</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshab</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshab.html"><code>x86::xop_vpshab</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshad</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshad.html"><code>x86::xop_vpshad</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshaq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshaq.html"><code>x86::xop_vpshaq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshaw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshaw.html"><code>x86::xop_vpshaw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshlb</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshlb.html"><code>x86::xop_vpshlb</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshld</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshld.html"><code>x86::xop_vpshld</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshlq</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshlq.html"><code>x86::xop_vpshlq</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vpshlw</code></strong></dt>
/// <dd><a href="../x86/fn.xop_vpshlw.html"><code>x86::xop_vpshlw</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestcpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestc_pd.html"><code>x86::avx_vtestc_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestcpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestc_pd_256.html"><code>x86::avx_vtestc_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestcps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestc_ps.html"><code>x86::avx_vtestc_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestcps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestc_ps_256.html"><code>x86::avx_vtestc_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestnzcpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestnzc_pd.html"><code>x86::avx_vtestnzc_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestnzcpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestnzc_pd_256.html"><code>x86::avx_vtestnzc_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestnzcps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestnzc_ps.html"><code>x86::avx_vtestnzc_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestnzcps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestnzc_ps_256.html"><code>x86::avx_vtestnzc_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestzpd</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestz_pd.html"><code>x86::avx_vtestz_pd</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestzpd256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestz_pd_256.html"><code>x86::avx_vtestz_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestzps</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestz_ps.html"><code>x86::avx_vtestz_ps</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vtestzps256</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vtestz_ps_256.html"><code>x86::avx_vtestz_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vzeroall</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vzeroall.html"><code>x86::avx_vzeroall</code></a></dd>
/// <dt><strong><code>__builtin_ia32_vzeroupper</code></strong></dt>
/// <dd><a href="../x86/fn.avx_vzeroupper.html"><code>x86::avx_vzeroupper</code></a></dd>
/// <dt><strong><code>__builtin_ia32_wrfsbase32</code></strong></dt>
/// <dd><a href="../x86/fn.wrfsbase_32.html"><code>x86::wrfsbase_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_wrfsbase64</code></strong></dt>
/// <dd><a href="../x86/fn.wrfsbase_64.html"><code>x86::wrfsbase_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_wrgsbase32</code></strong></dt>
/// <dd><a href="../x86/fn.wrgsbase_32.html"><code>x86::wrgsbase_32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_wrgsbase64</code></strong></dt>
/// <dd><a href="../x86/fn.wrgsbase_64.html"><code>x86::wrgsbase_64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_writeeflags_u32</code></strong></dt>
/// <dd><a href="../x86/fn.flags_write_u32.html"><code>x86::flags_write_u32</code></a></dd>
/// <dt><strong><code>__builtin_ia32_writeeflags_u64</code></strong></dt>
/// <dd><a href="../x86/fn.flags_write_u64.html"><code>x86::flags_write_u64</code></a></dd>
/// <dt><strong><code>__builtin_ia32_wrpkru</code></strong></dt>
/// <dd><a href="../x86/fn.wrpkru.html"><code>x86::wrpkru</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xabort</code></strong></dt>
/// <dd><a href="../x86/fn.xabort.html"><code>x86::xabort</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xbegin</code></strong></dt>
/// <dd><a href="../x86/fn.xbegin.html"><code>x86::xbegin</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xend</code></strong></dt>
/// <dd><a href="../x86/fn.xend.html"><code>x86::xend</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorpd128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_pd_128.html"><code>x86::avx512_mask_xor_pd_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorpd256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_pd_256.html"><code>x86::avx512_mask_xor_pd_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorpd512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_pd_512.html"><code>x86::avx512_mask_xor_pd_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorps128_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_ps_128.html"><code>x86::avx512_mask_xor_ps_128</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorps256_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_ps_256.html"><code>x86::avx512_mask_xor_ps_256</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xorps512_mask</code></strong></dt>
/// <dd><a href="../x86/fn.avx512_mask_xor_ps_512.html"><code>x86::avx512_mask_xor_ps_512</code></a></dd>
/// <dt><strong><code>__builtin_ia32_xtest</code></strong></dt>
/// <dd><a href="../x86/fn.xtest.html"><code>x86::xtest</code></a></dd>
/// <dt><strong><code>__builtin_init_trampoline</code></strong></dt>
/// <dd><a href="../fn.init_trampoline.html"><code>init_trampoline</code></a></dd>
/// <dt><strong><code>__builtin_mips_addsc</code></strong></dt>
/// <dd><a href="../mips/fn.addsc.html"><code>mips::addsc</code></a></dd>
/// <dt><strong><code>__builtin_mips_addu_ph</code></strong></dt>
/// <dd><a href="../mips/fn.addu_ph.html"><code>mips::addu_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_addu_qb</code></strong></dt>
/// <dd><a href="../mips/fn.addu_qb.html"><code>mips::addu_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_addu_s_ph</code></strong></dt>
/// <dd><a href="../mips/fn.addu_s_ph.html"><code>mips::addu_s_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_addu_s_qb</code></strong></dt>
/// <dd><a href="../mips/fn.addu_s_qb.html"><code>mips::addu_s_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_adduh_qb</code></strong></dt>
/// <dd><a href="../mips/fn.adduh_qb.html"><code>mips::adduh_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_adduh_r_qb</code></strong></dt>
/// <dd><a href="../mips/fn.adduh_r_qb.html"><code>mips::adduh_r_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_addwc</code></strong></dt>
/// <dd><a href="../mips/fn.addwc.html"><code>mips::addwc</code></a></dd>
/// <dt><strong><code>__builtin_mips_append</code></strong></dt>
/// <dd><a href="../mips/fn.append.html"><code>mips::append</code></a></dd>
/// <dt><strong><code>__builtin_mips_balign</code></strong></dt>
/// <dd><a href="../mips/fn.balign.html"><code>mips::balign</code></a></dd>
/// <dt><strong><code>__builtin_mips_bitrev</code></strong></dt>
/// <dd><a href="../mips/fn.bitrev.html"><code>mips::bitrev</code></a></dd>
/// <dt><strong><code>__builtin_mips_bposge32</code></strong></dt>
/// <dd><a href="../mips/fn.bposge32.html"><code>mips::bposge32</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgdu_eq_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgdu_eq_qb.html"><code>mips::cmpgdu_eq_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgdu_le_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgdu_le_qb.html"><code>mips::cmpgdu_le_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgdu_lt_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgdu_lt_qb.html"><code>mips::cmpgdu_lt_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgu_eq_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgu_eq_qb.html"><code>mips::cmpgu_eq_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgu_le_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgu_le_qb.html"><code>mips::cmpgu_le_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpgu_lt_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpgu_lt_qb.html"><code>mips::cmpgu_lt_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpu_eq_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpu_eq_qb.html"><code>mips::cmpu_eq_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpu_le_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpu_le_qb.html"><code>mips::cmpu_le_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_cmpu_lt_qb</code></strong></dt>
/// <dd><a href="../mips/fn.cmpu_lt_qb.html"><code>mips::cmpu_lt_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_dlsa</code></strong></dt>
/// <dd><a href="../mips/fn.dlsa.html"><code>mips::dlsa</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpa_w_ph</code></strong></dt>
/// <dd><a href="../mips/fn.dpa_w_ph.html"><code>mips::dpa_w_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpau_h_qbl</code></strong></dt>
/// <dd><a href="../mips/fn.dpau_h_qbl.html"><code>mips::dpau_h_qbl</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpau_h_qbr</code></strong></dt>
/// <dd><a href="../mips/fn.dpau_h_qbr.html"><code>mips::dpau_h_qbr</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpax_w_ph</code></strong></dt>
/// <dd><a href="../mips/fn.dpax_w_ph.html"><code>mips::dpax_w_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_dps_w_ph</code></strong></dt>
/// <dd><a href="../mips/fn.dps_w_ph.html"><code>mips::dps_w_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpsu_h_qbl</code></strong></dt>
/// <dd><a href="../mips/fn.dpsu_h_qbl.html"><code>mips::dpsu_h_qbl</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpsu_h_qbr</code></strong></dt>
/// <dd><a href="../mips/fn.dpsu_h_qbr.html"><code>mips::dpsu_h_qbr</code></a></dd>
/// <dt><strong><code>__builtin_mips_dpsx_w_ph</code></strong></dt>
/// <dd><a href="../mips/fn.dpsx_w_ph.html"><code>mips::dpsx_w_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_extp</code></strong></dt>
/// <dd><a href="../mips/fn.extp.html"><code>mips::extp</code></a></dd>
/// <dt><strong><code>__builtin_mips_extpdp</code></strong></dt>
/// <dd><a href="../mips/fn.extpdp.html"><code>mips::extpdp</code></a></dd>
/// <dt><strong><code>__builtin_mips_extr_r_w</code></strong></dt>
/// <dd><a href="../mips/fn.extr_r_w.html"><code>mips::extr_r_w</code></a></dd>
/// <dt><strong><code>__builtin_mips_extr_rs_w</code></strong></dt>
/// <dd><a href="../mips/fn.extr_rs_w.html"><code>mips::extr_rs_w</code></a></dd>
/// <dt><strong><code>__builtin_mips_extr_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.extr_s_h.html"><code>mips::extr_s_h</code></a></dd>
/// <dt><strong><code>__builtin_mips_extr_w</code></strong></dt>
/// <dd><a href="../mips/fn.extr_w.html"><code>mips::extr_w</code></a></dd>
/// <dt><strong><code>__builtin_mips_insv</code></strong></dt>
/// <dd><a href="../mips/fn.insv.html"><code>mips::insv</code></a></dd>
/// <dt><strong><code>__builtin_mips_lbux</code></strong></dt>
/// <dd><a href="../mips/fn.lbux.html"><code>mips::lbux</code></a></dd>
/// <dt><strong><code>__builtin_mips_lhx</code></strong></dt>
/// <dd><a href="../mips/fn.lhx.html"><code>mips::lhx</code></a></dd>
/// <dt><strong><code>__builtin_mips_lsa</code></strong></dt>
/// <dd><a href="../mips/fn.lsa.html"><code>mips::lsa</code></a></dd>
/// <dt><strong><code>__builtin_mips_lwx</code></strong></dt>
/// <dd><a href="../mips/fn.lwx.html"><code>mips::lwx</code></a></dd>
/// <dt><strong><code>__builtin_mips_madd</code></strong></dt>
/// <dd><a href="../mips/fn.madd.html"><code>mips::madd</code></a></dd>
/// <dt><strong><code>__builtin_mips_maddu</code></strong></dt>
/// <dd><a href="../mips/fn.maddu.html"><code>mips::maddu</code></a></dd>
/// <dt><strong><code>__builtin_mips_modsub</code></strong></dt>
/// <dd><a href="../mips/fn.modsub.html"><code>mips::modsub</code></a></dd>
/// <dt><strong><code>__builtin_mips_msub</code></strong></dt>
/// <dd><a href="../mips/fn.msub.html"><code>mips::msub</code></a></dd>
/// <dt><strong><code>__builtin_mips_msubu</code></strong></dt>
/// <dd><a href="../mips/fn.msubu.html"><code>mips::msubu</code></a></dd>
/// <dt><strong><code>__builtin_mips_mthlip</code></strong></dt>
/// <dd><a href="../mips/fn.mthlip.html"><code>mips::mthlip</code></a></dd>
/// <dt><strong><code>__builtin_mips_mul_ph</code></strong></dt>
/// <dd><a href="../mips/fn.mul_ph.html"><code>mips::mul_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_mul_s_ph</code></strong></dt>
/// <dd><a href="../mips/fn.mul_s_ph.html"><code>mips::mul_s_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_mulsa_w_ph</code></strong></dt>
/// <dd><a href="../mips/fn.mulsa_w_ph.html"><code>mips::mulsa_w_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_mult</code></strong></dt>
/// <dd><a href="../mips/fn.mult.html"><code>mips::mult</code></a></dd>
/// <dt><strong><code>__builtin_mips_multu</code></strong></dt>
/// <dd><a href="../mips/fn.multu.html"><code>mips::multu</code></a></dd>
/// <dt><strong><code>__builtin_mips_pick_qb</code></strong></dt>
/// <dd><a href="../mips/fn.pick_qb.html"><code>mips::pick_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_precr_qb_ph</code></strong></dt>
/// <dd><a href="../mips/fn.precr_qb_ph.html"><code>mips::precr_qb_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_precr_sra_ph_w</code></strong></dt>
/// <dd><a href="../mips/fn.precr_sra_ph_w.html"><code>mips::precr_sra_ph_w</code></a></dd>
/// <dt><strong><code>__builtin_mips_precr_sra_r_ph_w</code></strong></dt>
/// <dd><a href="../mips/fn.precr_sra_r_ph_w.html"><code>mips::precr_sra_r_ph_w</code></a></dd>
/// <dt><strong><code>__builtin_mips_prepend</code></strong></dt>
/// <dd><a href="../mips/fn.prepend.html"><code>mips::prepend</code></a></dd>
/// <dt><strong><code>__builtin_mips_raddu_w_qb</code></strong></dt>
/// <dd><a href="../mips/fn.raddu_w_qb.html"><code>mips::raddu_w_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_rddsp</code></strong></dt>
/// <dd><a href="../mips/fn.rddsp.html"><code>mips::rddsp</code></a></dd>
/// <dt><strong><code>__builtin_mips_repl_qb</code></strong></dt>
/// <dd><a href="../mips/fn.repl_qb.html"><code>mips::repl_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_shilo</code></strong></dt>
/// <dd><a href="../mips/fn.shilo.html"><code>mips::shilo</code></a></dd>
/// <dt><strong><code>__builtin_mips_shll_qb</code></strong></dt>
/// <dd><a href="../mips/fn.shll_qb.html"><code>mips::shll_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_shra_qb</code></strong></dt>
/// <dd><a href="../mips/fn.shra_qb.html"><code>mips::shra_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_shra_r_qb</code></strong></dt>
/// <dd><a href="../mips/fn.shra_r_qb.html"><code>mips::shra_r_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_shrl_ph</code></strong></dt>
/// <dd><a href="../mips/fn.shrl_ph.html"><code>mips::shrl_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_shrl_qb</code></strong></dt>
/// <dd><a href="../mips/fn.shrl_qb.html"><code>mips::shrl_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_subu_ph</code></strong></dt>
/// <dd><a href="../mips/fn.subu_ph.html"><code>mips::subu_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_subu_qb</code></strong></dt>
/// <dd><a href="../mips/fn.subu_qb.html"><code>mips::subu_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_subu_s_ph</code></strong></dt>
/// <dd><a href="../mips/fn.subu_s_ph.html"><code>mips::subu_s_ph</code></a></dd>
/// <dt><strong><code>__builtin_mips_subu_s_qb</code></strong></dt>
/// <dd><a href="../mips/fn.subu_s_qb.html"><code>mips::subu_s_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_subuh_qb</code></strong></dt>
/// <dd><a href="../mips/fn.subuh_qb.html"><code>mips::subuh_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_subuh_r_qb</code></strong></dt>
/// <dd><a href="../mips/fn.subuh_r_qb.html"><code>mips::subuh_r_qb</code></a></dd>
/// <dt><strong><code>__builtin_mips_wrdsp</code></strong></dt>
/// <dd><a href="../mips/fn.wrdsp.html"><code>mips::wrdsp</code></a></dd>
/// <dt><strong><code>__builtin_msa_add_a_b</code></strong></dt>
/// <dd><a href="../mips/fn.add_a_b.html"><code>mips::add_a_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_add_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.add_a_d.html"><code>mips::add_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_add_a_h</code></strong></dt>
/// <dd><a href="../mips/fn.add_a_h.html"><code>mips::add_a_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_add_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.add_a_w.html"><code>mips::add_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_a_b</code></strong></dt>
/// <dd><a href="../mips/fn.adds_a_b.html"><code>mips::adds_a_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.adds_a_d.html"><code>mips::adds_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_a_h</code></strong></dt>
/// <dd><a href="../mips/fn.adds_a_h.html"><code>mips::adds_a_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.adds_a_w.html"><code>mips::adds_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.adds_s_b.html"><code>mips::adds_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.adds_s_d.html"><code>mips::adds_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.adds_s_h.html"><code>mips::adds_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.adds_s_w.html"><code>mips::adds_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.adds_u_b.html"><code>mips::adds_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.adds_u_d.html"><code>mips::adds_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.adds_u_h.html"><code>mips::adds_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_adds_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.adds_u_w.html"><code>mips::adds_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_addv_b</code></strong></dt>
/// <dd><a href="../mips/fn.addv_b.html"><code>mips::addv_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_addv_d</code></strong></dt>
/// <dd><a href="../mips/fn.addv_d.html"><code>mips::addv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_addv_h</code></strong></dt>
/// <dd><a href="../mips/fn.addv_h.html"><code>mips::addv_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_addv_w</code></strong></dt>
/// <dd><a href="../mips/fn.addv_w.html"><code>mips::addv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_addvi_b</code></strong></dt>
/// <dd><a href="../mips/fn.addvi_b.html"><code>mips::addvi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_addvi_d</code></strong></dt>
/// <dd><a href="../mips/fn.addvi_d.html"><code>mips::addvi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_addvi_h</code></strong></dt>
/// <dd><a href="../mips/fn.addvi_h.html"><code>mips::addvi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_addvi_w</code></strong></dt>
/// <dd><a href="../mips/fn.addvi_w.html"><code>mips::addvi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_and_v</code></strong></dt>
/// <dd><a href="../mips/fn.and_v.html"><code>mips::and_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_andi_b</code></strong></dt>
/// <dd><a href="../mips/fn.andi_b.html"><code>mips::andi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.asub_s_b.html"><code>mips::asub_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.asub_s_d.html"><code>mips::asub_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.asub_s_h.html"><code>mips::asub_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.asub_s_w.html"><code>mips::asub_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.asub_u_b.html"><code>mips::asub_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.asub_u_d.html"><code>mips::asub_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.asub_u_h.html"><code>mips::asub_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_asub_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.asub_u_w.html"><code>mips::asub_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.ave_s_b.html"><code>mips::ave_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.ave_s_d.html"><code>mips::ave_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.ave_s_h.html"><code>mips::ave_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.ave_s_w.html"><code>mips::ave_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.ave_u_b.html"><code>mips::ave_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.ave_u_d.html"><code>mips::ave_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.ave_u_h.html"><code>mips::ave_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ave_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.ave_u_w.html"><code>mips::ave_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.aver_s_b.html"><code>mips::aver_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.aver_s_d.html"><code>mips::aver_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.aver_s_h.html"><code>mips::aver_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.aver_s_w.html"><code>mips::aver_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.aver_u_b.html"><code>mips::aver_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.aver_u_d.html"><code>mips::aver_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.aver_u_h.html"><code>mips::aver_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_aver_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.aver_u_w.html"><code>mips::aver_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclr_b</code></strong></dt>
/// <dd><a href="../mips/fn.bclr_b.html"><code>mips::bclr_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclr_d</code></strong></dt>
/// <dd><a href="../mips/fn.bclr_d.html"><code>mips::bclr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclr_h</code></strong></dt>
/// <dd><a href="../mips/fn.bclr_h.html"><code>mips::bclr_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclr_w</code></strong></dt>
/// <dd><a href="../mips/fn.bclr_w.html"><code>mips::bclr_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclri_b</code></strong></dt>
/// <dd><a href="../mips/fn.bclri_b.html"><code>mips::bclri_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclri_d</code></strong></dt>
/// <dd><a href="../mips/fn.bclri_d.html"><code>mips::bclri_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclri_h</code></strong></dt>
/// <dd><a href="../mips/fn.bclri_h.html"><code>mips::bclri_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bclri_w</code></strong></dt>
/// <dd><a href="../mips/fn.bclri_w.html"><code>mips::bclri_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsl_b</code></strong></dt>
/// <dd><a href="../mips/fn.binsl_b.html"><code>mips::binsl_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsl_d</code></strong></dt>
/// <dd><a href="../mips/fn.binsl_d.html"><code>mips::binsl_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsl_h</code></strong></dt>
/// <dd><a href="../mips/fn.binsl_h.html"><code>mips::binsl_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsl_w</code></strong></dt>
/// <dd><a href="../mips/fn.binsl_w.html"><code>mips::binsl_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsli_b</code></strong></dt>
/// <dd><a href="../mips/fn.binsli_b.html"><code>mips::binsli_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsli_d</code></strong></dt>
/// <dd><a href="../mips/fn.binsli_d.html"><code>mips::binsli_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsli_h</code></strong></dt>
/// <dd><a href="../mips/fn.binsli_h.html"><code>mips::binsli_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsli_w</code></strong></dt>
/// <dd><a href="../mips/fn.binsli_w.html"><code>mips::binsli_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsr_b</code></strong></dt>
/// <dd><a href="../mips/fn.binsr_b.html"><code>mips::binsr_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsr_d</code></strong></dt>
/// <dd><a href="../mips/fn.binsr_d.html"><code>mips::binsr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsr_h</code></strong></dt>
/// <dd><a href="../mips/fn.binsr_h.html"><code>mips::binsr_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsr_w</code></strong></dt>
/// <dd><a href="../mips/fn.binsr_w.html"><code>mips::binsr_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsri_b</code></strong></dt>
/// <dd><a href="../mips/fn.binsri_b.html"><code>mips::binsri_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsri_d</code></strong></dt>
/// <dd><a href="../mips/fn.binsri_d.html"><code>mips::binsri_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsri_h</code></strong></dt>
/// <dd><a href="../mips/fn.binsri_h.html"><code>mips::binsri_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_binsri_w</code></strong></dt>
/// <dd><a href="../mips/fn.binsri_w.html"><code>mips::binsri_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bmnz_v</code></strong></dt>
/// <dd><a href="../mips/fn.bmnz_v.html"><code>mips::bmnz_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_bmnzi_b</code></strong></dt>
/// <dd><a href="../mips/fn.bmnzi_b.html"><code>mips::bmnzi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bmz_v</code></strong></dt>
/// <dd><a href="../mips/fn.bmz_v.html"><code>mips::bmz_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_bmzi_b</code></strong></dt>
/// <dd><a href="../mips/fn.bmzi_b.html"><code>mips::bmzi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bneg_b</code></strong></dt>
/// <dd><a href="../mips/fn.bneg_b.html"><code>mips::bneg_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bneg_d</code></strong></dt>
/// <dd><a href="../mips/fn.bneg_d.html"><code>mips::bneg_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bneg_h</code></strong></dt>
/// <dd><a href="../mips/fn.bneg_h.html"><code>mips::bneg_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bneg_w</code></strong></dt>
/// <dd><a href="../mips/fn.bneg_w.html"><code>mips::bneg_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnegi_b</code></strong></dt>
/// <dd><a href="../mips/fn.bnegi_b.html"><code>mips::bnegi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnegi_d</code></strong></dt>
/// <dd><a href="../mips/fn.bnegi_d.html"><code>mips::bnegi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnegi_h</code></strong></dt>
/// <dd><a href="../mips/fn.bnegi_h.html"><code>mips::bnegi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnegi_w</code></strong></dt>
/// <dd><a href="../mips/fn.bnegi_w.html"><code>mips::bnegi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnz_b</code></strong></dt>
/// <dd><a href="../mips/fn.bnz_b.html"><code>mips::bnz_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnz_d</code></strong></dt>
/// <dd><a href="../mips/fn.bnz_d.html"><code>mips::bnz_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnz_h</code></strong></dt>
/// <dd><a href="../mips/fn.bnz_h.html"><code>mips::bnz_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnz_v</code></strong></dt>
/// <dd><a href="../mips/fn.bnz_v.html"><code>mips::bnz_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_bnz_w</code></strong></dt>
/// <dd><a href="../mips/fn.bnz_w.html"><code>mips::bnz_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bsel_v</code></strong></dt>
/// <dd><a href="../mips/fn.bsel_v.html"><code>mips::bsel_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_bseli_b</code></strong></dt>
/// <dd><a href="../mips/fn.bseli_b.html"><code>mips::bseli_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bset_b</code></strong></dt>
/// <dd><a href="../mips/fn.bset_b.html"><code>mips::bset_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bset_d</code></strong></dt>
/// <dd><a href="../mips/fn.bset_d.html"><code>mips::bset_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bset_h</code></strong></dt>
/// <dd><a href="../mips/fn.bset_h.html"><code>mips::bset_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bset_w</code></strong></dt>
/// <dd><a href="../mips/fn.bset_w.html"><code>mips::bset_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bseti_b</code></strong></dt>
/// <dd><a href="../mips/fn.bseti_b.html"><code>mips::bseti_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bseti_d</code></strong></dt>
/// <dd><a href="../mips/fn.bseti_d.html"><code>mips::bseti_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bseti_h</code></strong></dt>
/// <dd><a href="../mips/fn.bseti_h.html"><code>mips::bseti_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bseti_w</code></strong></dt>
/// <dd><a href="../mips/fn.bseti_w.html"><code>mips::bseti_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_bz_b</code></strong></dt>
/// <dd><a href="../mips/fn.bz_b.html"><code>mips::bz_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_bz_d</code></strong></dt>
/// <dd><a href="../mips/fn.bz_d.html"><code>mips::bz_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_bz_h</code></strong></dt>
/// <dd><a href="../mips/fn.bz_h.html"><code>mips::bz_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_bz_v</code></strong></dt>
/// <dd><a href="../mips/fn.bz_v.html"><code>mips::bz_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_bz_w</code></strong></dt>
/// <dd><a href="../mips/fn.bz_w.html"><code>mips::bz_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceq_b</code></strong></dt>
/// <dd><a href="../mips/fn.ceq_b.html"><code>mips::ceq_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceq_d</code></strong></dt>
/// <dd><a href="../mips/fn.ceq_d.html"><code>mips::ceq_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceq_h</code></strong></dt>
/// <dd><a href="../mips/fn.ceq_h.html"><code>mips::ceq_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceq_w</code></strong></dt>
/// <dd><a href="../mips/fn.ceq_w.html"><code>mips::ceq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceqi_b</code></strong></dt>
/// <dd><a href="../mips/fn.ceqi_b.html"><code>mips::ceqi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceqi_d</code></strong></dt>
/// <dd><a href="../mips/fn.ceqi_d.html"><code>mips::ceqi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceqi_h</code></strong></dt>
/// <dd><a href="../mips/fn.ceqi_h.html"><code>mips::ceqi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ceqi_w</code></strong></dt>
/// <dd><a href="../mips/fn.ceqi_w.html"><code>mips::ceqi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_cfcmsa</code></strong></dt>
/// <dd><a href="../mips/fn.cfcmsa.html"><code>mips::cfcmsa</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.cle_s_b.html"><code>mips::cle_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.cle_s_d.html"><code>mips::cle_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.cle_s_h.html"><code>mips::cle_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.cle_s_w.html"><code>mips::cle_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.cle_u_b.html"><code>mips::cle_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.cle_u_d.html"><code>mips::cle_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.cle_u_h.html"><code>mips::cle_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_cle_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.cle_u_w.html"><code>mips::cle_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.clei_s_b.html"><code>mips::clei_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.clei_s_d.html"><code>mips::clei_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.clei_s_h.html"><code>mips::clei_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.clei_s_w.html"><code>mips::clei_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.clei_u_b.html"><code>mips::clei_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.clei_u_d.html"><code>mips::clei_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.clei_u_h.html"><code>mips::clei_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clei_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.clei_u_w.html"><code>mips::clei_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.clt_s_b.html"><code>mips::clt_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.clt_s_d.html"><code>mips::clt_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.clt_s_h.html"><code>mips::clt_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.clt_s_w.html"><code>mips::clt_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.clt_u_b.html"><code>mips::clt_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.clt_u_d.html"><code>mips::clt_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.clt_u_h.html"><code>mips::clt_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clt_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.clt_u_w.html"><code>mips::clt_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.clti_s_b.html"><code>mips::clti_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.clti_s_d.html"><code>mips::clti_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.clti_s_h.html"><code>mips::clti_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.clti_s_w.html"><code>mips::clti_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.clti_u_b.html"><code>mips::clti_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.clti_u_d.html"><code>mips::clti_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.clti_u_h.html"><code>mips::clti_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_clti_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.clti_u_w.html"><code>mips::clti_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.copy_s_b.html"><code>mips::copy_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.copy_s_d.html"><code>mips::copy_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.copy_s_h.html"><code>mips::copy_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.copy_s_w.html"><code>mips::copy_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.copy_u_b.html"><code>mips::copy_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.copy_u_d.html"><code>mips::copy_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.copy_u_h.html"><code>mips::copy_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_copy_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.copy_u_w.html"><code>mips::copy_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ctcmsa</code></strong></dt>
/// <dd><a href="../mips/fn.ctcmsa.html"><code>mips::ctcmsa</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.div_s_b.html"><code>mips::div_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.div_s_d.html"><code>mips::div_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.div_s_h.html"><code>mips::div_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.div_s_w.html"><code>mips::div_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.div_u_b.html"><code>mips::div_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.div_u_d.html"><code>mips::div_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.div_u_h.html"><code>mips::div_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_div_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.div_u_w.html"><code>mips::div_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_s_d.html"><code>mips::dotp_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_s_h.html"><code>mips::dotp_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_s_w.html"><code>mips::dotp_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_u_d.html"><code>mips::dotp_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_u_h.html"><code>mips::dotp_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dotp_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.dotp_u_w.html"><code>mips::dotp_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_s_d.html"><code>mips::dpadd_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_s_h.html"><code>mips::dpadd_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_s_w.html"><code>mips::dpadd_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_u_d.html"><code>mips::dpadd_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_u_h.html"><code>mips::dpadd_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpadd_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.dpadd_u_w.html"><code>mips::dpadd_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_s_d.html"><code>mips::dpsub_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_s_h.html"><code>mips::dpsub_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_s_w.html"><code>mips::dpsub_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_u_d.html"><code>mips::dpsub_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_u_h.html"><code>mips::dpsub_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_dpsub_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.dpsub_u_w.html"><code>mips::dpsub_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fadd_d</code></strong></dt>
/// <dd><a href="../mips/fn.fadd_d.html"><code>mips::fadd_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fadd_w</code></strong></dt>
/// <dd><a href="../mips/fn.fadd_w.html"><code>mips::fadd_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcaf_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcaf_d.html"><code>mips::fcaf_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcaf_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcaf_w.html"><code>mips::fcaf_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fceq_d</code></strong></dt>
/// <dd><a href="../mips/fn.fceq_d.html"><code>mips::fceq_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fceq_w</code></strong></dt>
/// <dd><a href="../mips/fn.fceq_w.html"><code>mips::fceq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fclass_d</code></strong></dt>
/// <dd><a href="../mips/fn.fclass_d.html"><code>mips::fclass_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fclass_w</code></strong></dt>
/// <dd><a href="../mips/fn.fclass_w.html"><code>mips::fclass_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcle_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcle_d.html"><code>mips::fcle_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcle_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcle_w.html"><code>mips::fcle_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fclt_d</code></strong></dt>
/// <dd><a href="../mips/fn.fclt_d.html"><code>mips::fclt_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fclt_w</code></strong></dt>
/// <dd><a href="../mips/fn.fclt_w.html"><code>mips::fclt_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcne_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcne_d.html"><code>mips::fcne_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcne_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcne_w.html"><code>mips::fcne_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcor_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcor_d.html"><code>mips::fcor_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcor_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcor_w.html"><code>mips::fcor_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcueq_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcueq_d.html"><code>mips::fcueq_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcueq_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcueq_w.html"><code>mips::fcueq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcule_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcule_d.html"><code>mips::fcule_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcule_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcule_w.html"><code>mips::fcule_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcult_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcult_d.html"><code>mips::fcult_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcult_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcult_w.html"><code>mips::fcult_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcun_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcun_d.html"><code>mips::fcun_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcun_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcun_w.html"><code>mips::fcun_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcune_d</code></strong></dt>
/// <dd><a href="../mips/fn.fcune_d.html"><code>mips::fcune_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fcune_w</code></strong></dt>
/// <dd><a href="../mips/fn.fcune_w.html"><code>mips::fcune_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fdiv_d</code></strong></dt>
/// <dd><a href="../mips/fn.fdiv_d.html"><code>mips::fdiv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fdiv_w</code></strong></dt>
/// <dd><a href="../mips/fn.fdiv_w.html"><code>mips::fdiv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fexdo_w</code></strong></dt>
/// <dd><a href="../mips/fn.fexdo_w.html"><code>mips::fexdo_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fexp2_d</code></strong></dt>
/// <dd><a href="../mips/fn.fexp2_d.html"><code>mips::fexp2_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fexp2_w</code></strong></dt>
/// <dd><a href="../mips/fn.fexp2_w.html"><code>mips::fexp2_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fexupl_d</code></strong></dt>
/// <dd><a href="../mips/fn.fexupl_d.html"><code>mips::fexupl_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fexupr_d</code></strong></dt>
/// <dd><a href="../mips/fn.fexupr_d.html"><code>mips::fexupr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffint_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.ffint_s_d.html"><code>mips::ffint_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffint_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.ffint_s_w.html"><code>mips::ffint_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffint_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.ffint_u_d.html"><code>mips::ffint_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffint_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.ffint_u_w.html"><code>mips::ffint_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffql_d</code></strong></dt>
/// <dd><a href="../mips/fn.ffql_d.html"><code>mips::ffql_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffql_w</code></strong></dt>
/// <dd><a href="../mips/fn.ffql_w.html"><code>mips::ffql_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffqr_d</code></strong></dt>
/// <dd><a href="../mips/fn.ffqr_d.html"><code>mips::ffqr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ffqr_w</code></strong></dt>
/// <dd><a href="../mips/fn.ffqr_w.html"><code>mips::ffqr_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fill_b</code></strong></dt>
/// <dd><a href="../mips/fn.fill_b.html"><code>mips::fill_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_fill_d</code></strong></dt>
/// <dd><a href="../mips/fn.fill_d.html"><code>mips::fill_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fill_h</code></strong></dt>
/// <dd><a href="../mips/fn.fill_h.html"><code>mips::fill_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_fill_w</code></strong></dt>
/// <dd><a href="../mips/fn.fill_w.html"><code>mips::fill_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_flog2_d</code></strong></dt>
/// <dd><a href="../mips/fn.flog2_d.html"><code>mips::flog2_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_flog2_w</code></strong></dt>
/// <dd><a href="../mips/fn.flog2_w.html"><code>mips::flog2_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmadd_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmadd_d.html"><code>mips::fmadd_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmadd_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmadd_w.html"><code>mips::fmadd_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmax_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmax_a_d.html"><code>mips::fmax_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmax_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmax_a_w.html"><code>mips::fmax_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmax_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmax_d.html"><code>mips::fmax_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmax_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmax_w.html"><code>mips::fmax_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmin_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmin_a_d.html"><code>mips::fmin_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmin_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmin_a_w.html"><code>mips::fmin_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmin_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmin_d.html"><code>mips::fmin_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmin_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmin_w.html"><code>mips::fmin_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmsub_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmsub_d.html"><code>mips::fmsub_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmsub_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmsub_w.html"><code>mips::fmsub_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmul_d</code></strong></dt>
/// <dd><a href="../mips/fn.fmul_d.html"><code>mips::fmul_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fmul_w</code></strong></dt>
/// <dd><a href="../mips/fn.fmul_w.html"><code>mips::fmul_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_frcp_d</code></strong></dt>
/// <dd><a href="../mips/fn.frcp_d.html"><code>mips::frcp_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_frcp_w</code></strong></dt>
/// <dd><a href="../mips/fn.frcp_w.html"><code>mips::frcp_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_frint_d</code></strong></dt>
/// <dd><a href="../mips/fn.frint_d.html"><code>mips::frint_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_frint_w</code></strong></dt>
/// <dd><a href="../mips/fn.frint_w.html"><code>mips::frint_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_frsqrt_d</code></strong></dt>
/// <dd><a href="../mips/fn.frsqrt_d.html"><code>mips::frsqrt_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_frsqrt_w</code></strong></dt>
/// <dd><a href="../mips/fn.frsqrt_w.html"><code>mips::frsqrt_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsaf_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsaf_d.html"><code>mips::fsaf_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsaf_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsaf_w.html"><code>mips::fsaf_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fseq_d</code></strong></dt>
/// <dd><a href="../mips/fn.fseq_d.html"><code>mips::fseq_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fseq_w</code></strong></dt>
/// <dd><a href="../mips/fn.fseq_w.html"><code>mips::fseq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsle_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsle_d.html"><code>mips::fsle_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsle_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsle_w.html"><code>mips::fsle_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fslt_d</code></strong></dt>
/// <dd><a href="../mips/fn.fslt_d.html"><code>mips::fslt_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fslt_w</code></strong></dt>
/// <dd><a href="../mips/fn.fslt_w.html"><code>mips::fslt_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsne_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsne_d.html"><code>mips::fsne_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsne_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsne_w.html"><code>mips::fsne_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsor_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsor_d.html"><code>mips::fsor_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsor_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsor_w.html"><code>mips::fsor_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsqrt_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsqrt_d.html"><code>mips::fsqrt_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsqrt_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsqrt_w.html"><code>mips::fsqrt_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsub_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsub_d.html"><code>mips::fsub_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsub_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsub_w.html"><code>mips::fsub_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsueq_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsueq_d.html"><code>mips::fsueq_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsueq_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsueq_w.html"><code>mips::fsueq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsule_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsule_d.html"><code>mips::fsule_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsule_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsule_w.html"><code>mips::fsule_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsult_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsult_d.html"><code>mips::fsult_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsult_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsult_w.html"><code>mips::fsult_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsun_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsun_d.html"><code>mips::fsun_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsun_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsun_w.html"><code>mips::fsun_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsune_d</code></strong></dt>
/// <dd><a href="../mips/fn.fsune_d.html"><code>mips::fsune_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_fsune_w</code></strong></dt>
/// <dd><a href="../mips/fn.fsune_w.html"><code>mips::fsune_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftint_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.ftint_s_d.html"><code>mips::ftint_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftint_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.ftint_s_w.html"><code>mips::ftint_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftint_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.ftint_u_d.html"><code>mips::ftint_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftint_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.ftint_u_w.html"><code>mips::ftint_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftq_h</code></strong></dt>
/// <dd><a href="../mips/fn.ftq_h.html"><code>mips::ftq_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftq_w</code></strong></dt>
/// <dd><a href="../mips/fn.ftq_w.html"><code>mips::ftq_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftrunc_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.ftrunc_s_d.html"><code>mips::ftrunc_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftrunc_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.ftrunc_s_w.html"><code>mips::ftrunc_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftrunc_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.ftrunc_u_d.html"><code>mips::ftrunc_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ftrunc_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.ftrunc_u_w.html"><code>mips::ftrunc_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_s_d.html"><code>mips::hadd_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_s_h.html"><code>mips::hadd_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_s_w.html"><code>mips::hadd_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_u_d.html"><code>mips::hadd_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_u_h.html"><code>mips::hadd_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_hadd_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.hadd_u_w.html"><code>mips::hadd_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_s_d.html"><code>mips::hsub_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_s_h.html"><code>mips::hsub_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_s_w.html"><code>mips::hsub_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_u_d.html"><code>mips::hsub_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_u_h.html"><code>mips::hsub_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_hsub_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.hsub_u_w.html"><code>mips::hsub_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvev_b</code></strong></dt>
/// <dd><a href="../mips/fn.ilvev_b.html"><code>mips::ilvev_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvev_d</code></strong></dt>
/// <dd><a href="../mips/fn.ilvev_d.html"><code>mips::ilvev_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvev_h</code></strong></dt>
/// <dd><a href="../mips/fn.ilvev_h.html"><code>mips::ilvev_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvev_w</code></strong></dt>
/// <dd><a href="../mips/fn.ilvev_w.html"><code>mips::ilvev_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvl_b</code></strong></dt>
/// <dd><a href="../mips/fn.ilvl_b.html"><code>mips::ilvl_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvl_d</code></strong></dt>
/// <dd><a href="../mips/fn.ilvl_d.html"><code>mips::ilvl_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvl_h</code></strong></dt>
/// <dd><a href="../mips/fn.ilvl_h.html"><code>mips::ilvl_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvl_w</code></strong></dt>
/// <dd><a href="../mips/fn.ilvl_w.html"><code>mips::ilvl_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvod_b</code></strong></dt>
/// <dd><a href="../mips/fn.ilvod_b.html"><code>mips::ilvod_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvod_d</code></strong></dt>
/// <dd><a href="../mips/fn.ilvod_d.html"><code>mips::ilvod_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvod_h</code></strong></dt>
/// <dd><a href="../mips/fn.ilvod_h.html"><code>mips::ilvod_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvod_w</code></strong></dt>
/// <dd><a href="../mips/fn.ilvod_w.html"><code>mips::ilvod_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvr_b</code></strong></dt>
/// <dd><a href="../mips/fn.ilvr_b.html"><code>mips::ilvr_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvr_d</code></strong></dt>
/// <dd><a href="../mips/fn.ilvr_d.html"><code>mips::ilvr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvr_h</code></strong></dt>
/// <dd><a href="../mips/fn.ilvr_h.html"><code>mips::ilvr_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ilvr_w</code></strong></dt>
/// <dd><a href="../mips/fn.ilvr_w.html"><code>mips::ilvr_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_insert_b</code></strong></dt>
/// <dd><a href="../mips/fn.insert_b.html"><code>mips::insert_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_insert_d</code></strong></dt>
/// <dd><a href="../mips/fn.insert_d.html"><code>mips::insert_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_insert_h</code></strong></dt>
/// <dd><a href="../mips/fn.insert_h.html"><code>mips::insert_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_insert_w</code></strong></dt>
/// <dd><a href="../mips/fn.insert_w.html"><code>mips::insert_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_insve_b</code></strong></dt>
/// <dd><a href="../mips/fn.insve_b.html"><code>mips::insve_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_insve_d</code></strong></dt>
/// <dd><a href="../mips/fn.insve_d.html"><code>mips::insve_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_insve_h</code></strong></dt>
/// <dd><a href="../mips/fn.insve_h.html"><code>mips::insve_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_insve_w</code></strong></dt>
/// <dd><a href="../mips/fn.insve_w.html"><code>mips::insve_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ld_b</code></strong></dt>
/// <dd><a href="../mips/fn.ld_b.html"><code>mips::ld_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ld_d</code></strong></dt>
/// <dd><a href="../mips/fn.ld_d.html"><code>mips::ld_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ld_h</code></strong></dt>
/// <dd><a href="../mips/fn.ld_h.html"><code>mips::ld_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ld_w</code></strong></dt>
/// <dd><a href="../mips/fn.ld_w.html"><code>mips::ld_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_ldi_b</code></strong></dt>
/// <dd><a href="../mips/fn.ldi_b.html"><code>mips::ldi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_ldi_d</code></strong></dt>
/// <dd><a href="../mips/fn.ldi_d.html"><code>mips::ldi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_ldi_h</code></strong></dt>
/// <dd><a href="../mips/fn.ldi_h.html"><code>mips::ldi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_ldi_w</code></strong></dt>
/// <dd><a href="../mips/fn.ldi_w.html"><code>mips::ldi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_madd_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.madd_q_h.html"><code>mips::madd_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_madd_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.madd_q_w.html"><code>mips::madd_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddr_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.maddr_q_h.html"><code>mips::maddr_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddr_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.maddr_q_w.html"><code>mips::maddr_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddv_b</code></strong></dt>
/// <dd><a href="../mips/fn.maddv_b.html"><code>mips::maddv_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddv_d</code></strong></dt>
/// <dd><a href="../mips/fn.maddv_d.html"><code>mips::maddv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddv_h</code></strong></dt>
/// <dd><a href="../mips/fn.maddv_h.html"><code>mips::maddv_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_maddv_w</code></strong></dt>
/// <dd><a href="../mips/fn.maddv_w.html"><code>mips::maddv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_a_b</code></strong></dt>
/// <dd><a href="../mips/fn.max_a_b.html"><code>mips::max_a_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.max_a_d.html"><code>mips::max_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_a_h</code></strong></dt>
/// <dd><a href="../mips/fn.max_a_h.html"><code>mips::max_a_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.max_a_w.html"><code>mips::max_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.max_s_b.html"><code>mips::max_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.max_s_d.html"><code>mips::max_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.max_s_h.html"><code>mips::max_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.max_s_w.html"><code>mips::max_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.max_u_b.html"><code>mips::max_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.max_u_d.html"><code>mips::max_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.max_u_h.html"><code>mips::max_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_max_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.max_u_w.html"><code>mips::max_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_s_b.html"><code>mips::maxi_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_s_d.html"><code>mips::maxi_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_s_h.html"><code>mips::maxi_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_s_w.html"><code>mips::maxi_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_u_b.html"><code>mips::maxi_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_u_d.html"><code>mips::maxi_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_u_h.html"><code>mips::maxi_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_maxi_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.maxi_u_w.html"><code>mips::maxi_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_a_b</code></strong></dt>
/// <dd><a href="../mips/fn.min_a_b.html"><code>mips::min_a_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_a_d</code></strong></dt>
/// <dd><a href="../mips/fn.min_a_d.html"><code>mips::min_a_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_a_h</code></strong></dt>
/// <dd><a href="../mips/fn.min_a_h.html"><code>mips::min_a_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_a_w</code></strong></dt>
/// <dd><a href="../mips/fn.min_a_w.html"><code>mips::min_a_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.min_s_b.html"><code>mips::min_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.min_s_d.html"><code>mips::min_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.min_s_h.html"><code>mips::min_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.min_s_w.html"><code>mips::min_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.min_u_b.html"><code>mips::min_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.min_u_d.html"><code>mips::min_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.min_u_h.html"><code>mips::min_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_min_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.min_u_w.html"><code>mips::min_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.mini_s_b.html"><code>mips::mini_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.mini_s_d.html"><code>mips::mini_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.mini_s_h.html"><code>mips::mini_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.mini_s_w.html"><code>mips::mini_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.mini_u_b.html"><code>mips::mini_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.mini_u_d.html"><code>mips::mini_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.mini_u_h.html"><code>mips::mini_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mini_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.mini_u_w.html"><code>mips::mini_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.mod_s_b.html"><code>mips::mod_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.mod_s_d.html"><code>mips::mod_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.mod_s_h.html"><code>mips::mod_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.mod_s_w.html"><code>mips::mod_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.mod_u_b.html"><code>mips::mod_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.mod_u_d.html"><code>mips::mod_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.mod_u_h.html"><code>mips::mod_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mod_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.mod_u_w.html"><code>mips::mod_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_move_v</code></strong></dt>
/// <dd><a href="../mips/fn.move_v.html"><code>mips::move_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_msub_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.msub_q_h.html"><code>mips::msub_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_msub_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.msub_q_w.html"><code>mips::msub_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubr_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.msubr_q_h.html"><code>mips::msubr_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubr_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.msubr_q_w.html"><code>mips::msubr_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubv_b</code></strong></dt>
/// <dd><a href="../mips/fn.msubv_b.html"><code>mips::msubv_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubv_d</code></strong></dt>
/// <dd><a href="../mips/fn.msubv_d.html"><code>mips::msubv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubv_h</code></strong></dt>
/// <dd><a href="../mips/fn.msubv_h.html"><code>mips::msubv_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_msubv_w</code></strong></dt>
/// <dd><a href="../mips/fn.msubv_w.html"><code>mips::msubv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mul_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.mul_q_h.html"><code>mips::mul_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mul_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.mul_q_w.html"><code>mips::mul_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulr_q_h</code></strong></dt>
/// <dd><a href="../mips/fn.mulr_q_h.html"><code>mips::mulr_q_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulr_q_w</code></strong></dt>
/// <dd><a href="../mips/fn.mulr_q_w.html"><code>mips::mulr_q_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulv_b</code></strong></dt>
/// <dd><a href="../mips/fn.mulv_b.html"><code>mips::mulv_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulv_d</code></strong></dt>
/// <dd><a href="../mips/fn.mulv_d.html"><code>mips::mulv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulv_h</code></strong></dt>
/// <dd><a href="../mips/fn.mulv_h.html"><code>mips::mulv_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_mulv_w</code></strong></dt>
/// <dd><a href="../mips/fn.mulv_w.html"><code>mips::mulv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_nloc_b</code></strong></dt>
/// <dd><a href="../mips/fn.nloc_b.html"><code>mips::nloc_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_nloc_d</code></strong></dt>
/// <dd><a href="../mips/fn.nloc_d.html"><code>mips::nloc_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_nloc_h</code></strong></dt>
/// <dd><a href="../mips/fn.nloc_h.html"><code>mips::nloc_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_nloc_w</code></strong></dt>
/// <dd><a href="../mips/fn.nloc_w.html"><code>mips::nloc_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_nlzc_b</code></strong></dt>
/// <dd><a href="../mips/fn.nlzc_b.html"><code>mips::nlzc_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_nlzc_d</code></strong></dt>
/// <dd><a href="../mips/fn.nlzc_d.html"><code>mips::nlzc_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_nlzc_h</code></strong></dt>
/// <dd><a href="../mips/fn.nlzc_h.html"><code>mips::nlzc_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_nlzc_w</code></strong></dt>
/// <dd><a href="../mips/fn.nlzc_w.html"><code>mips::nlzc_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_nor_v</code></strong></dt>
/// <dd><a href="../mips/fn.nor_v.html"><code>mips::nor_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_nori_b</code></strong></dt>
/// <dd><a href="../mips/fn.nori_b.html"><code>mips::nori_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_or_v</code></strong></dt>
/// <dd><a href="../mips/fn.or_v.html"><code>mips::or_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_ori_b</code></strong></dt>
/// <dd><a href="../mips/fn.ori_b.html"><code>mips::ori_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckev_b</code></strong></dt>
/// <dd><a href="../mips/fn.pckev_b.html"><code>mips::pckev_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckev_d</code></strong></dt>
/// <dd><a href="../mips/fn.pckev_d.html"><code>mips::pckev_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckev_h</code></strong></dt>
/// <dd><a href="../mips/fn.pckev_h.html"><code>mips::pckev_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckev_w</code></strong></dt>
/// <dd><a href="../mips/fn.pckev_w.html"><code>mips::pckev_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckod_b</code></strong></dt>
/// <dd><a href="../mips/fn.pckod_b.html"><code>mips::pckod_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckod_d</code></strong></dt>
/// <dd><a href="../mips/fn.pckod_d.html"><code>mips::pckod_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckod_h</code></strong></dt>
/// <dd><a href="../mips/fn.pckod_h.html"><code>mips::pckod_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_pckod_w</code></strong></dt>
/// <dd><a href="../mips/fn.pckod_w.html"><code>mips::pckod_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_pcnt_b</code></strong></dt>
/// <dd><a href="../mips/fn.pcnt_b.html"><code>mips::pcnt_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_pcnt_d</code></strong></dt>
/// <dd><a href="../mips/fn.pcnt_d.html"><code>mips::pcnt_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_pcnt_h</code></strong></dt>
/// <dd><a href="../mips/fn.pcnt_h.html"><code>mips::pcnt_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_pcnt_w</code></strong></dt>
/// <dd><a href="../mips/fn.pcnt_w.html"><code>mips::pcnt_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.sat_s_b.html"><code>mips::sat_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.sat_s_d.html"><code>mips::sat_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.sat_s_h.html"><code>mips::sat_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.sat_s_w.html"><code>mips::sat_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.sat_u_b.html"><code>mips::sat_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.sat_u_d.html"><code>mips::sat_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.sat_u_h.html"><code>mips::sat_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sat_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.sat_u_w.html"><code>mips::sat_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_shf_b</code></strong></dt>
/// <dd><a href="../mips/fn.shf_b.html"><code>mips::shf_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_shf_h</code></strong></dt>
/// <dd><a href="../mips/fn.shf_h.html"><code>mips::shf_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_shf_w</code></strong></dt>
/// <dd><a href="../mips/fn.shf_w.html"><code>mips::shf_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sld_b</code></strong></dt>
/// <dd><a href="../mips/fn.sld_b.html"><code>mips::sld_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sld_d</code></strong></dt>
/// <dd><a href="../mips/fn.sld_d.html"><code>mips::sld_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sld_h</code></strong></dt>
/// <dd><a href="../mips/fn.sld_h.html"><code>mips::sld_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sld_w</code></strong></dt>
/// <dd><a href="../mips/fn.sld_w.html"><code>mips::sld_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sldi_b</code></strong></dt>
/// <dd><a href="../mips/fn.sldi_b.html"><code>mips::sldi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sldi_d</code></strong></dt>
/// <dd><a href="../mips/fn.sldi_d.html"><code>mips::sldi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sldi_h</code></strong></dt>
/// <dd><a href="../mips/fn.sldi_h.html"><code>mips::sldi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sldi_w</code></strong></dt>
/// <dd><a href="../mips/fn.sldi_w.html"><code>mips::sldi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sll_b</code></strong></dt>
/// <dd><a href="../mips/fn.sll_b.html"><code>mips::sll_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sll_d</code></strong></dt>
/// <dd><a href="../mips/fn.sll_d.html"><code>mips::sll_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sll_h</code></strong></dt>
/// <dd><a href="../mips/fn.sll_h.html"><code>mips::sll_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sll_w</code></strong></dt>
/// <dd><a href="../mips/fn.sll_w.html"><code>mips::sll_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_slli_b</code></strong></dt>
/// <dd><a href="../mips/fn.slli_b.html"><code>mips::slli_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_slli_d</code></strong></dt>
/// <dd><a href="../mips/fn.slli_d.html"><code>mips::slli_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_slli_h</code></strong></dt>
/// <dd><a href="../mips/fn.slli_h.html"><code>mips::slli_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_slli_w</code></strong></dt>
/// <dd><a href="../mips/fn.slli_w.html"><code>mips::slli_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_splat_b</code></strong></dt>
/// <dd><a href="../mips/fn.splat_b.html"><code>mips::splat_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_splat_d</code></strong></dt>
/// <dd><a href="../mips/fn.splat_d.html"><code>mips::splat_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_splat_h</code></strong></dt>
/// <dd><a href="../mips/fn.splat_h.html"><code>mips::splat_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_splat_w</code></strong></dt>
/// <dd><a href="../mips/fn.splat_w.html"><code>mips::splat_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_splati_b</code></strong></dt>
/// <dd><a href="../mips/fn.splati_b.html"><code>mips::splati_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_splati_d</code></strong></dt>
/// <dd><a href="../mips/fn.splati_d.html"><code>mips::splati_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_splati_h</code></strong></dt>
/// <dd><a href="../mips/fn.splati_h.html"><code>mips::splati_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_splati_w</code></strong></dt>
/// <dd><a href="../mips/fn.splati_w.html"><code>mips::splati_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_sra_b</code></strong></dt>
/// <dd><a href="../mips/fn.sra_b.html"><code>mips::sra_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_sra_d</code></strong></dt>
/// <dd><a href="../mips/fn.sra_d.html"><code>mips::sra_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_sra_h</code></strong></dt>
/// <dd><a href="../mips/fn.sra_h.html"><code>mips::sra_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_sra_w</code></strong></dt>
/// <dd><a href="../mips/fn.sra_w.html"><code>mips::sra_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srai_b</code></strong></dt>
/// <dd><a href="../mips/fn.srai_b.html"><code>mips::srai_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srai_d</code></strong></dt>
/// <dd><a href="../mips/fn.srai_d.html"><code>mips::srai_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srai_h</code></strong></dt>
/// <dd><a href="../mips/fn.srai_h.html"><code>mips::srai_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srai_w</code></strong></dt>
/// <dd><a href="../mips/fn.srai_w.html"><code>mips::srai_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srar_b</code></strong></dt>
/// <dd><a href="../mips/fn.srar_b.html"><code>mips::srar_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srar_d</code></strong></dt>
/// <dd><a href="../mips/fn.srar_d.html"><code>mips::srar_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srar_h</code></strong></dt>
/// <dd><a href="../mips/fn.srar_h.html"><code>mips::srar_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srar_w</code></strong></dt>
/// <dd><a href="../mips/fn.srar_w.html"><code>mips::srar_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srari_b</code></strong></dt>
/// <dd><a href="../mips/fn.srari_b.html"><code>mips::srari_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srari_d</code></strong></dt>
/// <dd><a href="../mips/fn.srari_d.html"><code>mips::srari_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srari_h</code></strong></dt>
/// <dd><a href="../mips/fn.srari_h.html"><code>mips::srari_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srari_w</code></strong></dt>
/// <dd><a href="../mips/fn.srari_w.html"><code>mips::srari_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srl_b</code></strong></dt>
/// <dd><a href="../mips/fn.srl_b.html"><code>mips::srl_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srl_d</code></strong></dt>
/// <dd><a href="../mips/fn.srl_d.html"><code>mips::srl_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srl_h</code></strong></dt>
/// <dd><a href="../mips/fn.srl_h.html"><code>mips::srl_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srl_w</code></strong></dt>
/// <dd><a href="../mips/fn.srl_w.html"><code>mips::srl_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srli_b</code></strong></dt>
/// <dd><a href="../mips/fn.srli_b.html"><code>mips::srli_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srli_d</code></strong></dt>
/// <dd><a href="../mips/fn.srli_d.html"><code>mips::srli_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srli_h</code></strong></dt>
/// <dd><a href="../mips/fn.srli_h.html"><code>mips::srli_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srli_w</code></strong></dt>
/// <dd><a href="../mips/fn.srli_w.html"><code>mips::srli_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlr_b</code></strong></dt>
/// <dd><a href="../mips/fn.srlr_b.html"><code>mips::srlr_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlr_d</code></strong></dt>
/// <dd><a href="../mips/fn.srlr_d.html"><code>mips::srlr_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlr_h</code></strong></dt>
/// <dd><a href="../mips/fn.srlr_h.html"><code>mips::srlr_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlr_w</code></strong></dt>
/// <dd><a href="../mips/fn.srlr_w.html"><code>mips::srlr_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlri_b</code></strong></dt>
/// <dd><a href="../mips/fn.srlri_b.html"><code>mips::srlri_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlri_d</code></strong></dt>
/// <dd><a href="../mips/fn.srlri_d.html"><code>mips::srlri_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlri_h</code></strong></dt>
/// <dd><a href="../mips/fn.srlri_h.html"><code>mips::srlri_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_srlri_w</code></strong></dt>
/// <dd><a href="../mips/fn.srlri_w.html"><code>mips::srlri_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_st_b</code></strong></dt>
/// <dd><a href="../mips/fn.st_b.html"><code>mips::st_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_st_d</code></strong></dt>
/// <dd><a href="../mips/fn.st_d.html"><code>mips::st_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_st_h</code></strong></dt>
/// <dd><a href="../mips/fn.st_h.html"><code>mips::st_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_st_w</code></strong></dt>
/// <dd><a href="../mips/fn.st_w.html"><code>mips::st_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.subs_s_b.html"><code>mips::subs_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.subs_s_d.html"><code>mips::subs_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.subs_s_h.html"><code>mips::subs_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.subs_s_w.html"><code>mips::subs_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.subs_u_b.html"><code>mips::subs_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.subs_u_d.html"><code>mips::subs_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.subs_u_h.html"><code>mips::subs_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subs_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.subs_u_w.html"><code>mips::subs_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsus_u_b</code></strong></dt>
/// <dd><a href="../mips/fn.subsus_u_b.html"><code>mips::subsus_u_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsus_u_d</code></strong></dt>
/// <dd><a href="../mips/fn.subsus_u_d.html"><code>mips::subsus_u_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsus_u_h</code></strong></dt>
/// <dd><a href="../mips/fn.subsus_u_h.html"><code>mips::subsus_u_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsus_u_w</code></strong></dt>
/// <dd><a href="../mips/fn.subsus_u_w.html"><code>mips::subsus_u_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsuu_s_b</code></strong></dt>
/// <dd><a href="../mips/fn.subsuu_s_b.html"><code>mips::subsuu_s_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsuu_s_d</code></strong></dt>
/// <dd><a href="../mips/fn.subsuu_s_d.html"><code>mips::subsuu_s_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsuu_s_h</code></strong></dt>
/// <dd><a href="../mips/fn.subsuu_s_h.html"><code>mips::subsuu_s_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subsuu_s_w</code></strong></dt>
/// <dd><a href="../mips/fn.subsuu_s_w.html"><code>mips::subsuu_s_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subv_b</code></strong></dt>
/// <dd><a href="../mips/fn.subv_b.html"><code>mips::subv_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subv_d</code></strong></dt>
/// <dd><a href="../mips/fn.subv_d.html"><code>mips::subv_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subv_h</code></strong></dt>
/// <dd><a href="../mips/fn.subv_h.html"><code>mips::subv_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subv_w</code></strong></dt>
/// <dd><a href="../mips/fn.subv_w.html"><code>mips::subv_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_subvi_b</code></strong></dt>
/// <dd><a href="../mips/fn.subvi_b.html"><code>mips::subvi_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_subvi_d</code></strong></dt>
/// <dd><a href="../mips/fn.subvi_d.html"><code>mips::subvi_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_subvi_h</code></strong></dt>
/// <dd><a href="../mips/fn.subvi_h.html"><code>mips::subvi_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_subvi_w</code></strong></dt>
/// <dd><a href="../mips/fn.subvi_w.html"><code>mips::subvi_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_vshf_b</code></strong></dt>
/// <dd><a href="../mips/fn.vshf_b.html"><code>mips::vshf_b</code></a></dd>
/// <dt><strong><code>__builtin_msa_vshf_d</code></strong></dt>
/// <dd><a href="../mips/fn.vshf_d.html"><code>mips::vshf_d</code></a></dd>
/// <dt><strong><code>__builtin_msa_vshf_h</code></strong></dt>
/// <dd><a href="../mips/fn.vshf_h.html"><code>mips::vshf_h</code></a></dd>
/// <dt><strong><code>__builtin_msa_vshf_w</code></strong></dt>
/// <dd><a href="../mips/fn.vshf_w.html"><code>mips::vshf_w</code></a></dd>
/// <dt><strong><code>__builtin_msa_xor_v</code></strong></dt>
/// <dd><a href="../mips/fn.xor_v.html"><code>mips::xor_v</code></a></dd>
/// <dt><strong><code>__builtin_msa_xori_b</code></strong></dt>
/// <dd><a href="../mips/fn.xori_b.html"><code>mips::xori_b</code></a></dd>
/// <dt><strong><code>__builtin_object_size</code></strong></dt>
/// <dd><a href="../fn.objectsize_v16i8_p0i8.html"><code>objectsize_v16i8_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_i8_p0i8.html"><code>objectsize_i8_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_v8i16_p0i8.html"><code>objectsize_v8i16_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_i16_p0i8.html"><code>objectsize_i16_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_v4i32_p0i8.html"><code>objectsize_v4i32_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_i32_p0i8.html"><code>objectsize_i32_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_v2i64_p0i8.html"><code>objectsize_v2i64_p0i8</code></a></dd>
/// <dd><a href="../fn.objectsize_i64_p0i8.html"><code>objectsize_i64_p0i8</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfabs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfabs.html"><code>ppc::qpx_qvfabs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfadd.html"><code>ppc::qpx_qvfadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfadds.html"><code>ppc::qpx_qvfadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcfid</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcfid.html"><code>ppc::qpx_qvfcfid</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcfids</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcfids.html"><code>ppc::qpx_qvfcfids</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcfidu</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcfidu.html"><code>ppc::qpx_qvfcfidu</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcfidus</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcfidus.html"><code>ppc::qpx_qvfcfidus</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcmpeq</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcmpeq.html"><code>ppc::qpx_qvfcmpeq</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcmpgt</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcmpgt.html"><code>ppc::qpx_qvfcmpgt</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcmplt</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcmplt.html"><code>ppc::qpx_qvfcmplt</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfcpsgn</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfcpsgn.html"><code>ppc::qpx_qvfcpsgn</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctid</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctid.html"><code>ppc::qpx_qvfctid</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctidu</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctidu.html"><code>ppc::qpx_qvfctidu</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctiduz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctiduz.html"><code>ppc::qpx_qvfctiduz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctidz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctidz.html"><code>ppc::qpx_qvfctidz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctiw</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctiw.html"><code>ppc::qpx_qvfctiw</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctiwu</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctiwu.html"><code>ppc::qpx_qvfctiwu</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctiwuz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctiwuz.html"><code>ppc::qpx_qvfctiwuz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfctiwz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfctiwz.html"><code>ppc::qpx_qvfctiwz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvflogical</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvflogical.html"><code>ppc::qpx_qvflogical</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmadd.html"><code>ppc::qpx_qvfmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmadds.html"><code>ppc::qpx_qvfmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmsub</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmsub.html"><code>ppc::qpx_qvfmsub</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmsubs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmsubs.html"><code>ppc::qpx_qvfmsubs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmul</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmul.html"><code>ppc::qpx_qvfmul</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfmuls</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfmuls.html"><code>ppc::qpx_qvfmuls</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfnabs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfnabs.html"><code>ppc::qpx_qvfnabs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfneg</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfneg.html"><code>ppc::qpx_qvfneg</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfnmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfnmadd.html"><code>ppc::qpx_qvfnmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfnmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfnmadds.html"><code>ppc::qpx_qvfnmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfnmsub</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfnmsub.html"><code>ppc::qpx_qvfnmsub</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfnmsubs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfnmsubs.html"><code>ppc::qpx_qvfnmsubs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfperm</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfperm.html"><code>ppc::qpx_qvfperm</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfre</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfre.html"><code>ppc::qpx_qvfre</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfres</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfres.html"><code>ppc::qpx_qvfres</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrim</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrim.html"><code>ppc::qpx_qvfrim</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrin</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrin.html"><code>ppc::qpx_qvfrin</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrip</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrip.html"><code>ppc::qpx_qvfrip</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfriz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfriz.html"><code>ppc::qpx_qvfriz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrsp</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrsp.html"><code>ppc::qpx_qvfrsp</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrsqrte</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrsqrte.html"><code>ppc::qpx_qvfrsqrte</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfrsqrtes</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfrsqrtes.html"><code>ppc::qpx_qvfrsqrtes</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfsel</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfsel.html"><code>ppc::qpx_qvfsel</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfsub</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfsub.html"><code>ppc::qpx_qvfsub</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfsubs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfsubs.html"><code>ppc::qpx_qvfsubs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvftstnan</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvftstnan.html"><code>ppc::qpx_qvftstnan</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxmadd.html"><code>ppc::qpx_qvfxmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxmadds.html"><code>ppc::qpx_qvfxmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxmul</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxmul.html"><code>ppc::qpx_qvfxmul</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxmuls</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxmuls.html"><code>ppc::qpx_qvfxmuls</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxcpnmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxcpnmadd.html"><code>ppc::qpx_qvfxxcpnmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxcpnmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxcpnmadds.html"><code>ppc::qpx_qvfxxcpnmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxmadd.html"><code>ppc::qpx_qvfxxmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxmadds.html"><code>ppc::qpx_qvfxxmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxnpmadd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxnpmadd.html"><code>ppc::qpx_qvfxxnpmadd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvfxxnpmadds</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvfxxnpmadds.html"><code>ppc::qpx_qvfxxnpmadds</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvgpci</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvgpci.html"><code>ppc::qpx_qvgpci</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfcd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfcd.html"><code>ppc::qpx_qvlfcd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfcda</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfcda.html"><code>ppc::qpx_qvlfcda</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfcs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfcs.html"><code>ppc::qpx_qvlfcs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfcsa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfcsa.html"><code>ppc::qpx_qvlfcsa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfd.html"><code>ppc::qpx_qvlfd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfda</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfda.html"><code>ppc::qpx_qvlfda</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfiwa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfiwa.html"><code>ppc::qpx_qvlfiwa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfiwaa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfiwaa.html"><code>ppc::qpx_qvlfiwaa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfiwz</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfiwz.html"><code>ppc::qpx_qvlfiwz</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfiwza</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfiwza.html"><code>ppc::qpx_qvlfiwza</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfs.html"><code>ppc::qpx_qvlfs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlfsa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlfsa.html"><code>ppc::qpx_qvlfsa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlpcld</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlpcld.html"><code>ppc::qpx_qvlpcld</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlpcls</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlpcls.html"><code>ppc::qpx_qvlpcls</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlpcrd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlpcrd.html"><code>ppc::qpx_qvlpcrd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvlpcrs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvlpcrs.html"><code>ppc::qpx_qvlpcrs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfcd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfcd.html"><code>ppc::qpx_qvstfcd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfcda</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfcda.html"><code>ppc::qpx_qvstfcda</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfcs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfcs.html"><code>ppc::qpx_qvstfcs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfcsa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfcsa.html"><code>ppc::qpx_qvstfcsa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfd</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfd.html"><code>ppc::qpx_qvstfd</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfda</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfda.html"><code>ppc::qpx_qvstfda</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfiw</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfiw.html"><code>ppc::qpx_qvstfiw</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfiwa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfiwa.html"><code>ppc::qpx_qvstfiwa</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfs</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfs.html"><code>ppc::qpx_qvstfs</code></a></dd>
/// <dt><strong><code>__builtin_qpx_qvstfsa</code></strong></dt>
/// <dd><a href="../ppc/fn.qpx_qvstfsa.html"><code>ppc::qpx_qvstfsa</code></a></dd>
/// <dt><strong><code>__builtin_r600_group_barrier</code></strong></dt>
/// <dd><a href="../r600/fn.group_barrier.html"><code>r600::group_barrier</code></a></dd>
/// <dt><strong><code>__builtin_r600_rat_store_typed</code></strong></dt>
/// <dd><a href="../r600/fn.rat_store_typed.html"><code>r600::rat_store_typed</code></a></dd>
/// <dt><strong><code>__builtin_s390_</code></strong></dt>
/// <dd><a href="../fn.s390_vaq.html"><code>s390_vaq</code></a></dd>
/// <dd><a href="../fn.s390_vacq.html"><code>s390_vacq</code></a></dd>
/// <dd><a href="../fn.s390_vaccq.html"><code>s390_vaccq</code></a></dd>
/// <dd><a href="../fn.s390_vacccq.html"><code>s390_vacccq</code></a></dd>
/// <dd><a href="../fn.s390_vcksm.html"><code>s390_vcksm</code></a></dd>
/// <dd><a href="../fn.s390_vsl.html"><code>s390_vsl</code></a></dd>
/// <dd><a href="../fn.s390_vslb.html"><code>s390_vslb</code></a></dd>
/// <dd><a href="../fn.s390_vsra.html"><code>s390_vsra</code></a></dd>
/// <dd><a href="../fn.s390_vsrab.html"><code>s390_vsrab</code></a></dd>
/// <dd><a href="../fn.s390_vsrl.html"><code>s390_vsrl</code></a></dd>
/// <dd><a href="../fn.s390_vsrlb.html"><code>s390_vsrlb</code></a></dd>
/// <dd><a href="../fn.s390_vsq.html"><code>s390_vsq</code></a></dd>
/// <dd><a href="../fn.s390_vsbiq.html"><code>s390_vsbiq</code></a></dd>
/// <dd><a href="../fn.s390_vscbiq.html"><code>s390_vscbiq</code></a></dd>
/// <dd><a href="../fn.s390_vsbcbiq.html"><code>s390_vsbcbiq</code></a></dd>
/// <dd><a href="../fn.s390_vsumb.html"><code>s390_vsumb</code></a></dd>
/// <dd><a href="../fn.s390_vsumh.html"><code>s390_vsumh</code></a></dd>
/// <dd><a href="../fn.s390_vsumgh.html"><code>s390_vsumgh</code></a></dd>
/// <dd><a href="../fn.s390_vsumgf.html"><code>s390_vsumgf</code></a></dd>
/// <dd><a href="../fn.s390_vsumqf.html"><code>s390_vsumqf</code></a></dd>
/// <dd><a href="../fn.s390_vsumqg.html"><code>s390_vsumqg</code></a></dd>
/// <dd><a href="../fn.s390_vtm.html"><code>s390_vtm</code></a></dd>
/// <dt><strong><code>__builtin_s390_lcbb</code></strong></dt>
/// <dd><a href="../fn.s390_lcbb.html"><code>s390_lcbb</code></a></dd>
/// <dt><strong><code>__builtin_s390_vlbb</code></strong></dt>
/// <dd><a href="../fn.s390_vlbb.html"><code>s390_vlbb</code></a></dd>
/// <dt><strong><code>__builtin_s390_vll</code></strong></dt>
/// <dd><a href="../fn.s390_vll.html"><code>s390_vll</code></a></dd>
/// <dt><strong><code>__builtin_s390_vpdi</code></strong></dt>
/// <dd><a href="../fn.s390_vpdi.html"><code>s390_vpdi</code></a></dd>
/// <dt><strong><code>__builtin_s390_vperm</code></strong></dt>
/// <dd><a href="../fn.s390_vperm.html"><code>s390_vperm</code></a></dd>
/// <dt><strong><code>__builtin_s390_vsldb</code></strong></dt>
/// <dd><a href="../fn.s390_vsldb.html"><code>s390_vsldb</code></a></dd>
/// <dt><strong><code>__builtin_s390_vstl</code></strong></dt>
/// <dd><a href="../fn.s390_vstl.html"><code>s390_vstl</code></a></dd>
/// <dt><strong><code>__builtin_set_texasr</code></strong></dt>
/// <dd><a href="../ppc/fn.set_texasr.html"><code>ppc::set_texasr</code></a></dd>
/// <dt><strong><code>__builtin_set_texasru</code></strong></dt>
/// <dd><a href="../ppc/fn.set_texasru.html"><code>ppc::set_texasru</code></a></dd>
/// <dt><strong><code>__builtin_set_tfhar</code></strong></dt>
/// <dd><a href="../ppc/fn.set_tfhar.html"><code>ppc::set_tfhar</code></a></dd>
/// <dt><strong><code>__builtin_set_tfiar</code></strong></dt>
/// <dd><a href="../ppc/fn.set_tfiar.html"><code>ppc::set_tfiar</code></a></dd>
/// <dt><strong><code>__builtin_setps</code></strong></dt>
/// <dd><a href="../xcore/fn.setps.html"><code>xcore::setps</code></a></dd>
/// <dt><strong><code>__builtin_stack_restore</code></strong></dt>
/// <dd><a href="../fn.stackrestore.html"><code>stackrestore</code></a></dd>
/// <dt><strong><code>__builtin_stack_save</code></strong></dt>
/// <dd><a href="../fn.stacksave.html"><code>stacksave</code></a></dd>
/// <dt><strong><code>__builtin_tabort</code></strong></dt>
/// <dd><a href="../ppc/fn.tabort.html"><code>ppc::tabort</code></a></dd>
/// <dt><strong><code>__builtin_tabortdc</code></strong></dt>
/// <dd><a href="../ppc/fn.tabortdc.html"><code>ppc::tabortdc</code></a></dd>
/// <dt><strong><code>__builtin_tabortdci</code></strong></dt>
/// <dd><a href="../ppc/fn.tabortdci.html"><code>ppc::tabortdci</code></a></dd>
/// <dt><strong><code>__builtin_tabortwc</code></strong></dt>
/// <dd><a href="../ppc/fn.tabortwc.html"><code>ppc::tabortwc</code></a></dd>
/// <dt><strong><code>__builtin_tabortwci</code></strong></dt>
/// <dd><a href="../ppc/fn.tabortwci.html"><code>ppc::tabortwci</code></a></dd>
/// <dt><strong><code>__builtin_tbegin</code></strong></dt>
/// <dd><a href="../ppc/fn.tbegin.html"><code>ppc::tbegin</code></a></dd>
/// <dt><strong><code>__builtin_tcheck</code></strong></dt>
/// <dd><a href="../ppc/fn.tcheck.html"><code>ppc::tcheck</code></a></dd>
/// <dt><strong><code>__builtin_tend</code></strong></dt>
/// <dd><a href="../fn.s390_tend.html"><code>s390_tend</code></a></dd>
/// <dd><a href="../ppc/fn.tend.html"><code>ppc::tend</code></a></dd>
/// <dt><strong><code>__builtin_tendall</code></strong></dt>
/// <dd><a href="../ppc/fn.tendall.html"><code>ppc::tendall</code></a></dd>
/// <dt><strong><code>__builtin_thread_pointer</code></strong></dt>
/// <dd><a href="../fn.thread_pointer.html"><code>thread_pointer</code></a></dd>
/// <dt><strong><code>__builtin_trap</code></strong></dt>
/// <dd><a href="../fn.trap.html"><code>trap</code></a></dd>
/// <dt><strong><code>__builtin_trechkpt</code></strong></dt>
/// <dd><a href="../ppc/fn.trechkpt.html"><code>ppc::trechkpt</code></a></dd>
/// <dt><strong><code>__builtin_treclaim</code></strong></dt>
/// <dd><a href="../ppc/fn.treclaim.html"><code>ppc::treclaim</code></a></dd>
/// <dt><strong><code>__builtin_tresume</code></strong></dt>
/// <dd><a href="../ppc/fn.tresume.html"><code>ppc::tresume</code></a></dd>
/// <dt><strong><code>__builtin_tsr</code></strong></dt>
/// <dd><a href="../ppc/fn.tsr.html"><code>ppc::tsr</code></a></dd>
/// <dt><strong><code>__builtin_tsuspend</code></strong></dt>
/// <dd><a href="../ppc/fn.tsuspend.html"><code>ppc::tsuspend</code></a></dd>
/// <dt><strong><code>__builtin_ttest</code></strong></dt>
/// <dd><a href="../ppc/fn.ttest.html"><code>ppc::ttest</code></a></dd>
/// <dt><strong><code>__builtin_tx_assist</code></strong></dt>
/// <dd><a href="../fn.s390_ppa_txassist.html"><code>s390_ppa_txassist</code></a></dd>
/// <dt><strong><code>__builtin_tx_nesting_depth</code></strong></dt>
/// <dd><a href="../fn.s390_etnd.html"><code>s390_etnd</code></a></dd>
/// <dt><strong><code>__builtin_unwind_init</code></strong></dt>
/// <dd><a href="../fn.eh_unwind_init.html"><code>eh_unwind_init</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xsmaxdp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xsmaxdp.html"><code>ppc::vsx_xsmaxdp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xsmindp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xsmindp.html"><code>ppc::vsx_xsmindp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpeqdp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpeqdp.html"><code>ppc::vsx_xvcmpeqdp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpeqdp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpeqdp_p.html"><code>ppc::vsx_xvcmpeqdp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpeqsp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpeqsp.html"><code>ppc::vsx_xvcmpeqsp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpeqsp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpeqsp_p.html"><code>ppc::vsx_xvcmpeqsp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgedp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgedp.html"><code>ppc::vsx_xvcmpgedp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgedp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgedp_p.html"><code>ppc::vsx_xvcmpgedp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgesp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgesp.html"><code>ppc::vsx_xvcmpgesp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgesp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgesp_p.html"><code>ppc::vsx_xvcmpgesp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgtdp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgtdp.html"><code>ppc::vsx_xvcmpgtdp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgtdp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgtdp_p.html"><code>ppc::vsx_xvcmpgtdp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgtsp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgtsp.html"><code>ppc::vsx_xvcmpgtsp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvcmpgtsp_p</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvcmpgtsp_p.html"><code>ppc::vsx_xvcmpgtsp_p</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvdivdp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvdivdp.html"><code>ppc::vsx_xvdivdp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvdivsp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvdivsp.html"><code>ppc::vsx_xvdivsp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvmaxdp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvmaxdp.html"><code>ppc::vsx_xvmaxdp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvmaxsp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvmaxsp.html"><code>ppc::vsx_xvmaxsp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvmindp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvmindp.html"><code>ppc::vsx_xvmindp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvminsp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvminsp.html"><code>ppc::vsx_xvminsp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvredp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvredp.html"><code>ppc::vsx_xvredp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvresp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvresp.html"><code>ppc::vsx_xvresp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvrsqrtedp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvrsqrtedp.html"><code>ppc::vsx_xvrsqrtedp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xvrsqrtesp</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xvrsqrtesp.html"><code>ppc::vsx_xvrsqrtesp</code></a></dd>
/// <dt><strong><code>__builtin_vsx_xxleqv</code></strong></dt>
/// <dd><a href="../ppc/fn.vsx_xxleqv.html"><code>ppc::vsx_xxleqv</code></a></dd>
/// <dt><strong><code>__nvvm_abs_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.abs_i.html"><code>nvvm::abs_i</code></a></dd>
/// <dt><strong><code>__nvvm_abs_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.abs_ll.html"><code>nvvm::abs_ll</code></a></dd>
/// <dt><strong><code>__nvvm_add_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rm_d.html"><code>nvvm::add_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_add_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rm_f.html"><code>nvvm::add_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rm_ftz_f.html"><code>nvvm::add_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rn_d.html"><code>nvvm::add_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_add_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rn_f.html"><code>nvvm::add_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rn_ftz_f.html"><code>nvvm::add_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rp_d.html"><code>nvvm::add_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_add_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rp_f.html"><code>nvvm::add_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rp_ftz_f.html"><code>nvvm::add_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rz_d.html"><code>nvvm::add_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_add_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rz_f.html"><code>nvvm::add_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_add_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.add_rz_ftz_f.html"><code>nvvm::add_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_bar0_and</code></strong></dt>
/// <dd><a href="../nvvm/fn.barrier0_and.html"><code>nvvm::barrier0_and</code></a></dd>
/// <dt><strong><code>__nvvm_bar0_or</code></strong></dt>
/// <dd><a href="../nvvm/fn.barrier0_or.html"><code>nvvm::barrier0_or</code></a></dd>
/// <dt><strong><code>__nvvm_bar0_popc</code></strong></dt>
/// <dd><a href="../nvvm/fn.barrier0_popc.html"><code>nvvm::barrier0_popc</code></a></dd>
/// <dt><strong><code>__nvvm_bar_sync</code></strong></dt>
/// <dd><a href="../nvvm/fn.bar_sync.html"><code>nvvm::bar_sync</code></a></dd>
/// <dt><strong><code>__nvvm_bitcast_d2ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.bitcast_d2ll.html"><code>nvvm::bitcast_d2ll</code></a></dd>
/// <dt><strong><code>__nvvm_bitcast_f2i</code></strong></dt>
/// <dd><a href="../nvvm/fn.bitcast_f2i.html"><code>nvvm::bitcast_f2i</code></a></dd>
/// <dt><strong><code>__nvvm_bitcast_i2f</code></strong></dt>
/// <dd><a href="../nvvm/fn.bitcast_i2f.html"><code>nvvm::bitcast_i2f</code></a></dd>
/// <dt><strong><code>__nvvm_bitcast_ll2d</code></strong></dt>
/// <dd><a href="../nvvm/fn.bitcast_ll2d.html"><code>nvvm::bitcast_ll2d</code></a></dd>
/// <dt><strong><code>__nvvm_brev32</code></strong></dt>
/// <dd><a href="../nvvm/fn.brev32.html"><code>nvvm::brev32</code></a></dd>
/// <dt><strong><code>__nvvm_brev64</code></strong></dt>
/// <dd><a href="../nvvm/fn.brev64.html"><code>nvvm::brev64</code></a></dd>
/// <dt><strong><code>__nvvm_ceil_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.ceil_d.html"><code>nvvm::ceil_d</code></a></dd>
/// <dt><strong><code>__nvvm_ceil_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.ceil_f.html"><code>nvvm::ceil_f</code></a></dd>
/// <dt><strong><code>__nvvm_ceil_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.ceil_ftz_f.html"><code>nvvm::ceil_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_clz_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.clz_i.html"><code>nvvm::clz_i</code></a></dd>
/// <dt><strong><code>__nvvm_clz_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.clz_ll.html"><code>nvvm::clz_ll</code></a></dd>
/// <dt><strong><code>__nvvm_cos_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.cos_approx_f.html"><code>nvvm::cos_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_cos_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.cos_approx_ftz_f.html"><code>nvvm::cos_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rm.html"><code>nvvm::d2f_rm</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rm_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rm_ftz.html"><code>nvvm::d2f_rm_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rn.html"><code>nvvm::d2f_rn</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rn_ftz.html"><code>nvvm::d2f_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rp.html"><code>nvvm::d2f_rp</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rp_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rp_ftz.html"><code>nvvm::d2f_rp_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rz.html"><code>nvvm::d2f_rz</code></a></dd>
/// <dt><strong><code>__nvvm_d2f_rz_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2f_rz_ftz.html"><code>nvvm::d2f_rz_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_hi</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_hi.html"><code>nvvm::d2i_hi</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_lo</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_lo.html"><code>nvvm::d2i_lo</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_rm.html"><code>nvvm::d2i_rm</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_rn.html"><code>nvvm::d2i_rn</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_rp.html"><code>nvvm::d2i_rp</code></a></dd>
/// <dt><strong><code>__nvvm_d2i_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2i_rz.html"><code>nvvm::d2i_rz</code></a></dd>
/// <dt><strong><code>__nvvm_d2ll_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ll_rm.html"><code>nvvm::d2ll_rm</code></a></dd>
/// <dt><strong><code>__nvvm_d2ll_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ll_rn.html"><code>nvvm::d2ll_rn</code></a></dd>
/// <dt><strong><code>__nvvm_d2ll_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ll_rp.html"><code>nvvm::d2ll_rp</code></a></dd>
/// <dt><strong><code>__nvvm_d2ll_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ll_rz.html"><code>nvvm::d2ll_rz</code></a></dd>
/// <dt><strong><code>__nvvm_d2ui_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ui_rm.html"><code>nvvm::d2ui_rm</code></a></dd>
/// <dt><strong><code>__nvvm_d2ui_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ui_rn.html"><code>nvvm::d2ui_rn</code></a></dd>
/// <dt><strong><code>__nvvm_d2ui_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ui_rp.html"><code>nvvm::d2ui_rp</code></a></dd>
/// <dt><strong><code>__nvvm_d2ui_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ui_rz.html"><code>nvvm::d2ui_rz</code></a></dd>
/// <dt><strong><code>__nvvm_d2ull_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ull_rm.html"><code>nvvm::d2ull_rm</code></a></dd>
/// <dt><strong><code>__nvvm_d2ull_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ull_rn.html"><code>nvvm::d2ull_rn</code></a></dd>
/// <dt><strong><code>__nvvm_d2ull_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ull_rp.html"><code>nvvm::d2ull_rp</code></a></dd>
/// <dt><strong><code>__nvvm_d2ull_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.d2ull_rz.html"><code>nvvm::d2ull_rz</code></a></dd>
/// <dt><strong><code>__nvvm_div_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_approx_f.html"><code>nvvm::div_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_approx_ftz_f.html"><code>nvvm::div_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rm_d.html"><code>nvvm::div_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_div_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rm_f.html"><code>nvvm::div_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rm_ftz_f.html"><code>nvvm::div_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rn_d.html"><code>nvvm::div_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_div_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rn_f.html"><code>nvvm::div_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rn_ftz_f.html"><code>nvvm::div_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rp_d.html"><code>nvvm::div_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_div_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rp_f.html"><code>nvvm::div_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rp_ftz_f.html"><code>nvvm::div_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rz_d.html"><code>nvvm::div_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_div_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rz_f.html"><code>nvvm::div_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_div_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.div_rz_ftz_f.html"><code>nvvm::div_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_ex2_approx_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.ex2_approx_d.html"><code>nvvm::ex2_approx_d</code></a></dd>
/// <dt><strong><code>__nvvm_ex2_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.ex2_approx_f.html"><code>nvvm::ex2_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_ex2_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.ex2_approx_ftz_f.html"><code>nvvm::ex2_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_f2h_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2h_rn.html"><code>nvvm::f2h_rn</code></a></dd>
/// <dt><strong><code>__nvvm_f2h_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2h_rn_ftz.html"><code>nvvm::f2h_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rm.html"><code>nvvm::f2i_rm</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rm_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rm_ftz.html"><code>nvvm::f2i_rm_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rn.html"><code>nvvm::f2i_rn</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rn_ftz.html"><code>nvvm::f2i_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rp.html"><code>nvvm::f2i_rp</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rp_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rp_ftz.html"><code>nvvm::f2i_rp_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rz.html"><code>nvvm::f2i_rz</code></a></dd>
/// <dt><strong><code>__nvvm_f2i_rz_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2i_rz_ftz.html"><code>nvvm::f2i_rz_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rm.html"><code>nvvm::f2ll_rm</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rm_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rm_ftz.html"><code>nvvm::f2ll_rm_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rn.html"><code>nvvm::f2ll_rn</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rn_ftz.html"><code>nvvm::f2ll_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rp.html"><code>nvvm::f2ll_rp</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rp_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rp_ftz.html"><code>nvvm::f2ll_rp_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rz.html"><code>nvvm::f2ll_rz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ll_rz_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ll_rz_ftz.html"><code>nvvm::f2ll_rz_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rm.html"><code>nvvm::f2ui_rm</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rm_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rm_ftz.html"><code>nvvm::f2ui_rm_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rn.html"><code>nvvm::f2ui_rn</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rn_ftz.html"><code>nvvm::f2ui_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rp.html"><code>nvvm::f2ui_rp</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rp_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rp_ftz.html"><code>nvvm::f2ui_rp_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rz.html"><code>nvvm::f2ui_rz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ui_rz_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ui_rz_ftz.html"><code>nvvm::f2ui_rz_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rm.html"><code>nvvm::f2ull_rm</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rm_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rm_ftz.html"><code>nvvm::f2ull_rm_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rn.html"><code>nvvm::f2ull_rn</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rn_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rn_ftz.html"><code>nvvm::f2ull_rn_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rp.html"><code>nvvm::f2ull_rp</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rp_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rp_ftz.html"><code>nvvm::f2ull_rp_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rz.html"><code>nvvm::f2ull_rz</code></a></dd>
/// <dt><strong><code>__nvvm_f2ull_rz_ftz</code></strong></dt>
/// <dd><a href="../nvvm/fn.f2ull_rz_ftz.html"><code>nvvm::f2ull_rz_ftz</code></a></dd>
/// <dt><strong><code>__nvvm_fabs_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fabs_d.html"><code>nvvm::fabs_d</code></a></dd>
/// <dt><strong><code>__nvvm_fabs_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fabs_f.html"><code>nvvm::fabs_f</code></a></dd>
/// <dt><strong><code>__nvvm_fabs_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fabs_ftz_f.html"><code>nvvm::fabs_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_floor_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.floor_d.html"><code>nvvm::floor_d</code></a></dd>
/// <dt><strong><code>__nvvm_floor_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.floor_f.html"><code>nvvm::floor_f</code></a></dd>
/// <dt><strong><code>__nvvm_floor_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.floor_ftz_f.html"><code>nvvm::floor_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rm_d.html"><code>nvvm::fma_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rm_f.html"><code>nvvm::fma_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rm_ftz_f.html"><code>nvvm::fma_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rn_d.html"><code>nvvm::fma_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rn_f.html"><code>nvvm::fma_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rn_ftz_f.html"><code>nvvm::fma_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rp_d.html"><code>nvvm::fma_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rp_f.html"><code>nvvm::fma_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rp_ftz_f.html"><code>nvvm::fma_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rz_d.html"><code>nvvm::fma_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rz_f.html"><code>nvvm::fma_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fma_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fma_rz_ftz_f.html"><code>nvvm::fma_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fmax_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmax_d.html"><code>nvvm::fmax_d</code></a></dd>
/// <dt><strong><code>__nvvm_fmax_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmax_f.html"><code>nvvm::fmax_f</code></a></dd>
/// <dt><strong><code>__nvvm_fmax_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmax_ftz_f.html"><code>nvvm::fmax_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_fmin_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmin_d.html"><code>nvvm::fmin_d</code></a></dd>
/// <dt><strong><code>__nvvm_fmin_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmin_f.html"><code>nvvm::fmin_f</code></a></dd>
/// <dt><strong><code>__nvvm_fmin_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.fmin_ftz_f.html"><code>nvvm::fmin_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_h2f</code></strong></dt>
/// <dd><a href="../nvvm/fn.h2f.html"><code>nvvm::h2f</code></a></dd>
/// <dt><strong><code>__nvvm_i2d_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2d_rm.html"><code>nvvm::i2d_rm</code></a></dd>
/// <dt><strong><code>__nvvm_i2d_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2d_rn.html"><code>nvvm::i2d_rn</code></a></dd>
/// <dt><strong><code>__nvvm_i2d_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2d_rp.html"><code>nvvm::i2d_rp</code></a></dd>
/// <dt><strong><code>__nvvm_i2d_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2d_rz.html"><code>nvvm::i2d_rz</code></a></dd>
/// <dt><strong><code>__nvvm_i2f_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2f_rm.html"><code>nvvm::i2f_rm</code></a></dd>
/// <dt><strong><code>__nvvm_i2f_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2f_rn.html"><code>nvvm::i2f_rn</code></a></dd>
/// <dt><strong><code>__nvvm_i2f_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2f_rp.html"><code>nvvm::i2f_rp</code></a></dd>
/// <dt><strong><code>__nvvm_i2f_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.i2f_rz.html"><code>nvvm::i2f_rz</code></a></dd>
/// <dt><strong><code>__nvvm_isspacep_const</code></strong></dt>
/// <dd><a href="../nvvm/fn.isspacep_const.html"><code>nvvm::isspacep_const</code></a></dd>
/// <dt><strong><code>__nvvm_isspacep_global</code></strong></dt>
/// <dd><a href="../nvvm/fn.isspacep_global.html"><code>nvvm::isspacep_global</code></a></dd>
/// <dt><strong><code>__nvvm_isspacep_local</code></strong></dt>
/// <dd><a href="../nvvm/fn.isspacep_local.html"><code>nvvm::isspacep_local</code></a></dd>
/// <dt><strong><code>__nvvm_isspacep_shared</code></strong></dt>
/// <dd><a href="../nvvm/fn.isspacep_shared.html"><code>nvvm::isspacep_shared</code></a></dd>
/// <dt><strong><code>__nvvm_istypep_sampler</code></strong></dt>
/// <dd><a href="../nvvm/fn.istypep_sampler.html"><code>nvvm::istypep_sampler</code></a></dd>
/// <dt><strong><code>__nvvm_istypep_surface</code></strong></dt>
/// <dd><a href="../nvvm/fn.istypep_surface.html"><code>nvvm::istypep_surface</code></a></dd>
/// <dt><strong><code>__nvvm_istypep_texture</code></strong></dt>
/// <dd><a href="../nvvm/fn.istypep_texture.html"><code>nvvm::istypep_texture</code></a></dd>
/// <dt><strong><code>__nvvm_lg2_approx_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.lg2_approx_d.html"><code>nvvm::lg2_approx_d</code></a></dd>
/// <dt><strong><code>__nvvm_lg2_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.lg2_approx_f.html"><code>nvvm::lg2_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_lg2_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.lg2_approx_ftz_f.html"><code>nvvm::lg2_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_ll2d_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2d_rm.html"><code>nvvm::ll2d_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ll2d_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2d_rn.html"><code>nvvm::ll2d_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ll2d_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2d_rp.html"><code>nvvm::ll2d_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ll2d_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2d_rz.html"><code>nvvm::ll2d_rz</code></a></dd>
/// <dt><strong><code>__nvvm_ll2f_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2f_rm.html"><code>nvvm::ll2f_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ll2f_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2f_rn.html"><code>nvvm::ll2f_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ll2f_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2f_rp.html"><code>nvvm::ll2f_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ll2f_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ll2f_rz.html"><code>nvvm::ll2f_rz</code></a></dd>
/// <dt><strong><code>__nvvm_lohi_i2d</code></strong></dt>
/// <dd><a href="../nvvm/fn.lohi_i2d.html"><code>nvvm::lohi_i2d</code></a></dd>
/// <dt><strong><code>__nvvm_max_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.max_i.html"><code>nvvm::max_i</code></a></dd>
/// <dt><strong><code>__nvvm_max_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.max_ll.html"><code>nvvm::max_ll</code></a></dd>
/// <dt><strong><code>__nvvm_max_ui</code></strong></dt>
/// <dd><a href="../nvvm/fn.max_ui.html"><code>nvvm::max_ui</code></a></dd>
/// <dt><strong><code>__nvvm_max_ull</code></strong></dt>
/// <dd><a href="../nvvm/fn.max_ull.html"><code>nvvm::max_ull</code></a></dd>
/// <dt><strong><code>__nvvm_membar_cta</code></strong></dt>
/// <dd><a href="../nvvm/fn.membar_cta.html"><code>nvvm::membar_cta</code></a></dd>
/// <dt><strong><code>__nvvm_membar_gl</code></strong></dt>
/// <dd><a href="../nvvm/fn.membar_gl.html"><code>nvvm::membar_gl</code></a></dd>
/// <dt><strong><code>__nvvm_membar_sys</code></strong></dt>
/// <dd><a href="../nvvm/fn.membar_sys.html"><code>nvvm::membar_sys</code></a></dd>
/// <dt><strong><code>__nvvm_min_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.min_i.html"><code>nvvm::min_i</code></a></dd>
/// <dt><strong><code>__nvvm_min_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.min_ll.html"><code>nvvm::min_ll</code></a></dd>
/// <dt><strong><code>__nvvm_min_ui</code></strong></dt>
/// <dd><a href="../nvvm/fn.min_ui.html"><code>nvvm::min_ui</code></a></dd>
/// <dt><strong><code>__nvvm_min_ull</code></strong></dt>
/// <dd><a href="../nvvm/fn.min_ull.html"><code>nvvm::min_ull</code></a></dd>
/// <dt><strong><code>__nvvm_mul24_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul24_i.html"><code>nvvm::mul24_i</code></a></dd>
/// <dt><strong><code>__nvvm_mul24_ui</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul24_ui.html"><code>nvvm::mul24_ui</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rm_d.html"><code>nvvm::mul_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rm_f.html"><code>nvvm::mul_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rm_ftz_f.html"><code>nvvm::mul_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rn_d.html"><code>nvvm::mul_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rn_f.html"><code>nvvm::mul_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rn_ftz_f.html"><code>nvvm::mul_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rp_d.html"><code>nvvm::mul_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rp_f.html"><code>nvvm::mul_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rp_ftz_f.html"><code>nvvm::mul_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rz_d.html"><code>nvvm::mul_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rz_f.html"><code>nvvm::mul_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_mul_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.mul_rz_ftz_f.html"><code>nvvm::mul_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_mulhi_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.mulhi_i.html"><code>nvvm::mulhi_i</code></a></dd>
/// <dt><strong><code>__nvvm_mulhi_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.mulhi_ll.html"><code>nvvm::mulhi_ll</code></a></dd>
/// <dt><strong><code>__nvvm_mulhi_ui</code></strong></dt>
/// <dd><a href="../nvvm/fn.mulhi_ui.html"><code>nvvm::mulhi_ui</code></a></dd>
/// <dt><strong><code>__nvvm_mulhi_ull</code></strong></dt>
/// <dd><a href="../nvvm/fn.mulhi_ull.html"><code>nvvm::mulhi_ull</code></a></dd>
/// <dt><strong><code>__nvvm_popc_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.popc_i.html"><code>nvvm::popc_i</code></a></dd>
/// <dt><strong><code>__nvvm_popc_ll</code></strong></dt>
/// <dd><a href="../nvvm/fn.popc_ll.html"><code>nvvm::popc_ll</code></a></dd>
/// <dt><strong><code>__nvvm_prmt</code></strong></dt>
/// <dd><a href="../nvvm/fn.prmt.html"><code>nvvm::prmt</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_approx_ftz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_approx_ftz_d.html"><code>nvvm::rcp_approx_ftz_d</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rm_d.html"><code>nvvm::rcp_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rm_f.html"><code>nvvm::rcp_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rm_ftz_f.html"><code>nvvm::rcp_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rn_d.html"><code>nvvm::rcp_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rn_f.html"><code>nvvm::rcp_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rn_ftz_f.html"><code>nvvm::rcp_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rp_d.html"><code>nvvm::rcp_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rp_f.html"><code>nvvm::rcp_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rp_ftz_f.html"><code>nvvm::rcp_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rz_d.html"><code>nvvm::rcp_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rz_f.html"><code>nvvm::rcp_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_rcp_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rcp_rz_ftz_f.html"><code>nvvm::rcp_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_laneid.html"><code>nvvm::read_ptx_sreg_laneid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_warpid.html"><code>nvvm::read_ptx_sreg_warpid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_nwarpid.html"><code>nvvm::read_ptx_sreg_nwarpid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_smid.html"><code>nvvm::read_ptx_sreg_smid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_nsmid.html"><code>nvvm::read_ptx_sreg_nsmid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_gridid.html"><code>nvvm::read_ptx_sreg_gridid</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_lanemask_eq.html"><code>nvvm::read_ptx_sreg_lanemask_eq</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_lanemask_le.html"><code>nvvm::read_ptx_sreg_lanemask_le</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_lanemask_lt.html"><code>nvvm::read_ptx_sreg_lanemask_lt</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_lanemask_ge.html"><code>nvvm::read_ptx_sreg_lanemask_ge</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_lanemask_gt.html"><code>nvvm::read_ptx_sreg_lanemask_gt</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_clock.html"><code>nvvm::read_ptx_sreg_clock</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_clock64.html"><code>nvvm::read_ptx_sreg_clock64</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_pm0.html"><code>nvvm::read_ptx_sreg_pm0</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_pm1.html"><code>nvvm::read_ptx_sreg_pm1</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_pm2.html"><code>nvvm::read_ptx_sreg_pm2</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_pm3.html"><code>nvvm::read_ptx_sreg_pm3</code></a></dd>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_warpsize.html"><code>nvvm::read_ptx_sreg_warpsize</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg0</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg0.html"><code>nvvm::read_ptx_sreg_envreg0</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg1</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg1.html"><code>nvvm::read_ptx_sreg_envreg1</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg10</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg10.html"><code>nvvm::read_ptx_sreg_envreg10</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg11</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg11.html"><code>nvvm::read_ptx_sreg_envreg11</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg12</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg12.html"><code>nvvm::read_ptx_sreg_envreg12</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg13</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg13.html"><code>nvvm::read_ptx_sreg_envreg13</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg14</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg14.html"><code>nvvm::read_ptx_sreg_envreg14</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg15</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg15.html"><code>nvvm::read_ptx_sreg_envreg15</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg16</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg16.html"><code>nvvm::read_ptx_sreg_envreg16</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg17</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg17.html"><code>nvvm::read_ptx_sreg_envreg17</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg18</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg18.html"><code>nvvm::read_ptx_sreg_envreg18</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg19</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg19.html"><code>nvvm::read_ptx_sreg_envreg19</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg2</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg2.html"><code>nvvm::read_ptx_sreg_envreg2</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg20</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg20.html"><code>nvvm::read_ptx_sreg_envreg20</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg21</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg21.html"><code>nvvm::read_ptx_sreg_envreg21</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg22</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg22.html"><code>nvvm::read_ptx_sreg_envreg22</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg23</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg23.html"><code>nvvm::read_ptx_sreg_envreg23</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg24</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg24.html"><code>nvvm::read_ptx_sreg_envreg24</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg25</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg25.html"><code>nvvm::read_ptx_sreg_envreg25</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg26</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg26.html"><code>nvvm::read_ptx_sreg_envreg26</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg27</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg27.html"><code>nvvm::read_ptx_sreg_envreg27</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg28</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg28.html"><code>nvvm::read_ptx_sreg_envreg28</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg29</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg29.html"><code>nvvm::read_ptx_sreg_envreg29</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg3</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg3.html"><code>nvvm::read_ptx_sreg_envreg3</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg30</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg30.html"><code>nvvm::read_ptx_sreg_envreg30</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg31</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg31.html"><code>nvvm::read_ptx_sreg_envreg31</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg4</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg4.html"><code>nvvm::read_ptx_sreg_envreg4</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg5</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg5.html"><code>nvvm::read_ptx_sreg_envreg5</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg6</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg6.html"><code>nvvm::read_ptx_sreg_envreg6</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg7</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg7.html"><code>nvvm::read_ptx_sreg_envreg7</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg8</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg8.html"><code>nvvm::read_ptx_sreg_envreg8</code></a></dd>
/// <dt><strong><code>__nvvm_read_ptx_sreg_envreg9</code></strong></dt>
/// <dd><a href="../nvvm/fn.read_ptx_sreg_envreg9.html"><code>nvvm::read_ptx_sreg_envreg9</code></a></dd>
/// <dt><strong><code>__nvvm_rotate_b32</code></strong></dt>
/// <dd><a href="../nvvm/fn.rotate_b32.html"><code>nvvm::rotate_b32</code></a></dd>
/// <dt><strong><code>__nvvm_rotate_b64</code></strong></dt>
/// <dd><a href="../nvvm/fn.rotate_b64.html"><code>nvvm::rotate_b64</code></a></dd>
/// <dt><strong><code>__nvvm_rotate_right_b64</code></strong></dt>
/// <dd><a href="../nvvm/fn.rotate_right_b64.html"><code>nvvm::rotate_right_b64</code></a></dd>
/// <dt><strong><code>__nvvm_round_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.round_d.html"><code>nvvm::round_d</code></a></dd>
/// <dt><strong><code>__nvvm_round_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.round_f.html"><code>nvvm::round_f</code></a></dd>
/// <dt><strong><code>__nvvm_round_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.round_ftz_f.html"><code>nvvm::round_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_rsqrt_approx_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.rsqrt_approx_d.html"><code>nvvm::rsqrt_approx_d</code></a></dd>
/// <dt><strong><code>__nvvm_rsqrt_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rsqrt_approx_f.html"><code>nvvm::rsqrt_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_rsqrt_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.rsqrt_approx_ftz_f.html"><code>nvvm::rsqrt_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sad_i</code></strong></dt>
/// <dd><a href="../nvvm/fn.sad_i.html"><code>nvvm::sad_i</code></a></dd>
/// <dt><strong><code>__nvvm_sad_ui</code></strong></dt>
/// <dd><a href="../nvvm/fn.sad_ui.html"><code>nvvm::sad_ui</code></a></dd>
/// <dt><strong><code>__nvvm_saturate_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.saturate_d.html"><code>nvvm::saturate_d</code></a></dd>
/// <dt><strong><code>__nvvm_saturate_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.saturate_f.html"><code>nvvm::saturate_f</code></a></dd>
/// <dt><strong><code>__nvvm_saturate_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.saturate_ftz_f.html"><code>nvvm::saturate_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_bfly_f32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_bfly_f32.html"><code>nvvm::shfl_bfly_f32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_bfly_i32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_bfly_i32.html"><code>nvvm::shfl_bfly_i32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_down_f32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_down_f32.html"><code>nvvm::shfl_down_f32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_down_i32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_down_i32.html"><code>nvvm::shfl_down_i32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_idx_f32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_idx_f32.html"><code>nvvm::shfl_idx_f32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_idx_i32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_idx_i32.html"><code>nvvm::shfl_idx_i32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_up_f32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_up_f32.html"><code>nvvm::shfl_up_f32</code></a></dd>
/// <dt><strong><code>__nvvm_shfl_up_i32</code></strong></dt>
/// <dd><a href="../nvvm/fn.shfl_up_i32.html"><code>nvvm::shfl_up_i32</code></a></dd>
/// <dt><strong><code>__nvvm_sin_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sin_approx_f.html"><code>nvvm::sin_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_sin_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sin_approx_ftz_f.html"><code>nvvm::sin_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_approx_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_approx_f.html"><code>nvvm::sqrt_approx_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_approx_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_approx_ftz_f.html"><code>nvvm::sqrt_approx_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_f.html"><code>nvvm::sqrt_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rm_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rm_d.html"><code>nvvm::sqrt_rm_d</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rm_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rm_f.html"><code>nvvm::sqrt_rm_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rm_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rm_ftz_f.html"><code>nvvm::sqrt_rm_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rn_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rn_d.html"><code>nvvm::sqrt_rn_d</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rn_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rn_f.html"><code>nvvm::sqrt_rn_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rn_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rn_ftz_f.html"><code>nvvm::sqrt_rn_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rp_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rp_d.html"><code>nvvm::sqrt_rp_d</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rp_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rp_f.html"><code>nvvm::sqrt_rp_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rp_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rp_ftz_f.html"><code>nvvm::sqrt_rp_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rz_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rz_d.html"><code>nvvm::sqrt_rz_d</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rz_f.html"><code>nvvm::sqrt_rz_f</code></a></dd>
/// <dt><strong><code>__nvvm_sqrt_rz_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.sqrt_rz_ftz_f.html"><code>nvvm::sqrt_rz_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_suq_array_size</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_array_size.html"><code>nvvm::suq_array_size</code></a></dd>
/// <dt><strong><code>__nvvm_suq_channel_data_type</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_channel_data_type.html"><code>nvvm::suq_channel_data_type</code></a></dd>
/// <dt><strong><code>__nvvm_suq_channel_order</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_channel_order.html"><code>nvvm::suq_channel_order</code></a></dd>
/// <dt><strong><code>__nvvm_suq_depth</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_depth.html"><code>nvvm::suq_depth</code></a></dd>
/// <dt><strong><code>__nvvm_suq_height</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_height.html"><code>nvvm::suq_height</code></a></dd>
/// <dt><strong><code>__nvvm_suq_width</code></strong></dt>
/// <dd><a href="../nvvm/fn.suq_width.html"><code>nvvm::suq_width</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i16_clamp.html"><code>nvvm::sust_b_1d_array_i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i16_trap.html"><code>nvvm::sust_b_1d_array_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i16_zero.html"><code>nvvm::sust_b_1d_array_i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i32_clamp.html"><code>nvvm::sust_b_1d_array_i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i32_trap.html"><code>nvvm::sust_b_1d_array_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i32_zero.html"><code>nvvm::sust_b_1d_array_i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i64_clamp.html"><code>nvvm::sust_b_1d_array_i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i64_trap.html"><code>nvvm::sust_b_1d_array_i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i64_zero.html"><code>nvvm::sust_b_1d_array_i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i8_clamp.html"><code>nvvm::sust_b_1d_array_i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i8_trap.html"><code>nvvm::sust_b_1d_array_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_i8_zero.html"><code>nvvm::sust_b_1d_array_i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i16_clamp.html"><code>nvvm::sust_b_1d_array_v2i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i16_trap.html"><code>nvvm::sust_b_1d_array_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i16_zero.html"><code>nvvm::sust_b_1d_array_v2i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i32_clamp.html"><code>nvvm::sust_b_1d_array_v2i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i32_trap.html"><code>nvvm::sust_b_1d_array_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i32_zero.html"><code>nvvm::sust_b_1d_array_v2i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i64_clamp.html"><code>nvvm::sust_b_1d_array_v2i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i64_trap.html"><code>nvvm::sust_b_1d_array_v2i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i64_zero.html"><code>nvvm::sust_b_1d_array_v2i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i8_clamp.html"><code>nvvm::sust_b_1d_array_v2i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i8_trap.html"><code>nvvm::sust_b_1d_array_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v2i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v2i8_zero.html"><code>nvvm::sust_b_1d_array_v2i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i16_clamp.html"><code>nvvm::sust_b_1d_array_v4i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i16_trap.html"><code>nvvm::sust_b_1d_array_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i16_zero.html"><code>nvvm::sust_b_1d_array_v4i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i32_clamp.html"><code>nvvm::sust_b_1d_array_v4i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i32_trap.html"><code>nvvm::sust_b_1d_array_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i32_zero.html"><code>nvvm::sust_b_1d_array_v4i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i8_clamp.html"><code>nvvm::sust_b_1d_array_v4i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i8_trap.html"><code>nvvm::sust_b_1d_array_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_array_v4i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_array_v4i8_zero.html"><code>nvvm::sust_b_1d_array_v4i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i16_clamp.html"><code>nvvm::sust_b_1d_i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i16_trap.html"><code>nvvm::sust_b_1d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i16_zero.html"><code>nvvm::sust_b_1d_i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i32_clamp.html"><code>nvvm::sust_b_1d_i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i32_trap.html"><code>nvvm::sust_b_1d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i32_zero.html"><code>nvvm::sust_b_1d_i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i64_clamp.html"><code>nvvm::sust_b_1d_i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i64_trap.html"><code>nvvm::sust_b_1d_i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i64_zero.html"><code>nvvm::sust_b_1d_i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i8_clamp.html"><code>nvvm::sust_b_1d_i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i8_trap.html"><code>nvvm::sust_b_1d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_i8_zero.html"><code>nvvm::sust_b_1d_i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i16_clamp.html"><code>nvvm::sust_b_1d_v2i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i16_trap.html"><code>nvvm::sust_b_1d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i16_zero.html"><code>nvvm::sust_b_1d_v2i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i32_clamp.html"><code>nvvm::sust_b_1d_v2i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i32_trap.html"><code>nvvm::sust_b_1d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i32_zero.html"><code>nvvm::sust_b_1d_v2i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i64_clamp.html"><code>nvvm::sust_b_1d_v2i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i64_trap.html"><code>nvvm::sust_b_1d_v2i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i64_zero.html"><code>nvvm::sust_b_1d_v2i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i8_clamp.html"><code>nvvm::sust_b_1d_v2i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i8_trap.html"><code>nvvm::sust_b_1d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v2i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v2i8_zero.html"><code>nvvm::sust_b_1d_v2i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i16_clamp.html"><code>nvvm::sust_b_1d_v4i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i16_trap.html"><code>nvvm::sust_b_1d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i16_zero.html"><code>nvvm::sust_b_1d_v4i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i32_clamp.html"><code>nvvm::sust_b_1d_v4i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i32_trap.html"><code>nvvm::sust_b_1d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i32_zero.html"><code>nvvm::sust_b_1d_v4i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i8_clamp.html"><code>nvvm::sust_b_1d_v4i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i8_trap.html"><code>nvvm::sust_b_1d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_1d_v4i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_1d_v4i8_zero.html"><code>nvvm::sust_b_1d_v4i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i16_clamp.html"><code>nvvm::sust_b_2d_array_i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i16_trap.html"><code>nvvm::sust_b_2d_array_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i16_zero.html"><code>nvvm::sust_b_2d_array_i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i32_clamp.html"><code>nvvm::sust_b_2d_array_i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i32_trap.html"><code>nvvm::sust_b_2d_array_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i32_zero.html"><code>nvvm::sust_b_2d_array_i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i64_clamp.html"><code>nvvm::sust_b_2d_array_i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i64_trap.html"><code>nvvm::sust_b_2d_array_i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i64_zero.html"><code>nvvm::sust_b_2d_array_i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i8_clamp.html"><code>nvvm::sust_b_2d_array_i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i8_trap.html"><code>nvvm::sust_b_2d_array_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_i8_zero.html"><code>nvvm::sust_b_2d_array_i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i16_clamp.html"><code>nvvm::sust_b_2d_array_v2i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i16_trap.html"><code>nvvm::sust_b_2d_array_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i16_zero.html"><code>nvvm::sust_b_2d_array_v2i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i32_clamp.html"><code>nvvm::sust_b_2d_array_v2i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i32_trap.html"><code>nvvm::sust_b_2d_array_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i32_zero.html"><code>nvvm::sust_b_2d_array_v2i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i64_clamp.html"><code>nvvm::sust_b_2d_array_v2i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i64_trap.html"><code>nvvm::sust_b_2d_array_v2i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i64_zero.html"><code>nvvm::sust_b_2d_array_v2i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i8_clamp.html"><code>nvvm::sust_b_2d_array_v2i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i8_trap.html"><code>nvvm::sust_b_2d_array_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v2i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v2i8_zero.html"><code>nvvm::sust_b_2d_array_v2i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i16_clamp.html"><code>nvvm::sust_b_2d_array_v4i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i16_trap.html"><code>nvvm::sust_b_2d_array_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i16_zero.html"><code>nvvm::sust_b_2d_array_v4i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i32_clamp.html"><code>nvvm::sust_b_2d_array_v4i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i32_trap.html"><code>nvvm::sust_b_2d_array_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i32_zero.html"><code>nvvm::sust_b_2d_array_v4i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i8_clamp.html"><code>nvvm::sust_b_2d_array_v4i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i8_trap.html"><code>nvvm::sust_b_2d_array_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_array_v4i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_array_v4i8_zero.html"><code>nvvm::sust_b_2d_array_v4i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i16_clamp.html"><code>nvvm::sust_b_2d_i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i16_trap.html"><code>nvvm::sust_b_2d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i16_zero.html"><code>nvvm::sust_b_2d_i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i32_clamp.html"><code>nvvm::sust_b_2d_i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i32_trap.html"><code>nvvm::sust_b_2d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i32_zero.html"><code>nvvm::sust_b_2d_i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i64_clamp.html"><code>nvvm::sust_b_2d_i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i64_trap.html"><code>nvvm::sust_b_2d_i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i64_zero.html"><code>nvvm::sust_b_2d_i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i8_clamp.html"><code>nvvm::sust_b_2d_i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i8_trap.html"><code>nvvm::sust_b_2d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_i8_zero.html"><code>nvvm::sust_b_2d_i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i16_clamp.html"><code>nvvm::sust_b_2d_v2i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i16_trap.html"><code>nvvm::sust_b_2d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i16_zero.html"><code>nvvm::sust_b_2d_v2i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i32_clamp.html"><code>nvvm::sust_b_2d_v2i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i32_trap.html"><code>nvvm::sust_b_2d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i32_zero.html"><code>nvvm::sust_b_2d_v2i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i64_clamp.html"><code>nvvm::sust_b_2d_v2i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i64_trap.html"><code>nvvm::sust_b_2d_v2i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i64_zero.html"><code>nvvm::sust_b_2d_v2i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i8_clamp.html"><code>nvvm::sust_b_2d_v2i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i8_trap.html"><code>nvvm::sust_b_2d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v2i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v2i8_zero.html"><code>nvvm::sust_b_2d_v2i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i16_clamp.html"><code>nvvm::sust_b_2d_v4i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i16_trap.html"><code>nvvm::sust_b_2d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i16_zero.html"><code>nvvm::sust_b_2d_v4i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i32_clamp.html"><code>nvvm::sust_b_2d_v4i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i32_trap.html"><code>nvvm::sust_b_2d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i32_zero.html"><code>nvvm::sust_b_2d_v4i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i8_clamp.html"><code>nvvm::sust_b_2d_v4i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i8_trap.html"><code>nvvm::sust_b_2d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_2d_v4i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_2d_v4i8_zero.html"><code>nvvm::sust_b_2d_v4i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i16_clamp.html"><code>nvvm::sust_b_3d_i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i16_trap.html"><code>nvvm::sust_b_3d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i16_zero.html"><code>nvvm::sust_b_3d_i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i32_clamp.html"><code>nvvm::sust_b_3d_i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i32_trap.html"><code>nvvm::sust_b_3d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i32_zero.html"><code>nvvm::sust_b_3d_i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i64_clamp.html"><code>nvvm::sust_b_3d_i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i64_trap.html"><code>nvvm::sust_b_3d_i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i64_zero.html"><code>nvvm::sust_b_3d_i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i8_clamp.html"><code>nvvm::sust_b_3d_i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i8_trap.html"><code>nvvm::sust_b_3d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_i8_zero.html"><code>nvvm::sust_b_3d_i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i16_clamp.html"><code>nvvm::sust_b_3d_v2i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i16_trap.html"><code>nvvm::sust_b_3d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i16_zero.html"><code>nvvm::sust_b_3d_v2i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i32_clamp.html"><code>nvvm::sust_b_3d_v2i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i32_trap.html"><code>nvvm::sust_b_3d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i32_zero.html"><code>nvvm::sust_b_3d_v2i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i64_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i64_clamp.html"><code>nvvm::sust_b_3d_v2i64_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i64_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i64_trap.html"><code>nvvm::sust_b_3d_v2i64_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i64_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i64_zero.html"><code>nvvm::sust_b_3d_v2i64_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i8_clamp.html"><code>nvvm::sust_b_3d_v2i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i8_trap.html"><code>nvvm::sust_b_3d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v2i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v2i8_zero.html"><code>nvvm::sust_b_3d_v2i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i16_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i16_clamp.html"><code>nvvm::sust_b_3d_v4i16_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i16_trap.html"><code>nvvm::sust_b_3d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i16_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i16_zero.html"><code>nvvm::sust_b_3d_v4i16_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i32_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i32_clamp.html"><code>nvvm::sust_b_3d_v4i32_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i32_trap.html"><code>nvvm::sust_b_3d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i32_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i32_zero.html"><code>nvvm::sust_b_3d_v4i32_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i8_clamp</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i8_clamp.html"><code>nvvm::sust_b_3d_v4i8_clamp</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i8_trap.html"><code>nvvm::sust_b_3d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_b_3d_v4i8_zero</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_b_3d_v4i8_zero.html"><code>nvvm::sust_b_3d_v4i8_zero</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_i16_trap.html"><code>nvvm::sust_p_1d_array_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_i32_trap.html"><code>nvvm::sust_p_1d_array_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_i8_trap.html"><code>nvvm::sust_p_1d_array_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v2i16_trap.html"><code>nvvm::sust_p_1d_array_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v2i32_trap.html"><code>nvvm::sust_p_1d_array_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v2i8_trap.html"><code>nvvm::sust_p_1d_array_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v4i16_trap.html"><code>nvvm::sust_p_1d_array_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v4i32_trap.html"><code>nvvm::sust_p_1d_array_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_array_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_array_v4i8_trap.html"><code>nvvm::sust_p_1d_array_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_i16_trap.html"><code>nvvm::sust_p_1d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_i32_trap.html"><code>nvvm::sust_p_1d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_i8_trap.html"><code>nvvm::sust_p_1d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v2i16_trap.html"><code>nvvm::sust_p_1d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v2i32_trap.html"><code>nvvm::sust_p_1d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v2i8_trap.html"><code>nvvm::sust_p_1d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v4i16_trap.html"><code>nvvm::sust_p_1d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v4i32_trap.html"><code>nvvm::sust_p_1d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_1d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_1d_v4i8_trap.html"><code>nvvm::sust_p_1d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_i16_trap.html"><code>nvvm::sust_p_2d_array_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_i32_trap.html"><code>nvvm::sust_p_2d_array_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_i8_trap.html"><code>nvvm::sust_p_2d_array_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v2i16_trap.html"><code>nvvm::sust_p_2d_array_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v2i32_trap.html"><code>nvvm::sust_p_2d_array_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v2i8_trap.html"><code>nvvm::sust_p_2d_array_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v4i16_trap.html"><code>nvvm::sust_p_2d_array_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v4i32_trap.html"><code>nvvm::sust_p_2d_array_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_array_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_array_v4i8_trap.html"><code>nvvm::sust_p_2d_array_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_i16_trap.html"><code>nvvm::sust_p_2d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_i32_trap.html"><code>nvvm::sust_p_2d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_i8_trap.html"><code>nvvm::sust_p_2d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v2i16_trap.html"><code>nvvm::sust_p_2d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v2i32_trap.html"><code>nvvm::sust_p_2d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v2i8_trap.html"><code>nvvm::sust_p_2d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v4i16_trap.html"><code>nvvm::sust_p_2d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v4i32_trap.html"><code>nvvm::sust_p_2d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_2d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_2d_v4i8_trap.html"><code>nvvm::sust_p_2d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_i16_trap.html"><code>nvvm::sust_p_3d_i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_i32_trap.html"><code>nvvm::sust_p_3d_i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_i8_trap.html"><code>nvvm::sust_p_3d_i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v2i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v2i16_trap.html"><code>nvvm::sust_p_3d_v2i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v2i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v2i32_trap.html"><code>nvvm::sust_p_3d_v2i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v2i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v2i8_trap.html"><code>nvvm::sust_p_3d_v2i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v4i16_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v4i16_trap.html"><code>nvvm::sust_p_3d_v4i16_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v4i32_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v4i32_trap.html"><code>nvvm::sust_p_3d_v4i32_trap</code></a></dd>
/// <dt><strong><code>__nvvm_sust_p_3d_v4i8_trap</code></strong></dt>
/// <dd><a href="../nvvm/fn.sust_p_3d_v4i8_trap.html"><code>nvvm::sust_p_3d_v4i8_trap</code></a></dd>
/// <dt><strong><code>__nvvm_swap_lo_hi_b64</code></strong></dt>
/// <dd><a href="../nvvm/fn.swap_lo_hi_b64.html"><code>nvvm::swap_lo_hi_b64</code></a></dd>
/// <dt><strong><code>__nvvm_trunc_d</code></strong></dt>
/// <dd><a href="../nvvm/fn.trunc_d.html"><code>nvvm::trunc_d</code></a></dd>
/// <dt><strong><code>__nvvm_trunc_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.trunc_f.html"><code>nvvm::trunc_f</code></a></dd>
/// <dt><strong><code>__nvvm_trunc_ftz_f</code></strong></dt>
/// <dd><a href="../nvvm/fn.trunc_ftz_f.html"><code>nvvm::trunc_ftz_f</code></a></dd>
/// <dt><strong><code>__nvvm_txq_array_size</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_array_size.html"><code>nvvm::txq_array_size</code></a></dd>
/// <dt><strong><code>__nvvm_txq_channel_data_type</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_channel_data_type.html"><code>nvvm::txq_channel_data_type</code></a></dd>
/// <dt><strong><code>__nvvm_txq_channel_order</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_channel_order.html"><code>nvvm::txq_channel_order</code></a></dd>
/// <dt><strong><code>__nvvm_txq_depth</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_depth.html"><code>nvvm::txq_depth</code></a></dd>
/// <dt><strong><code>__nvvm_txq_height</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_height.html"><code>nvvm::txq_height</code></a></dd>
/// <dt><strong><code>__nvvm_txq_num_mipmap_levels</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_num_mipmap_levels.html"><code>nvvm::txq_num_mipmap_levels</code></a></dd>
/// <dt><strong><code>__nvvm_txq_num_samples</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_num_samples.html"><code>nvvm::txq_num_samples</code></a></dd>
/// <dt><strong><code>__nvvm_txq_width</code></strong></dt>
/// <dd><a href="../nvvm/fn.txq_width.html"><code>nvvm::txq_width</code></a></dd>
/// <dt><strong><code>__nvvm_ui2d_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2d_rm.html"><code>nvvm::ui2d_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ui2d_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2d_rn.html"><code>nvvm::ui2d_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ui2d_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2d_rp.html"><code>nvvm::ui2d_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ui2d_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2d_rz.html"><code>nvvm::ui2d_rz</code></a></dd>
/// <dt><strong><code>__nvvm_ui2f_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2f_rm.html"><code>nvvm::ui2f_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ui2f_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2f_rn.html"><code>nvvm::ui2f_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ui2f_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2f_rp.html"><code>nvvm::ui2f_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ui2f_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ui2f_rz.html"><code>nvvm::ui2f_rz</code></a></dd>
/// <dt><strong><code>__nvvm_ull2d_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2d_rm.html"><code>nvvm::ull2d_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ull2d_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2d_rn.html"><code>nvvm::ull2d_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ull2d_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2d_rp.html"><code>nvvm::ull2d_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ull2d_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2d_rz.html"><code>nvvm::ull2d_rz</code></a></dd>
/// <dt><strong><code>__nvvm_ull2f_rm</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2f_rm.html"><code>nvvm::ull2f_rm</code></a></dd>
/// <dt><strong><code>__nvvm_ull2f_rn</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2f_rn.html"><code>nvvm::ull2f_rn</code></a></dd>
/// <dt><strong><code>__nvvm_ull2f_rp</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2f_rp.html"><code>nvvm::ull2f_rp</code></a></dd>
/// <dt><strong><code>__nvvm_ull2f_rz</code></strong></dt>
/// <dd><a href="../nvvm/fn.ull2f_rz.html"><code>nvvm::ull2f_rz</code></a></dd>
/// <dt><strong><code>__syncthreads</code></strong></dt>
/// <dd><a href="../nvvm/fn.barrier0.html"><code>nvvm::barrier0</code></a></dd>
/// </dl>
pub mod gcc_names {}
